#
# spec file for package kernel-debug
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needssslcertforbuild


%define srcversion 6.4
%define patchversion 6.4.0
%define git_commit 1b464b6f46d03a25a804468aecd37fe018b1b2b2
%define variant %{nil}
%define compress_modules zstd
%define compress_vmlinux gz
%define livepatch livepatch%{nil}
%define livepatch_rt %{nil}
%define sb_efi_only 0
%define split_base 0
%define split_optional 1
%define supported_modules_check 1
%define build_flavor debug
%define generate_compile_commands 1

%include %_sourcedir/kernel-spec-macros

%(chmod +x %_sourcedir/{guards,apply-patches,check-for-config-changes,group-source-files.pl,split-modules,modversions,kabi.pl,mkspec,compute-PATCHVERSION.sh,arch-symbols,log.sh,try-disable-staging-driver,compress-vmlinux.sh,mkspec-dtb,check-module-license,klp-symbols,splitflist,mergedep,moddep,modflist,kernel-subpackage-build})

Name:           kernel-debug
Version:        6.4.0
%if 0%{?is_kotd}
Release:        150700.1.1.g1b464b6
%else
Release:        150700.1.1
%endif
Summary:        A Debug Version of the Kernel
License:        GPL-2.0-only
Group:          System/Kernel
URL:            https://www.kernel.org/
%if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150300
BuildRequires:  bash-sh
%endif
BuildRequires:  bc
BuildRequires:  bison
BuildRequires:  coreutils
BuildRequires:  fdupes
BuildRequires:  flex
# Cannot test %%CONFIG_GCC_PLUGINS here because the buildservice parser
# does not expand %%(...)
%if "%build_flavor" == "syzkaller"
# Needed by scripts/gcc-plugin.sh
BuildRequires:  gcc-c++
BuildRequires:  gcc-devel
%endif
BuildRequires:  hmaccalc
BuildRequires:  libopenssl-devel
BuildRequires:  modutils
BuildRequires:  python3-base
# Used to sign the kernel in the buildservice
BuildRequires:  openssl
BuildRequires:  pesign-obs-integration
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
# pahole for CONFIG_DEBUG_INFO_BTF
BuildRequires:  dwarves >= 1.22
%endif
# for objtool
BuildRequires:  libelf-devel
# required for 50-check-kernel-build-id rpm check
BuildRequires:  elfutils
%ifarch %arm
BuildRequires:  u-boot-tools
%endif
# Do not install p-b and dracut for the install check, the %post script is
# able to handle this
#!BuildIgnore: perl-Bootloader dracut distribution-release suse-kernel-rpm-scriptlets
# Remove some packages that are installed automatically by the build system,
# but are not needed to build the kernel
#!BuildIgnore: autoconf automake gettext-runtime libtool cvs gettext-tools udev insserv
%if ! 0%{?is_kotd} || ! %{?is_kotd_qa}%{!?is_kotd_qa:0}
ExclusiveArch:  ppc64le x86_64
%else
ExclusiveArch:  do_not_build
%endif

%ifarch %ix86 x86_64
%define image vmlinuz
%endif
%ifarch ppc ppc64 ppc64le
%define image vmlinux
%endif
%ifarch s390 s390x
%define image image
%endif
%ifarch %arm
%define image zImage
%endif
%ifarch aarch64 riscv64
%define image Image
%endif

%ifarch %ix86 x86_64
%define install_vdso 1
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150500
%define separate_vdso 1
%endif
%else
%define install_vdso 0
%endif

%define build_default	("%build_flavor" == "default")
%define build_vanilla	("%build_flavor" == "vanilla")
%define vanilla_only    %{lua: if (rpm.expand("%variant") == "-vanilla") then print(1) else print(0) end}

%if ! %build_vanilla
%define src_install_dir /usr/src/linux-%kernelrelease%variant
%else
%define src_install_dir /usr/src/linux-%kernelrelease-vanilla
%endif
%define obj_install_dir /usr/src/linux-%kernelrelease%variant-obj
%define rpm_install_dir %buildroot%obj_install_dir
%define kernel_build_dir %my_builddir/linux-%srcversion/linux-obj
%define modules_dir %kernel_module_directory/%kernelrelease-%build_flavor

%global cpu_arch %(%_sourcedir/arch-symbols %_target_cpu)
%define cpu_arch_flavor %cpu_arch/%build_flavor

%if 0%{?_project:1} && ( %(echo %_project | grep -Ex -f %_sourcedir/release-projects | grep -vc ^PTF) || %(echo %_project | grep -Ec "^(Devel:)?Kernel:") )
	%define klp_symbols 1
%endif

# Define some CONFIG variables as rpm macros as well. (rpm cannot handle
# defining them all at once.)
%define config_vars CONFIG_MODULES CONFIG_MODULE_SIG CONFIG_MODULE_SIG_HASH CONFIG_KMSG_IDS CONFIG_SUSE_KERNEL_SUPPORTED CONFIG_EFI_STUB CONFIG_LIVEPATCH_IPA_CLONES CONFIG_DEBUG_INFO_BTF_MODULES CONFIG_PREEMPT_DYNAMIC
%{expand:%(eval "$(test -n "%cpu_arch_flavor" && tar -xjf %_sourcedir/config.tar.bz2 --to-stdout config/%cpu_arch_flavor)"; for config in %config_vars; do echo "%%global $config ${!config:-n}"; done)}
%define split_extra ("%CONFIG_MODULES" == "y" && "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y")

%if "%CONFIG_MODULES" != "y"
	%define klp_symbols 0
%endif

%global certs %( space="" ; for f in %_sourcedir/*.crt; do                                              \
    if ! test -e "$f"; then                                                                             \
        continue                                                                                        \
    fi                                                                                                  \
    h=$(openssl x509 -inform PEM -fingerprint -noout -in "$f")                                          \
    if [ -z "$h" ] ; then                                                                               \
        echo Cannot parse "$f" >&2                                                                      \
        confinue                                                                                        \
    fi                                                                                                  \
    cert=$(echo "$h" | sed -rn 's/^SHA1 Fingerprint=//; T; s/://g; s/(.{8}).*/\\1/p')                   \
    echo Found signing certificate "$f" "($cert)" >&2                                                   \
    cat "$f" >>%_sourcedir/.kernel_signing_key.pem                                                      \
    mkdir -p %_sourcedir/.kernel_signing_certs                                                          \
    openssl x509 -inform PEM -in "$f" -outform DER -out %_sourcedir/.kernel_signing_certs/"$cert".crt   \
    echo -n "$space$cert" ; space=" "                                                                   \
done )

Source0:        https://www.kernel.org/pub/linux/kernel/v6.x/linux-%srcversion.tar.xz
Source3:        kernel-source.rpmlintrc
Source14:       series.conf
Source16:       guards
Source17:       apply-patches
Source19:       kernel-binary-conflicts
Source20:       obsolete-kmps
Source21:       config.conf
Source23:       supported.conf
Source33:       check-for-config-changes
Source35:       group-source-files.pl
Source36:       README.PATCH-POLICY.SUSE
Source37:       README.SUSE
Source38:       README.KSYMS
Source40:       source-timestamp
Source46:       split-modules
Source47:       modversions
Source48:       macros.kernel-source
Source49:       kernel-module-subpackage
Source50:       kabi.pl
Source51:       mkspec
Source52:       kernel-source%variant.changes
Source53:       kernel-source.spec.in
Source54:       kernel-binary.spec.in
Source55:       kernel-syms.spec.in
Source56:       kernel-docs.spec.in
Source57:       kernel-cert-subpackage
Source58:       constraints.in
Source60:       config.sh
Source61:       compute-PATCHVERSION.sh
Source62:       old-flavors
Source63:       arch-symbols
Source64:       package-descriptions
Source65:       kernel-spec-macros
Source67:       log.sh
Source68:       host-memcpy-hack.h
Source69:       try-disable-staging-driver
Source70:       kernel-obs-build.spec.in
Source71:       kernel-obs-qa.spec.in
Source72:       compress-vmlinux.sh
Source73:       dtb.spec.in.in
Source74:       mkspec-dtb
Source75:       release-projects
Source76:       check-module-license
Source77:       klp-symbols
Source78:       modules.fips
Source79:       splitflist
Source80:       mergedep
Source81:       moddep
Source82:       modflist
Source83:       kernel-subpackage-build
Source84:       kernel-subpackage-spec
Source85:       kernel-default-base.spec.txt
Source86:       old_changelog.txt
Source100:      config.tar.bz2
Source101:      config.addon.tar.bz2
Source102:      patches.arch.tar.bz2
Source103:      patches.drivers.tar.bz2
Source104:      patches.fixes.tar.bz2
Source105:      patches.rpmify.tar.bz2
Source106:      patches.suse.tar.bz2
Source108:      patches.addon.tar.bz2
Source109:      patches.kernel.org.tar.bz2
Source110:      patches.apparmor.tar.bz2
Source111:      patches.rt.tar.bz2
Source113:      patches.kabi.tar.bz2
Source114:      patches.drm.tar.bz2
Source120:      kabi.tar.bz2
Source121:      sysctl.tar.bz2
# These files are found in the kernel-source package:
NoSource:       0
NoSource:       3
NoSource:       14
NoSource:       16
NoSource:       17
NoSource:       19
NoSource:       20
NoSource:       21
NoSource:       23
NoSource:       33
NoSource:       35
NoSource:       36
NoSource:       37
NoSource:       38
NoSource:       40
NoSource:       46
NoSource:       47
NoSource:       48
NoSource:       49
NoSource:       50
NoSource:       51
NoSource:       52
NoSource:       53
NoSource:       54
NoSource:       55
NoSource:       56
NoSource:       57
NoSource:       58
NoSource:       60
NoSource:       61
NoSource:       62
NoSource:       63
NoSource:       64
NoSource:       65
NoSource:       67
NoSource:       68
NoSource:       69
NoSource:       70
NoSource:       71
NoSource:       72
NoSource:       73
NoSource:       74
NoSource:       75
NoSource:       76
NoSource:       77
NoSource:       78
NoSource:       79
NoSource:       80
NoSource:       81
NoSource:       82
NoSource:       83
NoSource:       84
NoSource:       85
NoSource:       86
NoSource:       100
NoSource:       101
NoSource:       102
NoSource:       103
NoSource:       104
NoSource:       105
NoSource:       106
NoSource:       108
NoSource:       109
NoSource:       110
NoSource:       111
NoSource:       113
NoSource:       114
NoSource:       120
NoSource:       121

%ifarch %ix86
# Only i386/default supports i586, mark other flavors' packages as i686
%if ! %build_default
BuildArch:      i686
%endif
%endif
# Force bzip2 instead of lzma compression to
# 1) allow install on older dist versions, and
# 2) decrease build times (bsc#962356 boo#1175882)
%define _binary_payload w9.bzdio
# Do not recompute the build-id of vmlinux in find-debuginfo.sh (bsc#964063)
%undefine _unique_build_ids
%define _no_recompute_build_ids 1
# prevent usr/lib/debug/boot/vmlinux-4.12.14-11.10-default-4.12.14-11.10.ppc64le.debug
%undefine _unique_debug_names

%if "%{compress_modules}" == "zstd"
BuildRequires:  zstd
# Make sure kmod supports zstd compressed modules
Requires(post): kmod-zstd
%endif
Provides:       %name = %version-%source_rel
# bnc#901925
Provides:       %name-%version-%source_rel
Provides:       %{name}_%_target_cpu = %version-%source_rel
Provides:       kernel-base = %version-%source_rel
Provides:       multiversion(kernel)
# In SLE11, kernel-$flavor complemented kernel-$flavor-base. With SLE12,
# kernel-$flavor itself contains all the needed files and kernel-$flavor-base
# is a subset that can replace kernel-$flavor in some scenarios. We need to
# obsolete the -base subpackage from SLE11, so that the base files are not
# owned by multiple packages now. The dependency is not correct wrt openSUSE
# 11.2 - 11.4, but we primarily care about the supported upgrade path.
Obsoletes:      %name-base < 3.1
%if ("%build_flavor" != "kvmsmall") && ("%build_flavor" != "azure")
Recommends: kernel-firmware
%endif
# The following is copied to the -base subpackage as well
# BEGIN COMMON DEPS
Requires(pre):  suse-kernel-rpm-scriptlets
Requires(post): suse-kernel-rpm-scriptlets
Requires:       suse-kernel-rpm-scriptlets
Requires(preun): suse-kernel-rpm-scriptlets
Requires(postun): suse-kernel-rpm-scriptlets
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2 and /usr/lib/modprobe.d/*.conf
Requires(post): suse-module-tools
Requires:       suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for dracut.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
Requires(post): dracut
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release

%if %{usrmerged}
# make sure we have a post-usrmerge system
Conflicts:      filesystem < 16
%endif

Obsoletes:      microcode_ctl < 1.18

%{lua:	fd, err = io.open(rpm.expand('%_sourcedir') .. '/kernel-binary-conflicts')
	if not fd then io.stderr:write(err) end
	unpack = table.unpack or unpack
	for l in fd:lines() do
		if #l > 0 and l:sub(1,1) ~= '#' then
			words = {} ; for w in l:gmatch("([^%s]+)%s*") do table.insert(words, w) end
			package, version = unpack(words)
			print('Conflicts: ' .. package .. ' < '.. version .. '\n')
		end
	end
	fd:close()
}

%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel
Provides:       kernel-%build_flavor-base-srchash-%git_commit
Provides:       kernel-srchash-%git_commit
# END COMMON DEPS
Provides:       %name-srchash-%git_commit
%obsolete_rebuilds %name

%define kmp_target_cpu %_target_cpu
%ifarch %ix86
# KMPs are always built as i586, because rpm does not allow to build
# subpackages for different architectures. Therefore, we change the
# /usr/src/linux-obj/<arch> symlink to i586.
%define kmp_target_cpu i586
%endif

%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt = %version-%release
Provides:       kernel-preempt_%_target_cpu = %version-%source_rel
%endif
%endif

%{lua:	fd, err = io.open(rpm.expand('%_sourcedir') .. '/obsolete-kmps')
	if not fd then io.stderr:write(err) end
	unpack = table.unpack or unpack
	for l in fd:lines() do
		if #l > 0 and l:sub(1,1) ~= '#' then
			words = {} ; for w in l:gmatch("([^%s]+)%s*") do table.insert(words, w) end
			package, version = unpack(words)
			print('Obsoletes: ' .. package .. '-kmp-' .. rpm.expand('%build_flavor') .. ' <= '.. version .. '\n')
			print('Provides: ' .. package .. '-kmp = ' .. version .. '.1\n')
			print('Provides: ' .. package .. '-kmp-' .. rpm.expand('%build_flavor') .. ' = '.. version .. '.1\n')
		end
	end
	fd:close()
}

%description
This kernel has several debug facilities enabled that hurt performance.
Only use this kernel when investigating problems.


%source_timestamp

%pre
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-pre --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%post
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-post --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%preun
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-preun --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%postun
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-postun --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%posttrans
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-posttrans --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%files -f kernel-main.files

%if "%CONFIG_MODULES" == "y" && %split_base
%package base
Summary:        A Debug Version of the Kernel - base modules
Group:          System/Kernel
Url:            http://www.kernel.org/
Provides:       kernel-base = %version-%source_rel
Provides:       multiversion(kernel)
Conflicts:      %name = %version-%source_rel
Requires(pre):  suse-kernel-rpm-scriptlets
Requires(post): suse-kernel-rpm-scriptlets
Requires:       suse-kernel-rpm-scriptlets
Requires(preun): suse-kernel-rpm-scriptlets
Requires(postun): suse-kernel-rpm-scriptlets
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2 and /usr/lib/modprobe.d/*.conf
Requires(post): suse-module-tools
Requires:       suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for dracut.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
Requires(post): dracut
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release

%if %{usrmerged}
# make sure we have a post-usrmerge system
Conflicts:      filesystem < 16
%endif

Obsoletes:      microcode_ctl < 1.18

%{lua:	fd, err = io.open(rpm.expand('%_sourcedir') .. '/kernel-binary-conflicts')
	if not fd then io.stderr:write(err) end
	unpack = table.unpack or unpack
	for l in fd:lines() do
		if #l > 0 and l:sub(1,1) ~= '#' then
			words = {} ; for w in l:gmatch("([^%s]+)%s*") do table.insert(words, w) end
			package, version = unpack(words)
			print('Conflicts: ' .. package .. ' < '.. version .. '\n')
		end
	end
	fd:close()
}

%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel
Provides:       kernel-%build_flavor-base-srchash-%git_commit
Provides:       kernel-srchash-%git_commit

%obsolete_rebuilds %name-base
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif

%description base
This kernel has several debug facilities enabled that hurt performance.
Only use this kernel when investigating problems.

This package contains only the base modules, required in all installs.


%source_timestamp
%pre base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-pre --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-post --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-preun --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-postun --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-posttrans --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files base -f kernel-base.files
%endif

%package extra
Summary:        A Debug Version of the Kernel - Unsupported kernel modules
Group:          System/Kernel
URL:            https://www.kernel.org/
Provides:       %name-extra_%_target_cpu = %version-%source_rel
Provides:       kernel-extra = %version-%source_rel
Provides:       multiversion(kernel)
Requires:       %{name}_%_target_cpu = %version-%source_rel
Requires(pre):  coreutils awk
Requires(post): modutils
Requires(post): perl-Bootloader
Requires(post): dracut
%obsolete_rebuilds %name-extra
Supplements:    packageand(product(SLED):%{name}_%_target_cpu)
Supplements:    packageand(product(sle-we):%{name}_%_target_cpu)
Supplements:    packageand(product(Leap):%{name}_%_target_cpu)
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt-extra = %version-%release
Provides:       kernel-preempt-extra_%_target_cpu = %version-%source_rel
%endif
%endif

%description extra
This kernel has several debug facilities enabled that hurt performance.
Only use this kernel when investigating problems.

This package contains additional modules not supported by SUSE.


%source_timestamp

%pre extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%if %split_extra

%files extra -f kernel-extra.files
%endif

%if %split_extra && %split_optional
%package optional
Summary:        A Debug Version of the Kernel - Optional kernel modules
Group:          System/Kernel
URL:            https://www.kernel.org/
Provides:       %name-optional_%_target_cpu = %version-%source_rel
Provides:       kernel-optional = %version-%source_rel
Provides:       multiversion(kernel)
Requires:       %name-extra_%_target_cpu = %version-%source_rel
Requires(pre):  coreutils awk
Requires(post): modutils
Requires(post): perl-Bootloader
Requires(post): dracut
%obsolete_rebuilds %name-optional
Supplements:    packageand(product(Leap):%{name}_%_target_cpu)
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt-optional = %version-%release
Provides:       kernel-preempt-optional_%_target_cpu = %version-%source_rel
%endif
%endif

%description optional
This kernel has several debug facilities enabled that hurt performance.
Only use this kernel when investigating problems.

This package contains optional modules only for openSUSE Leap.


%source_timestamp

%pre optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files optional -f kernel-optional.files
%endif

%if "%CONFIG_KMSG_IDS" == "y"

%package man
Summary:        The collection of man pages generated by the kmsg script
Group:          System/Kernel

%description man
This package includes the man pages that have been generated from the
kmsg message documentation comments.


%source_timestamp
%files man
/usr/share/man/man9/*
%endif

%if 0%{?separate_vdso}
%package vdso
Summary:        vdso binaries for debugging purposes
Group:          System/Kernel

%description vdso
This package includes the vdso binaries. They can be used for debugging. The
actual binary linked to the programs is loaded from the in-memory image, not
from this package.


%source_timestamp
%files vdso
%dir %modules_dir
%modules_dir/vdso/
%endif

%package devel
Summary:        Development files necessary for building kernel modules
Group:          Development/Sources
Provides:       %name-devel = %version-%source_rel
Provides:       multiversion(kernel)
%if ! %build_vanilla && ! %vanilla_only
Requires:       kernel-devel%variant = %version-%source_rel
Recommends:     make
Recommends:     gcc
Recommends:     perl
# for objtool
Requires:	libelf-devel
Supplements:    packageand(%name:kernel-devel%variant)
%else
Requires:       kernel-source-vanilla = %version-%source_rel
Supplements:    packageand(%name:kernel-source-vanilla)
%endif
%if "%CONFIG_DEBUG_INFO_BTF_MODULES" == "y"
Requires:       dwarves >= 1.22
%endif
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt-devel = %version-%release
%endif
%endif
%obsolete_rebuilds %name-devel
PreReq:         coreutils

%description devel
This package contains files necessary for building kernel modules (and
kernel module packages) against the %build_flavor flavor of the kernel.


%source_timestamp

%if "%CONFIG_MODULES" == "y"

%pre devel

# handle update from an older kernel-source with linux-obj as symlink
if [ -h /usr/src/linux-obj ]; then
    rm -vf /usr/src/linux-obj
fi

%post devel
%relink_function

relink ../../linux-%{kernelrelease}%{variant}-obj/"%cpu_arch_flavor" /usr/src/linux-obj/"%cpu_arch_flavor"

%files devel -f kernel-devel.files
%dir /usr/src/linux-obj
%dir /usr/src/linux-obj/%cpu_arch
%ghost /usr/src/linux-obj/%cpu_arch_flavor
%exclude %obj_install_dir/%cpu_arch_flavor/Symbols.list
%if %generate_compile_commands
%exclude %obj_install_dir/%cpu_arch_flavor/compile_commands.json
%endif
%if "%kmp_target_cpu" != "%cpu_arch"
%obj_install_dir/%kmp_target_cpu
/usr/src/linux-obj/%kmp_target_cpu
%endif

%if "%livepatch" != "" && "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y" && (("%variant" == "" && %build_default) || ("%variant" == "-rt" && 0%livepatch_rt))
%if "%livepatch" == "kgraft"
%define patch_package %{livepatch}-patch
%else
%define patch_package kernel-%{livepatch}
%endif
%package %{livepatch}
Summary:        Metapackage to pull in matching %patch_package package
Group:          System/Kernel
Requires:       %{patch_package}-%(echo %{version}-%{source_rel} | sed 'y/\./_/')-%{build_flavor}
Provides:       multiversion(kernel)
%if "%variant" != "-rt"
Provides:	kernel-default-kgraft = %version
Provides:	kernel-xen-kgraft = %version
%if "%livepatch" != "kgraft"
Obsoletes:	kernel-default-kgraft < %version
Obsoletes:	kernel-xen-kgraft < %version
%endif
%endif

%description %{livepatch}
This is a metapackage that pulls in the matching %patch_package package for a
given kernel version. The advantage of the metapackage is that its name is
static, unlike the %{patch_package}-<kernel-version>-flavor package names.

%files %{livepatch}
# rpmlint complains about empty packages, so lets own something
%dir %modules_dir
%endif

%if 0%{?klp_symbols} && "%livepatch" != ""
%package %{livepatch}-devel
Summary:	Kernel symbols file used during kGraft patch development
Group:		System/Kernel
Provides:	klp-symbols = %version

%description %{livepatch}-devel
This package brings a file named Symbols.list, which contains a list of all
kernel symbols and its respective kernel object . This list is to be used by
the klp-convert tool, which helps livepatch developers by enabling automatic
symbol resolution.

%files %{livepatch}-devel -f livepatch-files
%endif

%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
%package -n cluster-md-kmp-%build_flavor
Summary:        Clustering support for MD devices
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       cluster-md-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       cluster-md-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:cluster-md-kmp-%build_flavor)
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n cluster-md-kmp-%build_flavor
Clustering support for MD devices. This enables locking and
synchronization across multiple systems on the cluster, so all
nodes in the cluster can access the MD devices simultaneously.

%pre -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n cluster-md-kmp-%build_flavor -f cluster-md-kmp.files

%package -n dlm-kmp-%build_flavor
Summary:        DLM kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       dlm-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       dlm-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:dlm-kmp-%build_flavor)

%description -n dlm-kmp-%build_flavor
DLM stands for Distributed Lock Manager, a means to synchronize access to
shared resources over the cluster.

%pre -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n dlm-kmp-%build_flavor -f dlm-kmp.files

%package -n gfs2-kmp-%build_flavor
Summary:        GFS2 kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       gfs2-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       gfs2-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:gfs2-kmp-%build_flavor)
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n gfs2-kmp-%build_flavor
GFS2 is Global Filesystem, a shared device filesystem.

%pre -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n gfs2-kmp-%build_flavor -f gfs2-kmp.files

%package -n kselftests-kmp-%build_flavor
Summary:        Kernel sefltests
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       kselftests-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kselftests-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:kselftests-kmp-%build_flavor)

%description -n kselftests-kmp-%build_flavor
This package contains kernel modules which are part of the upstream kernel
selftest effort. kselftest is the name of the upstream kernel target to build
and run all selftests. You can also run each test individually from the
respective upstream tools/testing/selftests/ directory, this package is
intended to be used using individial upstream selftest scripts given only
select supported selftest drivers are enabled.

It should always be possible to always run the latest linux-next version of the
selftest scripts and tests against any older kernel selftest driver.  Certain
tests facilities may be backported onto older kernels to enable further
testing.

Selftests also provide for a vehicle or proof of concept issues to be
reproduced, verified and corrected.

Selftest drivers are intended to be supported only in testing and QA
environments, they are not intended to be run on production systems.

%pre -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n kselftests-kmp-%build_flavor -f kselftests-kmp.files

%package -n ocfs2-kmp-%build_flavor
Summary:        OCFS2 kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       ocfs2-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       ocfs2-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:ocfs2-kmp-%build_flavor)
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n ocfs2-kmp-%build_flavor
OCFS2 is the Oracle Cluster Filesystem, a filesystem for shared devices
accessible simultaneously from multiple nodes of a cluster.

%pre -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n ocfs2-kmp-%build_flavor -f ocfs2-kmp.files

%package -n reiserfs-kmp-%build_flavor
Summary:        Reiserfs kernel module
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       reiserfs-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       reiserfs-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:reiserfs-kmp-%build_flavor)

%description -n reiserfs-kmp-%build_flavor
The reiserfs file system is no longer supported in SLE15.  This package
provides the reiserfs module for the installation system.

%pre -n reiserfs-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "reiserfs-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n reiserfs-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "reiserfs-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n reiserfs-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "reiserfs-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n reiserfs-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "reiserfs-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n reiserfs-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "reiserfs-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n reiserfs-kmp-%build_flavor -f reiserfs-kmp.files

%endif # %CONFIG_SUSE_KERNEL_SUPPORTED
%endif # %CONFIG_MODULES

%prep
if ! [ -e %{S:0} ]; then
    echo "The %name-%version.nosrc.rpm package does not contain the" \
	 "complete sources. Please install kernel-source-%version.src.rpm."
    exit 1
fi

SYMBOLS=
if test -e %_sourcedir/extra-symbols; then
	SYMBOLS=$(cat %_sourcedir/extra-symbols)
	echo "extra symbol(s):" $SYMBOLS
fi

# Unpack all sources and patches
%setup -q -c -T -a 0 -a 100 -a 101 -a 102 -a 103 -a 104 -a 105 -a 106 -a 108 -a 109 -a 110 -a 111 -a 113 -a 114 -a 120 -a 121

mkdir -p %kernel_build_dir

# Generate a list of modules with their support status marking
# The first marker is supposed to be either "+external", "-" or "-!optional",
# where "+external" is for an externally supported module, "-" is for an
# unsuppored module, "-!optional" is for Leap-only unsupported module.
# There can be an optional arch-specific second marker with "+arch" (e.g.
# +arm64), which enforces the module to be supported on the specific arch.
%_sourcedir/guards --list --with-guards <%_sourcedir/supported.conf | \
awk '{
    t = "";
    for (i = 1; i < NF; i++) {
	if ($i == "+external") {
		t = " external";
	} else if ($i == "+'%cpu_arch'") {
		t = "";
	} else if ($i ~ "^-") {
		t = " no";
	}
    }
    print $(NF) t;
}' >%kernel_build_dir/Module.supported
subpackages=(
	base
%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
	cluster-md-kmp dlm-kmp gfs2-kmp kselftests-kmp ocfs2-kmp reiserfs-kmp
%endif
)
for package in "${subpackages[@]}"; do
	%_sourcedir/guards --default=0 "$package" \
		<%_sourcedir/supported.conf | sed 's,.*/,,; s,\.ko$,,' | \
		sort -u >%kernel_build_dir/Module."$package"
done
%if %split_extra && %split_optional
# Module.optional is in a special form, containing guard markers for
# both extra and optional modules, which is processed by split-modules
%_sourcedir/guards --list --with-guards <%_sourcedir/supported.conf | \
awk '{
    t = "";
    for (i = 1; i < NF; i++) {
	if ($i == "+'%cpu_arch'") {
		t = "";
	} else if ($i ~ "^-") {
		t = $i
	}
    }
    if (t != "") {print t,$(NF);}
}' >%kernel_build_dir/Module.optional
%endif

cd linux-%srcversion

%_sourcedir/apply-patches \
%if %{build_vanilla} && ! %vanilla_only
	--vanilla \
%endif
	%_sourcedir/series.conf .. $SYMBOLS

cd %kernel_build_dir

# Override the timestamp 'uname -v' reports with the source timestamp and
# the commit hash.
date=$(head -n 1 %_sourcedir/source-timestamp)
commit=$(sed -n 's/GIT Revision: //p' %_sourcedir/source-timestamp)
cat > .kernel-binary.spec.buildenv <<EOF
export KBUILD_BUILD_TIMESTAMP="$(LANG=C date -d "$date") (${commit:0:7})"
export KBUILD_VERBOSE=0
export KBUILD_SYMTYPES=1
export KBUILD_BUILD_USER=geeko
export KBUILD_BUILD_HOST=buildhost
export HOST_EXTRACFLAGS="-include %_sourcedir/host-memcpy-hack.h"
EOF
source .kernel-binary.spec.buildenv

if [ -f %_sourcedir/localversion ] ; then
    cat %_sourcedir/localversion > localversion
fi

config_base="default"
%ifarch %ix86
config_base="pae"
%endif
if ! [ -f %my_builddir/config/%cpu_arch/$config_base ] ; then
    config_base=%variant
    config_base=${config_base#-}
fi
if ! grep -q CONFIG_MMU= "%my_builddir/config/%cpu_arch_flavor"; then
cp "%my_builddir/config/%cpu_arch/$config_base" .config
../scripts/kconfig/merge_config.sh -m .config \
                                   %my_builddir/config/%cpu_arch_flavor
else
cp %my_builddir/config/%cpu_arch_flavor .config
fi
if test -e %my_builddir/config.addon/%cpu_arch_flavor; then
	# FIXME: config.addon doesn't affect the %CONFIG_ macros defined at
	# the top of the specfile
	../scripts/kconfig/merge_config.sh -m .config %my_builddir/config.addon/%cpu_arch_flavor
fi

CONFIG_SUSE_KERNEL_RELEASED="--disable CONFIG_SUSE_KERNEL_RELEASED"
%if 0%{?_project:1}
if echo %_project | grep -Eqx -f %_sourcedir/release-projects; then
	CONFIG_SUSE_KERNEL_RELEASED="--enable CONFIG_SUSE_KERNEL_RELEASED"
fi
%endif

DEBUG_INFO_TYPE="$(grep "CONFIG_DEBUG_INFO_DWARF.*=y" .config)"
DEBUG_INFO_TYPE="${DEBUG_INFO_TYPE%%=y}"
DEBUG_INFO_TYPE="${DEBUG_INFO_TYPE##CONFIG_DEBUG_INFO_}"
echo "Kernel debuginfo type: ${DEBUG_INFO_TYPE}"

../scripts/config \
	--set-str CONFIG_LOCALVERSION -%source_rel-%build_flavor \
	--enable  CONFIG_SUSE_KERNEL \
	$CONFIG_SUSE_KERNEL_RELEASED \
%if 0%{?__debug_package:1}
	--enable  CONFIG_DEBUG_INFO
%else
	--disable CONFIG_DEBUG_INFO \
	--disable CONFIG_DEBUG_INFO_"${DEBUG_INFO_TYPE}" \
	--enable  CONFIG_DEBUG_INFO_NONE
%endif

if [ %CONFIG_MODULE_SIG = "y" ]; then
	if [ -n "%certs" ] ; then
		ln -s %_sourcedir/.kernel_signing_key.pem .
	else
		if ! [ -f .kernel.genkey ] ; then
			cat > .kernel.genkey <<EOF
[ req ]
default_bits = 4096
distinguished_name = req_distinguished_name
prompt = no
string_mask = utf8only
x509_extensions = myexts

[ req_distinguished_name ]
CN = Build time autogenerated kernel key

[ myexts ]
basicConstraints=critical,CA:FALSE
keyUsage=digitalSignature
subjectKeyIdentifier=hash
authorityKeyIdentifier=keyid
extendedKeyUsage=codeSigning
EOF
		fi
		openssl req -new -nodes -utf8 -%CONFIG_MODULE_SIG_HASH -days 36500 \
			-batch -x509 -config .kernel.genkey \
			-outform PEM -out .kernel_signing_key.pem \
			-keyout .kernel_signing_key.pem
	fi
	../scripts/config --set-str CONFIG_MODULE_SIG_KEY ".kernel_signing_key.pem"
fi

case %cpu_arch in
    x86_64 | i386)
        MAKE_ARGS="$MAKE_ARGS ARCH=x86"
        ;;
    ppc*)
        MAKE_ARGS="$MAKE_ARGS ARCH=powerpc"
        ;;
    s390x)
        MAKE_ARGS="$MAKE_ARGS ARCH=s390"
        ;;
    arm64)
        MAKE_ARGS="$MAKE_ARGS ARCH=arm64"
        ;;
    armv*)
        MAKE_ARGS="$MAKE_ARGS ARCH=arm"
        ;;
    riscv*)
        MAKE_ARGS="$MAKE_ARGS ARCH=riscv"
        ;;
    *)
        MAKE_ARGS="$MAKE_ARGS ARCH=%cpu_arch"
        ;;
esac

makeoutputsync=
if make --output-sync --help >/dev/null 2>&1 ; then
        makeoutputsync=--output-sync
else
        echo make does not support --output-sync flag. Build messages may be mangled. 1>&2
fi
MAKE_ARGS="$MAKE_ARGS $makeoutputsync %{?_smp_mflags}"
echo export MAKE_ARGS=\""$MAKE_ARGS"\" >> .kernel-binary.spec.buildenv

KERN_DIRS="-C .. O=$PWD"
if test -e %_sourcedir/TOLERATE-UNKNOWN-NEW-CONFIG-OPTIONS; then
    yes '' | make oldconfig $MAKE_ARGS $KERN_DIRS
else
    cp .config .config.orig
    if test -f ../scripts/kconfig/Makefile && \
       grep -q syncconfig ../scripts/kconfig/Makefile; then
        syncconfig="syncconfig"
    else
        syncconfig="silentoldconfig"
    fi
    make $syncconfig $MAKE_ARGS $KERN_DIRS < /dev/null
    %_sourcedir/check-for-config-changes .config.orig .config
    rm .config.orig
fi

make prepare $MAKE_ARGS
make scripts $MAKE_ARGS
krel=$(make -s kernelrelease $MAKE_ARGS)

if [ "$krel" != "%kernelrelease-%build_flavor" ]; then
    echo "Kernel release mismatch: $krel != %kernelrelease-%build_flavor" >&2
    exit 1
fi

make clean $MAKE_ARGS

rm -f source
find . ! -type d ! -name 'Module.base' ! -name 'Module.*-kmp' ! -name 'Module.optional' -printf '%%P\n' \
	> %my_builddir/obj-files

%build
cd %kernel_build_dir
source .kernel-binary.spec.buildenv

# create *.symref files in the tree
if test -e %my_builddir/kabi/%cpu_arch/symtypes-%build_flavor; then
    %_sourcedir/modversions --unpack . < $_
fi

%if "%CONFIG_KMSG_IDS" == "y"
    chmod +x ../scripts/kmsg-doc
    MAKE_ARGS="$MAKE_ARGS D=2"
%endif

mkdir -p %_topdir/OTHER
log=%_topdir/OTHER/make-stderr.log
while true; do
    make all $MAKE_ARGS 2> >(tee "$log")
    if test "${PIPESTATUS[0]}" -eq 0; then
        break
    fi
    # In the linux-next and vanilla branches, we try harder to build a
    # package.
    if test 0%vanilla_only -gt 0 &&
			%_sourcedir/try-disable-staging-driver "$log"; then
        echo "Retrying make"
    else
        exit 1
    fi
done

# Generate list of symbols that are used to create kernel livepatches
%if 0%{?klp_symbols}
	%_sourcedir/klp-symbols . Symbols.list

    %if %generate_compile_commands
        # Generate compile_commands.json
        make compile_commands.json
    %endif
%endif

%install

# get rid of /usr/lib/rpm/brp-strip-debug
# strip removes too much from the vmlinux ELF binary
export NO_BRP_STRIP_DEBUG=true
export STRIP_KEEP_SYMTAB='*/vmlinux*'

# %kernel_module_directory/%kernelrelease-%build_flavor/source points to the source
# directory installed by kernel-devel. The kernel-%build_flavor-devel package
# has a correct dependency on kernel-devel, but the brp check does not see
# kernel-devel during build.
export NO_BRP_STALE_LINK_ERROR=yes

cd %kernel_build_dir
source .kernel-binary.spec.buildenv

mkdir -p %buildroot/boot
# (Could strip out non-public symbols.)
cp -p System.map %buildroot/boot/System.map-%kernelrelease-%build_flavor

add_vmlinux()
{
    local vmlinux=boot/vmlinux-%kernelrelease-%build_flavor

    cp vmlinux %buildroot/$vmlinux
    # make sure that find-debuginfo.sh picks it up. In the filelist, we
    # mark the file 0644 again
    chmod +x %buildroot/$vmlinux
    if test $1 == "--compressed"; then
        # avoid using the gzip -n option to make kdump happy (bnc#880848#c20)
        ts="$(head -n1 %_sourcedir/source-timestamp)"
        touch -d "$ts" %buildroot/$vmlinux
        touch %buildroot/$vmlinux.%{compress_vmlinux}
%if 0%{?__debug_package:1}
        # compress the vmlinux image after find-debuginfo.sh has processed it
%global __debug_install_post %__debug_install_post \
%_sourcedir/compress-vmlinux.sh %buildroot/boot/vmlinux-%kernelrelease-%build_flavor
%else
        %_sourcedir/compress-vmlinux.sh %buildroot/$vmlinux
%endif
        ghost_vmlinux=true
    else
        ghost_vmlinux=false
    fi
}

# architecture specifics
%ifarch %ix86 x86_64
    add_vmlinux --compressed
    cp -p arch/x86/boot/bzImage %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif
%ifarch ppc ppc64 ppc64le
    add_vmlinux
%endif
%ifarch s390 s390x
    add_vmlinux --compressed
    image=image
    if test ! -f arch/s390/boot/$image; then
        image=bzImage
    fi
    cp -p arch/s390/boot/$image %buildroot/boot/%image-%kernelrelease-%build_flavor
%if "%CONFIG_KMSG_IDS" == "y"
    mkdir -p %buildroot/usr/share/man/man9
    find man -name '*.9' -exec install -m 644 -D '{}' %buildroot/usr/share/man/man9/ ';'
%endif
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
    s390x_vmlinux=arch/s390/boot/compressed/vmlinux
    if [ ! -f "$s390x_vmlinux" ]; then
        s390x_vmlinux=arch/s390/boot/vmlinux
    fi
    objcopy -R .rodata.compressed "$s390x_vmlinux" %buildroot/boot/zdebug-%kernelrelease-%build_flavor
%endif
%endif
%ifarch %arm
    add_vmlinux --compressed
    cp -p arch/arm/boot/%image %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif
%ifarch aarch64
    add_vmlinux --compressed
    cp -p arch/arm64/boot/%image %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif
%ifarch riscv64
    add_vmlinux --compressed
    cp -p arch/riscv/boot/%image %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif

# sign the modules, firmware and possibly the kernel in the buildservice
BRP_PESIGN_FILES=""
%if "%CONFIG_EFI_STUB" == "y"
%if %{usrmerged}
BRP_PESIGN_FILES="%modules_dir/%image"
%else
BRP_PESIGN_FILES="/boot/%image-%kernelrelease-%build_flavor"
%endif
%endif
%if ! %sb_efi_only
%ifarch s390x ppc64 ppc64le
%if %{usrmerged}
BRP_PESIGN_FILES="%modules_dir/%image"
%else
BRP_PESIGN_FILES="/boot/%image-%kernelrelease-%build_flavor"
%endif
%endif
%endif
%if "%CONFIG_MODULE_SIG" == "y"
BRP_PESIGN_FILES="$BRP_PESIGN_FILES *.ko"
%endif
%ifarch %ix86
# XXX: do not sign on x86, as the repackaging changes kernel-pae
# from i686 to i586
BRP_PESIGN_FILES=""
%endif
export BRP_PESIGN_FILES
%if "%{compress_modules}" != "none"
export BRP_PESIGN_COMPRESS_MODULE=%{compress_modules}
%endif
# Do not sign vanilla kernels released in official projects
%if %build_vanilla && ! %vanilla_only
BRP_PESIGN_FILES=""
%endif

if test -x /usr/lib/rpm/pesign/gen-hmac; then
	$_ -r %buildroot /boot/%image-%kernelrelease-%build_flavor
fi

# Package the compiled-in certificates as DER files in /etc/uefi/certs
# and have mokutil enroll them when the kernel is installed
echo Signing certificates "%certs"
if test %CONFIG_MODULE_SIG = "y" -a -d %_sourcedir/.kernel_signing_certs ; then
    for f in %_sourcedir/.kernel_signing_certs/*.crt; do
            mkdir -p %buildroot/etc/uefi/certs
            cp -v $f %buildroot/etc/uefi/certs
    done
fi

cp -p .config %buildroot/boot/config-%kernelrelease-%build_flavor
sysctl_file=%buildroot/boot/sysctl.conf-%kernelrelease-%build_flavor
for file in %my_builddir/sysctl/{defaults,%cpu_arch/arch-defaults,%cpu_arch_flavor}; do
	if [ -f "$file" ]; then
		cat "$file"
	fi
done | sed '1i # Generated file - do not edit.' >$sysctl_file
if [ ! -s $sysctl_file ]; then
	rm $sysctl_file
fi

%if %install_vdso
# Install the unstripped vdso's that are linked in the kernel image
make vdso_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot
rm -rf %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/vdso/.build-id
%endif

# Create a dummy initrd with roughly the size the real one will have.
# That way, YaST will know that this package requires some additional
# space in /boot.
dd if=/dev/zero of=%buildroot/boot/initrd-%kernelrelease-%build_flavor \
	bs=1024 seek=2047 count=1
# Also reserve some space for the kdump initrd
cp %buildroot/boot/initrd-%kernelrelease-%build_flavor{,-kdump}
%if 0%{?suse_version} >= 1500
# Use same permissions as dracut
chmod 0600 %buildroot/boot/initrd-%kernelrelease-%build_flavor{,-kdump}
%endif

if [ %CONFIG_MODULES = y ]; then
    mkdir -p %rpm_install_dir/%cpu_arch_flavor
    mkdir -p %buildroot/usr/src/linux-obj/%cpu_arch
    install -m 755 -D -t %rpm_install_dir/%cpu_arch_flavor/scripts/mod/ scripts/mod/ksym-provides

    gzip -n -c9 < Module.symvers > %buildroot/boot/symvers-%kernelrelease-%build_flavor.gz

    make modules_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot

%ifarch s390 s390x
    expoline=arch/s390/lib/expoline/expoline.o
    if test -f arch/s390/lib/expoline/expoline.o ; then
	install -m 644 -D -t %rpm_install_dir/%cpu_arch_flavor/$(dirname $expoline) $expoline
    fi
%endif

    # Also put the resulting file in %rpm_install_dir/%cpu_arch/%build_flavor
    # so that kernel-devel + kernel-%build_flavor is sufficient for building
    # modules that have modversions as well.
    mkdir -p %rpm_install_dir/%cpu_arch/%build_flavor
    cp Module.symvers %rpm_install_dir/%cpu_arch/%build_flavor

    # List of symbols that are used to generate kernel livepatches
    %if 0%{?klp_symbols}
        cp Symbols.list %rpm_install_dir/%cpu_arch/%build_flavor
        echo %obj_install_dir/%cpu_arch/%build_flavor/Symbols.list > %my_builddir/livepatch-files.no_dir

        %if %generate_compile_commands
		    cp compile_commands.json %rpm_install_dir/%cpu_arch/%build_flavor
		    echo %obj_install_dir/%cpu_arch/%build_flavor/compile_commands.json >> %my_builddir/livepatch-files.no_dir
        %endif

        %if "%CONFIG_LIVEPATCH_IPA_CLONES" == "y"
            find %kernel_build_dir -name "*.ipa-clones" ! -size 0 | sed -e 's|^%kernel_build_dir/||' | sort > ipa-clones.list
            cp ipa-clones.list %rpm_install_dir/%cpu_arch/%build_flavor
            echo %obj_install_dir/%cpu_arch/%build_flavor/ipa-clones.list >> %my_builddir/livepatch-files.no_dir
            tar -C %kernel_build_dir \
%if ! 0%{?suse_version} || 0%{?suse_version} >= 1500
		    --verbatim-files-from \
%endif
		    -T ipa-clones.list -cf- | tar -C %rpm_install_dir/%cpu_arch/%build_flavor -xvf-
            cat ipa-clones.list | sed -e 's|^|%obj_install_dir/%cpu_arch/%build_flavor/|' >> %my_builddir/livepatch-files.no_dir
        %endif
    %endif

    # Table of types used in exported symbols (for modversion debugging).
    %_sourcedir/modversions --pack . > %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    if [ -s %buildroot/boot/symtypes-%kernelrelease-%build_flavor ]; then
	gzip -n -9 %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    else
	rm -f %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    fi

    # Some architecture's $(uname -m) output is different from the ARCH
    # parameter that needs to be passed to kbuild. Create symlinks from
    # $(uname -m) to the ARCH directory.
    if [ ! -e %rpm_install_dir/%kmp_target_cpu ]; then
        ln -sf %cpu_arch %rpm_install_dir/%kmp_target_cpu
        ln -sf %cpu_arch %buildroot/usr/src/linux-obj/%kmp_target_cpu
    fi

    # We were building in %my_builddir/linux-%srcversion, but the sources will
    # later be installed in /usr/src/linux-%srcversion-%source_rel. Fix up the
    # build symlink.
    rm -f %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/{source,build}
    ln -s %src_install_dir \
	%buildroot%kernel_module_directory/%kernelrelease-%build_flavor/source
    ln -s %obj_install_dir/%cpu_arch/%build_flavor \
	%buildroot%kernel_module_directory/%kernelrelease-%build_flavor/build

    # Abort if there are any undefined symbols
    msg="$(/sbin/depmod -F %buildroot/boot/System.map-%kernelrelease-%build_flavor \
			-b %buildroot -ae %kernelrelease-%build_flavor 2>&1)"
    if [ $? -ne 0 ] || echo "$msg" | grep  'needs unknown symbol'; then
	exit 1
    fi

    %_sourcedir/split-modules -d %buildroot \
	-o %my_builddir \
	-b %kernel_build_dir \
%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
	-e \
%endif
%if ! %supported_modules_check
	-i \
%endif
	%nil
%if ! %split_extra
    cat %my_builddir/unsupported-modules >>%my_builddir/main-modules
%endif

    # The modules.dep file is sorted randomly which produces strange file
    # checksums. As the file is not included in the resulting RPM, it's
    # pointless to rely on its contents. Replacing by zeros to make the
    # checksums always the same for several builds of the same package.
    test -s %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/modules.dep && \
    dd if=/dev/zero of=%buildroot%kernel_module_directory/%kernelrelease-%build_flavor/modules.dep ibs=$(stat -c%s %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/modules.dep) count=1

    res=0
    if test -e %my_builddir/kabi/%cpu_arch/symvers-%build_flavor; then
        # check for kabi changes
        %_sourcedir/kabi.pl --rules %my_builddir/kabi/severities \
            %my_builddir/kabi/%cpu_arch/symvers-%build_flavor \
            Module.symvers || res=$?
    fi
    if [ $res -ne 0 ]; then
	# %ignore_kabi_badness is defined in the Kernel:* projects in the
	# OBS to be able to build the KOTD in spite of kabi errors
	if [ 0%{?ignore_kabi_badness} -eq 0 -a \
	     ! -e %my_builddir/kabi/%cpu_arch/ignore-%build_flavor -a \
	     ! -e %_sourcedir/IGNORE-KABI-BADNESS ]; then
	    echo "Create a file IGNORE-KABI-BADNESS in the kernel-source" \
		 "directory to build this kernel even though its badness is" \
		 "higher than allowed for an official kernel."
	   exit 1
	fi
    fi

    # Check the license in each module
    if ! sh %_sourcedir/check-module-license %buildroot; then
	echo "Please fix the missing licenses!"
%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
	exit 1
%endif
    fi

    # These files are required for building external modules
    for FILE in arch/powerpc/lib/crtsavres.o arch/arm64/kernel/ftrace-mod.o \
		arch/*/kernel/macros.s scripts/module.lds
    do
	    if [ -f %kernel_build_dir/$FILE ]; then
		echo $FILE >> %my_builddir/obj-files
	    fi
    done

    tar --exclude=\*.ipa-clones --exclude=.config.old --exclude=.kernel-binary.spec.buildenv \
        --exclude=.kernel_signing_key.pem --exclude=.kernel.genkey \
        -cf - -T %my_builddir/obj-files | \
	tar -xf - -C %rpm_install_dir/%cpu_arch_flavor
    # bnc#507084
    find %rpm_install_dir/%cpu_arch_flavor/scripts -type f -perm -111 | \
        while read f; do
            case "$(file -b "$f")" in
            ELF\ *\ executable*)
                strip "$f"
            esac
        done

    # Recreate the generated Makefile with correct path
    #
    # Linux 5.13 no longer has mkmakefile
    if [ -f ../scripts/mkmakefile ] ; then
        sh ../scripts/mkmakefile ../../../%{basename:%src_install_dir} \
            %rpm_install_dir/%cpu_arch_flavor \
            $(echo %srcversion | sed -r 's/^([0-9]+)\.([0-9]+).*/\1 \2/')
    else
       echo include ../../../%{basename:%src_install_dir}/Makefile > %rpm_install_dir/%cpu_arch_flavor/Makefile
    fi
fi

# CONFIG_GDB_SCRIPTS
if [ -e vmlinux-gdb.py ]; then
    DEST=%rpm_install_dir/%cpu_arch_flavor/
    install -m 755 -d "$DEST"
    # set sys.path to our devel.rpm scripts
    sed 's@\(sys\.path\.insert(0, \).*@\1"%obj_install_dir/%cpu_arch_flavor/scripts/gdb/")@' vmlinux-gdb.py > "$DEST/vmlinux-gdb.py"

    DEST=%rpm_install_dir/%cpu_arch_flavor/scripts/gdb/linux
    install -m 755 -d "$DEST"
    pushd scripts/gdb/linux/
    for file in *.py; do
	if test -L "$file"; then
	    # relink against our devel.rpm sources, not of buildroot's
	    ln -s "%src_install_dir/scripts/gdb/linux/$file" "$DEST/$file"
	else
	    cp -p "$file" "$DEST"
	fi
    done
    popd

    DEST=%{buildroot}%{_datadir}/gdb/auto-load%modules_dir
    install -m 755 -d "$DEST"
    ln -s %obj_install_dir/%cpu_arch_flavor/vmlinux-gdb.py "$DEST/vmlinux-gdb.py"
fi

rm -rf %{buildroot}/lib/firmware

add_dirs_to_filelist() {
    sed -rn '
        # print file name
        p
        # remove filelist macros
        s:%%[a-z]+(\([^)]+\))? ?::g
        # add %%dir prefix
        s:^:%%dir :
        # print all parents
        :a
            # skip directories owned by other packages
            s:^%%dir (/boot|/etc|(/usr)?/lib/(modules|firmware)|/usr/share|/usr/src)/[^/]+$::
            s:/[^/]+$::p
        ta
    ' "$@" | sort -u
}

# Collect the file lists.
if [ -f %my_builddir/livepatch-files.no_dir ] ; then
    cat %my_builddir/livepatch-files.no_dir | add_dirs_to_filelist > %my_builddir/livepatch-files
fi

# does not exist for non-modularized kernels
%if %{usrmerged}
        mkdir -p %{buildroot}%modules_dir
%endif
shopt -s nullglob dotglob
> %my_builddir/kernel-devel.files
{
    echo "%modules_dir/build"
    echo "%modules_dir/source"
    cd %buildroot
    for file in boot/symtypes*; do
%if %{usrmerged}
        l="${file##*/}"
        l="%modules_dir/${l//-%kernelrelease-%build_flavor}"
        mv "$file" "%{buildroot}$l"
        ln -s "..$l" $file
        echo "$l"
        echo "%%ghost /$file"
%else
        echo "/$file"
%endif
    done
    if test -d .%{_datadir}/gdb/; then
	find .%obj_install_dir/%cpu_arch_flavor/scripts/gdb/linux/ -name '*.py' -type l | sed -e 's/^[.]//'
	echo "%{_datadir}/gdb/auto-load%modules_dir/vmlinux-gdb.py"
    fi
} | add_dirs_to_filelist >%my_builddir/kernel-devel.files
( cd %buildroot ; find .%obj_install_dir/%cpu_arch_flavor -type f ; ) | \
sed -e 's/^[.]//' | grep -v -e '[.]ipa-clones$' -e '/Symbols[.]list$' -e '/ipa-clones[.]list$'| \
add_dirs_to_filelist >> %my_builddir/kernel-devel.files

{   echo %ghost /boot/%image
    echo %ghost /boot/initrd
    cd %buildroot
    for f in boot/*; do
        l="${f##*/}"
        l="%modules_dir/${l//-%kernelrelease-%build_flavor}"
        if test -L "$f"; then
            echo "%%ghost /$f"
            continue
        elif test ! -f "$f"; then
            continue
        fi
        case "$f" in
        boot/initrd-*)
            echo "%%ghost /$f"
            continue
            ;;
        boot/vmlinux-*.%{compress_vmlinux})
            ;;
        boot/vmlinux-*)
            if $ghost_vmlinux; then
                # fall through to mark next echo as %ghost
                echo -n "%%ghost "
            fi
            ;;
%if %{usrmerged}
        boot/vmlinuz-*)
            echo -n "%%attr(0644, root, root) "
            ;;
%endif
        boot/symtypes*)
%if %{usrmerged}
            echo "%exclude $l"
%endif
            continue
            ;;
        esac
%if %{usrmerged}
        mv "$f" "./$l"
        ln -s "..$l" $f
        # the find in the CONFIG_MODULES condition below also finds the files
        # but there's sort -u later, so this is ok
        echo "$l" # note: must be first after case statement above
        echo "%%ghost /$f"
%else
        echo "%%attr(0644, root, root) /$f"
%endif
    done

    if [ %CONFIG_MODULES = y ]; then
	MODULES=%{lua: print(rpm.expand('%kernel_module_directory'):sub(2))}/%kernelrelease-%build_flavor
	find "$MODULES" \
%if 0%{?separate_vdso}
	    -path "$MODULES/vdso" -prune -o \
%endif
	    -type d -o \
	    \( -path '*/modules.*' ! -path '*/modules.order' \
	     ! -path '*/modules.builtin' \
	     ! -path '*/modules.builtin.modinfo' \) -printf '%%%%ghost /%%p\n' \
	       -o -name '*.ko' -prune \
	       -o \( -type f \
%if %{usrmerged}
		! -path '*/symtypes*' ! -path '*/vmlinu*' \
%endif
		\) -printf '/%%p\n'
	cat %my_builddir/base-modules
    fi
    if test %CONFIG_MODULE_SIG = "y" -a -d etc/uefi/certs; then
        find etc/uefi/certs -type f -printf '/%%p\n'
    fi
    if test -d lib/firmware/%kernelrelease-%build_flavor; then
        echo "%%dir /lib/firmware/%kernelrelease-%build_flavor"
        cat %my_builddir/base-firmware
    fi
    if [ -e .%_docdir/%name ]; then
	echo "%%doc %_docdir/%name"
    fi
} | sort -u | add_dirs_to_filelist >%my_builddir/kernel-base.files

{
    add_dirs_to_filelist %my_builddir/kernel-base.files
    if [ %CONFIG_MODULES = y ]; then
        add_dirs_to_filelist %my_builddir/main-modules
    fi
    if test -d %buildroot/lib/firmware/%kernelrelease-%build_flavor; then
	echo "/lib/firmware/%kernelrelease-%build_flavor"
    fi
} > %my_builddir/kernel-main.files

%if %split_extra
    add_dirs_to_filelist %my_builddir/unsupported-modules > %my_builddir/kernel-extra.files
%if %split_extra && %split_optional
    add_dirs_to_filelist %my_builddir/optional-modules > %my_builddir/kernel-optional.files
%endif

%if 0%{?sle_version} >= 150000
    # By default, loading unsupported modules is disabled on SLE through
    # /etc/modprobe.d/10-unsupported-modules.conf from the suse-module-tools
    # package.
    # modules in kernel-$flavor-extra don't have the supported flag set,
    # yet loading them should be possible if the package is installed.
    # CAUTION PACKAGERS: The file content below must not change between
    # kernel versions, otherwise file conflicts might arise with
    # multiversion(kernel).

    modprobe_d_dir=/etc/modprobe.d
    %if 0%{?sle_version} > 150300
    modprobe_d_dir=/lib/modprobe.d
    %endif
    %if %{usrmerged}
    modprobe_d_dir=/usr/lib/modprobe.d
    %endif

    mkdir -p %buildroot$modprobe_d_dir
    cat >%buildroot$modprobe_d_dir/20-kernel-%{build_flavor}-extra.conf <<EOF
# This file overrides the default from 10-unsupported-modules.conf.
# This is necessary to load kernel modules from the
# kernel-%{build_flavor}-extra package.
#
# WARNING: loading unsupported modules may compromise SLE support.
# Please read the comments in 10-unsupported-modules.conf.
allow_unsupported_modules 1
EOF
    echo "%%dir $modprobe_d_dir" >> %my_builddir/kernel-extra.files
    echo "%%config(noreplace) $modprobe_d_dir/20-kernel-%{build_flavor}-extra.conf" >> %my_builddir/kernel-extra.files
%endif
%endif
for f in %my_builddir/*-kmp-modules; do
	f2=${f%%-modules}.files
	add_dirs_to_filelist "$f" >"$f2"
done

if [ %CONFIG_MODULES = y ]; then
  install -m 644 %_sourcedir/modules.fips %{buildroot}%modules_dir/modules.fips
  echo %modules_dir/modules.fips >> %my_builddir/kernel-base.files
  echo %modules_dir/modules.fips >> %my_builddir/kernel-main.files
fi

# Hardlink duplicate files automatically (from package fdupes): It doesn't save
# much, but it keeps rpmlint from breaking the package build. Note that we skip
# /usr/src/linux-obj intentionally, to not accidentally break timestamps there
%fdupes %buildroot%modules_dir

%changelog
* Thu Oct  3 2024 pjakobsson@suse.de
- blacklist.conf: c52c35e5b404 accel/ivpu: Return max freq for DRM_IVPU_PARAM_CORE_CLOCK_RATE
- commit c42fa2e
* Thu Oct  3 2024 pjakobsson@suse.de
- Refresh patches.suse/1927-accel-ivpu-avoid-build-failure-with-CONFIG_PM-n.patch (git-fixes)
  Alt-commit
- commit 2df1fee
* Wed Oct  2 2024 tbogendoerfer@suse.de
- net: microchip: vcap: Fix use-after-free error in kunit test
  (CVE-2024-46831 bsc#1231117).
- commit 630e2e8
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu/37xx: Fix interrupt_clear_with_0 WA initialization (drm-backport-placeholder)
- commit 90be63c
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: avoid build failure with CONFIG_PM=n (drm-backport-placeholder)
- commit c23dcdd
* Wed Oct  2 2024 pjakobsson@suse.de
- intel drm: Remove now superfluous sentinel element from ctl_table (drm-backport-placeholder)
- commit f057d9b
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Delete the TODO file (drm-backport-placeholder)
- commit 68b4650
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu/37xx: Remove support for FPGA and simics (drm-backport-placeholder)
- commit 3e2f052
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Do not initialize parameters on power up (drm-backport-placeholder).
- Refresh patches.suse/accel-ivpu-37xx-Fix-hangs-related-to-MMIO-reset.patch.
- commit ec10362
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Print IPC type string instead of number (drm-backport-placeholder)
- commit b5d137e
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Read clock rate only if device is up (drm-backport-placeholder)
- commit a121165
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Fix verbose version of REG_POLL macros (drm-backport-placeholder)
- commit c5a44ed
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Use ratelimited warn and err in IPC/JSM (drm-backport-placeholder)
- commit a2af9b3
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Add ivpu_bo_vaddr() and ivpu_bo_size() (drm-backport-placeholder)
- commit 2970210
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: fix spmu mask creation (drm-backport-placeholder)
- commit 07abb46
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: perform hard-reset upon PCIe AXI drain event (drm-backport-placeholder)
- commit 11ae380
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: fix bug in decoder wait for cs completion (drm-backport-placeholder)
- commit 492eba0
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: remove wrong doc for init_phys_pg_pack_from_userptr (drm-backport-placeholder)
- commit 0ef9fea
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: add missing debugfs function stubs (drm-backport-placeholder)
- commit a02d02a
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: minor cosmetic update to habanalabs.h (drm-backport-placeholder)
- commit a3227f7
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi: remove define used for simulator (drm-backport-placeholder)
- commit baa7260
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: remove leftover code (drm-backport-placeholder)
- commit 3add1bf
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: print device name when it is removed (drm-backport-placeholder)
- commit 2b4cef9
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: remove unused field (drm-backport-placeholder)
- commit e1a50da
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi: remove unused structure definition (drm-backport-placeholder)
- commit 8cc42cc
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: minor cosmetics update to trace file (drm-backport-placeholder)
- commit 386d94e
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: minor cosmetics update to cpucp_if.h (drm-backport-placeholder)
- commit 36c8348
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: trace dma map sgtable (drm-backport-placeholder)
- commit e3721b7
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: add traces for dma mappings (drm-backport-placeholder)
- commit cbef096
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: remove unused asic functions (drm-backport-placeholder)
- commit 1765a46
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: update boot status print (drm-backport-placeholder)
- commit 34ef07d
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: extend preboot timeout when preboot might take (drm-backport-placeholder)
- commit 04f8958
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: add fw status SHUTDOWN_PREP (drm-backport-placeholder)
- commit 5c1e966
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: add debug prints to dump content of SG table for (drm-backport-placeholder)
- commit 3ef70b4
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: add missing offset handling for dma-buf (drm-backport-placeholder)
- commit f7a6990
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: set hl_dmabuf_priv.device_address only when needed (drm-backport-placeholder)
- commit 3d496be
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: fix SG table creation for dma-buf mapping (drm-backport-placeholder)
- commit 86ed9da
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: split user interrupts pending list (drm-backport-placeholder)
- commit 65bcbae
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: optimize timestamp registration handler (drm-backport-placeholder)
- commit b950150
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: fix bug in timestamp interrupt handling (drm-backport-placeholder)
- commit 80b9d5d
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: tiny refactor of hl_map_dmabuf() (drm-backport-placeholder)
- commit 27e179b
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: export dma-buf only if size/offset multiples of (drm-backport-placeholder)
- commit fe499e9
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: use exported size from dma_buf and not from (drm-backport-placeholder)
- commit f796ad5
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: always pass exported size to (drm-backport-placeholder)
- commit 3294143
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: prevent sending heartbeat before events are enabled (drm-backport-placeholder)
- commit 5040efd
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: add eq health check using irq (drm-backport-placeholder)
- commit a88546c
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: handle eq health heartbeat check (drm-backport-placeholder)
- commit 4dcf4b5
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: print power-mode changes (drm-backport-placeholder)
- commit 5953201
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: fix inline doc typos (drm-backport-placeholder)
- commit 5e4a904
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: disable events ioctls on control device (drm-backport-placeholder)
- commit af897ae
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: move cpucp interface to linux/habanalabs (drm-backport-placeholder)
- commit d211dbd
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: include block id in ECC error reporting (drm-backport-placeholder)
- commit 90dd4b9
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: improve etf configuration (drm-backport-placeholder)
- commit 026182a
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: refactor deprecated strncpy (drm-backport-placeholder)
- commit b06dbfa
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: refactor deprecated strncpy to strscpy_pad (drm-backport-placeholder)
- commit f0a70ae
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: fix ETR/ETF flush logic (drm-backport-placeholder)
- commit 8e9c2b3
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2 : remove psoc_arc access (drm-backport-placeholder)
- commit 8147be3
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: prepare to remove cpu_rst_status (drm-backport-placeholder)
- commit ca38abc
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: Move ioctls to the device specific ioctls range (drm-backport-placeholder)
- commit 2be2f89
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: register compute device as an accel device (drm-backport-placeholder)
- commit ccfc2da
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: add info ioctl for engine error reports (drm-backport-placeholder)
- commit aa233bb
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: set default device release watchdog T/O as 30 sec (drm-backport-placeholder)
- commit 082a563
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: handle f/w reserved dram space request (drm-backport-placeholder)
- commit 73758ec
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: fix missing check of kernel ctx (drm-backport-placeholder)
- commit badac14
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: prepare to remove soft_rst_irq (drm-backport-placeholder)
- commit 051f20b
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: unsecure tpc count registers (drm-backport-placeholder)
- commit 7ad0e0d
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: un-secure register for engine cores (drm-backport-placeholder)
- commit 5c22a63
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi: Add MODULE_FIRMWARE macros (drm-backport-placeholder)
- commit 1575c70
* Wed Oct  2 2024 pjakobsson@suse.de
- accel: make accel_class a static const structure (drm-backport-placeholder)
- commit 3a06aaa
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: dump temperature threshold boot error (drm-backport-placeholder)
- commit 27be81f
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: reset device if scrubbing failed (drm-backport-placeholder)
- commit 70a9b18
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: remove pdev check on idle check (drm-backport-placeholder)
- commit abc97e6
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: fix wait_for_interrupt abortion flow (drm-backport-placeholder)
- commit 38d4972
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: Allow single timestamp registration request at a (drm-backport-placeholder)
- commit 9aa6a6e
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: rename fd_list to hpriv_list (drm-backport-placeholder)
- commit 11fe401
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: call put_pid after hpriv list is updated (drm-backport-placeholder)
- commit 601ebc5
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: print return code when process termination fails (drm-backport-placeholder)
- commit c1d67b1
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: fix standalone preboot descriptor request (drm-backport-placeholder)
- commit 02eae7b
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: handle arc farm razwi (drm-backport-placeholder)
- commit 05680e3
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: stop fetching MME SBTE error cause (drm-backport-placeholder)
- commit f2dba05
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: set device status 'malfunction' while in rmmod (drm-backport-placeholder)
- commit e9242b6
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: print task name upon creation of a user context (drm-backport-placeholder)
- commit 26d2725
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: print task name and request code upon ioctl failure (drm-backport-placeholder)
- commit 5882ff8
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: notify user about undefined opcode event (drm-backport-placeholder)
- commit a401c05
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: update pending reset flags with new reset requests (drm-backport-placeholder)
- commit 8cbf3c7
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: prevent immediate hard reset due to 2 adjacent H/W (drm-backport-placeholder)
- commit f291402
* Wed Oct  2 2024 pjakobsson@suse.de
- fbdev: Replace fb_pgprotect() with pgprot_framebuffer() (drm-backport-placeholder).
- commit 809d5cc
* Wed Oct  2 2024 pjakobsson@suse.de
- arch/m68k: Implement <asm/fb.h> with generic helpers (drm-backport-placeholder)
- commit 3dc7520
* Wed Oct  2 2024 pjakobsson@suse.de
- arch/m68k: Merge variants of fb_pgprotect() into single function (drm-backport-placeholder)
- commit 1271584
* Wed Oct  2 2024 pjakobsson@suse.de
- fbdev: Avoid file argument in fb_pgprotect() (drm-backport-placeholder)
- commit aa58fef
* Wed Oct  2 2024 pjakobsson@suse.de
- drm/i915: Zap some empty lines (drm-backport-placeholder)
- commit 2ecdc43
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Compile ivpu_debugfs.c conditionally (drm-backport-placeholder)
- commit 5c81b42
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Update debugfs to latest changes in DRM (drm-backport-placeholder)
- commit e0aec29
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/qaic: Add QAIC_DETACH_SLICE_BO IOCTL (drm-backport-placeholder)
- commit a037459
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/qaic: Create a function to initialize BO (drm-backport-placeholder)
- commit 5f103ca
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/qaic: Clean up BO during flushing of transfer list (drm-backport-placeholder)
- commit 524e4db
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/qaic: Undo slicing setup done in qaic_attach_slicing_bo() (drm-backport-placeholder)
- commit bc830fc
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/qaic: Declare BO 'sliced' after all the operations are complete (drm-backport-placeholder)
- commit 2901c86
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/qaic: Update BO metadata in a central location (drm-backport-placeholder)
- commit 9749bca
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/qaic: Use devm_drm_dev_alloc() instead of drm_dev_alloc() (drm-backport-placeholder)
- commit 347af6a
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/qaic: Register for PCI driver at the beginning of module init (drm-backport-placeholder)
- commit 2449127
* Wed Oct  2 2024 pjakobsson@suse.de
- drm: bridge: it66121: Simplify probe() (drm-backport-placeholder)
- commit 8c18ef5
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Print information about used workarounds (drm-backport-placeholder)
- commit ec18a83
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Move MMU register definitions to ivpu_mmu.c (drm-backport-placeholder)
- commit 51c30da
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu/37xx: White space cleanup (drm-backport-placeholder)
- commit 7db4f18
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu/37xx: Change register rename leftovers (drm-backport-placeholder)
- commit 77c878f
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Move ivpu_fw_load() to ivpu_fw_init() (drm-backport-placeholder)
- commit c78406a
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Initialize context with SSID = 1 (drm-backport-placeholder)
- commit b9327ce
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Add information about context on failure (drm-backport-placeholder)
- commit e133fc0
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Make ivpu_pm_init() void (drm-backport-placeholder)
- commit db1b911
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Remove duplicated error messages (drm-backport-placeholder)
- commit 5f6fa77
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Move set autosuspend delay to HW specific code (drm-backport-placeholder)
- commit 069ea86
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Annotate struct ivpu_job with __counted_by (drm-backport-placeholder)
- commit eae7ec1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1372-i2c-Add-i2c_get_match_data.patch (drm-backport-placeholder)
- commit 3e98e72
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0002-PCI-Add-pci_is_vga-helper.patch (drm-backport-placeholder)
- commit c6b02da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/string.h-add-array-wrappers-for-v-memdup_user.patch (drm-backport-placeholder)
- commit 0b72fe3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0001-PCI-Add-pci_get_base_class-helper.patch (drm-backport-placeholder)
- commit 3a1d0c6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2012-drm-nouveau-dp-Honor-GSP-link-training-retry-timeout.patch (drm-backport-placeholder)
- commit 717d6eb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2011-nouveau-push-event-block-allowing-out-of-the-fence-c.patch (drm-backport-placeholder)
- commit 05fc83e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2010-nouveau-gsp-always-free-the-alloc-messages-on-r535.patch (drm-backport-placeholder)
- commit 738dfe4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2009-nouveau-gsp-don-t-free-ctrl-messages-on-errors.patch (drm-backport-placeholder)
- commit 70ddcb1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2008-nouveau-gsp-convert-gsp-errors-to-generic-errors.patch (drm-backport-placeholder)
- commit 65234db
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2007-drm-nouveau-gsp-Fix-ACPI-MXDM-MXDS-method-invocation.patch (drm-backport-placeholder)
- commit a8acce7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2006-nouveau-gsp-free-userd-allocation.patch (drm-backport-placeholder)
- commit 5710cf4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2005-nouveau-gsp-free-acpi-object-after-use.patch (drm-backport-placeholder)
- commit 4f6d20d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2004-nouveau-fix-disp-disabling-with-GSP.patch (drm-backport-placeholder)
- commit 85e6cd9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2003-nouveau-gsp-drop-some-acpi-related-debug.patch (drm-backport-placeholder)
- commit 1497082
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2002-nouveau-gsp-add-three-notifier-callbacks-that-we-see.patch (drm-backport-placeholder)
- commit 06bc903
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2001-drm-amd-pm-Use-gpu_metrics_v1_5-for-SMUv13.0.6.patch (drm-backport-placeholder)
- commit 38fb975
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2000-drm-amd-pm-Add-gpu_metrics_v1_5.patch (drm-backport-placeholder)
- commit b357943
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1999-drm-amd-pm-Add-mem_busy_percent-for-GCv9.4.3-apu.patch (drm-backport-placeholder)
- commit b332265
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-sending-VSC-colorimetry-packets-.patch (drm-backport-placeholder)
- commit 7d4ed45
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-skip-gpu_info-fw-loading-on-navi12.patch (drm-backport-placeholder)
- commit d09e5f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-add-nv12-bounding-box.patch (drm-backport-placeholder)
- commit 300f1dc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1995-drm-amd-pm-Update-metric-table-for-jpeg-vcn-data.patch (drm-backport-placeholder)
- commit e972b2e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1994-drm-amd-pm-Use-separate-metric-table-for-APU.patch (drm-backport-placeholder)
- commit 907e01b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-pbn_div-need-be-updated-for-hotplug-.patch (drm-backport-placeholder)
- commit 84c36df
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mgag200-Fix-gamma-lut-not-initialized-for-G200ER.patch (drm-backport-placeholder)
- commit 3cbee37
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-ps8640-Fix-size-mismatch-warning-w-len.patch (drm-backport-placeholder)
- commit 6e08806
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-ti-sn65dsi86-Never-store-more-than-msg-si.patch (drm-backport-placeholder)
- commit 506595a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-parade-ps8640-Never-store-more-than-msg-s.patch (drm-backport-placeholder)
- commit beeb008
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/accel-qaic-Implement-quirk-for-SOC_HW_VERSION.patch (drm-backport-placeholder)
- commit a6fe112
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/accel-qaic-Fix-GEM-import-path-code.patch (drm-backport-placeholder)
- commit 8151fbe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-perf-Update-handling-of-MMIO-triggered-repo.patch (drm-backport-placeholder)
- commit b89a945
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dp-Fix-passing-the-correct-DPCD_REV-for-drm.patch (drm-backport-placeholder)
- commit 1d4e565
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dmc-Don-t-enable-any-pipe-DMC-events.patch (drm-backport-placeholder)
- commit bd6330c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mtl-Fix-HDMI-DP-PLL-clock-selection.patch (drm-backport-placeholder)
- commit ffada22
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Reject-async-flips-with-bigjoiner.patch (drm-backport-placeholder)
- commit b134555
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-hwmon-Fix-static-analysis-tool-reported-iss.patch (drm-backport-placeholder)
- commit 251cf77
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1982-drm-i915-display-Get-bigjoiner-config-before-dsc-con.patch (drm-backport-placeholder)
- commit 6928942
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-re-create-idle-bo-s-PTE-during-VM-state-m.patch (drm-backport-placeholder)
- commit bf82ef2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1980-drm-amd-display-dereference-variable-before-checking.patch (drm-backport-placeholder)
- commit 243599a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-get-dprefclk-ss-info-from-integratio.patch (drm-backport-placeholder)
- commit d91f7b1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-case-for-dcn35-to-support-usb4-d.patch (drm-backport-placeholder)
- commit c69de3d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1977-drm-amd-display-disable-FPO-and-SubVP-for-older-DMUB.patch (drm-backport-placeholder)
- commit 2b5fb00
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-svm-range-always-mapped-flag-not-working-.patch (drm-backport-placeholder)
- commit 88dd594
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1975-drm-amd-display-Revert-drm-amd-display-Use-channel_w.patch (drm-backport-placeholder)
- commit 574a7b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1974-drm-nouveau-kms-nv50-Don-t-allow-inheritance-of-head.patch (drm-backport-placeholder)
- commit ee32972
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1973-drm-nouveau-Fixup-gk20a-instobj-hierarchy.patch (drm-backport-placeholder)
- commit 27b216d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1972-drm-panel-ltk050h3146w-Set-burst-mode-for-ltk050h314.patch (drm-backport-placeholder)
- commit 63c5bb3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-edid-also-call-add-modes-in-EDID-connector-updat.patch (drm-backport-placeholder)
- commit da5356a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-crtc-fix-uninitialized-variable-use.patch (drm-backport-placeholder)
- commit c81dca8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-crtc-Fix-uninit-value-bug-in-drm_mode_setcrtc.patch (drm-backport-placeholder)
- commit 2b5c2e1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-Fix-FD-ownership-check-in-drm_master_check_perm.patch (drm-backport-placeholder)
- commit b295314
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1967-drm-amdgpu-warn-when-there-are-still-mappings-when-a.patch (drm-backport-placeholder)
- commit bd58bbc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-tear-down-order-in-amdgpu_vm_pt_free.patch (drm-backport-placeholder)
- commit ec4e243
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1965-drm-amd-Fix-a-probing-order-problem-on-SDMA-2.4.patch (drm-backport-placeholder)
- commit 2110e80
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-sdma5.2-add-begin-end_use-ring-callbacks.patch (drm-backport-placeholder)
- commit 455e2d9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Disable-PSR-SU-on-Parade-0803-TCON-a.patch (drm-backport-placeholder)
- commit 1ac614c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1962-drm-amd-display-Populate-dtbclk-from-bounding-box.patch (drm-backport-placeholder)
- commit e0cd6bf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1961-drm-amd-display-Revert-Fix-conversions-between-bytes.patch (drm-backport-placeholder)
- commit 52d89cf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1960-drm-amdgpu-jpeg-configure-doorbell-for-each-playback.patch (drm-backport-placeholder)
- commit 7700025
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Restore-guard-against-default-backli.patch (drm-backport-placeholder)
- commit 4f73887
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1958-drm-amd-display-fix-hw-rotated-modes-when-PSR-SU-is-.patch (drm-backport-placeholder)
- commit 20d9f57
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1957-drm-amd-pm-fix-pp_-clk_od-typo.patch (drm-backport-placeholder)
- commit 176a85b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1956-drm-amdgpu-fix-buffer-funcs-setting-order-on-suspend.patch (drm-backport-placeholder)
- commit ac8a2df
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-edp-don-t-write-to-DP_LINK_BW_SET-when-usin.patch (drm-backport-placeholder)
- commit 8198ebb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-ADL-tiled-plane-stride-when-the-POT-str.patch (drm-backport-placeholder)
- commit 4d3282f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-intel_atomic_setup_scalers-plane_state-.patch (drm-backport-placeholder)
- commit 485c5ea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-remapped-stride-with-CCS-on-ADL.patch (drm-backport-placeholder)
- commit e9f7fc7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Use-internal-class-when-counting-engine-res.patch (drm-backport-placeholder)
- commit f4364a9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-selftests-Fix-engine-reset-count-storage-fo.patch (drm-backport-placeholder)
- commit ca12fc7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-access-violation-in-mtk_drm_crtc_dm.patch (drm-backport-placeholder)
- commit b59f786
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Add-spinlock-for-setting-vblank-event-i.patch (drm-backport-placeholder)
- commit 4bac9ea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-fix-kernel-oops-if-no-crtc-is-found.patch (drm-backport-placeholder)
- commit e6a6030
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1946-drm-mediatek-mtk_disp_gamma-Fix-breakage-due-to-merg.patch (drm-backport-placeholder)
- commit 84cffe4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/misc-mei-client.c-fix-problem-of-return-EOVERFLOW-in.patch (drm-backport-placeholder)
- commit 3f3392b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/misc-mei-client.c-return-negative-error-code-in-mei_.patch (drm-backport-placeholder)
- commit a775b23
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1943-mei-pxp-fix-mei_pxp_send_message-return-value.patch (drm-backport-placeholder)
- commit b6eaf15
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-exynos-fix-a-wrong-error-checking.patch (drm-backport-placeholder)
- commit 4d9c616
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-exynos-fix-a-potential-error-pointer-dereference.patch (drm-backport-placeholder)
- commit be632f6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1940-drm-amdgpu-fix-buffer-funcs-setting-order-on-suspend.patch (drm-backport-placeholder)
- commit ba734e1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1939-drm-amdgpu-Avoid-querying-DRM-MGCG-status.patch (drm-backport-placeholder)
- commit 3ddc882
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1938-drm-amdgpu-Update-HDP-4.4.2-clock-gating-flags.patch (drm-backport-placeholder)
- commit a2c43ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Add-NULL-checks-for-function-pointers.patch (drm-backport-placeholder)
- commit 62fb1cd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1936-drm-amdgpu-Restrict-extended-wait-to-PSP-v13.0.6.patch (drm-backport-placeholder)
- commit 1b8ceee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Increase-frame-warning-limit-with-KA.patch (drm-backport-placeholder)
- commit 9e23557
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1934-drm-amdgpu-optimize-the-printing-order-of-error-data.patch (drm-backport-placeholder)
- commit de78a22
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1933-drm-amdgpu-Update-fw-version-for-boot-time-error-que.patch (drm-backport-placeholder)
- commit 92ab7a3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1932-drm-amd-pm-support-new-mca-smu-error-code-decoding.patch (drm-backport-placeholder)
- commit adfc710
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1931-drm-amd-swsmu-update-smu-v14_0_0-driver-if-version-a.patch (drm-backport-placeholder)
- commit 3c40690
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1930-drm-amd-display-Fix-array-index-out-of-bounds-in-dml.patch (drm-backport-placeholder)
- commit 9868c4f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-monitor-patch-for-specific-eDP.patch (drm-backport-placeholder)
- commit f436375
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1928-drm-amd-display-Use-channel_width-2-for-vram-table-3.patch (drm-backport-placeholder)
- commit 034dfe3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-disable-MCBP-by-default.patch (drm-backport-placeholder)
- commit 2f56b6c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-atomic-helpers-Invoke-end_fb_access-while-owning.patch (drm-backport-placeholder)
- commit 8973743
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-select-CONFIG_VIDEOMODE_HELPERS.patch (drm-backport-placeholder)
- commit 4e89604
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1924-drm-panfrost-Fix-incorrect-updating-of-current-devic.patch (drm-backport-placeholder)
- commit 7495e56
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1923-drm-panfrost-Consider-dma-buf-imported-objects-as-re.patch (drm-backport-placeholder)
- commit a9e6316
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-tu102-flush-all-pdbs-on-vmm-flush.patch (drm-backport-placeholder)
- commit d6799f8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1921-nouveau-gsp-document-some-aspects-of-GSP-RM.patch (drm-backport-placeholder)
- commit a7f5ada
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1920-drm-i915-correct-the-input-parameter-on-_intel_dsb_c.patch (drm-backport-placeholder)
- commit a2c95e4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mst-Reject-modes-that-require-the-bigjoiner.patch (drm-backport-placeholder)
- commit bae7236
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mst-Fix-.mode_valid_ctx-return-values.patch (drm-backport-placeholder)
- commit 9f294ee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Skip-some-timing-checks-on-BXT-GLK-DSI-tran.patch (drm-backport-placeholder)
- commit 1975ac0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1916-drm-i915-Check-pipe-active-state-in-planes-vrr-_-ena.patch (drm-backport-placeholder)
- commit a0da7bd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-prime-Unexport-helpers-for-fd-handle-conv.patch (drm-backport-placeholder)
- commit 2775d36
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Use-another-offset-for-GC-9.4.3-remap.patch (drm-backport-placeholder)
- commit bbbb7f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1913-drm-amd-display-Fix-some-HostVM-parameters-in-DML.patch (drm-backport-placeholder)
- commit 49e6ee9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Free-gang_ctx_bo-and-wptr_bo-in-pqm_unini.patch (drm-backport-placeholder)
- commit edb096f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Update-EEPROM-I2C-address-for-smu-v13_0_0.patch (drm-backport-placeholder)
- commit f7e088c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1910-drm-amd-display-Allow-DTBCLK-disable-for-DCN35.patch (drm-backport-placeholder)
- commit 3f53a4f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-cat-debugfs-amdgpu_regs_didt-causes-k.patch (drm-backport-placeholder)
- commit 695a07f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Enable-PCIe-PME-from-D3.patch (drm-backport-placeholder)
- commit f23e479
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-fix-a-memleak-in-aldebaran_tables_init.patch (drm-backport-placeholder)
- commit 5c1737d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1906-drm-amdgpu-fix-AGP-addressing-when-GART-is-not-at-0.patch (drm-backport-placeholder)
- commit 3d9aa7c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-update-dcn315-lpddr-pstate-latency.patch (drm-backport-placeholder)
- commit f4d06e6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-ABM-disablement.patch (drm-backport-placeholder)
- commit 779d384
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1903-drm-amd-display-Fix-black-screen-on-video-playback-w.patch (drm-backport-placeholder)
- commit 2e69b66
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1902-drm-amd-display-Fix-conversions-between-bytes-and-KB.patch (drm-backport-placeholder)
- commit d933b58
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Use-common-function-for-IP-version-check.patch (drm-backport-placeholder)
- commit 39a55fc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1900-drm-amd-display-Remove-config-update.patch (drm-backport-placeholder)
- commit 80ced04
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1899-drm-amd-display-Update-DCN35-clock-table-policy.patch (drm-backport-placeholder)
- commit 8bb6df6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-force-toggle-rate-wa-for-first-link-.patch (drm-backport-placeholder)
- commit 9c25db8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-correct-the-amdgpu-runtime-dereference-us.patch (drm-backport-placeholder)
- commit 8238c8d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Update-min-Z8-residency-time-to-2100.patch (drm-backport-placeholder)
- commit 8e63ade
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Remove-min_dst_y_next_start-check-fo.patch (drm-backport-placeholder)
- commit 8f5e1db
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-memory-overflow-in-the-IB-test.patch (drm-backport-placeholder)
- commit 334bfd8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1893-drm-amdgpu-add-init_registers-for-nbio-v7.11.patch (drm-backport-placeholder)
- commit c952328
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Simplify-brightness-initialization.patch (drm-backport-placeholder)
- commit 96af62e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Increase-num-voltage-states-to-40.patch (drm-backport-placeholder)
- commit 495d9a8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1890-drm-amd-display-Do-not-read-DPREFCLK-spread-info-fro.patch (drm-backport-placeholder)
- commit 1eb760a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Use-DRAM-speed-from-validation-for-d.patch (drm-backport-placeholder)
- commit 877ca7d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1888-drm-amd-display-Fix-MPCC-1DLUT-programming.patch (drm-backport-placeholder)
- commit c9851af
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1887-drm-amd-display-Feed-SR-and-Z8-watermarks-into-DML2-.patch (drm-backport-placeholder)
- commit 6268a89
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Force-order-between-a-read-and-write-to-t.patch (drm-backport-placeholder)
- commit 0b33531
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Do-not-issue-gpu-reset-from-nbio-v7_9-bif.patch (drm-backport-placeholder)
- commit 1ca14e6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1884-drm-amd-display-Add-Z8-watermarks-for-DML2-bbox-over.patch (drm-backport-placeholder)
- commit 476fa70
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1883-drm-amdgpu-optimize-RLC-powerdown-notification-on-Va.patch (drm-backport-placeholder)
- commit 04067bd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1882-drm-amd-display-fix-a-pipe-mapping-error-in-dcn32_fp.patch (drm-backport-placeholder)
- commit d67259b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1881-drm-amd-display-Update-DCN35-watermarks.patch (drm-backport-placeholder)
- commit fc6c820
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1880-drm-amdgpu-update-xgmi-num-links-info-post-gc9.4.2.patch (drm-backport-placeholder)
- commit e899246
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1879-drm-amd-display-Add-z-state-support-policy-for-dcn35.patch (drm-backport-placeholder)
- commit a19782b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Include-udelay-when-waiting-for-INBO.patch (drm-backport-placeholder)
- commit c7081db
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-nt36523-fix-return-value-check-in-nt36523_.patch (drm-backport-placeholder)
- commit dc49d4f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-starry-2081101qfh032011-53g-Fine-tune-the-.patch (drm-backport-placeholder)
- commit bcbc778
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1875-nouveau-gsp-replace-zero-length-array-with-flex-arra.patch (drm-backport-placeholder)
- commit 827e9a8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1874-nouveau-gsp-r535-remove-a-stray-unlock-in-r535_gsp_r.patch (drm-backport-placeholder)
- commit 3b43cdd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-find-the-smallest-page-allocation-to-cover-a.patch (drm-backport-placeholder)
- commit e1e6f5f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1872-drm-gpuvm-Fix-deprecated-license-identifier.patch (drm-backport-placeholder)
- commit a478511
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1871-Revert-drm-bridge-panel-Add-a-device-link-between-dr.patch (drm-backport-placeholder)
- commit 20380e8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1870-Revert-drm-bridge-panel-Check-device-dependency-befo.patch (drm-backport-placeholder)
- commit 2c6000f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/dma-buf-fix-check-in-dma_resv_add_fence.patch (drm-backport-placeholder)
- commit 825d339
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1868-drm-bridge-panel-Check-device-dependency-before-mana.patch (drm-backport-placeholder)
- commit e6b776a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Call-intel_pre_plane_updates-also-for-pipes.patch (drm-backport-placeholder)
- commit 94a90ca
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Also-check-for-VGA-converter-in-eDP-probe.patch (drm-backport-placeholder)
- commit ad188f6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gsc-Mark-internal-GSC-engine-with-reserved-.patch (drm-backport-placeholder)
- commit 85de199
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-do-not-clean-GT-table-on-error-path.patch (drm-backport-placeholder)
- commit 2a25c29
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1863-drm-i915-dp_mst-Fix-race-between-connector-registrat.patch (drm-backport-placeholder)
- commit 19e62e3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1862-nouveau-gsp-allocate-enough-space-for-all-channel-id.patch (drm-backport-placeholder)
- commit f81f61a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-boe-tv101wum-nl6-Fine-tune-Himax83102-j02-.patch (drm-backport-placeholder)
- commit 2b26b72
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-ast-Disconnect-BMC-if-physical-connector-is-conn.patch (drm-backport-placeholder)
- commit 0eeff21
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/accel-ivpu-37xx-Fix-hangs-related-to-MMIO-reset.patch (drm-backport-placeholder).
- commit e5f8941
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop-Fix-color-for-RGB888-BGR888-format-.patch (drm-backport-placeholder)
- commit 0edaabe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-simple-Fix-Innolux-G101ICE-L01-timings.patch (drm-backport-placeholder)
- commit b7f852a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-simple-Fix-Innolux-G101ICE-L01-bus-flags.patch (drm-backport-placeholder)
- commit ae8025b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-auo-b101uan08.3-Fine-tune-the-panel-power-.patch (drm-backport-placeholder)
- commit 2b624f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1855-drm-msm-remove-unnecessary-NULL-check.patch (drm-backport-placeholder)
- commit 0f8cb0e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1854-drm-msm-dp-attach-the-DP-subconnector-property.patch (drm-backport-placeholder)
- commit 2d72070
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1853-drm-msm-dp-don-t-touch-DP-subconnector-property-in-e.patch (drm-backport-placeholder)
- commit 9c56d44
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Add-missing-safe_lut_tbl-in-sc8280xp-cat.patch (drm-backport-placeholder)
- commit 8a3ec85
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1851-drm-msm-remove-exra-drm_kms_helper_poll_init-call.patch (drm-backport-placeholder)
- commit 2b9a5be
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-use-the-correct-VREG_CTRL_1-value-for-4n.patch (drm-backport-placeholder)
- commit a1e39a7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1849-drm-amdgpu-gmc9-disable-AGP-aperture.patch (drm-backport-placeholder)
- commit b236fb6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1848-drm-amdgpu-gmc10-disable-AGP-aperture.patch (drm-backport-placeholder)
- commit 6906582
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1847-drm-amdgpu-gmc11-disable-AGP-aperture.patch (drm-backport-placeholder)
- commit e2da280
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1846-drm-amdgpu-add-a-module-parameter-to-control-the-AGP.patch (drm-backport-placeholder)
- commit 46a69ef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1845-drm-amdgpu-gmc11-fix-logic-typo-in-AGP-check.patch (drm-backport-placeholder)
- commit 0a6938a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1844-drm-amd-display-Fix-encoder-disable-logic.patch (drm-backport-placeholder)
- commit ec9af34
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Change-the-DMCUB-mailbox-memory-loca.patch (drm-backport-placeholder)
- commit 3569563
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1842-drm-amdgpu-add-and-populate-the-port-num-into-xgmi-t.patch (drm-backport-placeholder)
- commit 0b88d06
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1841-drm-amd-display-Negate-IPS-allow-and-commit-bits.patch (drm-backport-placeholder)
- commit 36533ca
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1840-drm-amd-pm-Don-t-send-unload-message-for-reset.patch (drm-backport-placeholder)
- commit f754848
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1839-drm-amdgpu-fix-ras-err_data-null-pointer-issue-in-am.patch (drm-backport-placeholder)
- commit 655814b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Clear-dpcd_sink_ext_caps-if-not-set.patch (drm-backport-placeholder)
- commit 290b38b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Enable-fast-plane-updates-on-DCN3.2-.patch (drm-backport-placeholder)
- commit 0a44dfc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1836-drm-amd-display-fix-NULL-dereference.patch (drm-backport-placeholder)
- commit f738845
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-a-NULL-pointer-dereference-in-am.patch (drm-backport-placeholder)
- commit 8e8dbaa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1834-drm-amd-display-Add-null-checks-for-8K60-lightup.patch (drm-backport-placeholder)
- commit e9c1f90
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1833-drm-amd-pm-Fill-pcie-error-counters-for-gpu-v1_4.patch (drm-backport-placeholder)
- commit 8adc5a2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1832-drm-amd-pm-Update-metric-table-for-smu-v13_0_6.patch (drm-backport-placeholder)
- commit 445cb91
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-correct-chunk_ptr-to-a-pointer-to-chunk.patch (drm-backport-placeholder)
- commit 2280cb9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-DSC-not-Enabled-on-Direct-MST-Si.patch (drm-backport-placeholder)
- commit 9728c8b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1829-drm-amdgpu-Address-member-ring-not-described-in-amdg.patch (drm-backport-placeholder)
- commit 38e755c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-finalizing-mem_partitions-at-the-end-of-G.patch (drm-backport-placeholder)
- commit 4b2caa6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Do-not-program-VF-copy-regs-in-mmhub-v1.8.patch (drm-backport-placeholder)
- commit ce71c73
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Guard-against-invalid-RPTR-WPTR-bein.patch (drm-backport-placeholder)
- commit 9d02494
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1825-nouveau-don-t-fail-driver-load-if-no-display-hw-pres.patch (drm-backport-placeholder)
- commit 40b7dfc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1824-drm-panel-orientation-quirks-Add-quirk-for-Lenovo-Le.patch (drm-backport-placeholder)
- commit 0590bdc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-use-an-rwlock-for-the-event-lock.patch (drm-backport-placeholder)
- commit 10da763
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1822-nouveau-gsp-r535-Fix-a-NULL-vs-error-pointer-bug.patch (drm-backport-placeholder)
- commit 8812e2e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1821-nouveau-gsp-r535-uninitialized-variable-in-r535_gsp_.patch (drm-backport-placeholder)
- commit 51124a0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1820-drm-ci-make-github-dependabot-happy-again.patch (drm-backport-placeholder)
- commit a463ff8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-fsl-diu-fb-mark-wr_reg_wa-static.patch (drm-backport-placeholder)
- commit 8f218a2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1818-fbdev-amifb-Convert-to-platform-remove-callback-retu.patch (drm-backport-placeholder)
- commit 3d6233e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1817-fbdev-amifb-Mark-driver-struct-with-__refdata-to-pre.patch (drm-backport-placeholder)
- commit eb65401
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1816-fbdev-hyperv_fb-fix-uninitialized-local-variable-use.patch (drm-backport-placeholder)
- commit 941dbb9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1815-fbdev-omapfb-tpd12s015-Convert-to-platform-remove-ca.patch (drm-backport-placeholder)
- commit 79965f5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1814-fbdev-omapfb-tfp410-Convert-to-platform-remove-callb.patch (drm-backport-placeholder)
- commit 67305e8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1813-fbdev-omapfb-sharp-ls037v7dw01-Convert-to-platform-r.patch (drm-backport-placeholder)
- commit 685f4b8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1812-fbdev-omapfb-opa362-Convert-to-platform-remove-callb.patch (drm-backport-placeholder)
- commit 671220e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1811-fbdev-omapfb-hdmi-Convert-to-platform-remove-callbac.patch (drm-backport-placeholder)
- commit b43ac6e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1810-fbdev-omapfb-dvi-Convert-to-platform-remove-callback.patch (drm-backport-placeholder)
- commit 531b41c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1809-fbdev-omapfb-dsi-cm-Convert-to-platform-remove-callb.patch (drm-backport-placeholder)
- commit 905fd04
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1808-fbdev-omapfb-dpi-Convert-to-platform-remove-callback.patch (drm-backport-placeholder)
- commit e816425
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1807-fbdev-omapfb-analog-tv-Convert-to-platform-remove-ca.patch (drm-backport-placeholder)
- commit e96b227
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1806-fbdev-atmel_lcdfb-Convert-to-platform-remove-callbac.patch (drm-backport-placeholder)
- commit a34ffa6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1805-fbdev-omapfb-tpd12s015-Don-t-put-.remove-in-.exit.te.patch (drm-backport-placeholder)
- commit 1adb5d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1804-fbdev-omapfb-tfp410-Don-t-put-.remove-in-.exit.text-.patch (drm-backport-placeholder)
- commit 3d2e4f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1803-fbdev-omapfb-sharp-ls037v7dw01-Don-t-put-.remove-in-.patch (drm-backport-placeholder)
- commit ae4087d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1802-fbdev-omapfb-opa362-Don-t-put-.remove-in-.exit.text-.patch (drm-backport-placeholder)
- commit 09fb84f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1801-fbdev-omapfb-hdmi-Don-t-put-.remove-in-.exit.text-an.patch (drm-backport-placeholder)
- commit 93a8c75
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1800-fbdev-omapfb-dvi-Don-t-put-.remove-in-.exit.text-and.patch (drm-backport-placeholder)
- commit 2af8b63
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1799-fbdev-omapfb-dsi-cm-Don-t-put-.remove-in-.exit.text-.patch (drm-backport-placeholder)
- commit 060155f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1798-fbdev-omapfb-dpi-Don-t-put-.remove-in-.exit.text-and.patch (drm-backport-placeholder)
- commit 873206a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1797-fbdev-omapfb-analog-tv-Don-t-put-.remove-in-.exit.te.patch (drm-backport-placeholder)
- commit 59794ef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1796-fbdev-atmel_lcdfb-Stop-using-platform_driver_probe.patch (drm-backport-placeholder)
- commit ab9fbc0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-imsttfb-fix-double-free-in-probe.patch (drm-backport-placeholder)
- commit d335c9b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1793-fbdev-viafb-use-new-array-copying-wrapper.patch (drm-backport-placeholder)
- commit 4e52886
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-omapfb-Drop-unused-remove-function.patch (drm-backport-placeholder)
- commit b0775f9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1791-fbdev-offb-Simplify-offb_init_fb.patch (drm-backport-placeholder)
- commit 4dd7487
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1790-fbdev-omapfb-Replace-custom-memparse-implementation.patch (drm-backport-placeholder)
- commit 2b4e7fb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1789-fbdev-omapfb-Do-not-shadow-error-code-from-platform_.patch (drm-backport-placeholder)
- commit 10a99a7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-error-handling-in-amdgpu_vm_init.patch (drm-backport-placeholder)
- commit 222e5f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-possible-null-pointer-dereference.patch (drm-backport-placeholder)
- commit 4d709ad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1786-drm-amdgpu-move-UVD-and-VCE-sched-entity-init-after-.patch (drm-backport-placeholder)
- commit e5ba288
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1785-drm-amdgpu-move-kfd_resume-before-the-ip-late-init.patch (drm-backport-placeholder)
- commit c090160
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1784-drm-amd-Explicitly-check-for-GFXOFF-to-be-enabled-fo.patch (drm-backport-placeholder)
- commit 45e1c29
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1783-drm-amdgpu-Change-WREG32_RLC-to-WREG32_SOC15_RLC-whe.patch (drm-backport-placeholder)
- commit 4010299
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1782-drm-amdgpu-Use-correct-KIQ-MEC-engine-for-gfx9.4.3-v.patch (drm-backport-placeholder)
- commit 331ff70
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1781-drm-amdgpu-add-smu-v13.0.6-pcs-xgmi-ras-error-query-.patch (drm-backport-placeholder)
- commit ecfed5c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-software-pci_unplug-on-some-chips.patch (drm-backport-placeholder)
- commit 7cf99b0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1779-drm-amd-display-remove-duplicated-argument.patch (drm-backport-placeholder)
- commit 22cc396
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1778-drm-amdgpu-correct-mca-debugfs-dump-reg-list.patch (drm-backport-placeholder)
- commit 07ca02e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1777-drm-amdgpu-correct-acclerator-check-architecutre-dum.patch (drm-backport-placeholder)
- commit 2bf473b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1776-drm-amdgpu-add-pcs-xgmi-v6.4.0-ras-support.patch (drm-backport-placeholder)
- commit 7f42e9a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1775-drm-amdgpu-Change-extended-scope-MTYPE-on-GC-9.4.3.patch (drm-backport-placeholder)
- commit 67754fd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1774-drm-amdgpu-disable-smu-v13.0.6-mca-debug-mode-by-def.patch (drm-backport-placeholder)
- commit 73d72e3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1773-drm-amdgpu-Support-multiple-error-query-modes.patch (drm-backport-placeholder)
- commit b3acd46
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1772-drm-amdgpu-refine-smu-v13.0.6-mca-dump-driver.patch (drm-backport-placeholder)
- commit 7a2f62b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1771-drm-amdgpu-Do-not-program-PF-only-regs-in-hdp_v4_0.c.patch (drm-backport-placeholder)
- commit d8ba6df
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1770-drm-amdgpu-Skip-PCTL0_MMHUB_DEEPSLEEP_IB-write-in-jp.patch (drm-backport-placeholder)
- commit 5411e38
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1769-drm-amd-Resolve-Sphinx-unexpected-indentation-warnin.patch (drm-backport-placeholder)
- commit 2894a83
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1768-drm-amdgpu-correct-smu-v13.0.6-umc-ras-error-check.patch (drm-backport-placeholder)
- commit b44b5e1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1767-drm-amdgpu-Add-xcc-param-to-SRIOV-kiq-write-and-WREG.patch (drm-backport-placeholder)
- commit c18b955
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1766-drm-amdgpu-Add-flag-to-enable-indirect-RLCG-access-f.patch (drm-backport-placeholder)
- commit 8bce7ba
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1765-drm-amd-pm-raise-the-deep-sleep-clock-threshold-for-.patch (drm-backport-placeholder)
- commit 98d96dd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1764-drm-amdgpu-correct-amdgpu-ip-block-rev-info.patch (drm-backport-placeholder)
- commit 6178d6f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1763-drm-amd-pm-Hide-pp_dpm_pcie-device-attribute.patch (drm-backport-placeholder)
- commit 46abdf7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1762-drm-amdgpu-Don-t-warn-for-unsupported-set_xgmi_plpd_.patch (drm-backport-placeholder)
- commit 95a07ae
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-lower-CS-errors-to-debug-severity.patch (drm-backport-placeholder)
- commit 938872a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-error-handling-in-amdgpu_bo_list_get.patch (drm-backport-placeholder)
- commit 4b8a9fb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1759-drm-amdgpu-fix-AGP-init-order.patch (drm-backport-placeholder)
- commit 410096a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1758-drm-amdgpu-add-RAS-reset-query-operations-for-XGMI-v.patch (drm-backport-placeholder)
- commit 5dc945d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1757-drm-amdgpu-handle-extra-UE-register-entries-for-gfx-.patch (drm-backport-placeholder)
- commit 86c43c8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1756-drm-amd-pm-not-stop-rlc-for-IMU-enabled-APUs-when-su.patch (drm-backport-placeholder)
- commit c13947b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1755-drm-amd-display-avoid-variable-reinitialization.patch (drm-backport-placeholder)
- commit b5b6ae4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1754-drm-amd-pm-Hide-irrelevant-pm-device-attributes.patch (drm-backport-placeholder)
- commit 77f70c5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1753-drm-amdgpu-Fix-sdma-4.4.2-doorbell-rptr-wptr-init.patch (drm-backport-placeholder)
- commit 547e377
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1752-drm-amdgpu-soc21-add-mode2-asic-reset-for-SMU-IP-v14.patch (drm-backport-placeholder)
- commit fb01dfb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1751-drm-amd-display-Set-stream-s-DP-test-pattern-upon-te.patch (drm-backport-placeholder)
- commit 5f79ee0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1750-drm-amd-display-Fix-handling-duplicate-planes-on-one.patch (drm-backport-placeholder)
- commit f91d387
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1749-drm-amd-display-For-cursor-P-State-allow-for-SubVP.patch (drm-backport-placeholder)
- commit 6f2efb2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1748-drm-amd-display-Enable-physymclk-RCO.patch (drm-backport-placeholder)
- commit 8ccea14
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1747-drm-amd-display-Remove-references-to-unused-dml-arch.patch (drm-backport-placeholder)
- commit cb8c1e9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1746-drm-amd-display-Promote-DAL-to-3.2.259.patch (drm-backport-placeholder)
- commit 25b9753
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1745-drm-amd-display-save-and-restore-mall-state-when-app.patch (drm-backport-placeholder)
- commit 7aa6005
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1744-drm-amd-display-Remove-unused-duplicate-register-def.patch (drm-backport-placeholder)
- commit 77526d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1743-drm-amd-display-Create-optc.h-file.patch (drm-backport-placeholder)
- commit 38795dc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1742-drm-amd-display-Disable-OTG-for-mode-timing-switch-o.patch (drm-backport-placeholder)
- commit e813c20
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1741-drm-amd-display-Revise-Replay-Desync-Error-IRQ-handl.patch (drm-backport-placeholder)
- commit f7e88fe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1740-drm-amd-display-FW-Promotion-Release-0.0.190.0.patch (drm-backport-placeholder)
- commit 5e66503
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1739-drm-amd-display-3.2.258.patch (drm-backport-placeholder)
- commit 03e68bf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1738-drm-amd-display-Add-missing-dml2-init-value-for-dcn3.patch (drm-backport-placeholder)
- commit 019ed03
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1737-drm-amd-display-Fix-OTG-disable-workaround-logic.patch (drm-backport-placeholder)
- commit a7f1be1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1736-drm-amd-display-amend-HPD-handler-for-Replay.patch (drm-backport-placeholder)
- commit 7722189
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1735-drm-amd-display-Introduce-flag-for-disabling-Replay-.patch (drm-backport-placeholder)
- commit fa78426
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1734-drm-amd-display-DCN35-Disable-cm-power-optimization.patch (drm-backport-placeholder)
- commit 549e986
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1733-drm-amd-display-Update-DP-HPO-MSA-with-colorimetry-f.patch (drm-backport-placeholder)
- commit d1e84ae
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1732-drm-amd-display-Update-test-link-rate-DPCD-bit-field.patch (drm-backport-placeholder)
- commit d929376
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1731-drm-amd-display-Allow-16-max_slices-for-DP2-DSC.patch (drm-backport-placeholder)
- commit afb4c9c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1730-drm-amd-display-Enable-more-IPS-options.patch (drm-backport-placeholder)
- commit 0eda1c7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1729-drm-amd-display-Enable-RCO-options-for-dcn35.patch (drm-backport-placeholder)
- commit af64d1d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1728-drm-amd-display-Fix-FRL-assertion-on-boot.patch (drm-backport-placeholder)
- commit c2a56db
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1727-drm-amd-display-Fix-missing-blendTF-programming.patch (drm-backport-placeholder)
- commit e891c26
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1726-drm-amd-display-3.2.257.patch (drm-backport-placeholder)
- commit 3fda35d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1725-drm-amd-display-decouple-dmcub-execution-to-reduce-l.patch (drm-backport-placeholder)
- commit 2d14274
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1724-drm-amd-display-FW-Promotion-Release-0.0.189.0.patch (drm-backport-placeholder)
- commit 0e81842
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1723-drm-amd-display-On-boot-disable-domain22-force-power.patch (drm-backport-placeholder)
- commit e85d154
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1722-drm-amd-Disable-XNACK-on-SRIOV-environment.patch (drm-backport-placeholder)
- commit 65ee264
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-qxl-prevent-memory-leak.patch (drm-backport-placeholder)
- commit 48a6aaf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-syncobj-fix-DRM_SYNCOBJ_WAIT_FLAGS_WAIT_AVAILABL.patch (drm-backport-placeholder)
- commit e825914
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-vc4-tests-Fix-UAF-in-the-mock-helpers.patch (drm-backport-placeholder)
- commit 0296503
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-tc-Fix-Wformat-truncation-in-intel_tc_port_.patch (drm-backport-placeholder)
- commit 0b36905
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-potential-spectre-vulnerability.patch (drm-backport-placeholder)
- commit 40ef414
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Bump-GLK-CDCLK-frequency-when-driving-multi.patch (drm-backport-placeholder)
- commit ccda583
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1715-drm-i915-mtl-Apply-notify_guc-to-all-GTs.patch (drm-backport-placeholder)
- commit 91fa30c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mtl-Support-HBR3-rate-with-C10-phy-and-eDP-.patch (drm-backport-placeholder)
- commit 634b2ff
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Flush-WC-GGTT-only-on-required-platforms.patch (drm-backport-placeholder)
- commit d3e2e4d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mtl-avoid-stringop-overflow-warning.patch (drm-backport-placeholder)
- commit 7604e0e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1710-drm-amd-display-Enable-fast-update-on-blendTF-change.patch (drm-backport-placeholder)
- commit 19a413a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1709-drm-amd-display-Fix-blend-LUT-programming.patch (drm-backport-placeholder)
- commit dc461d8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1708-drm-amd-display-Program-plane-color-setting-correctl.patch (drm-backport-placeholder)
- commit 1057157
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1707-drm-amdgpu-Query-and-report-boot-status.patch (drm-backport-placeholder)
- commit a22e214
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1706-drm-amdgpu-Add-psp-v13-function-to-query-boot-status.patch (drm-backport-placeholder)
- commit fa6c2ec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1705-drm-amd-swsmu-remove-fw-version-check-in-sw_init.patch (drm-backport-placeholder)
- commit 199afef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1704-drm-amd-swsmu-update-smu-v14_0_0-driver-if-and-metri.patch (drm-backport-placeholder)
- commit 5b0d61f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1703-drm-amdgpu-Add-C2PMSG_109-126-reg-field-shift-masks.patch (drm-backport-placeholder)
- commit eb0b46b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1702-drm-amdgpu-Optimize-the-asic-type-fix-code.patch (drm-backport-placeholder)
- commit 5cc59fd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-GRBM-read-timeout-when-do-mes_self_te.patch (drm-backport-placeholder)
- commit fb6c05d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1700-drm-amdgpu-check-recovery-status-of-xgmi-hive-in-ras.patch (drm-backport-placeholder)
- commit fdffdda
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1699-drm-amd-pm-only-check-sriov-vf-flag-once-when-creati.patch (drm-backport-placeholder)
- commit dad8673
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1698-drm-amdgpu-Attach-eviction-fence-on-alloc.patch (drm-backport-placeholder)
- commit 0f55aa7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1697-drm-amdkfd-Improve-amdgpu_vm_handle_moved.patch (drm-backport-placeholder)
- commit ec7f943
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1696-drm-amd-display-Increase-frame-warning-limit-with-KA.patch (drm-backport-placeholder)
- commit ef4f084
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1694-drm-amdkfd-Update-cache-info-for-GFX-9.4.3.patch (drm-backport-placeholder)
- commit 4b7c6fc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1693-drm-amdkfd-Populate-cache-info-for-GFX-9.4.3.patch (drm-backport-placeholder)
- commit 62b1d39
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1692-drm-amdgpu-don-t-put-MQDs-in-VRAM-on-ARM-ARM64.patch (drm-backport-placeholder)
- commit 5e1adca
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-smu13-drop-compute-workload-workaround.patch (drm-backport-placeholder)
- commit 19fff18
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-add-a-retry-for-IP-discovery-init.patch (drm-backport-placeholder)
- commit a05cd18
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1689-drm-amdgpu-ungate-power-gating-when-system-suspend.patch (drm-backport-placeholder)
- commit f6a2004
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1688-drm-radeon-replace-1-element-arrays-with-flexible-ar.patch (drm-backport-placeholder)
- commit b1de745
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1687-drm-amd-Fix-UBSAN-array-index-out-of-bounds-for-Powe.patch (drm-backport-placeholder)
- commit d10ecea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-don-t-use-pci_is_thunderbolt_attached.patch (drm-backport-placeholder)
- commit da76d90
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1685-drm-amdgpu-don-t-use-ATRM-for-external-devices.patch (drm-backport-placeholder)
- commit 64ff67c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-gfx10-11-use-memcpy_to-fromio-for-MQDs.patch (drm-backport-placeholder)
- commit e3cc200
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1683-drm-amdgpu-use-mode-2-reset-for-RAS-poison-consumpti.patch (drm-backport-placeholder)
- commit 784480f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1682-drm-amdgpu-doorbell-range-should-be-set-when-gpu-rec.patch (drm-backport-placeholder)
- commit 4977b2d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1681-drm-amd-pm-Return-0-as-default-min-power-limit-for-l.patch (drm-backport-placeholder)
- commit 4941763
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1680-drm-amdgpu-remove-unused-macro-HW_REV.patch (drm-backport-placeholder)
- commit 0f04de1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-Fix-error-of-MACO-flag-setting-code.patch (drm-backport-placeholder)
- commit 7845973
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1678-drm-amdgpu-Fix-the-vram-base-start-address.patch (drm-backport-placeholder)
- commit 94be1ac
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1677-drm-amdgpu-set-XGMI-IP-version-manually-for-v6_4.patch (drm-backport-placeholder)
- commit 473c65b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1676-drm-amdgpu-add-unmap-latency-when-gfx11-set-kiq-reso.patch (drm-backport-placeholder)
- commit 3aafe8e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1675-drm-amd-pm-fix-the-high-voltage-and-temperature-issu.patch (drm-backport-placeholder)
- commit 56c2996
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1674-drm-amdgpu-remove-amdgpu_mes_self_test-in-gpu-recove.patch (drm-backport-placeholder)
- commit 83f902b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1673-drm-amdgpu-Drop-deferred-error-in-uncorrectable-erro.patch (drm-backport-placeholder)
- commit be22722
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1672-drm-amd-pm-Fix-warnings.patch (drm-backport-placeholder)
- commit 1ffba89
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1671-drm-amdgpu-check-RAS-supported-first-in-ras_reset_er.patch (drm-backport-placeholder)
- commit 783f849
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1670-drm-ssd130x-Fix-possible-uninitialized-usage-of-crtc.patch (drm-backport-placeholder)
- commit 8aa31d3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1669-drm-renesas-shmobile-Add-DT-support.patch (drm-backport-placeholder)
- commit 9a7a97f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1668-drm-renesas-shmobile-Atomic-conversion-part-3.patch (drm-backport-placeholder)
- commit 3c7f343
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1667-drm-renesas-shmobile-Remove-internal-CRTC-state-trac.patch (drm-backport-placeholder)
- commit 75a0f77
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1666-drm-renesas-shmobile-Use-suspend-resume-helpers.patch (drm-backport-placeholder)
- commit 3a4d9f5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1665-drm-renesas-shmobile-Atomic-conversion-part-2.patch (drm-backport-placeholder)
- commit 47a88f8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1664-drm-renesas-shmobile-Atomic-conversion-part-1.patch (drm-backport-placeholder)
- commit 6d5224b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1663-drm-renesas-shmobile-Cleanup-encoder.patch (drm-backport-placeholder)
- commit 71cd164
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1662-drm-renesas-shmobile-Shutdown-the-display-on-remove.patch (drm-backport-placeholder)
- commit 4573217
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1661-drm-renesas-shmobile-Turn-vblank-on-off-when-enablin.patch (drm-backport-placeholder)
- commit 30c441d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1660-drm-renesas-shmobile-Wait-for-page-flip-when-turning.patch (drm-backport-placeholder)
- commit 7bd52dd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1659-drm-renesas-shmobile-Move-shmob_drm_crtc_finish_page.patch (drm-backport-placeholder)
- commit 5920440
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1658-drm-renesas-shmobile-Use-drm_crtc_handle_vblank.patch (drm-backport-placeholder)
- commit 1c71fa8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1657-drm-renesas-shmobile-Rename-shmob_drm_plane.plane.patch (drm-backport-placeholder)
- commit dd2a435
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1656-drm-renesas-shmobile-Rename-shmob_drm_connector.conn.patch (drm-backport-placeholder)
- commit 5196f45
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1655-drm-renesas-shmobile-Rename-shmob_drm_crtc.crtc.patch (drm-backport-placeholder)
- commit 7a8abcf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1654-drm-renesas-shmobile-Unify-plane-allocation.patch (drm-backport-placeholder)
- commit f9fae93
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1653-drm-renesas-shmobile-Move-interface-handling-to-conn.patch (drm-backport-placeholder)
- commit 6b3bf38
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1652-drm-renesas-shmobile-Use-media-bus-formats-in-platfo.patch (drm-backport-placeholder)
- commit ef816c4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1650-drm-renesas-shmobile-Use-struct-videomode-in-platfor.patch (drm-backport-placeholder)
- commit cf2a483
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1649-drm-renesas-shmobile-Replace-.dev_private-with-conta.patch (drm-backport-placeholder)
- commit b33cdec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1648-drm-renesas-shmobile-Convert-container-helpers-to-st.patch (drm-backport-placeholder)
- commit a5ecc4e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1647-drm-renesas-shmobile-Embed-drm_device-in-shmob_drm_d.patch (drm-backport-placeholder)
- commit 600b220
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1646-drm-renesas-shmobile-Use-drmm_universal_plane_alloc.patch (drm-backport-placeholder)
- commit 8fef2c6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1645-drm-renesas-shmobile-Remove-custom-plane-destroy-cal.patch (drm-backport-placeholder)
- commit f19dbfa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1644-drm-renesas-shmobile-Convert-to-use-devm_request_irq.patch (drm-backport-placeholder)
- commit 5fe0c37
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1643-drm-renesas-shmobile-Improve-error-handling.patch (drm-backport-placeholder)
- commit c4137f8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1642-drm-renesas-shmobile-Remove-support-for-SYS-panels.patch (drm-backport-placeholder)
- commit 30aaf69
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1641-drm-renesas-shmobile-Rename-input-clocks.patch (drm-backport-placeholder)
- commit 29fed93
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1640-drm-renesas-shmobile-Don-t-set-display-info-width-an.patch (drm-backport-placeholder)
- commit 5893e8c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1639-drm-renesas-shmobile-Remove-backlight-support.patch (drm-backport-placeholder)
- commit f517f6d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1638-drm-renesas-shmobile-Improve-shmob_drm_format_info-t.patch (drm-backport-placeholder)
- commit ad78ff4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1637-drm-renesas-shmobile-Add-missing-YCbCr-formats.patch (drm-backport-placeholder)
- commit 3b46706
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1636-drm-renesas-shmobile-Use-p4cc-to-print-fourcc-code.patch (drm-backport-placeholder)
- commit b0fdbdb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1635-drm-renesas-shmobile-Restore-indentation-of-shmob_dr.patch (drm-backport-placeholder)
- commit 39b0202
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1634-drm-renesas-shmobile-Add-support-for-Runtime-PM.patch (drm-backport-placeholder)
- commit 15ab280
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1633-drm-renesas-shmobile-Correct-encoder-connector-types.patch (drm-backport-placeholder)
- commit d47515e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1632-drm-renesas-shmobile-Fix-ARGB32-overlay-format-typo.patch (drm-backport-placeholder)
- commit 26f5c12
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1631-drm-renesas-shmobile-Fix-overlay-plane-disable.patch (drm-backport-placeholder)
- commit 49f05f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1630-nouveau-gsp-add-some-basic-registry-entries.patch (drm-backport-placeholder)
- commit f41b6cb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1629-nouveau-gsp-fix-message-signature.patch (drm-backport-placeholder)
- commit 0c66cc6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1628-nouveau-gsp-move-to-535.113.01.patch (drm-backport-placeholder)
- commit 852f38b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1627-nouveau-disp-fix-post-gsp-build-on-32-bit-arm.patch (drm-backport-placeholder)
- commit efb20fc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1626-nouveau-fix-r535-build-on-32-bit-arm.patch (drm-backport-placeholder)
- commit 00a6920
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1625-drm-nouveau-ofa-r535-initial-support.patch (drm-backport-placeholder)
- commit 5d1af5c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1624-drm-nouveau-nvjpg-r535-initial-support.patch (drm-backport-placeholder)
- commit d072793
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1623-drm-nouveau-nvenc-r535-initial-support.patch (drm-backport-placeholder)
- commit f24a1bf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1622-drm-nouveau-nvdec-r535-initial-support.patch (drm-backport-placeholder)
- commit e4d6b57
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1621-drm-nouveau-gr-r535-initial-support.patch (drm-backport-placeholder)
- commit d397dc0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1620-drm-nouveau-ce-r535-initial-support.patch (drm-backport-placeholder)
- commit fd2e0da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1619-drm-nouveau-fifo-r535-initial-support.patch (drm-backport-placeholder)
- commit 99cd131
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1618-drm-nouveau-disp-r535-initial-support.patch (drm-backport-placeholder)
- commit 0f7c6fa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1617-drm-nouveau-mmu-r535-initial-support.patch (drm-backport-placeholder)
- commit f150dfd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1616-drm-nouveau-gsp-r535-add-interrupt-handling.patch (drm-backport-placeholder)
- commit 27fd8be
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1615-drm-nouveau-gsp-r535-add-support-for-rm-alloc.patch (drm-backport-placeholder)
- commit ecb5384
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1614-drm-nouveau-gsp-r535-add-support-for-rm-control.patch (drm-backport-placeholder)
- commit 0622a75
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1613-drm-nouveau-gsp-r535-add-support-for-booting-GSP-RM.patch (drm-backport-placeholder)
- commit 18147be
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1612-drm-nouveau-nvkm-support-loading-fws-into-sg_table.patch (drm-backport-placeholder)
- commit e1299b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1611-drm-nouveau-kms-tu102-disable-vbios-parsing-when-run.patch (drm-backport-placeholder)
- commit fe4ef31
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1610-drm-nouveau-sec2-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 579b31d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1609-drm-nouveau-nvenc-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 2fa768c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1608-drm-nouveau-nvdec-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit cac7475
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1607-drm-nouveau-gr-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 5908821
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1606-drm-nouveau-fifo-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 913a2e2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1605-drm-nouveau-disp-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 82f355a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1604-drm-nouveau-ce-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 5467b14
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1603-drm-nouveau-vfn-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit c243306
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1602-drm-nouveau-top-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit c55cbb1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1601-drm-nouveau-therm-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit a197419
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1600-drm-nouveau-privring-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 4dc4441
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1599-drm-nouveau-pmu-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 98b89e3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1598-drm-nouveau-mmu-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 2e68a5a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1597-drm-nouveau-mc-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit dfff1b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1596-drm-nouveau-ltc-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 7cfa058
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1595-drm-nouveau-imem-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 19b8d9b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1594-drm-nouveau-i2c-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit b632ccd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1593-drm-nouveau-gpio-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 9e07f6d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1592-drm-nouveau-fuse-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 2b8f25a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1591-drm-nouveau-fb-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 4929c02
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1590-drm-nouveau-fault-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit faa56f9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1589-drm-nouveau-devinit-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit ee811c9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1588-drm-nouveau-bus-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit b6caecb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1587-drm-nouveau-bar-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 7aa78b9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1586-drm-nouveau-acr-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 2cbd4c4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1585-drm-nouveau-gsp-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit d5ecbec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1584-drm-nouveau-nvkm-bump-maximum-number-of-NVJPG.patch (drm-backport-placeholder)
- commit 022f1ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1583-drm-nouveau-nvkm-bump-maximum-number-of-NVDEC.patch (drm-backport-placeholder)
- commit 9f74378
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1582-drm-nouveau-mmu-tu102-remove-write-to-0x100e68-durin.patch (drm-backport-placeholder)
- commit 880fcf5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1581-hyperv-avoid-dependency-on-screen_info.patch (drm-backport-placeholder)
- commit 5618be9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/vga16fb-drop-powerpc-support.patch (drm-backport-placeholder)
- commit 3bdc63f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1579-vgacon-remove-screen_info-dependency.patch (drm-backport-placeholder)
- commit 44607c4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1578-dummycon-limit-Arm-console-size-hack-to-footbridge.patch (drm-backport-placeholder)
- commit b1cc365
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1577-vgacon-rework-Kconfig-dependencies.patch (drm-backport-placeholder)
- commit 55268c2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1576-mei-me-emit-error-only-if-reset-was-unexpected.patch (drm-backport-placeholder)
- commit 31caa68
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1575-misc-mei-main.c-fix-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit f3050a3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1574-misc-mei-interrupt.c-fix-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit 190c9dd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1573-misc-mei-hw-me.c-fix-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit 519087b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1572-misc-mei-hbm.c-fix-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit b6ab136
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1571-misc-mei-dma-ring.c-fix-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit e31c27c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1570-misc-mei-client.c-fix-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit 47d1e42
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1569-misc-mei-hw.h-fix-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit 5e3142b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1568-mei-docs-fix-spelling-errors.patch (drm-backport-placeholder)
- commit 3f908bc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1567-mei-docs-add-missing-entries-to-kdoc-in-struct-mei_c.patch (drm-backport-placeholder)
- commit 44ab196
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1566-mei-docs-use-correct-structures-name-in-kdoc.patch (drm-backport-placeholder)
- commit 579d6c9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1565-mei-update-mei-pxp-s-component-interface-with-timeou.patch (drm-backport-placeholder)
- commit ccf8888
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1564-mei-pxp-re-enable-client-on-errors.patch (drm-backport-placeholder)
- commit 3c2f6c9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1563-mei-pxp-recover-from-recv-fail-under-memory-pressure.patch (drm-backport-placeholder)
- commit 17316a5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1562-mei-bus-add-send-and-recv-api-with-timeout.patch (drm-backport-placeholder)
- commit 6810b7e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1561-mei-fix-doc-typos.patch (drm-backport-placeholder)
- commit 8c32a59
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/backlight-pwm_bl-Disable-PWM-on-shutdown-suspend-and.patch (drm-backport-placeholder)
- commit 0a01233
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1559-drm-qxl-Use-pci_is_vga-to-identify-VGA-devices.patch (drm-backport-placeholder)
- commit f3dc70d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1558-drm-virtio-Use-pci_is_vga-to-identify-VGA-devices.patch (drm-backport-placeholder)
- commit e1aaf16
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1557-drm-radeon-Use-pci_get_base_class-to-reduce-duplicat.patch (drm-backport-placeholder)
- commit 4bc990f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1556-drm-amdgpu-Use-pci_get_base_class-to-reduce-duplicat.patch (drm-backport-placeholder)
- commit a51462f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1555-drm-nouveau-Use-pci_get_base_class-to-reduce-duplica.patch (drm-backport-placeholder)
- commit 3d579cc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-stifb-Make-the-STI-next-font-pointer-a-32-bit-.patch (drm-backport-placeholder)
- commit b767d25
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Remove-unused-variables-from-amdgpu_show_.patch (drm-backport-placeholder)
- commit 641a080
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Remove-duplicate-fdinfo-fields.patch (drm-backport-placeholder)
- commit 87978a6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1549-drm-amd-amdgpu-avoid-to-disable-gfxhub-interrupt-whe.patch (drm-backport-placeholder)
- commit 5f54e16
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1548-drm-amdgpu-Add-EXT_COHERENT-support-for-APU-and-NUMA.patch (drm-backport-placeholder)
- commit 1da13cf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1547-drm-amdgpu-Retrieve-CE-count-from-ce_count_lo_chip-i.patch (drm-backport-placeholder)
- commit af4fa6d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1546-drm-amdgpu-Identify-data-parity-error-corrected-in-r.patch (drm-backport-placeholder)
- commit e148189
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1545-drm-amdgpu-Fix-typo-in-IP-discovery-parsing.patch (drm-backport-placeholder)
- commit 4e51867
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1544-drm-amd-display-fix-S-G-display-enablement.patch (drm-backport-placeholder)
- commit 21a252f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1543-drm-amdxcp-fix-amdxcp-unloads-incompletely.patch (drm-backport-placeholder)
- commit f923485
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1542-drm-amd-amdgpu-fix-the-GPU-power-print-error-in-pm-i.patch (drm-backport-placeholder)
- commit 545c72f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1541-drm-amdgpu-Use-pcie-domain-of-xcc-acpi-objects.patch (drm-backport-placeholder)
- commit 81b6fec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1539-drm-amdgpu-Add-a-read-to-GFX-v9.4.3-ring-test.patch (drm-backport-placeholder)
- commit 18483a3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1538-drm-amd-pm-call-smu_cmn_get_smc_version-in-is_mode1_.patch (drm-backport-placeholder)
- commit 7c966ea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1537-drm-amdgpu-get-RAS-poison-status-from-DF-v4_6_2.patch (drm-backport-placeholder)
- commit bead3e8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1536-drm-amdgpu-Use-discovery-table-s-subrevision.patch (drm-backport-placeholder)
- commit 7e8dac8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1535-drm-amd-display-3.2.256.patch (drm-backport-placeholder)
- commit e852dad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1534-drm-amd-display-add-interface-to-query-SubVP-status.patch (drm-backport-placeholder)
- commit 2646b1a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1533-drm-amd-display-Read-before-writing-Backlight-Mode-S.patch (drm-backport-placeholder)
- commit f87390e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1532-drm-amd-display-Disable-SYMCLK32_SE-RCO-on-DCN314.patch (drm-backport-placeholder)
- commit 9df826c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1531-drm-amd-display-Fix-shaper-using-bad-LUT-params.patch (drm-backport-placeholder)
- commit bc76ae4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1530-drm-amd-display-add-null-check-for-invalid-opps.patch (drm-backport-placeholder)
- commit e1ba9c8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1529-drm-amd-display-Update-FAMS-sequence-for-DCN30-DCN32.patch (drm-backport-placeholder)
- commit 090506f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1528-drm-amd-display-fix-num_ways-overflow-error.patch (drm-backport-placeholder)
- commit 7f6bc3c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1527-drm-amd-display-Add-prefix-for-plane-functions.patch (drm-backport-placeholder)
- commit 3dcddb9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1526-drm-amd-display-Add-prefix-to-amdgpu-crtc-functions.patch (drm-backport-placeholder)
- commit b0838a3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1525-drm-amd-display-Correct-enum-typo.patch (drm-backport-placeholder)
- commit 3817688
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1524-drm-amd-display-Set-emulated-sink-type-to-HDMI-accor.patch (drm-backport-placeholder)
- commit 43503cd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1523-drm-amd-display-Revert-drm-amd-display-allow-edp-upd.patch (drm-backport-placeholder)
- commit a929ee8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1522-drm-amd-display-Fix-HDMI-framepack-3D-test-issue.patch (drm-backport-placeholder)
- commit 189009e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1521-drm-amd-display-Fix-IPS-handshake-for-idle-optimizat.patch (drm-backport-placeholder)
- commit 518ff39
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1520-drm-amd-display-implement-map-dc-pipe-with-callback-.patch (drm-backport-placeholder)
- commit 95c91b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1519-drm-amd-display-add-pipe-resource-management-callbac.patch (drm-backport-placeholder)
- commit 303a98a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Reduce-default-backlight-min-from-5-.patch (drm-backport-placeholder)
- commit 8b5f6d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1517-drm-amd-display-Update-SDP-VSC-colorimetry-from-DP-t.patch (drm-backport-placeholder)
- commit d53ee0c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1516-drm-amd-display-Add-a-check-for-idle-power-optimizat.patch (drm-backport-placeholder)
- commit be52f5e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1515-drm-amd-display-Revert-Improve-x86-and-dmub-ips-hand.patch (drm-backport-placeholder)
- commit 982dee2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1514-drm-amd-display-Fix-MST-Multi-Stream-Not-Lighting-Up.patch (drm-backport-placeholder)
- commit 58daace
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1513-drm-amd-Explicitly-disable-ASPM-when-dynamic-switchi.patch (drm-backport-placeholder)
- commit aba4b47
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1512-drm-amd-Move-AMD_IS_APU-check-for-ASPM-into-top-leve.patch (drm-backport-placeholder)
- commit e9aa6e3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Disable-PP_PCIE_DPM_MASK-when-dynamic-speed-.patch (drm-backport-placeholder)
- commit 4314b20
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1510-Revert-drm-amdkfd-Use-partial-migrations-in-GPU-page.patch (drm-backport-placeholder)
- commit 2b04d66
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1509-Revert-drm-amdkfd-remove-unused-code.patch (drm-backport-placeholder)
- commit 6416146
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1508-drm-amd-display-Fix-copyright-notice-in-DC-code.patch (drm-backport-placeholder)
- commit dd415d0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1507-drm-amd-display-Fix-copyright-notice-in-DML2-code.patch (drm-backport-placeholder)
- commit 22210d4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1506-drm-amd-display-Add-missing-copyright-notice-in-DMUB.patch (drm-backport-placeholder)
- commit fb86f54
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1505-drm-amdgpu-remove-restriction-of-sriov-max_pfn-on-Ve.patch (drm-backport-placeholder)
- commit 133d9d9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1504-drm-amdkfd-Address-remap_list-not-described-in-svm_r.patch (drm-backport-placeholder)
- commit 53b1761
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-a-null-pointer-access-when-the-smc_rr.patch (drm-backport-placeholder)
- commit a3ca0b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1502-drm-amdgpu-bypass-RAS-error-reset-in-some-conditions.patch (drm-backport-placeholder)
- commit 56b946a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1501-drm-amdgpu-enable-RAS-poison-mode-for-APU.patch (drm-backport-placeholder)
- commit e1b3fdf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1500-drm-amdgpu-vpe-correct-queue-stop-programing.patch (drm-backport-placeholder)
- commit 2c3407f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1499-drm-amd-display-Fix-DMUB-errors-introduced-by-DML2.patch (drm-backport-placeholder)
- commit a982700
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Remove-power-sequencing-check.patch (drm-backport-placeholder)
- commit db18f04
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1497-drm-amd-display-Set-the-DML2-attribute-to-false-in-a.patch (drm-backport-placeholder)
- commit 644e21d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1496-drm-amd-pm-Fix-the-return-value-in-default-case.patch (drm-backport-placeholder)
- commit d4ff88b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1495-drm-amdgpu-Add-API-to-get-full-IP-version.patch (drm-backport-placeholder)
- commit 6740914
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1494-drm-amdgpu-add-tmz-support-for-GC-IP-v11.5.0.patch (drm-backport-placeholder)
- commit b244c18
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1493-drm-amd-pm-drop-unneeded-dpm-features-disablement-fo.patch (drm-backport-placeholder)
- commit 2a87a3e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1492-drm-amdgpu-modify-if-condition-in-nbio_v7_7.c.patch (drm-backport-placeholder)
- commit ed9b790
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Fix-shift-out-of-bounds-issue.patch (drm-backport-placeholder)
- commit 7440146
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1490-drm-amdgpu-refine-ras-error-kernel-log-print.patch (drm-backport-placeholder)
- commit b5c9108
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1489-drm-amdgpu-fix-find-ras-error-node-error.patch (drm-backport-placeholder)
- commit a7434e4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1488-drm-amd-display-reprogram-det-size-while-seamless-bo.patch (drm-backport-placeholder)
- commit 8108f3e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1487-drm-amd-pm-record-mca-debug-mode-in-RAS.patch (drm-backport-placeholder)
- commit b0d9eef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1486-drm-amdgpu-move-buffer-funcs-setting-up-a-level.patch (drm-backport-placeholder)
- commit 2844708
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1485-drm-sched-Convert-the-GPU-scheduler-to-variable-numb.patch (drm-backport-placeholder)
- commit d05a1eb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1484-drm-ci-docs-add-step-about-how-to-request-privileges.patch (drm-backport-placeholder)
- commit 6dd6c37
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1483-drm-ci-do-not-automatically-retry-on-error.patch (drm-backport-placeholder)
- commit 1886ed1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1482-drm-ci-export-kernel-config.patch (drm-backport-placeholder)
- commit ecbb0b6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1481-drm-ci-increase-i915-job-timeout-to-1h30m.patch (drm-backport-placeholder)
- commit 1135799
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1480-drm-ci-add-subset-1-gfx-to-LAVA_TAGS-and-adjust-shar.patch (drm-backport-placeholder)
- commit bb28334
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1478-drm-ci-uprev-IGT-and-make-sure-core_getversion-is-ru.patch (drm-backport-placeholder)
- commit 04ad731
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1477-drm-ci-add-helper-script-update-xfails.py.patch (drm-backport-placeholder)
- commit 6a88806
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1476-drm-ci-fix-DEBIAN_ARCH-and-get-amdgpu-probing.patch (drm-backport-placeholder)
- commit 330e597
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1475-drm-ci-uprev-mesa-version-fix-container-build-crosvm.patch (drm-backport-placeholder)
- commit aafd198
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1474-drm-ci-Enable-CONFIG_BACKLIGHT_CLASS_DEVICE.patch (drm-backport-placeholder)
- commit 3421df0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1473-drm-ci-force-enable-CONFIG_MSM_MMCC_8996-as-built-in.patch (drm-backport-placeholder)
- commit 7a2381e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1472-drm-ci-pick-up-external-fixes-from-the-merge-target-.patch (drm-backport-placeholder)
- commit d8f04b6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1471-drm-doc-ci-Require-more-context-for-flaky-tests.patch (drm-backport-placeholder)
- commit 75879db
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1470-drm-doc-document-DRM_IOCTL_MODE_CREATE_DUMB.patch (drm-backport-placeholder)
- commit e4bb7d2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1469-drm-rockchip-vop-Add-NV15-NV20-and-NV30-support.patch (drm-backport-placeholder)
- commit 346cf46
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1468-drm-fourcc-Add-NV20-and-NV30-YUV-formats.patch (drm-backport-placeholder)
- commit 06d0672
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1467-drm-rockchip-vop2-rename-window-formats-to-show-wind.patch (drm-backport-placeholder)
- commit a90a0e5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1466-drm-rockchip-vop2-Add-more-supported-10bit-formats.patch (drm-backport-placeholder)
- commit ab3a7ba
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop2-remove-the-unsupported-format-of-c.patch (drm-backport-placeholder)
- commit 71aae13
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1464-drm-rockchip-vop-fix-format-bpp-calculation.patch (drm-backport-placeholder)
- commit f964bfa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1463-drm-bridge-synopsys-dw-mipi-dsi-Fix-hcomponent-lbcc-.patch (drm-backport-placeholder)
- commit 67bd022
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1462-drm-client-Convert-drm_client_buffer_addfb-to-drm_mo.patch (drm-backport-placeholder)
- commit b525eef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1461-drm-doc-use-cross-references-for-macros.patch (drm-backport-placeholder)
- commit ebf8450
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-vc4-fix-typo.patch (drm-backport-placeholder)
- commit 60fa54f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1459-drm-panel-ili9882t-Avoid-blurred-screen-from-fast-sl.patch (drm-backport-placeholder)
- commit 8db1331
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1458-drm-panel-ili9882t-Break-out-as-separate-driver.patch (drm-backport-placeholder)
- commit adb4c13
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1457-drm-ast-Move-register-constants-to-ast_reg.h.patch (drm-backport-placeholder)
- commit 76303e1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1456-drm-ast-Rename-AST_IO_MISC_PORT_READ-to-AST_IO_VGAMR.patch (drm-backport-placeholder)
- commit 0442df5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1455-drm-ast-Rename-AST_IO_INPUT_STATUS1_READ-to-AST_IO_V.patch (drm-backport-placeholder)
- commit da7e737
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1454-drm-ast-Rename-AST_IO_CRTC_PORT-to-AST_IO_VGACRI.patch (drm-backport-placeholder)
- commit f0281c6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1453-drm-ast-Rename-AST_IO_GR_PORT-to-AST_IO_VGAGRI.patch (drm-backport-placeholder)
- commit 2603d37
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1452-drm-ast-Rename-AST_IO_DAC_DATA-to-AST_IO_VGAPDR.patch (drm-backport-placeholder)
- commit ca07bee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1451-drm-ast-Rename-AST_IO_DAC_INDEX_WRITE-to-AST_IO_VGAD.patch (drm-backport-placeholder)
- commit f1c0167
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1450-drm-ast-Rename-AST_IO_DAC_INDEX_READ-to-AST_IO_VGADR.patch (drm-backport-placeholder)
- commit 111abd3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1449-drm-ast-Rename-AST_IO_SEQ_PORT-to-AST_IO_VGASRI.patch (drm-backport-placeholder)
- commit 527fee9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1448-drm-ast-Rename-AST_IO_VGA_ENABLE_PORT-to-AST_IO_VGAE.patch (drm-backport-placeholder)
- commit 660f78b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1447-drm-ast-Rename-AST_IO_MISC_PORT_WRITE-to-AST_IO_VGAM.patch (drm-backport-placeholder)
- commit 6a8ab3e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1446-drm-ast-Rename-AST_IO_AR_PORT_WRITE-to-AST_IO_VGAARI.patch (drm-backport-placeholder)
- commit c2ab2ef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1445-fbdev-vt8623fb-Initialize-fb_ops-to-fbdev-I-O-memory.patch (drm-backport-placeholder)
- commit 0b033c2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1444-fbdev-viafb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 89adb0b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1443-fbdev-vga16fb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch (drm-backport-placeholder)
- commit 2b0b95d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1442-fbdev-vermilionfb-Initialize-fb_ops-to-fbdev-I-O-mem.patch (drm-backport-placeholder)
- commit 64524dc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1441-fbdev-tridentfb-Initialize-fb_ops-to-fbdev-I-O-memor.patch (drm-backport-placeholder)
- commit 10b60c5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1440-fbdev-tgafb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 41fd8ab
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1439-fbdev-tdfxfb-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch (drm-backport-placeholder)
- commit 1a51d67
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1438-fbdev-sunxvr500-Initialize-fb_ops-to-fbdev-I-O-memor.patch (drm-backport-placeholder)
- commit 13566ec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1437-fbdev-stifb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 941c9d3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1436-fbdev-sm712fb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch (drm-backport-placeholder)
- commit b07a5a0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1435-fbdev-sm501fb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch (drm-backport-placeholder)
- commit 348c203
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1434-fbdev-sisfb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 5fe470d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1433-fbdev-savagefb-Initialize-fb_ops-to-fbdev-I-O-memory.patch (drm-backport-placeholder)
- commit 7b93fa2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1432-fbdev-sa1100fb-Initialize-fb_ops-to-fbdev-I-O-memory.patch (drm-backport-placeholder)
- commit 89e208f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1431-fbdev-s3fb-Initialize-fb_ops-to-fbdev-I-O-memory-hel.patch (drm-backport-placeholder)
- commit 7105b32
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1430-fbdev-s1d13xxxfb-Initialize-fb_ops-to-fbdev-I-O-memo.patch (drm-backport-placeholder)
- commit 16b5203
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1429-fbdev-rivafb-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch (drm-backport-placeholder)
- commit d785625
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1428-fbdev-radeon-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch (drm-backport-placeholder)
- commit da2971c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1427-fbdev-pvr2fb-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch (drm-backport-placeholder)
- commit ec872f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1426-fbdev-pm3fb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit c7d7763
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1425-fbdev-pm2fb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 9c650db
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1424-fbdev-omapfb-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch (drm-backport-placeholder)
- commit 95cd010
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1423-fbdev-nvidiafb-Initialize-fb_ops-to-fbdev-I-O-memory.patch (drm-backport-placeholder)
- commit 61a4ccc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1422-fbdev-neofb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit ce437b0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1421-fbdev-matroxfb-Initialize-fb_ops-to-fbdev-I-O-memory.patch (drm-backport-placeholder)
- commit 2ec3193
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1420-fbdev-intelfb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch (drm-backport-placeholder)
- commit 4e075d2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1419-fbdev-imsttfb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch (drm-backport-placeholder)
- commit 7850876
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1418-fbdev-i810fb-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch (drm-backport-placeholder)
- commit 5360c4a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1417-fbdev-hpfb-Initialize-fb_ops-to-fbdev-I-O-memory-hel.patch (drm-backport-placeholder)
- commit 328b12d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1416-fbdev-hitfb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 624b2e0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1415-fbdev-hgafb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit dfccfa4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1414-fbdev-gbefb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 3827800
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1413-fbdev-ep93xx-fb-Initialize-fb_ops-to-fbdev-I-O-memor.patch (drm-backport-placeholder)
- commit 123bf75
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1412-fbdev-dnfb-Initialize-fb_ops-to-fbdev-I-O-memory-hel.patch (drm-backport-placeholder)
- commit 8604436
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1411-fbdev-cyber2000fb-Initialize-fb_ops-to-fbdev-I-O-mem.patch (drm-backport-placeholder)
- commit b1bfe78
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1410-fbdev-controlfb-Initialize-fb_ops-to-fbdev-I-O-memor.patch (drm-backport-placeholder)
- commit e9547cd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1409-fbdev-cobalt-lcd-Initialize-fb_ops-to-fbdev-I-O-memo.patch (drm-backport-placeholder)
- commit e14036b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1408-fbdev-cirrusfb-Initialize-fb_ops-to-fbdev-I-O-memory.patch (drm-backport-placeholder)
- commit b27df38
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1407-fbdev-au1100fb-Initialize-fb_ops-to-fbdev-I-O-memory.patch (drm-backport-placeholder)
- commit 4acf2b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1406-fbdev-atyfb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 416e368
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1405-fbdev-atafb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 016700d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1404-fbdev-arkfb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit eedf32c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1403-fbdev-amifb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit b300ff6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1402-fbdev-amba-clcd-Initialize-fb_ops-to-fbdev-I-O-memor.patch (drm-backport-placeholder)
- commit 3d3cf02
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1401-fbdev-68328fb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch (drm-backport-placeholder)
- commit f8d530a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1400-fbdev-Provide-I-O-memory-helpers-as-module.patch (drm-backport-placeholder)
- commit 0d6c505
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1399-drm-ssd130x-Add-support-for-the-SSD132x-OLED-control.patch (drm-backport-placeholder)
- commit 106c45d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1398-drm-ssd130x-Rename-commands-that-are-shared-across-c.patch (drm-backport-placeholder)
- commit f77b00e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1397-drm-ssd130x-Add-a-controller-family-id-to-the-device.patch (drm-backport-placeholder)
- commit 03783ee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1396-drm-ssd130x-Replace-.page_height-field-in-device-inf.patch (drm-backport-placeholder)
- commit ec836df
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1395-drm-gpuvm-Dual-licence-the-drm_gpuvm-code-GPL-2.0-OR.patch (drm-backport-placeholder)
- commit e1e8e62
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1394-Documentation-gpu-Add-a-VM_BIND-async-document.patch (drm-backport-placeholder)
- commit 7dfacea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1393-drm-panel-st7703-Add-Powkiddy-RGB30-Panel-Support.patch (drm-backport-placeholder)
- commit 2c177af
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1392-drm-rockchip-remove-NR_LAYERS-macro-on-vop2.patch (drm-backport-placeholder)
- commit 637131c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-remove-unused-struct-in-vop2.patch (drm-backport-placeholder)
- commit 04b1815
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-Fix-type-promotion-bug-in-rockchip_gem_.patch (drm-backport-placeholder)
- commit 60202b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-lt9611uxc-fix-the-race-in-the-error-path.patch (drm-backport-placeholder)
- commit eb86635
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1388-drm-bridge-imx-Add-i.MX93-MIPI-DSI-support.patch (drm-backport-placeholder)
- commit de2c0b8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1387-drm-bridge-synopsys-dw-mipi-dsi-Disable-HSTX-and-LPR.patch (drm-backport-placeholder)
- commit f660d5f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1386-drm-bridge-synopsys-dw-mipi-dsi-Set-minimum-lane-byt.patch (drm-backport-placeholder)
- commit ac32254
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1385-drm-bridge-synopsys-dw-mipi-dsi-Use-pixel-clock-rate.patch (drm-backport-placeholder)
- commit e3a79fa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1384-drm-bridge-synopsys-dw-mipi-dsi-Add-mode-fixup-suppo.patch (drm-backport-placeholder)
- commit 7512a0d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1383-drm-bridge-synopsys-dw-mipi-dsi-Force-input-bus-flag.patch (drm-backport-placeholder)
- commit 0ea487c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1382-drm-bridge-synopsys-dw-mipi-dsi-Add-input-bus-format.patch (drm-backport-placeholder)
- commit 87eb65d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1381-drm-bridge-synopsys-dw-mipi-dsi-Add-dw_mipi_dsi_get_.patch (drm-backport-placeholder)
- commit 589f7f4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1380-drm-adv7511-Add-hpd_override_enable-variable-to-stru.patch (drm-backport-placeholder)
- commit f4615d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1379-drm-adv7511-Add-link_config-variable-to-struct-adv75.patch (drm-backport-placeholder)
- commit 292afbe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1378-drm-adv7511-Add-has_dsi-variable-to-struct-adv7511_c.patch (drm-backport-placeholder)
- commit d3c9e9e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1377-drm-adv7511-Add-reg_cec_offset-variable-to-struct-ad.patch (drm-backport-placeholder)
- commit 7178fdc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1376-drm-adv7511-Add-supply_names-and-num_supplies-variab.patch (drm-backport-placeholder)
- commit 214fa8e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1375-drm-adv7511-Add-max_lane_freq_khz-variable-to-struct.patch (drm-backport-placeholder)
- commit 5ee1fdd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1374-drm-adv7511-Add-max_mode_clock_khz-variable-to-struc.patch (drm-backport-placeholder)
- commit b80a170
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1373-drm-adv7511-Add-struct-adv7511_chip_info-and-use-i2c.patch (drm-backport-placeholder)
- commit 911498d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1371-drm-panel-st7703-Fix-timings-when-entering-exiting-s.patch (drm-backport-placeholder)
- commit 515cb79
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-st7703-Pick-different-reset-sequence.patch (drm-backport-placeholder)
- commit c508fbb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1369-drm-ssd130x-Fix-atomic_check-for-disabled-planes.patch (drm-backport-placeholder)
- commit c67ea32
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1368-drm-bridge-megachips-stdpxxxx-ge-b850v3-fw-switch-to.patch (drm-backport-placeholder)
- commit 43564d9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1367-drm-amd-display-Fix-stack-size-issue-on-DML2.patch (drm-backport-placeholder)
- commit ec05d62
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1366-drm-amd-display-Reduce-stack-size-by-splitting-funct.patch (drm-backport-placeholder)
- commit da42a98
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1365-drm-amdkfd-remap-unaligned-svm-ranges-that-have-spli.patch (drm-backport-placeholder)
- commit 6787855
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1364-drm-amdgpu-Create-version-number-for-coredumps.patch (drm-backport-placeholder)
- commit 4c350ad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1363-drm-amdgpu-Move-coredump-code-to-amdgpu_reset-file.patch (drm-backport-placeholder)
- commit 65b496a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1362-drm-amdgpu-Encapsulate-all-device-reset-info.patch (drm-backport-placeholder)
- commit 8da3021
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1361-drm-amdgpu-support-the-port-num-info-based-on-the-ca.patch (drm-backport-placeholder)
- commit ac7f640
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1360-drm-amdgpu-prepare-the-output-buffer-for-GET_PEER_LI.patch (drm-backport-placeholder)
- commit e691c7e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1359-drm-amdgpu-drop-status-query-reset-for-GCEA-9.4.3-an.patch (drm-backport-placeholder)
- commit b8e7080
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1358-drm-amdgpu-update-the-xgmi-ta-interface-header.patch (drm-backport-placeholder)
- commit 6975620
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1357-drm-amdgpu-add-set-get-mca-debug-mode-operations.patch (drm-backport-placeholder)
- commit d09b1e0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1356-drm-amdgpu-replace-reset_error_count-with-amdgpu_ras.patch (drm-backport-placeholder)
- commit c700be0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1355-drm-amdgpu-add-clockgating-support-for-NBIO-v7.7.1.patch (drm-backport-placeholder)
- commit c8d1c3a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1354-drm-amdgpu-fix-missing-stuff-in-NBIO-v7.11.patch (drm-backport-placeholder)
- commit 8201f8d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1353-drm-amdgpu-Enable-RAS-feature-by-default-for-APU.patch (drm-backport-placeholder)
- commit 2b52433
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1352-drm-amdgpu-fix-typo-for-amdgpu-ras-error-data-print.patch (drm-backport-placeholder)
- commit f702602
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1351-drm-amd-amdgpu-vcn-Add-RB-decouple-feature-under-SRI.patch (drm-backport-placeholder)
- commit c0bb87a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1350-drm-amd-amdgpu-vcn-Add-RB-decouple-feature-under-SRI.patch (drm-backport-placeholder)
- commit 7eac718
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1349-drm-amd-amdgpu-vcn-Add-RB-decouple-feature-under-SRI.patch (drm-backport-placeholder)
- commit 40fa6f3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1348-drm-amd-amdgpu-vcn-Add-RB-decouple-feature-under-SRI.patch (drm-backport-placeholder)
- commit d649d28
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1347-drm-amdgpu-Fix-delete-nodes-that-have-been-relesed.patch (drm-backport-placeholder)
- commit 0100dd3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1346-drm-amdgpu-Enable-mca-debug-mode-mode-when-ras-enabl.patch (drm-backport-placeholder)
- commit 8317d45
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1345-drm-amdgpu-Add-UVD_VCPU_INT_EN2-to-dpg-sram.patch (drm-backport-placeholder)
- commit fbcc67a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1344-drm-amd-display-Respect-CONFIG_FRAME_WARN-0-in-DML2.patch (drm-backport-placeholder)
- commit 39f464e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1343-drm-amd-display-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 88c1251
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1342-drm-amd-display-Simplify-bool-conversion.patch (drm-backport-placeholder)
- commit 5eb799f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1341-drm-amd-display-Remove-unneeded-semicolon.patch (drm-backport-placeholder)
- commit afdc70a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1340-drm-amd-display-Remove-duplicated-include-in-dce110_.patch (drm-backport-placeholder)
- commit ace3762
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1339-drm-amd-display-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 9e12d01
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-Handle-non-terminated-overdrive-commands.patch (drm-backport-placeholder)
- commit 9cca535
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1337-drm-amdgpu-Enable-software-RAS-in-vcn-v4_0_3.patch (drm-backport-placeholder)
- commit ccf16d8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1336-drm-amdgpu-define-ras_reset_error_count-function.patch (drm-backport-placeholder)
- commit 0962246
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1335-drm-amdkfd-remove-unused-code.patch (drm-backport-placeholder)
- commit 52e5d7f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1334-drm-amd-pm-Support-for-getting-power1_cap_min-value.patch (drm-backport-placeholder)
- commit c3b2da2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1333-drm-amdgpu-Log-UE-corrected-by-replay-as-correctable.patch (drm-backport-placeholder)
- commit eee37a3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1332-drm-amdgpu-Workaround-to-skip-kiq-ring-test-during-r.patch (drm-backport-placeholder)
- commit 614c575
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1331-drm-amd-display-Fix-a-handful-of-spelling-mistakes-i.patch (drm-backport-placeholder)
- commit 5716322
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1330-drm-amdkfd-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 6c43d37
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1329-drm-amd-display-Remove-brackets-in-macro-to-conform-.patch (drm-backport-placeholder)
- commit 777818a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1328-drm-amd-Read-IMU-FW-version-from-scratch-register-du.patch (drm-backport-placeholder)
- commit 9030781
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1327-drm-amd-Don-t-parse-IMU-ucode-version-if-it-won-t-be.patch (drm-backport-placeholder)
- commit 8a16877
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1326-drm-amd-Move-microcode-init-step-to-early_init.patch (drm-backport-placeholder)
- commit 0a71826
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-update-retry-times-for-psp-BL-wait.patch (drm-backport-placeholder)
- commit 37423d3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1324-drm-amd-Add-missing-kernel-doc-for-prepare_suspend.patch (drm-backport-placeholder)
- commit 48a9fcc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1323-drm-amdgpu-update-to-the-latest-GC-11.5-headers.patch (drm-backport-placeholder)
- commit 558b9d7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-Fix-a-memory-leak-on-an-error-path.patch (drm-backport-placeholder)
- commit 481af1a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1321-drm-amdgpu-mes11-remove-aggregated-doorbell-code.patch (drm-backport-placeholder)
- commit e9251ec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1320-drm-amdgpu-Add-hive-ras-recovery-check.patch (drm-backport-placeholder)
- commit 86e29ea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1319-drm-amd-display-Add-missing-lines-of-code-in-dc.c.patch (drm-backport-placeholder)
- commit d6cd7c8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amdgpu-Program-xcp_ctl-registers-as-neede.patch (drm-backport-placeholder)
- commit 4c15a00
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1317-drm-amdgpu-umsch-add-suspend-and-resume-callback.patch (drm-backport-placeholder)
- commit 3aaa1f4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1316-drm-amdgpu-pm-update-SMU-13.0.0-PMFW-version-check.patch (drm-backport-placeholder)
- commit 8ef115f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx_surface.c-copy-user-array-safely.patch (drm-backport-placeholder)
- commit 644ee87
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm_lease.c-copy-user-array-safely.patch (drm-backport-placeholder)
- commit bf80560
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1312-drm-msm-a7xx-actually-use-a7xx-state-registers.patch (drm-backport-placeholder)
- commit 9eed746
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1311-drm-msm-dpu-enable-writeback-on-SM8550.patch (drm-backport-placeholder)
- commit a7dc4ee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1310-drm-msm-dpu-sm8550-remove-unused-VIG-and-DMA-clock-c.patch (drm-backport-placeholder)
- commit e8ddd23
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1309-drm-msm-dpu-move-setup_force_clk_ctrl-handling-into-.patch (drm-backport-placeholder)
- commit d283a6f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1308-drm-msm-dpu-add-setup_clk_force_ctrl-op-to-sspp-wb.patch (drm-backport-placeholder)
- commit 8260504
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1307-drm-msm-dpu-create-a-dpu_hw_clk_force_ctrl-helper.patch (drm-backport-placeholder)
- commit 8139e6d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1306-drm-msm-a6xx-Fix-up-QMP-handling.patch (drm-backport-placeholder)
- commit 62bf62c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-free-TX-buffer-in-unbind.patch (drm-backport-placeholder)
- commit 3e8f61e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-use-msm_gem_kernel_put-to-free-TX-buffer.patch (drm-backport-placeholder)
- commit 3db8800
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1303-drm-msm-dp-use-correct-lifetime-device-for-devm_drm_.patch (drm-backport-placeholder)
- commit 5e00220
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1302-drm-msm-hdmi-use-correct-lifetime-device-for-devm_dr.patch (drm-backport-placeholder)
- commit b05e8cf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1301-drm-msm-dsi-use-correct-lifetime-device-for-devm_drm.patch (drm-backport-placeholder)
- commit bf44fe7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1300-drm-msm-fix-fault-injection-support.patch (drm-backport-placeholder)
- commit 1ed03c9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1299-drm-msm-carve-out-KMS-code-from-msm_drv.c.patch (drm-backport-placeholder)
- commit 1aa3d26
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1298-drm-msm-make-fb-debugfs-file-available-only-in-KMS-c.patch (drm-backport-placeholder)
- commit 1e553a3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1297-drm-msm-only-register-kms-debug-file-if-KMS-is-used.patch (drm-backport-placeholder)
- commit 564caa0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1296-drm-msm-switch-to-drmm_mode_config_init.patch (drm-backport-placeholder)
- commit 00da7c2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1295-drm-msm-rename-msm_drv_shutdown-to-msm_kms_shutdown.patch (drm-backport-placeholder)
- commit f37c308
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1294-drm-msm-remove-shutdown-callback-from-msm_platform_d.patch (drm-backport-placeholder)
- commit dcd45f1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1293-drm-msm-rename-msm_pm_prepare-complete-to-note-the-K.patch (drm-backport-placeholder)
- commit 2379b42
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1292-drm-msm-drop-pm-ops-from-the-headless-msm-driver.patch (drm-backport-placeholder)
- commit 4310440
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1291-drm-msm-remove-msm_drm_private-bridges-field.patch (drm-backport-placeholder)
- commit 4a8978f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1290-drm-msm-dp-switch-to-devm_drm_bridge_add.patch (drm-backport-placeholder)
- commit e6f030d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1289-drm-msm-dp-move-pdev-from-struct-dp_display_private-.patch (drm-backport-placeholder)
- commit 9957934
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1288-drm-msm-hdmi-switch-to-devm_drm_bridge_add.patch (drm-backport-placeholder)
- commit 6fac89e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1287-drm-msm-dsi-switch-to-devm_drm_bridge_add.patch (drm-backport-placeholder)
- commit cafc005
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1286-drm-msm-mdp5-move-resource-allocation-to-the-_probe-.patch (drm-backport-placeholder)
- commit 2d42f5c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1285-drm-msm-mdp4-move-resource-allocation-to-the-_probe-.patch (drm-backport-placeholder)
- commit 218c1f4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1284-drm-msm-dpu-move-resource-allocation-to-the-_probe-f.patch (drm-backport-placeholder)
- commit a65d2ca
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1283-drm-msm-allow-passing-struct-msm_kms-to-msm_drv_prob.patch (drm-backport-placeholder)
- commit 2749351
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1282-drm-msm-adreno-Add-A635-speedbin-0xac-A643.patch (drm-backport-placeholder)
- commit 25dbf48
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1281-drm-msm-adreno-Add-ZAP-firmware-name-to-A635.patch (drm-backport-placeholder)
- commit 5c23b2b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a6xx-Fix-unknown-speedbin-case.patch (drm-backport-placeholder)
- commit c731449
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-adreno-Fix-SM6375-GPU-ID.patch (drm-backport-placeholder)
- commit 4422ce4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1278-drm-msm-a6xx-Poll-for-GBIF-unhalt-status-in-hw_init.patch (drm-backport-placeholder)
- commit ec2aec2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1277-drm-msm-a6xx-Add-A740-support.patch (drm-backport-placeholder)
- commit 8c6ec49
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1276-drm-msm-a6xx-Add-A730-support.patch (drm-backport-placeholder)
- commit 5a81b9f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1275-drm-msm-a6xx-Mostly-implement-A7xx-gpu_state.patch (drm-backport-placeholder)
- commit ad64dd7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1274-drm-msm-a6xx-Send-ACD-state-to-QMP-at-GMU-resume.patch (drm-backport-placeholder)
- commit 84fdaa1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1273-drm-msm-a6xx-Add-skeleton-A7xx-support.patch (drm-backport-placeholder)
- commit d91b2c3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1272-drm-msm-a6xx-Add-missing-regs-for-A7XX.patch (drm-backport-placeholder)
- commit 4cfb592
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1271-drm-msm-dp-support-setting-the-DP-subconnector-type.patch (drm-backport-placeholder)
- commit f2e2e2c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1270-drm-msm-dp-Remove-error-message-when-downstream-port.patch (drm-backport-placeholder)
- commit fc9f106
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1269-drm-msm-dp-Inline-dp_display_is_sink_count_zero.patch (drm-backport-placeholder)
- commit a3b8396
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1268-drm-msm-dpu-move-INTF-tearing-checks-to-dpu_encoder_.patch (drm-backport-placeholder)
- commit 4f9665b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1267-drm-msm-dpu-drop-useless-check-from-dpu_encoder_phys.patch (drm-backport-placeholder)
- commit 4d5f92c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1266-drm-msm-dpu-drop-DPU_INTF_TE-feature-flag.patch (drm-backport-placeholder)
- commit 0a3873d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1265-drm-msm-dpu-enable-INTF-TE-operations-only-when-supp.patch (drm-backport-placeholder)
- commit 71978ef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1264-drm-msm-dpu-inline-_setup_intf_ops.patch (drm-backport-placeholder)
- commit 95621d1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1263-drm-msm-dpu-drop-the-DPU_PINGPONG_TE-flag.patch (drm-backport-placeholder)
- commit aeba5b7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1262-drm-msm-dpu-enable-PINGPONG-TE-operations-only-when-.patch (drm-backport-placeholder)
- commit 27a3965
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1261-drm-msm-dpu-inline-_setup_pingpong_ops.patch (drm-backport-placeholder)
- commit 3a7281d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dp-skip-validity-check-for-DP-CTS-EDID-check.patch (drm-backport-placeholder)
- commit 251cdad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1259-drm-msm-dp-Remove-dp_display_is_ds_bridge.patch (drm-backport-placeholder)
- commit 8815ef2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1258-drm-msm-dp-Inline-dp_link_parse_sink_count.patch (drm-backport-placeholder)
- commit e736a50
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1257-drm-msm-dp-Simplify-with-drm_dp_-max_link_rate-max_l.patch (drm-backport-placeholder)
- commit 3e32ac3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1256-drm-msm-dp-Remove-aux_cfg_update_done-and-related-co.patch (drm-backport-placeholder)
- commit 12d6e6d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1255-drm-msm-dp-Remove-dead-code-related-to-downstream-ca.patch (drm-backport-placeholder)
- commit e8f58d9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1254-drm-msm-dp-Use-drm_dp_read_sink_count-helper.patch (drm-backport-placeholder)
- commit 8afda81
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1253-drm-msm-dp-Replace-open-coded-drm_dp_read_dpcd_caps.patch (drm-backport-placeholder)
- commit d470d2e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1252-drm-msm-dsi-Enable-widebus-for-DSI.patch (drm-backport-placeholder)
- commit c58796e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1251-drm-msm-dsi-Add-DATABUS_WIDEN-MDP_CTRL2-bit.patch (drm-backport-placeholder)
- commit c618f24
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1250-drm-msm-dpu-Enable-widebus-for-DSI-INTF.patch (drm-backport-placeholder)
- commit dacaab5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1249-drm-msm-dpu-Move-setting-of-dpu_enc-wide_bus_en-to-a.patch (drm-backport-placeholder)
- commit 9c97da6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1248-drm-msm-Remove-unnecessary-NULL-values.patch (drm-backport-placeholder)
- commit c3a4d2f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1247-drm-msm-dpu-shift-IRQ-indices-by-1.patch (drm-backport-placeholder)
- commit 6c98f07
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1246-drm-msm-dpu-stop-using-raw-IRQ-indices-in-the-kernel.patch (drm-backport-placeholder)
- commit 6fe6d10
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1245-drm-msm-dpu-stop-using-raw-IRQ-indices-in-the-kernel.patch (drm-backport-placeholder)
- commit 147ee30
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1244-drm-msm-dpu-make-the-irq-table-size-static.patch (drm-backport-placeholder)
- commit 8c99e6c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1243-drm-msm-dpu-add-helper-to-get-IRQ-related-data.patch (drm-backport-placeholder)
- commit d6045d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1242-drm-msm-dpu-extract-dpu_core_irq_is_valid-helper.patch (drm-backport-placeholder)
- commit 0ac9aa2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1241-drm-msm-dpu-remove-irq_idx-argument-from-IRQ-callbac.patch (drm-backport-placeholder)
- commit c2b8941
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-mtk_dsi-Fix-NO_EOT_PACKET-settings-hand.patch (drm-backport-placeholder)
- commit aae14b1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1239-drm-mediatek-aal-Compress-of_device_id-entries-and-a.patch (drm-backport-placeholder)
- commit fa6cd0e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1238-drm-mediatek-gamma-Add-kerneldoc-for-struct-mtk_disp.patch (drm-backport-placeholder)
- commit c3b9c8d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1237-drm-mediatek-aal-Add-kerneldoc-for-struct-mtk_disp_a.patch (drm-backport-placeholder)
- commit fe502a3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1236-drm-mediatek-gamma-Program-gamma-LUT-type-for-descen.patch (drm-backport-placeholder)
- commit 5f0b13d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1235-drm-mediatek-gamma-Make-sure-relay-mode-is-disabled.patch (drm-backport-placeholder)
- commit 0efdd7e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1234-drm-mediatek-gamma-Add-support-for-MT8195.patch (drm-backport-placeholder)
- commit 2a92992
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1233-drm-mediatek-gamma-Add-support-for-12-bit-LUT.patch (drm-backport-placeholder)
- commit 5aa3308
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1232-drm-mediatek-gamma-Support-multi-bank-gamma-LUT.patch (drm-backport-placeholder)
- commit 472121e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1231-drm-mediatek-De-commonize-disp_aal-disp_gamma-gamma_.patch (drm-backport-placeholder)
- commit 6b2cc2e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1230-drm-mediatek-aal-Use-bitfield-macros.patch (drm-backport-placeholder)
- commit 3922b22
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1229-drm-mediatek-gamma-Use-bitfield-macros.patch (drm-backport-placeholder)
- commit 8a2d31a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1228-drm-mediatek-gamma-Enable-the-Gamma-LUT-table-only-a.patch (drm-backport-placeholder)
- commit 3e03527
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1227-drm-mediatek-gamma-Improve-and-simplify-HW-LUT-calcu.patch (drm-backport-placeholder)
- commit a65aa50
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1226-drm-mediatek-gamma-Support-SoC-specific-LUT-size.patch (drm-backport-placeholder)
- commit a7ecee9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1225-drm-mediatek-gamma-Reduce-indentation-in-mtk_gamma_s.patch (drm-backport-placeholder)
- commit 2093c6f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1224-drm-mediatek-gamma-Adjust-mtk_drm_gamma_set_common-p.patch (drm-backport-placeholder)
- commit bbd10ff
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-iommu-fault-during-crtc-enabling.patch (drm-backport-placeholder)
- commit 76b0e57
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-iommu-fault-by-swapping-FBs-after-u.patch (drm-backport-placeholder)
- commit 8e2949b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1221-drm-mediatek-Support-dynamic-selection-of-MT8188-VDO.patch (drm-backport-placeholder)
- commit eb8fe77
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1220-drm-mediatek-dsi-Support-dynamic-connector-selection.patch (drm-backport-placeholder)
- commit a8b44cb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1219-drm-mediatek-dpi-Support-dynamic-connector-selection.patch (drm-backport-placeholder)
- commit a3a0e55
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1218-drm-mediatek-Add-connector-dynamic-selection-capabil.patch (drm-backport-placeholder)
- commit fb9db48
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1217-drm-mediatek-Add-encoder_index-interface-for-mtk_ddp.patch (drm-backport-placeholder)
- commit 302f238
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-using-wrong-drm-private-data-to-bin.patch (drm-backport-placeholder)
- commit 7a00e6b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Add-crtc-path-enum-for-all_drm_priv-arr.patch (drm-backport-placeholder)
- commit e326afb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Add-mmsys_dev_num-to-mt8188-vdosys0-dri.patch (drm-backport-placeholder)
- commit 42e6ba3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1213-drm-mediatek-dsi-Add-mode_valid-callback-to-DSI-brid.patch (drm-backport-placeholder)
- commit 7628001
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-dp-fix-memory-leak-on-get_edid-callback-fcaf976.patch (drm-backport-placeholder)
- commit a61deda
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-dp-fix-memory-leak-on-get_edid-callback.patch (drm-backport-placeholder)
- commit ae4beae
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1210-drm-mediatek-dp-Add-support-MT8188-dp-edp-function.patch (drm-backport-placeholder)
- commit 451fa4e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1209-drm-mediatek-dp-Add-the-audio-divider-to-mtk_dp_data.patch (drm-backport-placeholder)
- commit 02a7c40
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1208-drm-mediatek-dp-Add-the-audio-packet-flag-to-mtk_dp_.patch (drm-backport-placeholder)
- commit 93d1c24
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-coverity-issue-with-unintentional-i.patch (drm-backport-placeholder)
- commit a48b99b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1206-drm-mediatek-Add-mt8188-dsi-compatible-to-mtk_dsi.c.patch (drm-backport-placeholder)
- commit 3e9f104
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1205-drm-mediatek-dsi-Add-dsi-cmdq_ctl-to-send-panel-init.patch (drm-backport-placeholder)
- commit 7b12c18
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1204-drm-i915-mtl-Don-t-set-PIPE_CONTROL_FLUSH_L3.patch (drm-backport-placeholder)
- commit 48fcf70
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1203-drm-i915-Prevent-potential-null-ptr-deref-in-engine_.patch (drm-backport-placeholder)
- commit 8f36aaf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1202-drm-i915-Enable-GuC-TLB-invalidations-for-MTL.patch (drm-backport-placeholder)
- commit 5cad52d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1201-drm-i915-gt-Increase-sleep-in-gt_tlb-selftest-sanity.patch (drm-backport-placeholder)
- commit a1ed873
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1200-drm-i915-No-TLB-invalidation-on-wedged-GT.patch (drm-backport-placeholder)
- commit cc8001b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1199-drm-i915-No-TLB-invalidation-on-suspended-GT.patch (drm-backport-placeholder)
- commit 02808c7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1198-drm-i915-Define-and-use-GuC-and-CTB-TLB-invalidation.patch (drm-backport-placeholder)
- commit c929c0c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1197-drm-i915-guc-Add-CT-size-delay-helper.patch (drm-backport-placeholder)
- commit b962c9a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1196-drm-i915-Add-GuC-TLB-Invalidation-device-info-flags.patch (drm-backport-placeholder)
- commit 45e119c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1195-drm-i915-pxp-Clean-up-zero-initializers.patch (drm-backport-placeholder)
- commit cb2aa09
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1194-drm-i915-guc-Clean-up-zero-initializers.patch (drm-backport-placeholder)
- commit da7c996
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1193-drm-i915-mtl-Remove-the-force_probe-requirement-for-.patch (drm-backport-placeholder)
- commit 640d531
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1192-drm-i915-pci-Clean-up-zero-initializers.patch (drm-backport-placeholder)
- commit ba7bc84
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1191-drm-i915-hdcp-Clean-up-zero-initializers.patch (drm-backport-placeholder)
- commit 8cd499f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1190-drm-i915-display-Clean-up-zero-initializers.patch (drm-backport-placeholder)
- commit 1bfe05b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1189-drm-i915-dp-Remove-unused-DSC-caps-from-intel_dp.patch (drm-backport-placeholder)
- commit a1790d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1188-drm-i915-dp_mst-Use-connector-DSC-DPCD-in-intel_dp_m.patch (drm-backport-placeholder)
- commit 7b8e6da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1187-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_c.patch (drm-backport-placeholder)
- commit ffa8347
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1186-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_mode_.patch (drm-backport-placeholder)
- commit b5086f4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1185-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_g.patch (drm-backport-placeholder)
- commit b565727
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1184-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_s.patch (drm-backport-placeholder)
- commit 6d769a4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1183-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_c.patch (drm-backport-placeholder)
- commit a1dc6b3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1182-drm-i915-dp-Pass-only-the-required-DSC-DPCD-to-intel.patch (drm-backport-placeholder)
- commit 9d9c62f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1181-drm-i915-dp-Pass-only-the-required-i915-to-intel_dp_.patch (drm-backport-placeholder)
- commit 4e48fbd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1180-drm-i915-dp-Pass-connector-DSC-DPCD-to-drm_dp_dsc_si.patch (drm-backport-placeholder)
- commit 8fb8b08
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1179-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_m.patch (drm-backport-placeholder)
- commit eaea88a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1178-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_suppo.patch (drm-backport-placeholder)
- commit 9c87b9f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1177-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_suppo.patch (drm-backport-placeholder)
- commit 2f2b015
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1176-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_c.patch (drm-backport-placeholder)
- commit 4fb6240
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1175-drm-i915-dp-Use-connector-DSC-DPCD-in-i915_dsc_fec_s.patch (drm-backport-placeholder)
- commit 5f0d4e7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1174-drm-i915-dp-Use-i915-intel-connector-local-variables.patch (drm-backport-placeholder)
- commit df8e9b7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1173-drm-i915-dp_mst-Set-connector-DSC-capabilities-and-d.patch (drm-backport-placeholder)
- commit ad3da54
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1172-drm-i915-dp-Store-DSC-DPCD-capabilities-in-the-conne.patch (drm-backport-placeholder)
- commit c023bae
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1171-drm-i915-dp-Sanitize-DPCD-revision-check-in-intel_dp.patch (drm-backport-placeholder)
- commit f9871c9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1170-drm-i915-dsb-Re-instate-DSB-for-LUT-updates.patch (drm-backport-placeholder)
- commit 3369e1e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1169-drm-i915-dsb-Correct-DSB-command-buffer-cache-cohere.patch (drm-backport-placeholder)
- commit 5b1f059
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1168-drm-i915-dsb-Allocate-command-buffer-from-local-memo.patch (drm-backport-placeholder)
- commit 98018e0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1167-drm-i915-lnl-Remove-watchdog-timers-for-PSR.patch (drm-backport-placeholder)
- commit b3ab97a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1166-drm-i915-Add-new-DG2-PCI-IDs.patch (drm-backport-placeholder)
- commit cd40680
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1164-drm-amd-swsmu-update-smu-v14_0_0-header-files-and-me.patch (drm-backport-placeholder)
- commit 3a5c238
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1163-drm-amdgpu-add-RAS-error-info-support-for-umc_v12_0.patch (drm-backport-placeholder)
- commit 477d878
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1162-drm-amdgpu-add-RAS-error-info-support-for-mmhub_v1_8.patch (drm-backport-placeholder)
- commit 4ce035f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1161-drm-amdgpu-add-RAS-error-info-support-for-gfx_v9_4_3.patch (drm-backport-placeholder)
- commit 2e1cb63
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1160-drm-amdgpu-add-RAS-error-info-support-for-sdma_v4_4_.patch (drm-backport-placeholder)
- commit abbaf06
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1159-drm-amdgpu-add-ras_err_info-to-identify-RAS-error-so.patch (drm-backport-placeholder)
- commit 2f16b00
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1158-drm-amdgpu-flush-the-correct-vmid-tlb-for-specific-p.patch (drm-backport-placeholder)
- commit f438d48
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1157-drm-amdgpu-make-err_data-structure-built-in-for-ras_.patch (drm-backport-placeholder)
- commit 092f7e0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1156-drm-amdgpu-disable-GFXOFF-and-PG-during-compute-for-.patch (drm-backport-placeholder)
- commit 60615a7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1155-drm-amdgpu-umsch-fix-missing-stuff-during-rebase.patch (drm-backport-placeholder)
- commit d270d7f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1154-drm-amdgpu-umsch-correct-IP-version-format.patch (drm-backport-placeholder)
- commit 64b23fc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1153-drm-amdgpu-don-t-use-legacy-invalidation-on-MMHUB-v3.patch (drm-backport-placeholder)
- commit e26f3b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1152-drm-amdgpu-correct-NBIO-v7.11-programing.patch (drm-backport-placeholder)
- commit 53c43fd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-fix-a-possible-null-pointer-dereference.patch (drm-backport-placeholder)
- commit 3c9a582
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1150-drm-amdgpu-Correctly-use-bo_va-ref_count-in-compute-.patch (drm-backport-placeholder)
- commit 6a5d5a6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1149-drm-amd-pm-Add-P2S-tables-for-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit a7e0065
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1148-drm-amdgpu-Add-support-to-load-P2S-tables.patch (drm-backport-placeholder)
- commit 7a68229
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1147-drm-amdgpu-Update-PSP-interface-header.patch (drm-backport-placeholder)
- commit a9421dc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1146-drm-amdgpu-Avoid-FRU-EEPROM-access-on-APU.patch (drm-backport-placeholder)
- commit 499ab59
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1145-drm-amdgpu-save-VCN-instances-init-info-before-jpeg-.patch (drm-backport-placeholder)
- commit 5131deb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1144-Revert-drm-amd-display-Skip-entire-amdgpu_dm-build-i.patch (drm-backport-placeholder)
- commit d12257f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1143-Revert-drm-amd-display-Create-one-virtual-connector-.patch (drm-backport-placeholder)
- commit 9a534ed
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1142-Revert-drm-amd-display-Disable-virtual-links.patch (drm-backport-placeholder)
- commit 2a3f7f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1141-Revert-drm-amd-display-Initialize-writeback-connecto.patch (drm-backport-placeholder)
- commit 4fe1bde
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1140-Revert-drm-amd-display-Skip-writeback-connector-when.patch (drm-backport-placeholder)
- commit 651849b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1139-Revert-drm-amd-display-Return-drm_connector-from-fin.patch (drm-backport-placeholder)
- commit 69596da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1138-Revert-drm-amd-display-Use-drm_connector-in-create_s.patch (drm-backport-placeholder)
- commit f1d3d36
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1137-drm-amd-pm-drop-most-smu_cmn_get_smc_version-in-smu.patch (drm-backport-placeholder)
- commit de89cdf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1136-drm-amd-pm-Add-reset-option-for-fan_ctrl-on-smu-13.0.patch (drm-backport-placeholder)
- commit d3f1361
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1135-drm-amd-pm-Add-reset-option-for-fan_ctrl-interfaces.patch (drm-backport-placeholder)
- commit 6afc55d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1134-Revert-drm-amd-display-Create-amdgpu_dm_wb_connector.patch (drm-backport-placeholder)
- commit 0f71bad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1133-Revert-drm-amd-display-Create-fake-sink-and-stream-f.patch (drm-backport-placeholder)
- commit b527831
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1132-Revert-drm-amd-display-Hande-writeback-request-from-.patch (drm-backport-placeholder)
- commit f84d2d3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1131-Revert-drm-amd-display-Add-writeback-enable-disable-.patch (drm-backport-placeholder)
- commit d9425f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1130-Revert-drm-amd-display-Fix-writeback_info-never-got-.patch (drm-backport-placeholder)
- commit aa02757
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1129-Revert-drm-amd-display-Validate-hw_points_num-before.patch (drm-backport-placeholder)
- commit 1cba33e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1128-Revert-drm-amd-display-Fix-writeback_info-is-not-rem.patch (drm-backport-placeholder)
- commit 106299b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1127-Revert-drm-amd-display-Add-writeback-enable-field-wb.patch (drm-backport-placeholder)
- commit e33c069
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1126-Revert-drm-amd-display-Setup-for-mmhubbub3_warmup_mc.patch (drm-backport-placeholder)
- commit e5dad02
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1125-Revert-drm-amd-display-Add-new-set_fc_enable-to-stru.patch (drm-backport-placeholder)
- commit 6079a29
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1124-Revert-drm-amd-display-Disable-DWB-frame-capture-to-.patch (drm-backport-placeholder)
- commit 1a95460
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1123-drm-amd-display-Revert-drm-amd-display-Use-drm_conne.patch (drm-backport-placeholder)
- commit 8aeceea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1122-drm-amdgpu-Expose-ras-version-schema-info.patch (drm-backport-placeholder)
- commit b9b5ab8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1121-drm-amdgpu-Read-PSPv13-OS-version-from-register.patch (drm-backport-placeholder)
- commit ef1a9da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1120-drm-amd-display-add-missing-NULL-check-for-DML2.patch (drm-backport-placeholder)
- commit 59342fd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1119-drm-amdgpu-umsch-enable-doorbell-for-umsch.patch (drm-backport-placeholder)
- commit c08e96f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1118-drm-amd-display-make-dc_set_power_state-return-type-.patch (drm-backport-placeholder)
- commit 456e22f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1117-drm-amd-display-Destroy-DC-context-while-keeping-DML.patch (drm-backport-placeholder)
- commit efa9eaa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1116-drm-amd-display-Catch-errors-from-drm_atomic_helper_.patch (drm-backport-placeholder)
- commit 550eb5f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1115-drm-amd-Split-up-UVD-suspend-into-prepare-and-suspen.patch (drm-backport-placeholder)
- commit 7414227
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1114-drm-amd-Add-concept-of-running-prepare_suspend-seque.patch (drm-backport-placeholder)
- commit 9e17ca3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1113-drm-amd-Evict-resources-during-PM-ops-prepare-callba.patch (drm-backport-placeholder)
- commit 583eaf7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1112-drm-amdgpu-enable-GFX-IP-v11.5.0-CG-and-PG-support.patch (drm-backport-placeholder)
- commit 43fe8a6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1111-drm-amdgpu-add-support-to-power-up-down-UMSCH-by-SMU.patch (drm-backport-placeholder)
- commit 993ea0d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1110-drm-amdgpu-add-power-up-down-UMSCH-ppt-callback.patch (drm-backport-placeholder)
- commit 23ad513
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1109-drm-amdgpu-add-support-to-powerup-VPE-by-SMU.patch (drm-backport-placeholder)
- commit 9665217
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1108-drm-amdgpu-discovery-add-SMU-14-support.patch (drm-backport-placeholder)
- commit ece703d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1107-drm-amd-swsmu-add-smu14-ip-support.patch (drm-backport-placeholder)
- commit 47fd328
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1106-drm-amd-swsmu-add-smu-v14_0_0-pmfw-if-file.patch (drm-backport-placeholder)
- commit 4da9220
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1105-drm-amd-swsmu-add-smu-v14_0_0-ppsmc-file.patch (drm-backport-placeholder)
- commit f41e781
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1104-drm-amdgpu-swsmu-add-smu-v14_0_0-driver-if-file.patch (drm-backport-placeholder)
- commit ff7ae8f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1103-drm-amdgpu-umsch-power-on-off-UMSCH-by-DLDO.patch (drm-backport-placeholder)
- commit a5a0b1d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1102-drm-amdgpu-umsch-fix-psp-frontdoor-loading.patch (drm-backport-placeholder)
- commit 478c074
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1101-drm-amdgpu-Increase-IP-discovery-region-size.patch (drm-backport-placeholder)
- commit 501fe09
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1100-drm-amd-pm-Use-gpu_metrics_v1_4-for-SMUv13.0.6.patch (drm-backport-placeholder)
- commit 12cc7b5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1099-drm-amd-pm-Add-gpu_metrics_v1_4.patch (drm-backport-placeholder)
- commit 9420a42
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1098-drm-amd-pm-Update-metric-table-for-smu-v13_0_6.patch (drm-backport-placeholder)
- commit cd6a712
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1097-drm-amdgpu-Return-EINVAL-when-MMSCH-init-status-inco.patch (drm-backport-placeholder)
- commit 01c1268
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1096-drm-amd-pm-wait-for-completion-of-the-EnableGfxImu-c.patch (drm-backport-placeholder)
- commit 9eeddcf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1095-drm-amdgpu-vpe-fix-insert_nop-ops.patch (drm-backport-placeholder)
- commit 8a6869c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1094-drm-amdgpu-Address-member-gart_placement-not-describ.patch (drm-backport-placeholder)
- commit 51e32c0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1093-drm-amdgpu-vpe-align-with-mcbp-changes.patch (drm-backport-placeholder)
- commit 20f27ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1092-drm-amdgpu-vpe-remove-IB-end-boundary-requirement.patch (drm-backport-placeholder)
- commit 892b694
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1091-drm-amdgpu-Improve-MES-responsiveness-during-oversub.patch (drm-backport-placeholder)
- commit 6bec14f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1090-drm-amdgpu-discovery-enable-DCN-3.5.0-support.patch (drm-backport-placeholder)
- commit 1747285
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-get-doorbell-s-absolute-offset-based-on-t.patch (drm-backport-placeholder)
- commit 6d0a40c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1088-drm-amd-display-3.2.255.patch (drm-backport-placeholder)
- commit 6b904e7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1087-drm-amd-display-Disable-virtual-links.patch (drm-backport-placeholder)
- commit 57753a4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1086-drm-amd-display-Disable-SubVP-if-test-pattern-is-ena.patch (drm-backport-placeholder)
- commit 2c3aed6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1085-drm-amd-display-Refactor-DPG-test-pattern-logic-for-.patch (drm-backport-placeholder)
- commit c16096a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1084-drm-amd-display-Don-t-set-dpms_off-for-seamless-boot.patch (drm-backport-placeholder)
- commit c408014
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1083-drm-amd-display-Refactor-HWSS-into-component-folder.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Delete patches.suse/drm-amd-display-Fix-DPSTREAM-CLK-on-and-off-sequence.patch.
- Delete patches.suse/drm-amd-display-Prevent-crash-when-disable-stream.patch.
- commit 4e9356d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1082-drm-amd-display-Revert-drm-amd-display-Add-a-check-f.patch (drm-backport-placeholder)
- commit da41ead
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1081-drm-amdgpu-add-hub-ctx_distance-in-setup_vmid_config.patch (drm-backport-placeholder)
- commit 8f17512
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Don-t-use-fsleep-for-PSR-exit-waits.patch (drm-backport-placeholder)
- commit 2f35b52
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1079-drm-amd-display-Update-cursor-limits-based-on-SW-cur.patch (drm-backport-placeholder)
- commit 11b5f16
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1078-drm-amd-display-Update-dml-ssb-from-pmfw-clock-table.patch (drm-backport-placeholder)
- commit bd5cd15
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1077-drm-amd-display-Update-stream-mask.patch (drm-backport-placeholder)
- commit c1c0325
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1076-drm-amd-display-Revert-drm-amd-display-remove-duplic.patch (drm-backport-placeholder)
- commit 9bf9ac5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1075-drm-amd-display-Modify-Vmin-default-value.patch (drm-backport-placeholder)
- commit f04f3d4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1074-drm-amd-display-Update-pmfw_driver_if-new-structure.patch (drm-backport-placeholder)
- commit bacd32d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1073-drm-amd-display-VSIF-v3-set-Max-Refresh-Rate.patch (drm-backport-placeholder)
- commit 400392b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1072-drm-amd-display-Modify-SMU-message-logs.patch (drm-backport-placeholder)
- commit 37aa8ea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1070-drm-amd-display-enable-S-G-display-for-for-recent-AP.patch (drm-backport-placeholder)
- commit df25c7e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1069-Documentation-amdgpu-Add-FRU-attribute-details.patch (drm-backport-placeholder)
- commit d5a943c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1068-drm-amdgpu-Add-more-FRU-field-information.patch (drm-backport-placeholder)
- commit 9081f30
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1067-drm-amdgpu-Refactor-FRU-product-information.patch (drm-backport-placeholder)
- commit 35d94bd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1066-drm-amdgpu-enable-FRU-device-for-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit 13dadc2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1065-drm-amdgpu-update-ib-start-and-size-alignment.patch (drm-backport-placeholder)
- commit 4a4cee0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1064-drm-amd-display-add-check-in-validate_only-in-dml2.patch (drm-backport-placeholder)
- commit de210cc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1063-drm-amd-display-Port-replay-vblank-logic-to-DML2.patch (drm-backport-placeholder)
- commit abcf194
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1062-drm-amd-display-Modify-Pipe-Selection-for-Policy-for.patch (drm-backport-placeholder)
- commit 2bc7060
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1061-drm-amd-display-correct-dml2-input-and-dlg_refclk.patch (drm-backport-placeholder)
- commit 53cdc93
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1060-drm-amd-display-Fix-Chroma-Surface-height-width-init.patch (drm-backport-placeholder)
- commit 2d63bab
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1059-drm-amd-display-Move-stereo-timing-check-to-helper.patch (drm-backport-placeholder)
- commit 255af34
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1058-drm-amd-display-Split-pipe-for-stereo-timings.patch (drm-backport-placeholder)
- commit 9a2fa4f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1057-drm-amd-display-Use-fixed-DET-Buffer-Size.patch (drm-backport-placeholder)
- commit 40c117b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1056-drm-amd-display-Handle-multiple-streams-sourcing-sam.patch (drm-backport-placeholder)
- commit dd1c567
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1055-drm-amd-display-Add-z8_marks-in-dml.patch (drm-backport-placeholder)
- commit 79feb35
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1054-drm-amd-display-Add-DCN35-DML2-support.patch (drm-backport-placeholder)
- commit c6ec561
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1053-drm-amd-display-Introduce-DML2.patch (drm-backport-placeholder)
- commit 0b02d91
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1052-drm-amd-display-Move-dml-code-under-CONFIG_DRM_AMD_D.patch (drm-backport-placeholder)
- commit 2a7f6e8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1051-drm-amd-display-Move-bw_fixed-from-DML-folder.patch (drm-backport-placeholder)
- commit 7b7a055
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1050-drm-amd-display-Move-custom_float-from-DML-folder.patch (drm-backport-placeholder)
- commit 393f7b5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1049-drm-amd-display-Move-dce_calcs-from-DML-folder.patch (drm-backport-placeholder)
- commit 6cfb232
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1048-drm-amdgpu-Enable-SMU-13.0.0-optimizations-when-ROCm.patch (drm-backport-placeholder)
- commit 70a3617
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1047-drm-amd-display-Move-the-memory-allocation-out-of-dc.patch (drm-backport-placeholder)
- commit 49b7be9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1046-drm-amd-display-Move-the-memory-allocation-out-of-dc.patch (drm-backport-placeholder)
- commit bf6d1f5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1045-drm-amd-display-Add-a-warning-if-the-FPU-is-used-out.patch (drm-backport-placeholder)
- commit 30ccdab
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Fix-UBSAN-array-index-out-of-bounds-for-Pola.patch (drm-backport-placeholder)
- commit 104b4e9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1043-drm-radeon-Fix-UBSAN-array-index-out-of-bounds-for-R.patch (drm-backport-placeholder)
- commit d31138a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1041-drm-amdgpu-Annotate-struct-amdgpu_bo_list-with-__cou.patch (drm-backport-placeholder)
- commit 1cc5a99
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1040-drm-amdgpu-Drop-unnecessary-return-statements.patch (drm-backport-placeholder)
- commit 1addaf9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1039-Documentation-amdgpu-Add-board-info-details.patch (drm-backport-placeholder)
- commit d535b07
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1038-drm-amdgpu-Add-sysfs-attribute-to-get-board-info.patch (drm-backport-placeholder)
- commit 57fe387
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1037-drm-amdgpu-Get-package-types-for-smuio-v13.0.patch (drm-backport-placeholder)
- commit 6f0122c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1036-drm-amdgpu-Add-more-smuio-v13.0.3-package-types.patch (drm-backport-placeholder)
- commit d474e9e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1035-drm-amdgpu-fix-ip-count-query-for-xcp-partitions.patch (drm-backport-placeholder)
- commit 90df5f1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1034-drm-amd-pm-Remove-set-df-cstate-for-SMUv13.0.6.patch (drm-backport-placeholder)
- commit 39fd799
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1033-drm-amdgpu-Move-package-type-enum-to-amdgpu_smuio.patch (drm-backport-placeholder)
- commit 37e230a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1032-drm-amdgpu-Fix-complex-macros-error.patch (drm-backport-placeholder)
- commit d802475
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1031-drm-amdkfd-Use-partial-migrations-in-GPU-page-faults.patch (drm-backport-placeholder)
- commit e2d8f95
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1030-drm-amd-display-Simplify-the-per-CPU-usage.patch (drm-backport-placeholder)
- commit 9d807d8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1029-drm-amd-display-Remove-migrate_en-dis-from-dc_fpu_be.patch (drm-backport-placeholder)
- commit 6953e2a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1028-drm-amdgpu-amdgpu_drm.h-fix-comment-typos.patch (drm-backport-placeholder)
- commit 08b3c6f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1027-drm-amdgpu-refine-fault-cache-updates.patch (drm-backport-placeholder)
- commit 696399c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1026-drm-amdgpu-add-new-INFO-ioctl-query-for-the-last-GPU.patch (drm-backport-placeholder)
- commit 20e76eb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1025-drm-amd-pm-Add-GC-v9.4.3-thermal-limits-to-hwmon.patch (drm-backport-placeholder)
- commit 5db8ff3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1024-drm-amd-pm-Add-throttle-limit-for-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit 8c874e9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1023-drm-amd-display-3.2.254.patch (drm-backport-placeholder)
- commit d6f7606
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1022-drm-amd-display-Adjust-code-style-for-hw_sequencer.h.patch (drm-backport-placeholder)
- commit 2c3773d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1021-drm-amd-display-Adjust-code-style-for-dmub_cmd.h.patch (drm-backport-placeholder)
- commit 4eafb1d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1020-drm-amd-display-Update-DMUB-cmd-header.patch (drm-backport-placeholder)
- commit 165b320
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1019-drm-amd-display-Add-a-check-for-idle-power-optimizat.patch (drm-backport-placeholder)
- commit 074d4ea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-use-full-update-for-clip-size-increa.patch (drm-backport-placeholder)
- commit db8536d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1017-drm-amd-display-Clean-up-code-warnings.patch (drm-backport-placeholder)
- commit 29080c5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1016-drm-amd-display-Make-driver-backwards-compatible-wit.patch (drm-backport-placeholder)
- commit cc236ec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-refactor-ILR-to-make-it-work.patch (drm-backport-placeholder)
- commit eef5c25
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1014-drm-amd-display-remove-duplicated-edp-relink-to-fast.patch (drm-backport-placeholder)
- commit 4123077
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1013-drm-amd-display-enable-dsc_clk-even-if-dsc_pg-disabl.patch (drm-backport-placeholder)
- commit f3240b8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1012-drm-amdkfd-Fix-EXT_COHERENT-memory-allocation-crash.patch (drm-backport-placeholder)
- commit 9bfc9d3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1011-drm-amdgpu-ratelimited-override-pte-flags-messages.patch (drm-backport-placeholder)
- commit ab2b261
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-Null-check-for-DPP-resource.patch (drm-backport-placeholder)
- commit 467a900
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1009-drm-amd-Drop-all-hand-built-MIN-and-MAX-macros-in-th.patch (drm-backport-placeholder)
- commit 97d6fba
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Update-update_pcie_parameters-functions-to-u.patch (drm-backport-placeholder)
- commit 4a563c0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Bail-from-dm_check_crtc_cursor-if-no.patch (drm-backport-placeholder)
- commit ff15f16
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amd-display-Enable-Replay-for-static-scre.patch (drm-backport-placeholder)
- commit 8957dd5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1005-drm-amdgpu-cache-gpuvm-fault-information-for-gmc7.patch (drm-backport-placeholder)
- commit dc2095c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1004-drm-amdgpu-add-cached-GPU-fault-structure-to-vm-stru.patch (drm-backport-placeholder)
- commit ba7708b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Refactor-dm_get_plane_scale-helper.patch (drm-backport-placeholder)
- commit 35130a4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1002-drm-amdgpu-Use-ttm_pages_limit-to-override-vram-repo.patch (drm-backport-placeholder)
- commit accd498
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1001-drm-amdgpu-Rework-KFD-memory-max-limits.patch (drm-backport-placeholder)
- commit 2b11f14
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1000-drm-amdgpu-gmc11-set-gart-placement-GC11.patch (drm-backport-placeholder)
- commit 99cd905
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0999-drm-amdgpu-gmc-add-a-way-to-force-a-particular-place.patch (drm-backport-placeholder)
- commit 8a70d53
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0998-drm-amd-display-fix-problems-in-power_helper.patch (drm-backport-placeholder)
- commit cb3d3c3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0997-drm-amdgpu-correct-gpu-clock-counter-query-on-cyan-s.patch (drm-backport-placeholder)
- commit bd0c114
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0996-drm-amd-display-Disable-DWB-frame-capture-to-emulate.patch (drm-backport-placeholder)
- commit bd59d79
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0995-drm-amd-display-Add-new-set_fc_enable-to-struct-dwbc.patch (drm-backport-placeholder)
- commit 91ba0c3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0994-drm-amd-display-Setup-for-mmhubbub3_warmup_mcif-with.patch (drm-backport-placeholder)
- commit 907f2c4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0993-drm-amd-display-Add-writeback-enable-field-wb_enable.patch (drm-backport-placeholder)
- commit 0c702d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0992-drm-amd-display-Fix-writeback_info-is-not-removed.patch (drm-backport-placeholder)
- commit f64bfbb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0991-drm-amd-display-Validate-hw_points_num-before-using-.patch (drm-backport-placeholder)
- commit f207336
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0990-drm-amd-display-Fix-writeback_info-never-got-updated.patch (drm-backport-placeholder)
- commit 1c17a5a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0989-drm-amd-display-Add-writeback-enable-disable-in-dc.patch (drm-backport-placeholder)
- commit abd4fdd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0988-drm-amd-display-Hande-writeback-request-from-userspa.patch (drm-backport-placeholder)
- commit df0d48f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0987-drm-amd-display-Create-fake-sink-and-stream-for-writ.patch (drm-backport-placeholder)
- commit 4f19066
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0986-drm-amd-display-Create-amdgpu_dm_wb_connector.patch (drm-backport-placeholder)
- commit ee1b822
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0985-drm-amd-display-Use-drm_connector-in-create_validate.patch (drm-backport-placeholder)
- commit c0a3087
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0984-drm-amd-display-Address-srf_updates-not-described-in.patch (drm-backport-placeholder)
- commit 294a601
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0983-drm-amd-pm-delete-dead-code.patch (drm-backport-placeholder)
- commit 79db3a0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0982-drm-amd-display-Use-drm_connector-in-create_stream_f.patch (drm-backport-placeholder)
- commit c142f9d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0981-drm-amdkfd-drop-struct-kfd_cu_info.patch (drm-backport-placeholder)
- commit d3cf3a9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0980-drm-amd-display-Return-drm_connector-from-find_first.patch (drm-backport-placeholder)
- commit d934e9f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0979-drm-amdkfd-reduce-stack-size-in-kfd_topology_add_dev.patch (drm-backport-placeholder)
- commit cdbeb52
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-update-retry-times-for-psp-vmbx-wait.patch (drm-backport-placeholder)
- commit 70f1d62
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0977-drm-amd-display-Skip-writeback-connector-when-we-get.patch (drm-backport-placeholder)
- commit a9b8709
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0976-drm-amdgpu-exit-directly-if-gpu-reset-fails.patch (drm-backport-placeholder)
- commit 9639c1f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0975-drm-amd-pm-Disallow-managing-power-profiles-on-SRIOV.patch (drm-backport-placeholder)
- commit 7ae8a4b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Check-all-enabled-planes-in-dm_check.patch (drm-backport-placeholder)
- commit 4d92cae
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0972-drm-amd-display-Initialize-writeback-connector.patch (drm-backport-placeholder)
- commit 5c3560d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0971-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch (drm-backport-placeholder)
- commit 0de5a9f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0970-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch (drm-backport-placeholder)
- commit 2abd844
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0969-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch (drm-backport-placeholder)
- commit c20d5ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0968-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch (drm-backport-placeholder)
- commit 5593399
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0967-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch (drm-backport-placeholder)
- commit 35d7a83
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0966-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch (drm-backport-placeholder)
- commit fbe9e5a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0964-drm-amd-display-Create-one-virtual-connector-in-DC.patch (drm-backport-placeholder)
- commit 441bbab
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0963-drm-amd-Drop-error-message-about-failing-to-load-SDM.patch (drm-backport-placeholder)
- commit c4e6b9b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0962-drm-amd-pm-fix-the-print_clk_levels-issue-for-SMU-v1.patch (drm-backport-placeholder)
- commit 4544668
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0961-drm-amd-pm-deprecate-allow_xgmi_power_down-interface.patch (drm-backport-placeholder)
- commit abfd6ed
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0960-drm-amd-pm-integrate-plpd-allow-disallow-into-select.patch (drm-backport-placeholder)
- commit 0df41f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0959-drm-amd-pm-init-plpd_mode-properly-for-different-asi.patch (drm-backport-placeholder)
- commit 457af13
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0958-drm-amd-display-Remove-unused-DPCD-declarations.patch (drm-backport-placeholder)
- commit 15fa8ba
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0957-drm-amd-display-Skip-entire-amdgpu_dm-build-if-CONFI.patch (drm-backport-placeholder)
- commit a8146e5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0956-drm-amd-Limit-seamless-boot-by-default-to-APUs.patch (drm-backport-placeholder)
- commit 0c7fbe6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0955-drm-amd-Drop-error-message-about-failing-to-load-DMU.patch (drm-backport-placeholder)
- commit 30ce299
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Handle-errors-from-svm-validate-and-map.patch (drm-backport-placeholder)
- commit db326f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0953-drm-amd-pm-add-xgmi_plpd_policy-sysfs-node-for-user-.patch (drm-backport-placeholder)
- commit 33a5935
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0952-drm-amd-pm-add-xgmi-plpd-mode-selecting-interface-fo.patch (drm-backport-placeholder)
- commit d810913
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0951-drm-amd-pm-add-plpd_mode-in-smu_context-to-indicate-.patch (drm-backport-placeholder)
- commit 46856f1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0950-drm-amd-pm-update-pmfw-headers-for-version-85.73.0.patch (drm-backport-placeholder)
- commit 395f3c9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0949-drm-amdgpu-Add-description-for-AMD_IP_BLOCK_TYPE_VPE.patch (drm-backport-placeholder)
- commit ab0d87f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0948-drm-amd-display-Change-dc_set_power_state-to-bool-in.patch (drm-backport-placeholder)
- commit 86d169f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0947-drm-amdgpu-gmc11-disable-AGP-on-GC-11.5.patch (drm-backport-placeholder)
- commit 4b947d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-not-to-save-bo-in-the-case-of-RAS-err_eve.patch (drm-backport-placeholder)
- commit f665467
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0945-drm-amd-Propagate-failures-in-dc_set_power_state.patch (drm-backport-placeholder)
- commit 723dc8e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0944-drm-amd-display-set-stream-gamut-remap-matrix-to-MPC.patch (drm-backport-placeholder)
- commit 0e2884c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0943-drm-amdgpu-gmc-set-a-default-disable-value-for-AGP.patch (drm-backport-placeholder)
- commit ea75ba5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0942-drm-amdgpu-gmc6-8-properly-disable-the-AGP-aperture.patch (drm-backport-placeholder)
- commit df1ecad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0941-drm-amdgpu-Expose-physical-id-of-device-in-XGMI-hive.patch (drm-backport-placeholder)
- commit 2b1bd78
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0940-drm-amd-display-Break-after-finding-supported-vlevel.patch (drm-backport-placeholder)
- commit badb3a8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0939-drm-amd-display-Update-OPP-counter-from-new-interfac.patch (drm-backport-placeholder)
- commit 104313f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0938-drm-amd-display-augment-display-clock-in-dc_cap-stru.patch (drm-backport-placeholder)
- commit 83b709d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0937-drm-amd-display-3.2.253.patch (drm-backport-placeholder)
- commit 2e8b78e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0936-drm-amd-display-fix-incorrect-odm-change-detection-l.patch (drm-backport-placeholder)
- commit 935af65
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0935-drm-amd-display-add-primary-pipe-check-when-building.patch (drm-backport-placeholder)
- commit 75292af
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0934-drm-amd-display-add-get-primary-dpp-pipe-resource-in.patch (drm-backport-placeholder)
- commit 9752728
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0933-drm-amd-display-add-missing-function-pointer-for-DCN.patch (drm-backport-placeholder)
- commit e55167d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0932-drm-amd-display-Rename-DisableMinDispClkODM-in-dc_co.patch (drm-backport-placeholder)
- commit 9d7266e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0931-drm-amdgpu-vpe-fix-truncation-warnings.patch (drm-backport-placeholder)
- commit b425c50
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0930-drm-amd-display-Improve-code-style-on-bios_parser2.patch (drm-backport-placeholder)
- commit 657953a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0929-drm-amd-display-Remove-unwanted-drm-edid-references.patch (drm-backport-placeholder)
- commit 192f1a2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0928-drm-amd-display-switch-DC-over-to-the-new-DRM-loggin.patch (drm-backport-placeholder)
- commit cbf2773
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0927-drm-amd-display-skip-audio-config-for-virtual-signal.patch (drm-backport-placeholder)
- commit db6857f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0926-drm-amd-pm-Add-reset-option-for-fan_curve-on-smu13_0.patch (drm-backport-placeholder)
- commit f1b0a2e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0925-drm-amd-display-block-MPO-if-it-prevents-pstate-supp.patch (drm-backport-placeholder)
- commit eea0089
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0924-drm-amd-display-Fix-DP2.0-timing-sync.patch (drm-backport-placeholder)
- commit b26d421
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0923-drm-amd-display-Improve-x86-and-dmub-ips-handshake.patch (drm-backport-placeholder)
- commit 4743188
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0922-drm-amd-display-remove-guaranteed-viewports-limitati.patch (drm-backport-placeholder)
- commit 40a0bd8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0921-drm-amd-display-add-new-windowed-mpo-odm-minimal-tra.patch (drm-backport-placeholder)
- commit be88dfc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0920-drm-amd-display-reset-stream-slice-count-for-new-ODM.patch (drm-backport-placeholder)
- commit c4f6000
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0919-drm-amd-display-determine-fast-update-only-before-co.patch (drm-backport-placeholder)
- commit 0362669
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0918-drm-amd-display-remove-unused-mmhub_reg_offsets.patch (drm-backport-placeholder)
- commit 743ed39
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-fix-some-race-conditions-in-vram-buffer-a.patch (drm-backport-placeholder)
- commit d984388
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0916-drm-amdkfd-Move-dma-unmapping-after-TLB-flush.patch (drm-backport-placeholder)
- commit 1b2ce10
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0915-drm-amdgpu-further-move-TLB-hw-workarounds-a-layer-u.patch (drm-backport-placeholder)
- commit afc5d1c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0914-drm-amdgpu-rework-lock-handling-for-flush_tlb-v2.patch (drm-backport-placeholder)
- commit 72d9135
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0913-drm-amdgpu-drop-error-return-from-flush_gpu_tlb_pasi.patch (drm-backport-placeholder)
- commit c567026
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0912-drm-amdgpu-fix-and-cleanup-gmc_v11_0_flush_gpu_tlb_p.patch (drm-backport-placeholder)
- commit 98cae8e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0911-drm-amdgpu-cleanup-gmc_v10_0_flush_gpu_tlb_pasid.patch (drm-backport-placeholder)
- commit 46481dc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0910-drm-amdgpu-fix-and-cleanup-gmc_v9_0_flush_gpu_tlb_pa.patch (drm-backport-placeholder)
- commit f47a5fa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0909-drm-amdgpu-fix-and-cleanup-gmc_v8_0_flush_gpu_tlb_pa.patch (drm-backport-placeholder)
- commit f341b5c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0908-drm-amdgpu-fix-and-cleanup-gmc_v7_0_flush_gpu_tlb_pa.patch (drm-backport-placeholder)
- commit 7e997e0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0907-drm-amdgpu-cleanup-gmc_v11_0_flush_gpu_tlb.patch (drm-backport-placeholder)
- commit 6582315
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0906-drm-amdgpu-rework-gmc_v10_0_flush_gpu_tlb-v2.patch (drm-backport-placeholder)
- commit 03c9103
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0905-drm-amdgpu-change-if-condition-for-bad-channel-bitma.patch (drm-backport-placeholder)
- commit e80a3f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0904-drm-amdgpu-fix-value-of-some-UMC-parameters-for-UMC-.patch (drm-backport-placeholder)
- commit df542cc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0903-drm-amd-display-fix-some-style-issues.patch (drm-backport-placeholder)
- commit a9429cf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0902-drm-amdkfd-Don-t-use-sw-fault-filter-if-retry-cam-en.patch (drm-backport-placeholder)
- commit b3a21da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0901-drm-amdgpu-fix-and-cleanup-gmc_v9_0_flush_gpu_tlb.patch (drm-backport-placeholder)
- commit 02514f9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0900-gpu-drm-amd-display-fix-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit 4db853b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Increase-IH-soft-ring-size-for-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit 86c1219
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0898-drm-amdgpu-Restore-partition-mode-after-reset.patch (drm-backport-placeholder)
- commit 250ed02
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0897-drm-amd-display-3.2.252.patch (drm-backport-placeholder)
- commit 285122a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0896-drm-amd-display-Drop-unused-link-FPGA-code.patch (drm-backport-placeholder)
- commit 5c62d2d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0895-drm-amd-display-Enable-DCN-low-mem-power-by-default.patch (drm-backport-placeholder)
- commit c0ff201
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0894-drm-amd-display-Expand-DML-to-better-support-replay.patch (drm-backport-placeholder)
- commit 62ca3fe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0893-drm-amd-display-Use-optc32-instead-of-optc30-in-DC.patch (drm-backport-placeholder)
- commit d5dfcf8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0892-drm-amd-display-Optimize-OLED-T7-delay.patch (drm-backport-placeholder)
- commit ab76da7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Remove-svm-range-validated_once-flag.patch (drm-backport-placeholder)
- commit 57831a4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0890-drm-amdgpu-Add-more-fields-to-IP-version.patch (drm-backport-placeholder)
- commit 8ba6f69
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0889-drm-amdgpu-print-channel-index-for-UMC-bad-page.patch (drm-backport-placeholder)
- commit bfb9122
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0888-drm-amdkfd-Separate-dma-unmap-and-free-of-dma-addres.patch (drm-backport-placeholder)
- commit 3356a28
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0887-drm-amd-pm-Remove-SMUv13.0.6-unsupported-feature.patch (drm-backport-placeholder)
- commit 6999d2d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0886-drm-amd-pm-Round-Q10-format-values-in-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit 0fa3f72
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0885-drm-amdgpu-update-IP-count-INFO-query.patch (drm-backport-placeholder)
- commit e361dba
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0884-drm-amdgpu-Fix-false-positive-error-log.patch (drm-backport-placeholder)
- commit a82ed5c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0883-drm-amdgpu-jpeg-skip-set-pg-for-sriov.patch (drm-backport-placeholder)
- commit be5405c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0882-drm-amd-display-3.2.251.patch (drm-backport-placeholder)
- commit 4a9531b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0881-drm-amd-display-FW-Promotion-Release-0.0.183.0.patch (drm-backport-placeholder)
- commit 77d3941
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0880-drm-amd-display-Fix-MST-recognizes-connected-display.patch (drm-backport-placeholder)
- commit 28b6dc4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0879-drm-amd-display-fix-some-non-initialized-register-ma.patch (drm-backport-placeholder)
- commit f095a35
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0878-drm-amd-display-Enable-replay-for-dcn35.patch (drm-backport-placeholder)
- commit bf23081
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0877-drm-amd-display-Add-option-to-flip-ODM-optimization.patch (drm-backport-placeholder)
- commit 05c878b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0876-drm-amd-display-disable-IPS.patch (drm-backport-placeholder)
- commit 6de347a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0875-drm-amd-display-Add-IPS-control-flag.patch (drm-backport-placeholder)
- commit cd124e2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0874-drm-amd-display-Update-driver-and-IPS-interop.patch (drm-backport-placeholder)
- commit 2d61198
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0873-drm-amd-display-Correct-z8-watermark-mask.patch (drm-backport-placeholder)
- commit 160084c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0872-drm-amd-display-STREAM_MAPPER_CONTROL-register-offse.patch (drm-backport-placeholder)
- commit 4a2e675
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0871-drm-amd-display-Update-pipe-resource-interfaces-for-.patch (drm-backport-placeholder)
- commit ca7d703
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0870-drm-amd-display-Add-DPIA-Link-Encoder-Assignment-Fix.patch (drm-backport-placeholder)
- commit cf7dd57
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0869-drm-amd-display-fix-static-screen-detection-setting-.patch (drm-backport-placeholder)
- commit bec4870
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0868-drm-amd-display-Add-pointer-check-before-function-ca.patch (drm-backport-placeholder)
- commit 0a8f3ec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0867-drm-amd-display-Enable-DCLK_DS-from-driver-by-defaul.patch (drm-backport-placeholder)
- commit f56ce17
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0866-drm-amd-display-Add-DCN35-case-for-dc_clk_mgr_create.patch (drm-backport-placeholder)
- commit bcb3f10
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0865-drm-amd-display-Add-z8_marks-related-in-dml-for-DCN3.patch (drm-backport-placeholder)
- commit 6484f76
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0864-drm-amd-display-Fix-dig-register-undefined.patch (drm-backport-placeholder)
- commit 81b272d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0863-drm-amd-display-Temporarily-disable-clock-gating.patch (drm-backport-placeholder)
- commit 4eb8487
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0862-drm-amd-display-disable-clock-gating-logic.patch (drm-backport-placeholder)
- commit 4ec9771
* Wed Oct  2 2024 mhocko@suse.com
- vmalloc: modify the alloc_vmap_area() error message for better
  diagnostics (jsc#PED-10978).
- mm: mmap: no need to call khugepaged_enter_vma() for stack
  (jsc#PED-10978).
- commit 41e1775
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0861-drm-amd-display-Add-reset-for-SYMCLKC_FE_SRC_SEL.patch (drm-backport-placeholder)
- commit 5d61108
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0860-drm-amdgpu-Rework-coredump-to-use-memory-dynamically.patch (drm-backport-placeholder)
- commit d29c789
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0859-drm-amd-display-Remove-unused-display_content_suppor.patch (drm-backport-placeholder)
- commit 42d17eb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0858-drm-amd-display-Hook-up-content-type-property-for-HD.patch (drm-backport-placeholder)
- commit 772e669
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0857-drm-amdgpu-Fix-vbios-version-string-search.patch (drm-backport-placeholder)
- commit 5159ea7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0856-drm-amd-pm-add-smu_13_0_6-mca-dump-support.patch (drm-backport-placeholder)
- commit e3d135d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0855-drm-amd-pm-update-smu_v13_0_6-ppsmc-header.patch (drm-backport-placeholder)
- commit fc1f1f0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0854-drm-amdgpu-Add-EXT_COHERENT-memory-allocation-flags.patch (drm-backport-placeholder)
- commit 0522afc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0853-drm-amdkfd-fix-add-queue-process-context-clear-witho.patch (drm-backport-placeholder)
- commit f5f32b8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0852-drm-amdgpu-add-amdgpu-mca-debug-sysfs-support.patch (drm-backport-placeholder)
- commit 8e23c2c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0851-drm-amdgpu-add-VPE-IP-discovery-info-to-HW-IP-info-q.patch (drm-backport-placeholder)
- commit 2a4bc26
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0850-drm-amdgpu-add-amdgpu-smu-mca-dump-feature-support.patch (drm-backport-placeholder)
- commit a307a89
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0849-Documentation-amdgpu-Modify-pp_dpm_-clk-details.patch (drm-backport-placeholder)
- commit 4b4ca53
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0848-drm-amd-Enable-seamless-boot-by-default-on-newer-ASI.patch (drm-backport-placeholder)
- commit 6ee1e9e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0847-drm-amd-Add-a-module-parameter-for-seamless-boot.patch (drm-backport-placeholder)
- commit 2614876
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0846-drm-amd-Add-HDP-flush-during-jpeg-init.patch (drm-backport-placeholder)
- commit 3f7bb87
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0845-drm-amd-Move-seamless-boot-check-out-of-display.patch (drm-backport-placeholder)
- commit e851c14
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0844-drm-amd-Drop-special-case-for-yellow-carp-without-di.patch (drm-backport-placeholder)
- commit d2e9356
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0843-drm-amd-pm-Fix-GFX-deep-sleep-clock-reporting.patch (drm-backport-placeholder)
- commit 91bd61e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0842-drm-amd-pm-Fix-clock-reporting-for-SMUv13.0.6.patch (drm-backport-placeholder)
- commit 4e309ab
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0841-drm-amdgpu-Use-function-for-IP-version-check.patch (drm-backport-placeholder)
- commit f14897c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0840-drm-amdgpu-add-remap_hdp_registers-callback-for-nbio.patch (drm-backport-placeholder)
- commit 036a506
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0839-drm-amdgpu-add-vcn_doorbell_range-callback-for-nbio-.patch (drm-backport-placeholder)
- commit 024ba61
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0838-drm-amdgpu-Create-an-option-to-disable-soft-recovery.patch (drm-backport-placeholder)
- commit 176c905
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0837-drm-amdgpu-Merge-debug-module-parameters.patch (drm-backport-placeholder)
- commit 9d01d78
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0836-drm-amd-display-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit f9e83fb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0835-drm-amd-display-add-skip_implict_edp_power_control-f.patch (drm-backport-placeholder)
- commit d002876
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0834-drm-amd-display-minior-logging-improvements.patch (drm-backport-placeholder)
- commit 4119bce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0833-drm-amd-display-do-not-skip-ODM-minimal-transition-b.patch (drm-backport-placeholder)
- commit acca476
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0832-drm-amd-display-move-odm-power-optimization-decision.patch (drm-backport-placeholder)
- commit d90a3fc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-add-seamless-pipe-topology-transitio.patch (drm-backport-placeholder)
- commit 5511701
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0830-drm-amd-display-3.2.250.patch (drm-backport-placeholder)
- commit c080a5e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0829-drm-amd-display-fix-some-non-initialized-register-ma.patch (drm-backport-placeholder)
- commit 780f066
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0828-drm-amd-display-Add-check-for-vrr_active_fixed.patch (drm-backport-placeholder)
- commit 8dfe361
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0827-drm-amd-display-dc-cleanup-for-tests.patch (drm-backport-placeholder)
- commit 539ed0d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0826-drm-amdgpu-add-type-conversion-for-gc-info.patch (drm-backport-placeholder)
- commit 43d9b68
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0825-drm-amd-display-Drop-unused-registers.patch (drm-backport-placeholder)
- commit 5f26388
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0824-drm-amd-display-add-dp-dto-programming-function-to-d.patch (drm-backport-placeholder)
- commit fbb68fb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0823-drm-amd-display-only-allow-ODM-power-optimization-if.patch (drm-backport-placeholder)
- commit 6a50a3d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0822-drm-amd-display-do-not-attempt-ODM-power-optimizatio.patch (drm-backport-placeholder)
- commit b7c360c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0821-drm-amd-display-remove-a-function-that-does-complex-.patch (drm-backport-placeholder)
- commit 58ce987
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0820-drm-amd-display-Add-DCHUBBUB-callback-to-report-MALL.patch (drm-backport-placeholder)
- commit d5159ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0819-drm-amd-display-Add-new-logs-for-AutoDPMTest.patch (drm-backport-placeholder)
- commit 15242ef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0818-drm-amd-display-support-main-link-off-before-specifi.patch (drm-backport-placeholder)
- commit cbef097
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0817-drm-amdgpu-Rename-KGD_MAX_QUEUES-to-AMDGPU_MAX_QUEUE.patch (drm-backport-placeholder)
- commit 541fa07
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0816-drm-amd-display-do-not-block-ODM-OPM-on-one-side-of-.patch (drm-backport-placeholder)
- commit 82c2b1a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0815-drm-amd-display-Fix-DML-calculation-errors.patch (drm-backport-placeholder)
- commit fe52a90
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0814-drm-amdgpu-print-more-address-info-of-UMC-bad-page.patch (drm-backport-placeholder)
- commit e20176d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0813-drm-amd-display-FW-Promotion-Release-0.0.181.0.patch (drm-backport-placeholder)
- commit 89905a5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0812-drm-amd-display-set-default-return-value-for-ODM-Com.patch (drm-backport-placeholder)
- commit 6831a5e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Don-t-lock-phantom-pipe-on-disabling.patch (drm-backport-placeholder)
- commit 14307df
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Blank-phantom-OTG-before-enabling.patch (drm-backport-placeholder)
- commit 59a633c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0809-drm-amdgpu-add-channel-index-table-for-UMC-v12.patch (drm-backport-placeholder)
- commit 648bc73
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0808-drm-amd-pm-enable-smu_v13_0_6-mca-debug-mode-when-UM.patch (drm-backport-placeholder)
- commit 54250ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0807-drm-amd-pm-update-smu_v13_0_6-smu-header.patch (drm-backport-placeholder)
- commit c8d2d25
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0806-drm-amdgpu-add-address-conversion-for-UMC-v12.patch (drm-backport-placeholder)
- commit 0f17e0d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0805-drm-amdgpu-Use-default-reset-method-handler.patch (drm-backport-placeholder)
- commit b060793
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0804-drm-amd-Fix-the-flag-setting-code-for-interrupt-requ.patch (drm-backport-placeholder)
- commit 563ad77
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0803-drm-amdgpu-fix-unsigned-error-codes.patch (drm-backport-placeholder)
- commit 69e57c8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0802-drm-amd-display-clean-up-one-inconsistent-indenting.patch (drm-backport-placeholder)
- commit e17278f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0801-drm-amdgpu-Add-umc-v12_0-ras-functions.patch (drm-backport-placeholder)
- commit 7e90d24
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-refclk-reporting-for-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit 2ee338e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0799-drm-amdgpu-Correct-se_num-and-reg_inst-for-gfx-v9_4_.patch (drm-backport-placeholder)
- commit b5fd1a3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0798-drm-amdgpu-Add-only-valid-firmware-version-nodes.patch (drm-backport-placeholder)
- commit 527ebc5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0797-drm-amdgpu-fix-incompatible-types-in-conditional-exp.patch (drm-backport-placeholder)
- commit a3eee31
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0796-drm-amdgpu-Use-min_t-to-replace-min.patch (drm-backport-placeholder)
- commit f8cc692
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0795-drm-amd-Add-umc-v12_0_0-ip-headers.patch (drm-backport-placeholder)
- commit d2509bd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0794-drm-amdgpu-Update-amdgpu_device_indirect_r-wreg_ext.patch (drm-backport-placeholder)
- commit 4e6f6fe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0793-drm-amdgpu-Add-RREG64_PCIE_EXT-WREG64_PCIE_EXT-funct.patch (drm-backport-placeholder)
- commit 63bd830
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0792-drm-amdgpu-Declare-array-with-strings-as-pointers-co.patch (drm-backport-placeholder)
- commit 0e18296
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0791-amdgpu-pm-Optimize-emit_clock_levels-for-aldebaran-p.patch (drm-backport-placeholder)
- commit a765805
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0790-amdgpu-pm-Optimize-emit_clock_levels-for-aldebaran-p.patch (drm-backport-placeholder)
- commit 7360e8b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0789-amdgpu-pm-Optimize-emit_clock_levels-for-aldebaran-p.patch (drm-backport-placeholder)
- commit 99b2412
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0788-amdgpu-pm-Replace-print_clock_levels-with-emit_clock.patch (drm-backport-placeholder)
- commit caa6b5a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0787-drm-amd-display-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 7c674a7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0786-drm-amd-display-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit fc8a120
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0785-drm-amd-display-clean-up-one-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 2ed1f65
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0784-drm-amd-display-clean-up-one-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 70cbc93
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0783-drm-amd-display-Remove-duplicated-include-in-dcn35_c.patch (drm-backport-placeholder)
- commit 40fd8ec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0782-drm-amd-display-Remove-duplicated-include-in-dcn35_h.patch (drm-backport-placeholder)
- commit 77e918d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0781-drm-amd-display-Remove-duplicated-include-in-dcn35_o.patch (drm-backport-placeholder)
- commit dc0a9b5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0780-drm-amd-display-Remove-duplicated-include-in-dcn35_r.patch (drm-backport-placeholder)
- commit b8be0af
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0779-drm-amdgpu-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 076ff57
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0778-drm-amdgpu-calling-address-translation-functions-to-.patch (drm-backport-placeholder)
- commit d7258cf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0777-drm-amd-pm-only-poweron-off-vcn-jpeg-when-they-are-v.patch (drm-backport-placeholder)
- commit 3739f0d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-remove-useless-check-in-should_enabl.patch (drm-backport-placeholder)
- commit 6cca041
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0775-Revert-drm-amd-pm-disable-the-SMU13-OD-feature-suppo.patch (drm-backport-placeholder)
- commit d012d60
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0774-drm-amd-pm-add-fan-minimum-pwm-OD-setting-support-fo.patch (drm-backport-placeholder)
- commit 8f18be3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0773-drm-amd-pm-add-fan-target-temperature-OD-setting-sup.patch (drm-backport-placeholder)
- commit 1177f97
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0772-drm-amd-pm-add-fan-acoustic-target-OD-setting-suppor.patch (drm-backport-placeholder)
- commit 176a9b1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0771-drm-amdgpu-update-SET_HW_RESOURCES-definition-for-UM.patch (drm-backport-placeholder)
- commit 64310da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0770-drm-amdgpu-add-amdgpu_umsch_mm-module-parameter.patch (drm-backport-placeholder)
- commit 8f504ed
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0769-drm-amdgpu-discovery-enable-UMSCH-4.0-in-IP-discover.patch (drm-backport-placeholder)
- commit 1a4dba4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0768-drm-amdgpu-add-PSP-loading-support-for-UMSCH.patch (drm-backport-placeholder)
- commit cff1a46
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0767-drm-amdgpu-reserve-mmhub-engine-3-for-UMSCH-FW.patch (drm-backport-placeholder)
- commit b664093
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0766-drm-amdgpu-add-VPE-queue-submission-test.patch (drm-backport-placeholder)
- commit 45f55dc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0765-drm-amdgpu-add-selftest-framework-for-UMSCH.patch (drm-backport-placeholder)
- commit 41ac370
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0764-drm-amdgpu-enable-UMSCH-scheduling-for-VPE.patch (drm-backport-placeholder)
- commit 2ff3fbd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0763-drm-amdgpu-add-initial-support-for-UMSCH.patch (drm-backport-placeholder)
- commit 363bd49
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0762-drm-amdgpu-add-UMSCH-4.0-api-definition.patch (drm-backport-placeholder)
- commit e70fbb4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0761-drm-amdgpu-add-UMSCH-firmware-header-definition.patch (drm-backport-placeholder)
- commit e5b489e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0760-drm-amdgpu-add-UMSCH-RING-TYPE-definition.patch (drm-backport-placeholder)
- commit f444e78
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0759-drm-amd-pm-add-fan-acoustic-limit-OD-setting-support.patch (drm-backport-placeholder)
- commit 3e2476e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0758-drm-amd-pm-add-fan-temperature-pwm-curve-OD-setting-.patch (drm-backport-placeholder)
- commit 2d03fc8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0757-drm-amdgpu-jpeg-initialize-number-of-jpeg-ring.patch (drm-backport-placeholder)
- commit 1944262
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0756-drm-amdgpu-revise-the-device-initialization-sequence.patch (drm-backport-placeholder)
- commit 23c9d35
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0755-drm-amd-pm-introduce-a-new-set-of-OD-interfaces.patch (drm-backport-placeholder)
- commit 1ed3c22
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0754-drm-amdgpu-add-UMSCH-IP-BLOCK-TYPE-definition.patch (drm-backport-placeholder)
- commit 7728d4d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0753-amdgpu-pm-Optimize-emit_clock_levels-for-arcturus-pa.patch (drm-backport-placeholder)
- commit c783ebf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0752-drm-amdgpu-add-UMSCH-4.0-register-headers.patch (drm-backport-placeholder)
- commit 3771b70
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0751-drm-amdgpu-enable-PG-flags-for-VCN.patch (drm-backport-placeholder)
- commit 23dd088
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0750-drm-amdgpu-discovery-add-VCN-4.0.5-Support.patch (drm-backport-placeholder)
- commit 80abbfd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0749-drm-amdgpu-soc21-Add-video-cap-query-support-for-VCN.patch (drm-backport-placeholder)
- commit 5e2bfce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0748-drm-amdgpu-enable-CG-and-PG-flags-for-VCN.patch (drm-backport-placeholder)
- commit 008b6d9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0747-drm-amdgpu-add-VCN_4_0_5-firmware-support.patch (drm-backport-placeholder)
- commit 653d004
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0746-drm-amdgpu-jpeg-add-jpeg-support-for-VCN4_0_5.patch (drm-backport-placeholder)
- commit 37d8735
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0745-drm-amdgpu-add-VCN4-ip-block-support.patch (drm-backport-placeholder)
- commit 88f5bad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0744-drm-amdgpu-add-vcn-4_0_5-header-files.patch (drm-backport-placeholder)
- commit 9eac2f1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0743-drm-amdgpu-fix-VPE-front-door-loading-issue.patch (drm-backport-placeholder)
- commit 43f4607
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0742-drm-amdgpu-add-VPE-FW-version-query-support.patch (drm-backport-placeholder)
- commit bac80ea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0741-drm-amdgpu-enable-VPE-for-VPE-6.1.0.patch (drm-backport-placeholder)
- commit 87de70a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0740-drm-amdgpu-add-user-space-CS-support-for-VPE.patch (drm-backport-placeholder)
- commit 4ccf342
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0739-drm-amdgpu-add-PSP-loading-support-for-VPE.patch (drm-backport-placeholder)
- commit 9d6f1c5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0738-drm-amdgpu-add-VPE-6.1.0-support.patch (drm-backport-placeholder)
- commit 49bd001
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0737-drm-amdgpu-add-nbio-7.11-callback-for-VPE.patch (drm-backport-placeholder)
- commit 91f4db4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0736-drm-amdgpu-add-nbio-callback-for-VPE.patch (drm-backport-placeholder)
- commit 116a638
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0735-drm-amdgpu-add-PSP-FW-TYPE-for-VPE.patch (drm-backport-placeholder)
- commit 55ba0de
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0734-drm-amdgpu-add-UCODE-ID-for-VPE.patch (drm-backport-placeholder)
- commit 47a7f65
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0733-drm-amdgpu-add-support-for-VPE-firmware-name-decodin.patch (drm-backport-placeholder)
- commit 0ce94bf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0732-drm-amdgpu-add-doorbell-index-for-VPE.patch (drm-backport-placeholder)
- commit 2f5284d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0731-drm-amdgpu-add-irq-src-id-definitions-for-VPE.patch (drm-backport-placeholder)
- commit ccae9c9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0730-drm-amdgpu-add-IH-CLIENT-ID-for-VPE.patch (drm-backport-placeholder)
- commit 6113d3c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0729-drm-amdgpu-add-HWID-for-VPE.patch (drm-backport-placeholder)
- commit a656153
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0728-drm-amdgpu-add-VPE-firmware-interface.patch (drm-backport-placeholder)
- commit f5c6a0f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0727-drm-amdgpu-add-VPE-firmware-header-definition.patch (drm-backport-placeholder)
- commit 4c6e5be
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0726-drm-amdgpu-add-VPE-HW-IP-BLOCK-definition.patch (drm-backport-placeholder)
- commit 7e317bb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0725-drm-amdgpu-add-VPE-IP-BLOCK-definition.patch (drm-backport-placeholder)
- commit aa40004
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0724-drm-amdgpu-add-VPE-RING-TYPE-definition.patch (drm-backport-placeholder)
- commit 3ad6be3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0723-drm-amdgpu-add-VPE-HW-IP-definition.patch (drm-backport-placeholder)
- commit 28de44b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0722-drm-amdgpu-add-VPE-6.1.0-header-files.patch (drm-backport-placeholder)
- commit 603f630
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0721-drm-amdgpu-Fix-printk_ratelimit-with-DRM_ERROR_RATEL.patch (drm-backport-placeholder)
- commit 371e060
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0720-drm-amdgpu-Use-READ_ONCE-when-reading-the-values-in-.patch (drm-backport-placeholder)
- commit 25f514f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0719-drm-amdgpu-remove-unused-parameter-in-amdgpu_vmid_gr.patch (drm-backport-placeholder)
- commit 0db40b7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0718-drm-amdkfd-Replace-pr_err-with-dev_err.patch (drm-backport-placeholder)
- commit 460586d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0717-amdgpu-pm-Optimize-emit_clock_levels-for-arcturus-pa.patch (drm-backport-placeholder)
- commit af9ff49
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0716-amdgpu-pm-Optimize-emit_clock_levels-for-arcturus-pa.patch (drm-backport-placeholder)
- commit f094c8e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0715-drm-amd-display-Adjust-kdoc-for-optc35_set_odm_combi.patch (drm-backport-placeholder)
- commit c4aaf8d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0714-drm-amd-Simplify-the-bo-size-check-funciton.patch (drm-backport-placeholder)
- commit 9f267de
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-ratelimited-SQ-interrupt-messages.patch (drm-backport-placeholder)
- commit c0d275e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0712-drm-amdgpu-access-RLC_SPM_MC_CNTL-through-MMIO-in-SR.patch (drm-backport-placeholder)
- commit f63225d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0711-drm-amd-amdgpu-sdma_v6_0-Demote-a-bunch-of-half-comp.patch (drm-backport-placeholder)
- commit d152308
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0710-drm-amd-display-Add-DCN35-DM-Support.patch (drm-backport-placeholder)
- commit 6db1b28
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0709-drm-amd-display-Add-DCN35-CORE.patch (drm-backport-placeholder)
- commit 04f4b49
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0708-drm-amd-display-Add-DCN35-blocks-to-Makefile.patch (drm-backport-placeholder)
- commit 49a7c70
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0707-drm-amd-display-Add-DCN35-DML.patch (drm-backport-placeholder)
- commit f3aa0b5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0706-drm-amd-display-Add-DCN35-Resource.patch (drm-backport-placeholder)
- commit 3d02831
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0705-drm-amd-display-Add-DCN35-init.patch (drm-backport-placeholder)
- commit be798e0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0704-drm-amd-display-Add-DCN35-DMUB.patch (drm-backport-placeholder)
- commit 26d8463
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0703-drm-amd-display-Add-DCN35-IRQ.patch (drm-backport-placeholder)
- commit 6af522f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0702-drm-amd-display-Add-DCN35-CLK_MGR.patch (drm-backport-placeholder)
- commit bf422b9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0701-drm-amd-display-Add-DCN35-HWSEQ.patch (drm-backport-placeholder)
- commit e09d13f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0700-drm-amd-display-Add-DCN35-DSC.patch (drm-backport-placeholder)
- commit 58cde12
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0699-drm-amd-display-Add-DCN35-MMHUBBUB.patch (drm-backport-placeholder)
- commit c3b0e1e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0698-drm-amd-display-Add-DCN35-HUBBUB.patch (drm-backport-placeholder)
- commit dc6b14e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0697-drm-amd-display-Add-DCN35-HUBP.patch (drm-backport-placeholder)
- commit 81db8e3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0696-drm-amd-display-Add-DCN35-DWB.patch (drm-backport-placeholder)
- commit a9c3296
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0695-drm-amd-display-Add-DCN35-DPP.patch (drm-backport-placeholder)
- commit fd82aee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0694-drm-amd-display-Add-DCN35-OPP.patch (drm-backport-placeholder)
- commit 28fef9b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0693-drm-amd-display-Add-DCN35-OPTC.patch (drm-backport-placeholder)
- commit 7e1473a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0692-drm-amd-display-Add-DCN35-PG_CNTL.patch (drm-backport-placeholder)
- commit e68fc10
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0691-drm-amd-display-Add-DCN35-DIO.patch (drm-backport-placeholder)
- commit b607258
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0690-drm-amd-display-Add-DCN35-DCCG.patch (drm-backport-placeholder)
- commit 0abddce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0689-drm-amd-display-Add-DCN35-GPIO.patch (drm-backport-placeholder)
- commit 9c0dc6c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0688-drm-amd-display-Add-DCN35-BIOS-command-table-support.patch (drm-backport-placeholder)
- commit 448d481
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0687-drm-amd-display-Update-dc.h-for-DCN35-support.patch (drm-backport-placeholder)
- commit f685c07
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0686-drm-amd-display-Update-DCN32-for-DCN35-support.patch (drm-backport-placeholder)
- commit 598fb1e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0685-drm-amd-display-Update-DCN314-for-DCN35-support.patch (drm-backport-placeholder)
- commit 20afb98
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0684-drm-amd-display-Update-DCN31-for-DCN35-support.patch (drm-backport-placeholder)
- commit 9386ac9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0683-drm-amd-display-Update-DCN30-for-DCN35-support.patch (drm-backport-placeholder)
- commit dceb229
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0682-drm-amd-display-Update-DCN20-for-DCN35-support.patch (drm-backport-placeholder)
- commit 328817d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0681-drm-amd-display-Update-DCN10-for-DCN35-support.patch (drm-backport-placeholder)
- commit bd25735
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0680-drm-amd-display-Update-DCE-for-DCN35-support.patch (drm-backport-placeholder)
- commit 5c30c19
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0679-drm-amd-display-Add-DCN35-family-information.patch (drm-backport-placeholder)
- commit 6a8fca7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0678-drm-amd-display-Add-dcn35-register-header-files.patch (drm-backport-placeholder)
- commit a06c658
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-Remove-the-references-of-radeon_gem_-prea.patch (drm-backport-placeholder)
- commit d3e82ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0676-drm-amd-display-Fix-up-kdoc-format-for-dc_set_edp_po.patch (drm-backport-placeholder)
- commit 3c13c6f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0675-drm-amd-display-3.2.249.patch (drm-backport-placeholder)
- commit 20c3591
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0674-drm-amd-display-fix-pipe-topology-logging-error.patch (drm-backport-placeholder)
- commit 6a8a15c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0673-drm-amd-display-Add-debugfs-interface-for-ODM-combin.patch (drm-backport-placeholder)
- commit 3734eb9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0672-drm-amd-display-correct-z8_watermark-16bit-to-20bit-.patch (drm-backport-placeholder)
- commit 1170707
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0671-drm-amd-display-Fix-incorrect-comment.patch (drm-backport-placeholder)
- commit 1f7b8fb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0670-drm-amd-display-Skip-dmub-memory-flush-when-not-need.patch (drm-backport-placeholder)
- commit b886745
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0669-drm-amd-display-add-pipe-topology-update-log.patch (drm-backport-placeholder)
- commit b93d2da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0668-drm-amd-display-switch-to-new-ODM-policy-for-windowe.patch (drm-backport-placeholder)
- commit e33487c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0667-drm-amd-display-use-new-pipe-allocation-interface-in.patch (drm-backport-placeholder)
- commit 026b4b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0666-drm-amd-display-add-more-pipe-resource-interfaces.patch (drm-backport-placeholder)
- commit d03b0f3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0665-drm-amd-display-add-new-resource-interfaces-to-updat.patch (drm-backport-placeholder)
- commit de71902
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0664-drm-amd-display-add-new-resource-interface-for-acqui.patch (drm-backport-placeholder)
- commit 513031a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0663-drm-amd-display-rename-function-to-add-otg-master-fo.patch (drm-backport-placeholder)
- commit c8cafa7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0662-drm-amd-display-add-comments-to-add-plane-functions.patch (drm-backport-placeholder)
- commit a273de9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0661-drm-amd-display-Add-support-for-1080p-SubVP-to-reduc.patch (drm-backport-placeholder)
- commit 172a93d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0660-drm-amdgpu-add-header-files-for-MP-14.0.0.patch (drm-backport-placeholder)
- commit 5fd08be
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-amdgpu-amdgpu_doorbell_mgr-Correct-misdocume.patch (drm-backport-placeholder)
- commit ccc736b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0658-drm-amd-amdgpu-imu_v11_0-Increase-buffer-size-to-ens.patch (drm-backport-placeholder)
- commit 31e800d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0657-drm-amd-amdgpu-amdgpu_sdma-Increase-buffer-size-to-a.patch (drm-backport-placeholder)
- commit f62d9ee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0656-drm-amd-amdgpu-amdgpu_ras-Increase-buffer-size-to-ac.patch (drm-backport-placeholder)
- commit 798edbb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0655-drm-amd-amdgpu-amdgpu_device-Provide-suitable-descri.patch (drm-backport-placeholder)
- commit 4647ce5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0654-drm-radeon-radeon_ttm-Remove-unused-variable-rbo-fro.patch (drm-backport-placeholder)
- commit c84ae9b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0653-drm-amd-Fix-spelling-mistake-throtting-throttling.patch (drm-backport-placeholder)
- commit 593d8e4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0652-drm-amdgpu-Use-kvzalloc-to-simplify-code.patch (drm-backport-placeholder)
- commit 4031700
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0651-drm-amdgpu-Remove-amdgpu_bo_list_array_entry.patch (drm-backport-placeholder)
- commit e14b426
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0650-drm-amdgpu-Remove-a-redundant-sanity-check.patch (drm-backport-placeholder)
- commit 2468669
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0649-drm-amdgpu-Explicitly-add-a-flexible-array-at-the-en.patch (drm-backport-placeholder)
- commit 8ed9a24
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0648-drm-amdgpu-Allow-issue-disable-gfx-ras-cmd-to-firmwa.patch (drm-backport-placeholder)
- commit 69ac427
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0647-amdgpu-pm-Replace-print_clock_levels-with-emit_clock.patch (drm-backport-placeholder)
- commit 3c5f767
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0646-drm-amd-pm-fulfill-the-support-for-SMU13-pp_dpm_dcef.patch (drm-backport-placeholder)
- commit 0ce312d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0645-drm-amd-pm-correct-SMU13-gfx-voltage-related-OD-sett.patch (drm-backport-placeholder)
- commit 4e6c470
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0644-drm-amdgpu-pm-Remove-the-duplicate-dpm-status-check.patch (drm-backport-placeholder)
- commit 89cba8e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0643-drm-amd-pm-Vangogh-Get-average_-from-average-field-o.patch (drm-backport-placeholder)
- commit 16ab0cc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0642-drm-amd-pm-Fixes-incorrect-type-in-amdgpu_hwmon_show.patch (drm-backport-placeholder)
- commit 2905ace
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0641-drm-amd-pm-fix-error-flow-in-sensor-fetching.patch (drm-backport-placeholder)
- commit fa9c2e9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0640-drm-amdgpu-Fix-kcalloc-over-kzalloc-in-gmc_v9_0_init.patch (drm-backport-placeholder)
- commit ff08a05
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0639-drm-amdkfd-Share-the-original-BO-for-GTT-mapping.patch (drm-backport-placeholder)
- commit 184a289
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0638-drm-amd-display-3.2.248.patch (drm-backport-placeholder)
- commit 0c44920
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0637-drm-amd-display-FW-Promotion-Release-0.0.180.0.patch (drm-backport-placeholder)
- commit 4abeea4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0636-drm-amd-display-ensure-FS-is-enabled-before-sending-.patch (drm-backport-placeholder)
- commit d7cc7b1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0635-drm-amd-display-add-check-for-PMFW-hard-min-request-.patch (drm-backport-placeholder)
- commit b2948ed
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0634-drm-amd-display-Save-addr-update-in-scratch-before-f.patch (drm-backport-placeholder)
- commit 3e3c839
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0633-drm-amdgpu-add-gfxhub-11.5.0-support.patch (drm-backport-placeholder)
- commit dfbfdde
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0632-drm-amdgpu-enable-gmc11-for-GC-11.5.0.patch (drm-backport-placeholder)
- commit d186b64
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0631-drm-amdgpu-add-mmhub-3.3.0-support.patch (drm-backport-placeholder)
- commit 7352ae7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0630-drm-amdgpu-add-mmhub-3.3.0-headers.patch (drm-backport-placeholder)
- commit 7a1ecac
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0629-drm-amdgpu-discovery-enable-gfx11-for-GC-11.5.0.patch (drm-backport-placeholder)
- commit 0665893
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0628-drm-amdgpu-discovery-enable-mes-block-for-gc-11.5.0.patch (drm-backport-placeholder)
- commit 78f0047
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0627-drm-amdgpu-add-mes-firmware-support-for-gc_11_5_0.patch (drm-backport-placeholder)
- commit 98141ea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0626-drm-amdgpu-add-imu-firmware-support-for-gc_11_5_0.patch (drm-backport-placeholder)
- commit 836aefd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0625-drm-amdkfd-add-KFD-support-for-GC-11.5.0.patch (drm-backport-placeholder)
- commit d134b72
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0624-drm-amdgpu-add-golden-setting-for-gc_11_5_0.patch (drm-backport-placeholder)
- commit d031f6b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0623-drm-amdgpu-gfx11-initialize-gfx11.5.0.patch (drm-backport-placeholder)
- commit cbe5a97
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0622-drm-amdgpu-gmc11-initialize-GMC-for-GC-11.5.0-memory.patch (drm-backport-placeholder)
- commit 31da162
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0621-drm-amdgpu-add-gc-headers-for-gc-11.5.0.patch (drm-backport-placeholder)
- commit a25e323
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0620-drm-amdgpu-discovery-add-nbio-7.11.0-support.patch (drm-backport-placeholder)
- commit 0d95262
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0619-drm-amdgpu-add-nbio-7.11-support.patch (drm-backport-placeholder)
- commit 6cbcfb0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0618-drm-amdgpu-add-nbio-7.11-registers.patch (drm-backport-placeholder)
- commit 233f2a2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0617-drm-amdgpu-discovery-enable-soc21-support.patch (drm-backport-placeholder)
- commit 7fa58cc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0616-drm-amdgpu-soc21-add-initial-GC-11.5.0-soc21-support.patch (drm-backport-placeholder)
- commit e85afa4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0615-drm-amdgpu-add-new-AMDGPU_FAMILY-definition.patch (drm-backport-placeholder)
- commit 0727429
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0614-drm-amdgpu-use-6.1.0-register-offset-for-HDP-CLK_CNT.patch (drm-backport-placeholder)
- commit 34a3023
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0612-drm-amd-display-Write-flip-addr-to-scratch-reg-for-s.patch (drm-backport-placeholder)
- commit 0c4f4fb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0611-drm-amd-display-Enable-runtime-register-offset-init-.patch (drm-backport-placeholder)
- commit 5a7fced
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Refactor-edp-power-control.patch (drm-backport-placeholder)
- commit e26b954
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0609-drm-amd-display-PQ-regamma-end-point.patch (drm-backport-placeholder)
- commit 35ff1de
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0608-drm-amd-display-PQ-tail-accuracy.patch (drm-backport-placeholder)
- commit 15152fc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0607-drm-amd-display-Expose-mall-capability.patch (drm-backport-placeholder)
- commit 9f81d33
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0606-drm-amd-display-Fix-useless-else-if-in-display_mode_.patch (drm-backport-placeholder)
- commit d2952de
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0605-drm-radeon-Cleanup-radeon-radeon_fence.c.patch (drm-backport-placeholder)
- commit 12ad026
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0604-drm-amd-display-Fix-unnecessary-conversion-to-bool-i.patch (drm-backport-placeholder)
- commit c7fdad2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0603-drm-amdgpu-Keep-reset-handlers-shared.patch (drm-backport-placeholder)
- commit 9c50b98
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0602-drm-amd-amdgpu-Use-kmemdup-to-simplify-kmalloc-and-m.patch (drm-backport-placeholder)
- commit 45276a0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0601-accel-habanalabs-change-Greco-to-Gaudi2.patch (drm-backport-placeholder)
- commit 20c594c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0600-accel-habanalabs-add-tsc-clock-sampling-to-clock-syn.patch (drm-backport-placeholder)
- commit 1448c00
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0599-drm-i915-More-use-of-GT-specific-print-helpers.patch (drm-backport-placeholder)
- commit 69ca090
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0598-drm-i915-gt-More-use-of-GT-specific-print-helpers.patch (drm-backport-placeholder)
- commit c488014
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0597-drm-i915-guc-Enable-WA-14018913170.patch (drm-backport-placeholder)
- commit 892762d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0596-drm-i915-guc-Annotate-struct-ct_incoming_msg-with-__.patch (drm-backport-placeholder)
- commit e3127a7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0595-drm-i915-guc-Update-recommended-version-to-70.12.1-f.patch (drm-backport-placeholder)
- commit 54cfa92
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0594-drm-i915-guc-Suppress-ignoring-reset-notification-me.patch (drm-backport-placeholder)
- commit 8157f9f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0593-drm-i915-Clarify-type-evolution-of-uabi_node-uabi_en.patch (drm-backport-placeholder)
- commit 1afac83
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0592-drm-i915-Enable-GGTT-updates-with-binder-in-MTL.patch (drm-backport-placeholder)
- commit d0dadb8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0591-drm-i915-Toggle-binder-context-ready-status.patch (drm-backport-placeholder)
- commit 9764239
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0590-drm-i915-Implement-GGTT-update-method-with-MI_UPDATE.patch (drm-backport-placeholder)
- commit 2d821d4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0589-drm-i915-Parameterize-binder-context-creation.patch (drm-backport-placeholder)
- commit 04c0676
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0588-drm-i915-Implement-for_each_sgt_daddr_next.patch (drm-backport-placeholder)
- commit 82a1074
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0587-drm-i915-Create-a-kernel-context-for-GGTT-updates.patch (drm-backport-placeholder)
- commit 8450355
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0586-drm-i915-Lift-runtime-pm-acquire-callbacks-out-of-in.patch (drm-backport-placeholder)
- commit 6bf63fd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0585-drm-i915-gem-Make-i915_gem_shrinker-multi-gt-aware.patch (drm-backport-placeholder)
- commit 8450b44
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0584-drm-i915-mtl-Skip-MCR-ops-for-ring-fault-register.patch (drm-backport-placeholder)
- commit 3dad69c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0583-drm-i915-Clean-steer-semaphore-on-resume.patch (drm-backport-placeholder)
- commit 7e02bb1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0582-drm-i915-Introduce-the-intel_gt_resume_early.patch (drm-backport-placeholder)
- commit 04bd1e8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0581-drm-i915-Introduce-intel_gt_mcr_lock_sanitize.patch (drm-backport-placeholder)
- commit b526610
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0580-drm-i915-dsi-Add-some-debug-logging-to-mipi_exec_i2c.patch (drm-backport-placeholder)
- commit 146c1a5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0579-drm-i915-vlv_dsi-Add-DMI-quirk-for-backlight-control.patch (drm-backport-placeholder)
- commit 3176eeb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0578-drm-i915-vlv_dsi-Add-DMI-quirk-for-wrong-I2C-bus-and.patch (drm-backport-placeholder)
- commit 9f203c0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0577-drm-i915-vlv_dsi-Add-DMI-quirk-for-wrong-panel-model.patch (drm-backport-placeholder)
- commit b3b5971
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0576-drm-i915-Remove-the-module-parameter-fastboot.patch (drm-backport-placeholder)
- commit 0670db8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0575-drm-i915-hdcp-Move-common-message-filling-function-t.patch (drm-backport-placeholder)
- commit a29c310
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0574-drm-i915-hdcp-Move-checks-for-gsc-health-status.patch (drm-backport-placeholder)
- commit bb6d32f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0573-drm-i915-display-Use-correct-method-to-free-crtc_sta.patch (drm-backport-placeholder)
- commit 4927343
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0572-drm-i915-display-Use-intel_crtc_destroy_state-instea.patch (drm-backport-placeholder)
- commit 94d9127
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0571-drm-i915-enable-W-1-warnings-by-default.patch (drm-backport-placeholder)
- commit 49d9a11
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0570-drm-i915-drop-Wall-and-related-disables-from-cflags-.patch (drm-backport-placeholder)
- commit de06077
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0569-drm-i915-gvt-move-structs-intel_gvt_irq_info-and-int.patch (drm-backport-placeholder)
- commit edb2501
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0568-drm-i915-gvt-move-struct-engine_mmio-to-mmio_context.patch (drm-backport-placeholder)
- commit 32eadca
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0567-drm-i915-gvt-don-t-include-gvt.h-from-intel_gvt_mmio.patch (drm-backport-placeholder)
- commit 6127278
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0566-drm-i915-gvt-remove-unused-to_gvt-and-reduce-include.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit c4119b5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0565-drm-i915-xe2lpd-update-the-scaler-feature-capability.patch (drm-backport-placeholder)
- commit a3968b6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0564-drm-i915-xe2lpd-update-the-dsc-feature-capability.patch (drm-backport-placeholder)
- commit 674128d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0563-drm-i915-xe2lpd-display-capability-register-definiti.patch (drm-backport-placeholder)
- commit 6bda643
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0562-drm-i915-Add-wrapper-for-getting-display-step.patch (drm-backport-placeholder)
- commit c327d0d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0561-drm-i915-display-Free-crtc_state-in-verify_crtc_stat.patch (drm-backport-placeholder)
- commit 54e55cf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0560-drm-i915-Fix-VLV-color-state-readout.patch (drm-backport-placeholder)
- commit 48c499e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0559-drm-i915-uapi-fix-doc-typos.patch (drm-backport-placeholder)
- commit da340e8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0558-drm-i915-ddi-Remove-redundant-intel_connector-NULL-c.patch (drm-backport-placeholder)
- commit 4012e39
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0557-drm-i915-s-dev_priv-i915-in-the-state-checker.patch (drm-backport-placeholder)
- commit 779bb0c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0556-drm-i915-s-pipe_config-crtc_state-in-the-state-check.patch (drm-backport-placeholder)
- commit 31c78bc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0555-drm-i915-Simplify-the-state-checker-calling-convetio.patch (drm-backport-placeholder)
- commit e26795c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0554-drm-i915-Constify-remainder-of-the-state-checker.patch (drm-backport-placeholder)
- commit 19ad54d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0553-drm-i915-Simplify-snps-c10x-DPLL-state-checker-calli.patch (drm-backport-placeholder)
- commit 3b9155d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0552-drm-i915-Constify-the-snps-c10x-PLL-state-checkers.patch (drm-backport-placeholder)
- commit 6a67ce5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0551-drm-i915-Simplify-watermark-state-checker-calling-co.patch (drm-backport-placeholder)
- commit d01d80d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0550-drm-i915-Constify-watermark-state-checker.patch (drm-backport-placeholder)
- commit a924473
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0549-drm-i915-Simplify-DPLL-state-checker-calling-convent.patch (drm-backport-placeholder)
- commit c6b2f41
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0548-drm-i915-Constify-the-crtc-states-in-the-DPLL-checke.patch (drm-backport-placeholder)
- commit 32c1aaa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0547-drm-i915-Stop-clobbering-old-crtc-state-during-state.patch (drm-backport-placeholder)
- commit 333e583
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0546-drm-i915-psr-Unify-PSR-pre-post-plane-update-hooks.patch (drm-backport-placeholder)
- commit 205582c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0545-drm-i915-fbc-Remove-pointless-stride-is-multiple-of-.patch (drm-backport-placeholder)
- commit e9d7e3b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0544-drm-i915-fbc-Split-plane-pixel-format-checks-per-pla.patch (drm-backport-placeholder)
- commit 76ae3ff
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0543-drm-i915-fbc-Split-plane-rotation-checks-per-platfor.patch (drm-backport-placeholder)
- commit 4bbfcd0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0542-drm-i915-fbc-Split-plane-tiling-checks-per-platform.patch (drm-backport-placeholder)
- commit fb0800c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0541-drm-i915-fbc-Split-plane-stride-checks-per-platform.patch (drm-backport-placeholder)
- commit c6cf442
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0540-drm-i915-fbc-Remove-ancient-16k-plane-stride-limit.patch (drm-backport-placeholder)
- commit fb12771
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0539-drm-i915-pmu-Use-local64_try_cmpxchg-in-i915_pmu_eve.patch (drm-backport-placeholder)
- commit a25093b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0538-drm-i915-display-Created-exclusive-version-of-vga-de.patch (drm-backport-placeholder)
- commit e536c55
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0537-drm-i915-dp_mst-Make-sure-pbn_div-is-up-to-date-afte.patch (drm-backport-placeholder)
- commit 3f85e68
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0536-drm-i915-display-lspcon-Increase-LSPCON-mode-settle-.patch (drm-backport-placeholder)
- commit ef92e02
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0535-drm-i915-gt-remove-i915-gt0-in-favour-of-i915-gt-0.patch (drm-backport-placeholder)
- commit 78b05f3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0534-drm-i915-allocate-i915-gt0-dynamically.patch (drm-backport-placeholder)
- commit d22c768
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0533-drm-i915-mocs-use-to_gt-instead-of-direct-i915-gt.patch (drm-backport-placeholder)
- commit 07184a2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0532-drm-i915-s-dev_priv-i915-in-the-shared_dpll-code.patch (drm-backport-placeholder)
- commit 6f2be0c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0531-drm-i915-Introduce-for_each_shared_dpll.patch (drm-backport-placeholder)
- commit c049db7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0530-drm-i915-Decouple-I915_NUM_PLLS-from-PLL-IDs.patch (drm-backport-placeholder)
- commit 9c2ac47
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0529-drm-i915-Stop-requiring-PLL-index-PLL-ID.patch (drm-backport-placeholder)
- commit 2a9284f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0528-drm-i915-separate-subplatform-init-and-runtime-featu.patch (drm-backport-placeholder)
- commit 7b73bf6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0527-drm-i915-separate-display-runtime-info-init.patch (drm-backport-placeholder)
- commit b540cd3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0526-drm-i915-move-display-info-related-macros-to-display.patch (drm-backport-placeholder)
- commit b919aa9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0525-drm-i915-convert-INTEL_DISPLAY_ENABLED-into-a-functi.patch (drm-backport-placeholder)
- commit c28a651
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0524-drm-i915-lnl-update-the-supported-plane-formats-with.patch (drm-backport-placeholder)
- commit 92e8e53
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0523-drm-i915-lnl-possibility-to-enable-FBC-on-first-thre.patch (drm-backport-placeholder)
- commit 2f7942c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Add-missing-GSCCS-documentation.patch (drm-backport-placeholder)
- commit ead43ee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Add-missing-CCS-documentation.patch (drm-backport-placeholder)
- commit 245c5ff
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0520-drm-i915-Abstract-display-info-away-during-probe.patch (drm-backport-placeholder)
- commit 74be68a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0519-drm-i915-display-Include-i915_active-header-in-front.patch (drm-backport-placeholder)
- commit 3c0f806
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0518-drm-i915-display-add-I915-conditional-build-to-vlv_d.patch (drm-backport-placeholder)
- commit 15f20a4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0517-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 158739b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0516-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 1a35f90
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0515-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 894ea78
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0514-drm-i915-display-add-I915-conditional-build-to-g4x_h.patch (drm-backport-placeholder)
- commit e7d3c42
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0513-drm-i915-display-add-I915-conditional-build-to-i9xx_.patch (drm-backport-placeholder)
- commit a4df461
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0512-drm-i915-display-add-I915-conditional-build-to-vlv_d.patch (drm-backport-placeholder)
- commit cea3710
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0511-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 35ee5b9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0510-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 87134ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0509-drm-i915-display-add-I915-conditional-build-to-g4x_d.patch (drm-backport-placeholder)
- commit c918644
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0508-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 86258f9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0507-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 96f41df
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0506-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit f453c61
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0505-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 20ccaca
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0504-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 06949bb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0503-drm-i915-display-add-I915-conditional-build-to-i9xx_.patch (drm-backport-placeholder)
- commit f950eae
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0502-drm-i915-display-add-I915-conditional-build-to-hsw_i.patch (drm-backport-placeholder)
- commit ee09a06
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0501-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 8e22420
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0500-drm-i915-define-I915-during-i915-driver-build.patch (drm-backport-placeholder)
- commit 023efa5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0499-drm-simpledrm-Fix-power-domain-device-link-validity-.patch (drm-backport-placeholder)
- commit 268b3b3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0498-drm-Replace-drm_framebuffer-plane-size-functions-wit.patch (drm-backport-placeholder)
- commit a21d931
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0497-drm-Remove-plane-hsub-vsub-alignment-requirement-for.patch (drm-backport-placeholder)
- commit 87f5925
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0496-drm-tegra-gem-Do-not-return-NULL-in-tegra_bo_mmap.patch (drm-backport-placeholder)
- commit c49a532
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0495-drm-tegra-Zero-initialize-iosys_map.patch (drm-backport-placeholder)
- commit 411d932
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/gpu-host1x-Correct-allocated-size-for-contexts.patch (drm-backport-placeholder)
- commit e587fdd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0493-gpu-host1x-Syncpoint-interrupt-sharding.patch (drm-backport-placeholder)
- commit c546a96
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0492-gpu-host1x-Enable-system-suspend-callbacks.patch (drm-backport-placeholder)
- commit 1f614da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0491-gpu-host1x-Stop-CDMA-before-suspending.patch (drm-backport-placeholder)
- commit 70f8e46
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0490-gpu-host1x-Add-locking-in-channel-allocation.patch (drm-backport-placeholder)
- commit f7ef107
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0489-drm-tegra-hub-Increase-buffer-size-to-ensure-all-pos.patch (drm-backport-placeholder)
- commit 8d3fe41
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0488-drm-tegra-Remove-two-unused-function-declarations.patch (drm-backport-placeholder)
- commit 286c2bc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0487-drm-tegra-Remove-surplus-else-after-return.patch (drm-backport-placeholder)
- commit f9deea7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0486-drm-bridge_connector-implement-oob_hotplug_event.patch (drm-backport-placeholder)
- commit d207ee6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0485-drm-bridge_connector-stop-filtering-events-in-drm_br.patch (drm-backport-placeholder)
- commit 2cf61b9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0483-drm-i915-Update-DRIVER_DATE-to-20230929.patch (drm-backport-placeholder)
- commit 85a2101
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0482-drm-i915-Warn-on-if-set-frontbuffer-return-value-is-.patch (drm-backport-placeholder)
- commit 4071d59
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0481-drm-i915-fdi-Recompute-state-for-affected-CRTCs-on-F.patch (drm-backport-placeholder)
- commit 5821664
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0480-drm-i915-fdi-Improve-FDI-BW-sharing-between-pipe-B-a.patch (drm-backport-placeholder)
- commit 741c621
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0479-drm-i915-Add-helpers-for-BW-management-on-shared-dis.patch (drm-backport-placeholder)
- commit 430e235
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0478-drm-i915-Factor-out-a-helper-to-check-compute-all-th.patch (drm-backport-placeholder)
- commit 334fdd3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0477-drm-i915-Rename-intel_modeset_all_pipes-to-intel_mod.patch (drm-backport-placeholder)
- commit 021f7b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0476-drm-i915-Add-helper-to-modeset-a-set-of-pipes.patch (drm-backport-placeholder)
- commit db682fa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0475-drm-i915-dp-Limit-the-output-link-bpp-in-DSC-mode.patch (drm-backport-placeholder)
- commit 4aea637
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0474-drm-i915-dp-Update-the-link-bpp-limits-for-DSC-mode.patch (drm-backport-placeholder)
- commit b8cc349
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0473-drm-i915-dp-Skip-computing-a-non-DSC-link-config-if-.patch (drm-backport-placeholder)
- commit ac50d96
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0472-drm-i915-dp-Track-the-pipe-and-link-bpp-limits-separ.patch (drm-backport-placeholder)
- commit 56c9fe1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0471-drm-i915-dp-Factor-out-helpers-to-compute-the-link-l.patch (drm-backport-placeholder)
- commit a311fb4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0470-drm-i915-dsb-Use-DEwake-to-combat-PkgC-latency.patch (drm-backport-placeholder)
- commit 1c086e9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0469-drm-i915-Introduce-intel_crtc_scanline_to_hw.patch (drm-backport-placeholder)
- commit deb9ecc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0468-drm-i915-Introduce-skl_watermark_max_latency.patch (drm-backport-placeholder)
- commit 017e90b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0467-drm-i915-dsb-Evade-transcoder-undelayed-vblank-when-.patch (drm-backport-placeholder)
- commit ce94e1e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0466-drm-i915-dsb-Use-non-posted-register-writes-for-lega.patch (drm-backport-placeholder)
- commit 036dab9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0465-drm-i915-dsb-Load-LUTs-using-the-DSB-during-vblank.patch (drm-backport-placeholder)
- commit f853bbd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0464-drm-i915-dsb-Don-t-use-DSB-to-load-the-LUTs-during-f.patch (drm-backport-placeholder)
- commit 6a907a7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0463-drm-i915-dsb-Add-support-for-non-posted-DSB-register.patch (drm-backport-placeholder)
- commit 1e257a6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0462-drm-i915-dsb-Introduce-intel_dsb_reg_write_masked.patch (drm-backport-placeholder)
- commit 88db2ba
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0461-drm-i915-dsb-Introduce-intel_dsb_noop.patch (drm-backport-placeholder)
- commit 68eb3ff
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0460-drm-i915-dsb-Define-the-contents-of-some-intstructio.patch (drm-backport-placeholder)
- commit bfa66c6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0459-drm-i915-dsb-Define-more-DSB-bits.patch (drm-backport-placeholder)
- commit d1d0d58
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0458-drm-i915-dsb-Use-non-locked-register-access.patch (drm-backport-placeholder)
- commit bebc84d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0457-drm-i915-cx0-prefer-forward-declarations-over-includ.patch (drm-backport-placeholder)
- commit 8ce7b7e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0456-drm-i915-dp-refactor-aux_ch_name.patch (drm-backport-placeholder)
- commit 4b28adb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0455-drm-i915-irq-Clear-GFX_MSTR_IRQ-as-part-of-IRQ-reset.patch (drm-backport-placeholder)
- commit 0d34e3c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0454-drm-i915-display-Print-display-info-inside-driver-di.patch (drm-backport-placeholder)
- commit 6da3162
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0453-drm-i915-bios-Fixup-h-vsync_end-instead-of-h-vtotal.patch (drm-backport-placeholder)
- commit 4d39642
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0452-drm-i915-lnl-Start-using-CDCLK-through-PLL.patch (drm-backport-placeholder)
- commit 872d0f8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0451-drm-i915-xe2lpd-Add-DC-state-support.patch (drm-backport-placeholder)
- commit ac8cc96
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0450-drm-i915-xe2lpd-Add-display-power-well.patch (drm-backport-placeholder)
- commit 3034380
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0449-drm-i915-lnl-Add-CDCLK-table.patch (drm-backport-placeholder)
- commit fe8c342
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0448-drm-i915-lnl-Add-gmbus-ddc-support.patch (drm-backport-placeholder)
- commit 549d6d0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0447-drm-i915-xe2lpd-Extend-Wa_15010685871.patch (drm-backport-placeholder)
- commit c7b5d59
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0446-drm-i915-xe2lpd-Add-support-for-HPD.patch (drm-backport-placeholder)
- commit f31a92e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0445-drm-i915-xe2lpd-Enable-odd-size-and-panning-for-plan.patch (drm-backport-placeholder)
- commit 4f196b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0444-drm-i915-xe2lpd-Read-pin-assignment-from-IOM.patch (drm-backport-placeholder)
- commit 6d18710
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0443-drm-i915-xe2lpd-Handle-port-AUX-interrupts.patch (drm-backport-placeholder)
- commit 5405f4d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0442-drm-i915-xe2lpd-Re-order-DP-AUX-regs.patch (drm-backport-placeholder)
- commit f38b453
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0441-drm-i915-display-Use-_PICK_EVEN_2RANGES-in-DP-AUX-re.patch (drm-backport-placeholder)
- commit 35be3a7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0440-drm-i915-display-Fix-style-and-conventions-for-DP-AU.patch (drm-backport-placeholder)
- commit edc8fb5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0439-drm-i915-xe2lpd-Register-DE_RRMR-has-been-removed.patch (drm-backport-placeholder)
- commit 6f3784c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0438-drm-i915-xe2lpd-Don-t-try-to-program-PLANE_AUX_DIST.patch (drm-backport-placeholder)
- commit 91017fe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0437-drm-i915-xe2lpd-Treat-cursor-plane-as-regular-plane-.patch (drm-backport-placeholder)
- commit 3be7827
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0436-drm-i915-xe2lpd-Add-fake-PCH.patch (drm-backport-placeholder)
- commit 1297b20
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0435-drm-i915-Re-order-if-else-ladder-in-intel_detect_pch.patch (drm-backport-placeholder)
- commit 6091379
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0434-drm-i915-display-Remove-FBC-capability-from-fused-of.patch (drm-backport-placeholder)
- commit 1d243e2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0433-drm-i915-xe2lpd-FBC-is-now-supported-on-all-pipes.patch (drm-backport-placeholder)
- commit 541c55a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0432-drm-i915-lnl-Add-display-definitions.patch (drm-backport-placeholder)
- commit 992f730
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0431-drm-i915-xelpdp-Add-XE_LPDP_FEATURES.patch (drm-backport-placeholder)
- commit 77c1516
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0430-Revert-drm-i915-mst-Populate-connector-ddc.patch (drm-backport-placeholder)
- commit 24fca24
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0429-drm-i915-add-a-note-about-fec_enable-with-128b-132b.patch (drm-backport-placeholder)
- commit 57bbb78
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0428-drm-i915-Implement-transcoder-LRR-for-TGL.patch (drm-backport-placeholder)
- commit 5fe612f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0427-drm-i915-Assert-that-VRR-is-off-during-vblank-evasio.patch (drm-backport-placeholder)
- commit fa700d5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0426-drm-i915-Update-VRR-parameters-in-fastset.patch (drm-backport-placeholder)
- commit 8afcf94
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0425-drm-i915-Disable-VRR-during-seamless-M-N-changes.patch (drm-backport-placeholder)
- commit 7f53ef9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0424-drm-i915-Validate-that-the-timings-are-within-the-VR.patch (drm-backport-placeholder)
- commit b2940fe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0423-drm-i915-Relocate-is_in_vrr_range.patch (drm-backport-placeholder)
- commit d36f941
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0422-drm-i915-Optimize-out-redundant-M-N-updates.patch (drm-backport-placeholder)
- commit 435b9d0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0421-drm-i915-Adjust-seamless_m_n-flag-behaviour.patch (drm-backport-placeholder)
- commit 3647489
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0420-drm-i915-Enable-VRR-later-during-fastsets.patch (drm-backport-placeholder)
- commit 7aaed24
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0419-drm-i915-Extract-intel_crtc_vblank_evade_scanlines.patch (drm-backport-placeholder)
- commit 0f7574c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0418-drm-i915-Change-intel_pipe_update_-start-end-calling.patch (drm-backport-placeholder)
- commit 5f3cea9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0417-drm-i915-Move-psr-unlock-out-from-the-pipe-update-cr.patch (drm-backport-placeholder)
- commit 6bc15cd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0416-drm-i915-dsi-let-HW-maintain-CLK_POST.patch (drm-backport-placeholder)
- commit 7626644
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0415-drm-i915-cx0-Add-step-for-programming-msgbus-timer.patch (drm-backport-placeholder)
- commit a8d5437
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0414-drm-i915-dp_mst-Tune-down-error-message-during-paylo.patch (drm-backport-placeholder)
- commit 204cae9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0413-drm-i915-Remove-runtime-suspended-boolean-from-intel.patch (drm-backport-placeholder)
- commit 85200f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0412-drm-i915-move-intel_display_device_probe-one-level-h.patch (drm-backport-placeholder)
- commit f3807d4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0411-drm-i915-display-call-gmdid-display-probe-at-a-highe.patch (drm-backport-placeholder)
- commit 3d8537f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0410-drm-i915-move-more-of-the-display-probe-to-display-c.patch (drm-backport-placeholder)
- commit 4594291
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0409-drm-i915-dpt-replace-GEM_BUG_ON-with-drm_WARN_ON.patch (drm-backport-placeholder)
- commit a9db01f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0408-drm-i915-fb-replace-GEM_WARN_ON-with-drm_WARN_ON.patch (drm-backport-placeholder)
- commit de64f17
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0407-drm-i915-fbc-replace-GEM_BUG_ON-to-drm_WARN_ON.patch (drm-backport-placeholder)
- commit ec8883c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0406-drm-i915-sdvo-Constify-mapping-structs.patch (drm-backport-placeholder)
- commit 9645317
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0405-drm-i915-hdmi-Remove-old-i2c-symlink.patch (drm-backport-placeholder)
- commit 901d850
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0404-drm-i915-hdmi-Nuke-hdmi-ddc_bus.patch (drm-backport-placeholder)
- commit ed1b569
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0403-drm-i915-hdmi-Use-connector-ddc-everwhere.patch (drm-backport-placeholder)
- commit 3ad9d65
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0402-drm-i915-mst-Populate-connector-ddc.patch (drm-backport-placeholder)
- commit 8ca10d4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0401-drm-i915-dp-Populate-connector-ddc.patch (drm-backport-placeholder)
- commit 989b6f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0400-drm-i915-dvo-Populate-connector-ddc.patch (drm-backport-placeholder)
- commit 461b856
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0399-drm-i915-crt-Populate-connector-ddc.patch (drm-backport-placeholder)
- commit 7f572b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0398-drm-i915-lvds-Populate-connector-ddc.patch (drm-backport-placeholder)
- commit 4aa0ea8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0397-drm-i915-Call-the-DDC-bus-i2c-adapter-ddc.patch (drm-backport-placeholder)
- commit 52c8818
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0396-drm-sysfs-Register-ddc-symlink-later.patch (drm-backport-placeholder)
- commit 8ffca88
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0395-drm-Reorder-drm_sysfs_connector_remove-vs.-drm_debug.patch (drm-backport-placeholder)
- commit 3e24f4e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0394-drm-i915-dsc-Fix-pic_width-readout.patch (drm-backport-placeholder)
- commit 7f23b93
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Introduce-crtc_state-enhanced_framing.patch (drm-backport-placeholder)
- commit 0886fa3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0392-drm-i915-Reduce-combo-PHY-log-spam.patch (drm-backport-placeholder)
- commit e9221f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0391-drm-i915-Stop-spamming-the-logs-with-PLL-state.patch (drm-backport-placeholder)
- commit 6c046a5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0390-drm-i915-Split-some-long-lines-in-hsw_fdi_link_train.patch (drm-backport-placeholder)
- commit 3d9e013
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-FEC-state-dump.patch (drm-backport-placeholder)
- commit 046fcca
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0388-drm-i915-Fix-FEC-pipe-A-vs.-DDI-A-mixup.patch (drm-backport-placeholder)
- commit 34c6758
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0387-drm-i915-mst-Read-out-FEC-state.patch (drm-backport-placeholder)
- commit d8a53cd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0386-drm-i915-gt-rename-DBG-to-GTT_TRACE.patch (drm-backport-placeholder)
- commit 44b08f4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0385-drm-i915-dsc-use-REG_BIT-REG_GENMASK-and-friends-for.patch (drm-backport-placeholder)
- commit 0c6a99c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0384-drm-i915-dsc-add-the-PPS-number-to-the-register-cont.patch (drm-backport-placeholder)
- commit fb048ef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0383-drm-i915-dsc-clean-up-pps-comments.patch (drm-backport-placeholder)
- commit b8e1589
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0382-drm-i915-dsc-drop-redundant-0-assignments.patch (drm-backport-placeholder)
- commit 5a57f74
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0381-drm-i915-dsc-rename-pps-write-to-intel_dsc_pps_write.patch (drm-backport-placeholder)
- commit 5bebf7c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0380-drm-i915-dsc-have-intel_dsc_pps_read-return-the-valu.patch (drm-backport-placeholder)
- commit 836c1fb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0379-drm-i915-dsc-have-intel_dsc_pps_read_and_verify-retu.patch (drm-backport-placeholder)
- commit 2111f74
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0378-drm-i915-dsc-improve-clarity-of-the-pps-reg-read-wri.patch (drm-backport-placeholder)
- commit 94712b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0377-drm-i915-display-Apply-workarounds-during-display-in.patch (drm-backport-placeholder)
- commit 170f2a7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0376-drm-i915-display-Extract-display-workarounds-from-cl.patch (drm-backport-placeholder)
- commit 1a9b7b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0375-drm-i915-adlp-Stop-calling-gen12lp_init_clock_gating.patch (drm-backport-placeholder)
- commit 0beb54d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0374-drm-i915-Stop-forcing-clock-gating-init-for-future-p.patch (drm-backport-placeholder)
- commit a062d80
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0373-drm-i915-dsb-Don-t-use-indexed-writes-when-byte-enab.patch (drm-backport-placeholder)
- commit 2231bc9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0372-drm-i915-dsb-Avoid-corrupting-the-first-register-wri.patch (drm-backport-placeholder)
- commit 301c053
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0371-drm-i915-dsb-Dump-the-DSB-command-buffer-when-DSB-fa.patch (drm-backport-placeholder)
- commit ba51bdd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0370-drm-i915-Constify-LUT-entries-in-checker.patch (drm-backport-placeholder)
- commit b493d8a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0369-drm-i915-cx0-Check-and-increase-msgbus-timeout-thres.patch (drm-backport-placeholder)
- commit 12b3835
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0368-drm-i915-add-trailing-newlines-to-msgs.patch (drm-backport-placeholder)
- commit a1b2905
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0367-drm-i915-psr-Add-psr-sink-error-status-into-sink-sta.patch (drm-backport-placeholder)
- commit b365dc2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0366-drm-i915-tc-remove-fia-from-intel_tc_port_fia_max_la.patch (drm-backport-placeholder)
- commit 74094e8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0365-drm-i915-tc-move-legacy-code-out-of-the-main-_max_la.patch (drm-backport-placeholder)
- commit f45ca33
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0364-drm-i915-tc-make-intel_tc_port_get_lane_mask-static.patch (drm-backport-placeholder)
- commit 132ee57
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0363-drm-i915-tc-rename-mtl_tc_port_get_pin_assignment_ma.patch (drm-backport-placeholder)
- commit 8dcbb4a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0362-drm-i915-display-Compare-the-readout-dsc-pps-params.patch (drm-backport-placeholder)
- commit 2b30021
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0361-drm-i915-vdsc-Fill-the-intel_dsc_get_pps_config-func.patch (drm-backport-placeholder)
- commit dd5f189
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0360-drm-i915-vdsc-Remove-unused-dsc-registers.patch (drm-backport-placeholder)
- commit b0f31c3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0359-drm-i915-vdsc-Add-function-to-write-in-PPS-register.patch (drm-backport-placeholder)
- commit 5abb790
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0358-drm-i915-vdsc-Add-function-to-read-any-PPS-register.patch (drm-backport-placeholder)
- commit 00e13fb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0357-drm-i915-vdsc-Add-func-to-get-no.-of-vdsc-instances-.patch (drm-backport-placeholder)
- commit 67fcdec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0356-drm-i915-vdsc-Add-a-check-for-dsc-split-cases.patch (drm-backport-placeholder)
- commit 3b3367b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0355-drm-i915-vdsc-Refactor-dsc-register-field-macro.patch (drm-backport-placeholder)
- commit da7826d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0354-drm-i915-Handle-dma-fences-in-dirtyfb-callback.patch (drm-backport-placeholder)
- commit f5493db
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0353-drm-i915-Add-new-frontbuffer-tracking-interface-to-q.patch (drm-backport-placeholder)
- commit eb7da7e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0352-drm-i915-psr-Clear-frontbuffer-busy-bits-on-flip.patch (drm-backport-placeholder)
- commit 3e24e9c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0351-drm-i915-fbc-Clear-frontbuffer-busy-bits-on-flip.patch (drm-backport-placeholder)
- commit acab271
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0350-drm-i915-cec-switch-to-setting-physical-address-dire.patch (drm-backport-placeholder)
- commit fd37be7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0349-drm-cec-add-drm_dp_cec_attach-as-the-non-edid-versio.patch (drm-backport-placeholder)
- commit 6fd7b5d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0348-drm-edid-parse-source-physical-address.patch (drm-backport-placeholder)
- commit 62d75a9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0347-drm-i915-display-use-drm_edid_is_digital.patch (drm-backport-placeholder)
- commit bb46e44
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0346-drm-edid-add-drm_edid_is_digital.patch (drm-backport-placeholder)
- commit aec21a4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0345-drm-i915-hdcp-Use-correct-aux-for-capability-check-s.patch (drm-backport-placeholder)
- commit f369159
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0344-drm-i915-hdcp-Use-intel_connector-as-argument-for-hd.patch (drm-backport-placeholder)
- commit cd8ddb8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0343-drm-i915-add-minimal-i915_gem_object_frontbuffer.h.patch (drm-backport-placeholder)
- commit e121efa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0342-drm-i915-mtl-Add-TC-port-lockdep-assert-to-AUX-power.patch (drm-backport-placeholder)
- commit 528c3ae
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0341-drm-i915-dp-Drop-redundant-AUX-power-get-put-in-inte.patch (drm-backport-placeholder)
- commit 4299295
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0340-drm-i915-dg2-Add-support-for-new-DG2-G12-revid-0x1.patch (drm-backport-placeholder)
- commit c9cd13e
* Wed Oct  2 2024 dwagner@suse.de
- nvme-pci: qdepth 1 quirk (git-fixes).
- commit ee2b909
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0339-drivers-drm-i915-Honor-limits-max_bpp-while-computin.patch (drm-backport-placeholder)
- commit c7935ff
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0338-drm-display-dp-Assume-8-bpc-support-when-DSC-is-supp.patch (drm-backport-placeholder)
- commit ed2393d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0337-drm-i915-psr-Apply-Wa_14015648006-for-all-display-14.patch (drm-backport-placeholder)
- commit 80db97d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0336-drm-i915-sdvo-Print-out-the-i2c-pin-and-slave-addres.patch (drm-backport-placeholder)
- commit 02be643
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0335-drm-i915-sdvo-Rework-DDC-bus-handling.patch (drm-backport-placeholder)
- commit 4c85555
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0334-drm-i915-sdvo-Get-rid-of-the-per-connector-i2c-symli.patch (drm-backport-placeholder)
- commit 8e5854f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0333-drm-i915-sdvo-Nuke-the-duplicate-sdvo-port.patch (drm-backport-placeholder)
- commit 6bbe353
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0332-drm-i915-sdvo-Initialize-the-encoder-earlier.patch (drm-backport-placeholder)
- commit edc812b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0331-drm-i915-sdvo-Nuke-attached_output-tracking.patch (drm-backport-placeholder)
- commit 07644ad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0330-drm-i915-hdcp-Adjust-timeout-for-read-in-DPMST-Scena.patch (drm-backport-placeholder)
- commit 8145c1e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0329-drm-i915-hdcp-Send-the-correct-aux-for-DPMST-HDCP-sc.patch (drm-backport-placeholder)
- commit 13ef37d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0328-drm-i915-hdcp-Propagate-aux-info-in-DP-HDCP-function.patch (drm-backport-placeholder)
- commit 8712f73
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0327-drm-i915-hdcp-Use-intel_connector-argument-in-intel_.patch (drm-backport-placeholder)
- commit a853ef1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0326-drm-i915-color-move-pre-SKL-gamma-and-CSC-enable-rea.patch (drm-backport-placeholder)
- commit da0f867
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0325-drm-i915-color-move-SKL-gamma-and-CSC-enable-read-to.patch (drm-backport-placeholder)
- commit af7c795
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0324-drm-i915-move-ILK-CSC-mode-read-to-intel_color.patch (drm-backport-placeholder)
- commit aaf180a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0323-drm-i915-move-HSW-gamma-mode-read-to-intel_color.patch (drm-backport-placeholder)
- commit cdac7db
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0322-drm-i915-color-move-CHV-CGM-pipe-mode-read-to-intel_.patch (drm-backport-placeholder)
- commit bdb9ab1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0321-drm-i915-regs-split-out-intel_color_regs.h.patch (drm-backport-placeholder)
- commit 856a1bc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0320-drm-i915-display-configure-SDP-split-for-DP-MST.patch (drm-backport-placeholder)
- commit 2a09843
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0319-drm-i915-display-update-intel_dp_has_audio-to-suppor.patch (drm-backport-placeholder)
- commit 0440756
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0318-drm-i915-vma-constify-unbind_fence_ops.patch (drm-backport-placeholder)
- commit a5a82dd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0317-drm-i915-rpl-Update-pci-ids-for-RPL-P-U.patch (drm-backport-placeholder)
- commit 6275468
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0316-drm-i915-sdvo-Fail-gracefully-if-the-TV-dotclock-is-.patch (drm-backport-placeholder)
- commit 2eb507b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0315-drm-i915-sdvo-Pick-the-TV-dotclock-from-adjusted_mod.patch (drm-backport-placeholder)
- commit 2932dd6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0314-drm-i915-Fully-populate-crtc_state-dpll.patch (drm-backport-placeholder)
- commit fe3b0e0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0313-drm-i915-Don-t-warn-about-zero-N-P-in-_calc_dpll_par.patch (drm-backport-placeholder)
- commit ecf6968
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0312-drm-i915-sdvo-s-sdvo_inputs_mask-sdvo_num_inputs.patch (drm-backport-placeholder)
- commit a66f948
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0311-drm-i915-sdvo-Protect-macro-args.patch (drm-backport-placeholder)
- commit 817c1d2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0310-drm-i915-sdvo-Issue-SetTargetOutput-prior-to-GetAtta.patch (drm-backport-placeholder)
- commit 18c00d7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0309-drm-i915-display-add-lock-while-printing-frontbuffer.patch (drm-backport-placeholder)
- commit 34fc41a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0308-drm-i915-display-combine-DP-audio-compute-config-ste.patch (drm-backport-placeholder)
- commit 5f82879
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0307-drm-i915-display-remove-redundant-parameter-from-sdp.patch (drm-backport-placeholder)
- commit 8d6002e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-display-Eliminate-IS_METEORLAKE-checks.patch (drm-backport-placeholder)
- commit 8d17045
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Eliminate-IS_MTL_DISPLAY_STEP.patch (drm-backport-placeholder)
- commit ba27276
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0304-drm-i915-display-Remove-unused-POWER_DOMAIN_MODESET.patch (drm-backport-placeholder)
- commit 1a856b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0303-drm-i915-dp-Check-if-force_dsc_output_format-is-poss.patch (drm-backport-placeholder)
- commit 10bfe7c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0302-drm-i915-dp-Check-src-sink-compressed-bpp-limit-for-.patch (drm-backport-placeholder)
- commit 8b57b61
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0301-drm-i915-dp-Get-optimal-link-config-to-have-best-com.patch (drm-backport-placeholder)
- commit 89ebe80
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0300-drm-i915-dp-Separate-out-function-to-get-compressed-.patch (drm-backport-placeholder)
- commit 40a2ca0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0299-drm-i915-dp-Add-DSC-BPC-BPP-constraints-while-select.patch (drm-backport-placeholder)
- commit a991f1e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0298-drm-i915-dp-Separate-out-functions-for-edp-DP-for-co.patch (drm-backport-placeholder)
- commit b0bc691
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0297-drm-i915-dp-Rename-helper-to-get-DSC-max-pipe_bpp.patch (drm-backport-placeholder)
- commit acbddb4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0296-drm-i915-dp-Avoid-left-shift-of-DSC-output-bpp-by-4.patch (drm-backport-placeholder)
- commit 6f804f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0295-drm-i915-dp-Check-min-bpc-DSC-limits-for-dsc_force_b.patch (drm-backport-placeholder)
- commit aa28297
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0294-drm-i915-dp-Add-functions-to-get-min-max-src-input-b.patch (drm-backport-placeholder)
- commit 284c152
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0293-drm-i915-dp-Avoid-forcing-DSC-BPC-for-MST-case.patch (drm-backport-placeholder)
- commit fea3a84
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0292-drm-i915-dp-Remove-extra-logs-for-printing-DSC-info.patch (drm-backport-placeholder)
- commit 234a4be
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0291-drm-i915-intel_cdclk-Add-vdsc-with-bigjoiner-constra.patch (drm-backport-placeholder)
- commit ce276e0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0290-drm-i915-dp-Update-Bigjoiner-interface-bits-for-comp.patch (drm-backport-placeholder)
- commit 07e8727
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0289-drm-i915-dp-Use-consistent-name-for-link-bpp-and-com.patch (drm-backport-placeholder)
- commit 02334bd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0288-drm-i915-dp_mst-Use-output_format-to-get-the-final-l.patch (drm-backport-placeholder)
- commit 40ebf8d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0287-drm-i915-dp-Move-compressed-bpp-check-with-420-forma.patch (drm-backport-placeholder)
- commit 6d550a5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0286-drm-i915-dp-Consider-output_format-while-computing-d.patch (drm-backport-placeholder)
- commit 35bf8b0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0285-drm-i915-Eliminate-has_4tile-feature-flag.patch (drm-backport-placeholder)
- commit 1f7399b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0284-drm-i915-selftest-Simplify-Y-major-tiling-in-blit-se.patch (drm-backport-placeholder)
- commit c30f848
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dg2-Drop-pre-production-display-workarounds.patch (drm-backport-placeholder)
- commit 0826b04
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dg2-Recognize-pre-production-hardware.patch (drm-backport-placeholder)
- commit 34c7ca9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0281-drm-i915-cx0-Program-vswing-only-for-owned-lanes.patch (drm-backport-placeholder)
- commit 2fbe5da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0280-drm-i915-cx0-Enable-disable-TX-only-for-owned-PHY-la.patch (drm-backport-placeholder)
- commit 0fd190c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0279-drm-i915-Simplify-intel_cx0_program_phy_lane-with-lo.patch (drm-backport-placeholder)
- commit 60f8dcc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0278-drm-i915-cx0-Add-intel_cx0_get_owned_lane_mask.patch (drm-backport-placeholder)
- commit b24e0c7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0277-drm-i915-display-Remove-unused-POWER_DOMAIN_MASK.patch (drm-backport-placeholder)
- commit 53d03da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0276-drm-i915-pxp-Optimize-GET_PARAM-PXP_STATUS.patch (drm-backport-placeholder)
- commit eb980ff
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0275-drm-i915-pxp-mtl-intel_pxp_init_hw-needs-runtime-pm-.patch (drm-backport-placeholder)
- commit 95ebb77
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0274-drm-i915-dp-Fix-LT-debug-print-in-SDP-CRC-enable.patch (drm-backport-placeholder)
- commit 98b8193
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0273-drm-i915-vdsc-Fix-first_line_bpg_offset-calculation.patch (drm-backport-placeholder)
- commit 4311bc5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0272-drm-i915-Don-t-change-the-status-of-forced-connector.patch (drm-backport-placeholder)
- commit 89c494b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0271-drm-i915-Don-t-change-the-status-of-forced-connector.patch (drm-backport-placeholder)
- commit b1ffc47
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0270-drm-i915-Avoid-endless-HPD-poll-detect-loop-via-runt.patch (drm-backport-placeholder)
- commit d2fcf09
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0269-drm-i915-Do-not-disable-preemption-for-resets.patch (drm-backport-placeholder)
- commit 6a3d44a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0268-drm-i915-perf-Remove-gtt_offset-from-stream-oa_buffe.patch (drm-backport-placeholder)
- commit 133e76b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0267-drm-i915-Add-Wa_18028616096.patch (drm-backport-placeholder)
- commit 0b694f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0266-drm-i915-gem-remove-inlines-from-i915_gem_execbuffer.patch (drm-backport-placeholder)
- commit 5364abc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0265-drm-i915-gt-remove-a-static-inline-that-requires-inc.patch (drm-backport-placeholder)
- commit 911ddb9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0264-drm-i915-gt-Update-RC6-mask-for-mtl_drpc.patch (drm-backport-placeholder)
- commit 30a485e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0263-drm-i915-refactor-deprecated-strncpy.patch (drm-backport-placeholder)
- commit 5d9f762
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0262-drm-i915-lrc-User-PXP-contexts-requires-runalone-bit.patch (drm-backport-placeholder)
- commit 29635d3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0261-drm-i915-pxp-mtl-Update-pxp-firmware-packet-size.patch (drm-backport-placeholder)
- commit a945b8f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0260-drm-i915-pxp-mtl-Update-pxp-firmware-response-timeou.patch (drm-backport-placeholder)
- commit 43653d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0259-drm-i915-huc-silence-injected-failure-in-the-load-vi.patch (drm-backport-placeholder)
- commit ce6c435
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0258-drm-i915-Add-Wa_18022495364.patch (drm-backport-placeholder)
- commit 6dec89f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0257-drm-i915-gt-skip-WA-verification-for-GEN7_MISCCPCTL-.patch (drm-backport-placeholder)
- commit 1b772b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0256-drm-i915-Run-relevant-bits-of-debugfs-drop_caches-pe.patch (drm-backport-placeholder)
- commit 922c2ac
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0255-drm-i915-mtl-Drop-Wa_14017240301.patch (drm-backport-placeholder)
- commit 7b714b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0254-drm-i915-Add-Wa_14015150844.patch (drm-backport-placeholder)
- commit dd71a0f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0253-drm-i915-gt-Wait-longer-for-tasks-in-migrate-selftes.patch (drm-backport-placeholder)
- commit 11be646
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mtl-Update-workaround-14016712196.patch (drm-backport-placeholder)
- commit 990ce97
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0251-drm-i915-gsc-define-gsc-fw.patch (drm-backport-placeholder)
- commit 312ab65
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0250-drm-i915-mtl-Adding-DeviceID-for-Arrowlake-S-under-M.patch (drm-backport-placeholder)
- commit f1b69ac
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0249-drm-i915-guc-Force-a-reset-on-internal-GuC-error.patch (drm-backport-placeholder)
- commit 483a278
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Replace-several-IS_METEORLAKE-with-proper-I.patch (drm-backport-placeholder)
- commit 07aada1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mtl-Eliminate-subplatforms.patch (drm-backport-placeholder)
- commit 84404d2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Eliminate-IS_MTL_MEDIA_STEP.patch (drm-backport-placeholder)
- commit 01eaa1a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Eliminate-IS_MTL_GRAPHICS_STEP.patch (drm-backport-placeholder)
- commit b2254b6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-xelpg-Call-Xe_LPG-workaround-functions-base.patch (drm-backport-placeholder)
- commit 22cddb2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-xelpmp-Don-t-assume-workarounds-extend-to-f.patch (drm-backport-placeholder)
- commit 8e6f26e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Consolidate-condition-for-Wa_22011802037.patch (drm-backport-placeholder)
- commit 2537546
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dg2-Drop-Wa_16011777198.patch (drm-backport-placeholder)
- commit 4bd1473
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Tidy-workaround-definitions.patch (drm-backport-placeholder)
- commit 9ed1f64
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dg2-Drop-pre-production-GT-workarounds.patch (drm-backport-placeholder)
- commit e970a88
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0238-drm-i915-selftests-Align-igt_spinner_create_request-.patch (drm-backport-placeholder)
- commit e734481
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0237-drm-i915-dg2-Remove-Wa_15010599737.patch (drm-backport-placeholder)
- commit d12a0e7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0236-drm-panel-ltk050h3146w-add-support-for-Leadtek-LTK05.patch (drm-backport-placeholder)
- commit 21fd0d0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0235-drm-panel-ltk050h3146w-add-mipi_dsi_device.mode_flag.patch (drm-backport-placeholder)
- commit b7e2391
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0232-drm-rockchip-dsi-Use-devm_platform_get_and_ioremap_r.patch (drm-backport-placeholder)
- commit 9fadd11
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0231-drm-rockchip-remove-redundant-of_match_ptr.patch (drm-backport-placeholder)
- commit 71a478f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-cdn-dp-Fix-some-error-handling-paths-in.patch (drm-backport-placeholder)
- commit 9e04dfb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0229-drm-rockchip-vop2-Convert-to-use-maple-tree-register.patch (drm-backport-placeholder)
- commit 7f1bc22
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0228-drm-rockchip-vop2-Demote-message-in-mod_supported-to.patch (drm-backport-placeholder)
- commit 30b00dd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0227-Documentation-gpu-fix-Panfrost-documentation-build-w.patch (drm-backport-placeholder)
- commit ad7d451
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0226-drm-panel-simple-allow-LVDS-format-override.patch (drm-backport-placeholder)
- commit 372b1a1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0225-drm-bridge-samsung-dsim-calculate-porches-in-Hz.patch (drm-backport-placeholder)
- commit 7ff2bb5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0224-drm-bridge-samsung-dsim-adjust-porches-by-rounding-u.patch (drm-backport-placeholder)
- commit eb42dbe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0223-drm-bridge-samsung-dsim-update-PLL-reference-clock.patch (drm-backport-placeholder)
- commit c5c31f5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0222-drm-bridge-samsung-dsim-reread-ref-clock-before-conf.patch (drm-backport-placeholder)
- commit 53ba316
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0221-drm-bridge-samsung-dsim-add-more-mipi-dsi-device-deb.patch (drm-backport-placeholder)
- commit ca3e30a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0220-drm-exynos-dsi-Convert-to-platform-remove-callback-r.patch (drm-backport-placeholder)
- commit dd0d75a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0219-drm-amd-display-Fix-mst-hub-unplug-warning.patch (drm-backport-placeholder)
- commit 487d45c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0218-drm-panel-nv3051d-Add-Support-for-Anbernic-351V.patch (drm-backport-placeholder)
- commit 1aef014
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0217-drm-dp-switch-drm_dp_downstream_-helpers-to-struct-d.patch (drm-backport-placeholder)
- commit feaf30b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0216-drm-v3d-Annotate-struct-v3d_perfmon-with-__counted_b.patch (drm-backport-placeholder)
- commit 1c0f386
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0215-drm-vmwgfx-Annotate-struct-vmw_surface_dirty-with-__.patch (drm-backport-placeholder)
- commit 8a69dd6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0214-drm-virtio-Annotate-struct-virtio_gpu_object_array-w.patch (drm-backport-placeholder)
- commit 013baec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0213-drm-vc4-Annotate-struct-vc4_perfmon-with-__counted_b.patch (drm-backport-placeholder)
- commit f49474f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0212-drm-nouveau-pm-Annotate-struct-nvkm_perfdom-with-__c.patch (drm-backport-placeholder)
- commit 4ea6193
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0211-drm-msm-dpu-Annotate-struct-dpu_hw_intr-with-__count.patch (drm-backport-placeholder)
- commit 97758dd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0210-drm-i915-selftests-Annotate-struct-perf_series-with-.patch (drm-backport-placeholder)
- commit bdca5bb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0209-drm-amdgpu-discovery-Annotate-struct-ip_hw_instance-.patch (drm-backport-placeholder)
- commit 55c089a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0208-drm-amd-pm-Annotate-struct-smu10_voltage_dependency_.patch (drm-backport-placeholder)
- commit 36eccc9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0207-drm-panfrost-Implement-generic-DRM-object-RSS-report.patch (drm-backport-placeholder)
- commit 9f4f163
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0206-drm-drm_file-Add-DRM-obj-s-RSS-reporting-function-fo.patch (drm-backport-placeholder)
- commit 8b4e65b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0205-drm-panfrost-Add-fdinfo-support-for-memory-stats.patch (drm-backport-placeholder)
- commit 55d13e9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0204-drm-panfrost-Add-fdinfo-support-GPU-load-metrics.patch (drm-backport-placeholder)
- commit a19739c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0203-drm-panfrost-Add-cycle-count-GPU-register-definition.patch (drm-backport-placeholder)
- commit 37fd991
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0202-drm-vblank-Warn-when-silently-cancelling-vblank-work.patch (drm-backport-placeholder)
- commit 1f4f1c3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0201-drm-doc-Document-DRM-device-reset-expectations.patch (drm-backport-placeholder)
- commit 0873aad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0200-drm-panel-Add-driver-for-BOE-RM692E5-AMOLED-panel.patch (drm-backport-placeholder)
- commit 137a4a1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0199-drm-panel-ili9322-Convert-to-use-maple-tree-register.patch (drm-backport-placeholder)
- commit fa0b8b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0198-drm-panel-ili9322-Remove-redundant-volatle_reg-opera.patch (drm-backport-placeholder)
- commit d0ae28b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0197-drm-bridge-sn65dsi83-Convert-to-use-maple-tree-regis.patch (drm-backport-placeholder)
- commit f6e6ef7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0196-drm-bridge-lt9211-Convert-to-use-maple-tree-register.patch (drm-backport-placeholder)
- commit 3a65930
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0195-drm-bridge-icn6211-Convert-to-use-maple-tree-registe.patch (drm-backport-placeholder)
- commit dc273ee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0194-drm-bridge-tc358767-Convert-to-use-maple-tree-regist.patch (drm-backport-placeholder)
- commit 4febe7f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0193-drm-bridge-dpc3433-Convert-to-use-maple-tree-registe.patch (drm-backport-placeholder)
- commit 8f3c88f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0192-drm-bridge-adv7511-Convert-to-use-maple-tree-registe.patch (drm-backport-placeholder)
- commit f7424ff
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0191-drm-tests-Add-new-format-conversion-tests-to-better-.patch (drm-backport-placeholder)
- commit 1986e58
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0190-drm-tests-Add-calls-to-drm_fb_blit-on-supported-form.patch (drm-backport-placeholder)
- commit e40bc40
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0189-drm-bridge-lt9611uxc-use-drm_bridge_get_edid-instead.patch (drm-backport-placeholder)
- commit 462e1d5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0188-drm-bridge-use-drm_bridge_get_edid-instead-of-using-.patch (drm-backport-placeholder)
- commit f0a33c0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0187-drm-nouveau-kms-nv50-hide-unused-variables.patch (drm-backport-placeholder)
- commit 6868587
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0186-drm-gpuvm-doc-fix-filename-references.patch (drm-backport-placeholder)
- commit 7ee0a46
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0185-drm-gma500-refactor-deprecated-strncpy.patch (drm-backport-placeholder)
- commit 7fa8b55
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0184-drm-nouveau-uvmm-rename-umgr-to-base.patch (drm-backport-placeholder)
- commit 61554ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0183-drm-gpuvm-allow-building-as-module.patch (drm-backport-placeholder)
- commit 6a33214
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0182-drm-gpuvm-rename-struct-drm_gpuva_manager-to-struct-.patch (drm-backport-placeholder)
- commit e48cc37
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0181-drm-imx-dcss-Call-drm_atomic_helper_shutdown-at-shut.patch (drm-backport-placeholder)
- commit 58af456
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0180-drm-bridge-Add-200ms-delay-to-wait-FW-HPD-status-sta.patch (drm-backport-placeholder)
- commit b8e93ef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0179-drm-simpledrm-Add-support-for-multiple-power-domains.patch (drm-backport-placeholder)
- commit 78ea874
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0178-accel-qaic-Remove-size-field-from-struct-qaic_bo.patch (drm-backport-placeholder)
- commit 9301957
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0177-drm-ssd130x-Drop-_helper-prefix-from-struct-drm_-_he.patch (drm-backport-placeholder)
- commit ac0f11b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-edid-Fixup-h-vsync_end-instead-of-h-vtotal.patch (drm-backport-placeholder)
- commit 877591b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0175-drm-hisilicon-kirin-Call-drm_atomic_helper_shutdown-.patch (drm-backport-placeholder)
- commit 4a1ad57
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-Call-drm_atomic_helper_shutdown-at-shutdown-remo.patch (drm-backport-placeholder)
- commit 1f5e65f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0173-drm-ssd130x-Call-drm_atomic_helper_shutdown-at-remov.patch (drm-backport-placeholder)
- commit 803ba63
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0172-drm-vc4-Call-drm_atomic_helper_shutdown-at-shutdown-.patch (drm-backport-placeholder)
- commit 968b78b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0171-drm-Call-drm_atomic_helper_shutdown-at-shutdown-time.patch (drm-backport-placeholder)
- commit 266e11c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0170-drm-armada-Call-drm_atomic_helper_shutdown-at-shutdo.patch (drm-backport-placeholder)
- commit ca0c97e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0169-drm-bridge-panel-Fix-device-link-for-DRM_BRIDGE_ATTA.patch (drm-backport-placeholder)
- commit 21315fe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-Update-file-owner-during-use.patch (drm-backport-placeholder)
- commit efa039d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0167-drm-bridge-tc358768-Attempt-to-fix-DSI-horizontal-ti.patch (drm-backport-placeholder)
- commit bd4901c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Fix-tc358768_ns_to_cnt.patch (drm-backport-placeholder)
- commit 08c5dd3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Clean-up-clock-period-code.patch (drm-backport-placeholder)
- commit 4f75fdb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Rename-dsibclk-to-hsbyteclk.patch (drm-backport-placeholder)
- commit 54360bc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Use-dev-for-dbg-prints-not-priv-.patch (drm-backport-placeholder)
- commit af89ad1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Print-logical-values-not-raw-reg.patch (drm-backport-placeholder)
- commit 4482458
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Use-struct-videomode.patch (drm-backport-placeholder)
- commit 92bbd2a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0160-drm-bridge-tc358768-Cleanup-PLL-calculations.patch (drm-backport-placeholder)
- commit 2fe3b48
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Fix-bit-updates.patch (drm-backport-placeholder)
- commit 49de390
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0158-drm-bridge-tc358768-Default-to-positive-h-v-syncs.patch (drm-backport-placeholder)
- commit fabed63
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Fix-use-of-uninitialized-variabl.patch (drm-backport-placeholder)
- commit 6b68a4e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0156-drm-tegra-rgb-Parameterize-V-and-H-sync-polarities.patch (drm-backport-placeholder)
- commit 3faf1f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0155-drm-bridge-analogix-anx78xx-Add-missing-definition.patch (drm-backport-placeholder)
- commit 8c422f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0154-drm-nouveau-kms-nv50-disable-dcb-parsing.patch (drm-backport-placeholder)
- commit d972515
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0153-drm-nouveau-kms-nv50-create-outputs-based-on-nvkm-in.patch (drm-backport-placeholder)
- commit ae7687e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0152-drm-nouveau-kms-nv50-create-connectors-based-on-nvkm.patch (drm-backport-placeholder)
- commit ce0a9f6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0151-drm-nouveau-kms-nv50-name-aux-channels-after-their-c.patch (drm-backport-placeholder)
- commit d1fcbaf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0150-drm-nouveau-kms-nv50-create-heads-after-outps-conns.patch (drm-backport-placeholder)
- commit 914b3ac
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0149-drm-nouveau-kms-nv50-create-heads-based-on-nvkm-head.patch (drm-backport-placeholder)
- commit 91b2d02
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0148-drm-nouveau-disp-nv50-skip-DCB_OUTPUT_TV.patch (drm-backport-placeholder)
- commit ababa6a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0147-drm-nouveau-disp-move-outp-init-fini-paths-to-chipse.patch (drm-backport-placeholder)
- commit 98d49d0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0146-drm-nouveau-disp-move-outp-conn-construction-to-chip.patch (drm-backport-placeholder)
- commit 50fb938
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0145-drm-nouveau-disp-add-dp-mst-id-get-put-methods.patch (drm-backport-placeholder)
- commit e7bb467
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0144-drm-nouveau-disp-add-dp-sst-config-method.patch (drm-backport-placeholder)
- commit 7445a27
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0143-drm-nouveau-disp-move-link-training-out-of-superviso.patch (drm-backport-placeholder)
- commit 0981cf1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0142-drm-nouveau-disp-add-dp-train-method.patch (drm-backport-placeholder)
- commit 67b9500
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0141-drm-nouveau-kms-nv50-fixup-sink-D3-before-tearing-do.patch (drm-backport-placeholder)
- commit 6687dd7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0140-drm-nouveau-kms-nv50-flush-mst-disables-together.patch (drm-backport-placeholder)
- commit c900d94
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0139-drm-nouveau-kms-nv50-split-DP-disable-enable-into-tw.patch (drm-backport-placeholder)
- commit 7231ea8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0138-drm-nouveau-disp-add-dp-rates-method.patch (drm-backport-placeholder)
- commit 1084860
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0137-drm-nouveau-disp-add-dp-aux-xfer-method.patch (drm-backport-placeholder)
- commit e59d021
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0136-drm-nouveau-disp-move-dp-aux-pwr-method-to-HAL.patch (drm-backport-placeholder)
- commit b28a385
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0135-drm-nouveau-disp-add-hdmi-audio-hal-function.patch (drm-backport-placeholder)
- commit bfdd0a4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0134-drm-nouveau-disp-add-output-lvds-config-method.patch (drm-backport-placeholder)
- commit 8b53532
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0133-drm-nouveau-disp-add-output-backlight-control-method.patch (drm-backport-placeholder)
- commit 0706d37
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0132-drm-nouveau-disp-remove-SOR-routing-updates-from-sup.patch (drm-backport-placeholder)
- commit 1f427ab
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0131-drm-nouveau-disp-release-outputs-post-modeset.patch (drm-backport-placeholder)
- commit eac15d4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0130-drm-nouveau-disp-move-hdmi-disable-out-of-release.patch (drm-backport-placeholder)
- commit 819cced
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0129-drm-nouveau-disp-add-output-hdmi-config-method.patch (drm-backport-placeholder)
- commit b52f194
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0128-drm-nouveau-kms-nv50-move-audio-enable-post-modeset.patch (drm-backport-placeholder)
- commit 940d316
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0127-drm-nouveau-kms-nv50-keep-output-state-around-until-.patch (drm-backport-placeholder)
- commit ab3b987
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0126-drm-nouveau-kms-nv50-remove-nv_encoder.audio.connect.patch (drm-backport-placeholder)
- commit a7b225a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0125-drm-nouveau-kms-nv50-pull-some-common-init-out-of-OR.patch (drm-backport-placeholder)
- commit 98117bb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0124-drm-nouveau-disp-update-SOR-routing-immediately-on-a.patch (drm-backport-placeholder)
- commit 25cf50e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0123-drm-nouveau-disp-add-acquire_sor-pior.patch (drm-backport-placeholder)
- commit 7479654
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0122-drm-nouveau-disp-add-acquire_dac.patch (drm-backport-placeholder)
- commit 6bdf0e6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0121-drm-nouveau-disp-shuffle-to-make-upcoming-diffs-pret.patch (drm-backport-placeholder)
- commit ed196d5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0120-drm-nouveau-kms-Add-INHERIT-ioctl-to-nvkm-nvif-for-r.patch (drm-backport-placeholder)
- commit e7d217d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0119-drm-nouveau-disp-rename-internal-output-acquire-rele.patch (drm-backport-placeholder)
- commit 8e99750
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0118-drm-nouveau-disp-add-output-method-to-fetch-edid.patch (drm-backport-placeholder)
- commit 74742ec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0117-drm-nouveau-disp-add-output-detect-method.patch (drm-backport-placeholder)
- commit 64b4c56
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0116-drm-nouveau-disp-rearrange-output-methods.patch (drm-backport-placeholder)
- commit 45bb760
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0115-drm-nouveau-kms-nv50-fix-mst-payload-alloc-fail-cras.patch (drm-backport-placeholder)
- commit 9c16cb6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0114-drm-nouveau-mmu-gp100-always-invalidate-TLBs-at-CACH.patch (drm-backport-placeholder)
- commit 6d1690a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0113-drm-nouveau-gr-gf100-lose-contents-of-global-ctxbufs.patch (drm-backport-placeholder)
- commit 2ec0c5e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0112-drm-nouveau-imem-support-allocations-not-preserved-a.patch (drm-backport-placeholder)
- commit e360940
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0111-drm-nouveau-devinit-tu102-remove-attempt-at-loading-.patch (drm-backport-placeholder)
- commit b21d6b3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0110-drm-dp_mst-Tune-down-error-message-during-payload-ad.patch (drm-backport-placeholder)
- commit 2db7fde
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0109-drm-dp_mst-Sanitize-error-return-during-payload-addi.patch (drm-backport-placeholder)
- commit 93aadd4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0108-drm-dp_mst-Fix-NULL-dereference-during-payload-addit.patch (drm-backport-placeholder)
- commit 8ad1a07
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0107-drm-bridge-dw-hdmi-cec-Add-arbitration-lost-event.patch (drm-backport-placeholder)
- commit 6cbf86a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0106-drm-nouveau-pm-refactor-deprecated-strncpy.patch (drm-backport-placeholder)
- commit 41b53c3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0105-drm-nouveau-core-refactor-deprecated-strncpy.patch (drm-backport-placeholder)
- commit dbb9a58
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0104-drm-nouveau-nvif-refactor-deprecated-strncpy.patch (drm-backport-placeholder)
- commit 8131282
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0103-drm-komeda-add-NV12-format-to-support-writeback-laye.patch (drm-backport-placeholder)
- commit 927bf1e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-it66121-get_edid-callback-must-not-return.patch (drm-backport-placeholder)
- commit ee18df9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0101-drm-ssd130x-Store-the-HW-buffer-in-the-driver-privat.patch (drm-backport-placeholder)
- commit 3caf178
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0100-drm-debugfs-Fix-drm_debugfs_remove_files-stub.patch (drm-backport-placeholder)
- commit 6633c4c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0099-drm-amd-display-Fix-Wuninitialized-in-dm_helpers_dp_.patch (drm-backport-placeholder)
- commit 938cdf6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0098-drm-ingenic-Call-drm_atomic_helper_shutdown-at-shutd.patch (drm-backport-placeholder)
- commit 97f592b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0097-drm-imx-ipuv3-Call-drm_atomic_helper_shutdown-at-shu.patch (drm-backport-placeholder)
- commit 189a8b9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0096-drm-atomic-helper-drm_atomic_helper_shutdown-NULL-sh.patch (drm-backport-placeholder)
- commit 9966d0a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0095-drm-panel-otm8009a-Don-t-double-check-prepared-enabl.patch (drm-backport-placeholder)
- commit 6c290e7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0094-drm-panel-s6e63m0-Don-t-store-check-prepared-enabled.patch (drm-backport-placeholder)
- commit 53bd6c1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0093-drm-panel-Don-t-store-check-prepared-enabled-for-sim.patch (drm-backport-placeholder)
- commit 47ba132
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0092-drm-i915-Move-the-size-computations-to-drm-buddy.patch (drm-backport-placeholder)
- commit 2d7091a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0091-drm-amdgpu-Move-the-size-computations-to-drm-buddy.patch (drm-backport-placeholder)
- commit ae9de70
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0090-drm-buddy-Improve-contiguous-memory-allocation.patch (drm-backport-placeholder)
- commit 3039e96
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0089-fbdev-core-Clean-up-include-statements-in-fbmem.c.patch (drm-backport-placeholder)
- commit 04a4b28
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0088-fbdev-core-Remove-empty-internal-helpers-from-fb_log.patch (drm-backport-placeholder)
- commit 1f063a9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0087-fbdev-core-Move-logo-functions-into-separate-source-.patch (drm-backport-placeholder)
- commit d488b52
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0086-fbdev-core-Unexport-logo-helpers.patch (drm-backport-placeholder)
- commit 4cb4ec3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0085-fbdev-core-Fix-style-of-code-for-boot-up-logo.patch (drm-backport-placeholder)
- commit 883127c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0084-fbdev-mmp-mmpfb-Do-not-display-boot-up-logo.patch (drm-backport-placeholder)
- commit d7afb16
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0083-fbdev-au1200fb-Do-not-display-boot-up-logo.patch (drm-backport-placeholder)
- commit fd6234a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0082-drm-ssd130x-Use-bool-for-ssd130x_deviceinfo-flags.patch (drm-backport-placeholder)
- commit 074f42e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-ssd130x-Fix-screen-clearing.patch (drm-backport-placeholder)
- commit d4306c6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0080-drm-ssd130x-Print-the-PWM-s-label-instead-of-its-num.patch (drm-backport-placeholder)
- commit 947af41
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0079-drm-shmobile-Convert-to-platform-remove-callback-ret.patch (drm-backport-placeholder)
- commit 8dd9c6c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0078-drm-msm-Convert-to-platform-remove-callback-returnin.patch (drm-backport-placeholder)
- commit 1b8c5bd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0077-drm-ingenic-Convert-to-platform-remove-callback-retu.patch (drm-backport-placeholder)
- commit 6766518
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0076-drm-imx-ipuv3-Convert-to-platform-remove-callback-re.patch (drm-backport-placeholder)
- commit 0704c9d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0075-drm-mst-Refactor-the-flow-for-payload-allocation-rem.patch (drm-backport-placeholder)
- commit e7ca92a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0074-drm-mst-delete-unnecessary-case-in-drm_dp_add_payloa.patch (drm-backport-placeholder)
- commit de2c8aa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0073-drm-tests-Zero-initialize-fourccs_out.patch (drm-backport-placeholder)
- commit b1deec5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0072-drm-debugfs-Add-inline-to-drm_debugfs_dev_init-to-su.patch (drm-backport-placeholder)
- commit 6d2aae4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0071-drm-doc-rfc-Mark-GPU-VA-as-complete.patch (drm-backport-placeholder)
- commit 109f558
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0070-drm-doc-rfc-Mark-DRM_VM_BIND-as-complete.patch (drm-backport-placeholder)
- commit 341c6eb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0069-drm-doc-rfc-Mark-Dev_coredump-as-completed.patch (drm-backport-placeholder)
- commit fa63776
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0068-drm-doc-rfc-No-STAGING-out-of-drivers-staging.patch (drm-backport-placeholder)
- commit 671183f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0067-drm-connector-document-DRM_MODE_COLORIMETRY_COUNT.patch (drm-backport-placeholder)
- commit e73a804
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0066-drm-bridge-Drop-CONFIG_OF-conditionals-around-of_nod.patch (drm-backport-placeholder)
- commit 2cc7315
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0065-drm-bridge-Drop-conditionals-around-of_node-pointers.patch (drm-backport-placeholder)
- commit dfe7bb4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0064-drm-bridge-analogix-anx78xx-Drop-ID-table.patch (drm-backport-placeholder)
- commit 25d8c37
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-lt8912b-Add-missing-drm_bridge_attach-cal.patch (drm-backport-placeholder)
- commit f66ee7e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-lt8912b-Manually-disable-HPD-only-if-it-w.patch (drm-backport-placeholder)
- commit e5833be
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-lt8912b-Fix-crash-on-bridge-detach.patch (drm-backport-placeholder)
- commit 4d10590
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-lt8912b-Fix-bridge_detach.patch (drm-backport-placeholder)
- commit c81aa9f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0058-drm-bridge-it66121-Extend-match-support-for-OF-table.patch (drm-backport-placeholder)
- commit b9136c3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0057-fbdev-hyperv_fb-Use-fb_ops-helpers-for-deferred-I-O.patch (drm-backport-placeholder)
- commit 138b05c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0056-fbdev-Add-Kconfig-macro-FB_IOMEM_HELPERS_DEFERRED.patch (drm-backport-placeholder)
- commit 350b801
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0055-fbdev-udlfb-Use-fb_ops-helpers-for-deferred-I-O.patch (drm-backport-placeholder)
- commit eddea00
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0054-fbdev-smscufx-Use-fb_ops-helpers-for-deferred-I-O.patch (drm-backport-placeholder)
- commit 0f4d18a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0053-drm-virtio-Remove-unused-function-declarations.patch (drm-backport-placeholder)
- commit b48b690
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0052-drm-debugfs-rework-drm_debugfs_create_files-implemen.patch (drm-backport-placeholder)
- commit 657f4af
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0051-drm-debugfs-remove-dev-debugfs_list-and-debugfs_mute.patch (drm-backport-placeholder)
- commit 60f63b9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0050-drm-debugfs-rework-debugfs-directory-creation-v5.patch (drm-backport-placeholder)
- commit 996b913
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-komeda-drop-all-currently-held-locks-if-deadlock.patch (drm-backport-placeholder)
- commit de6d8e3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0048-drm-debugfs-disallow-debugfs-access-when-device-isn-.patch (drm-backport-placeholder)
- commit 42bd7aa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0047-drm-debugfs-drop-debugfs_init-for-the-render-and-acc.patch (drm-backport-placeholder)
- commit 4370c9d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0046-fbdev-tcx-Use-initializer-macro-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit 9d9a3bd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0045-fbdev-p9100-Use-initializer-macro-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit cab1401
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0044-fbdev-leo-Use-initializer-macro-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit cbc83c7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0043-fbdev-ffb-Use-initializer-macro-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit 454f18d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0042-fbdev-cg6-Use-initializer-macro-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit 7746956
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0041-fbdev-cg3-Use-initializer-macro-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit 35fbbe4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0040-fbdev-cg14-Use-initializer-macro-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit 862f06a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0039-fbdev-bw2-Use-initializer-macro-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit 62d0cfa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0038-fbdev-sbus-Add-initializer-macros-and-Kconfig-tokens.patch (drm-backport-placeholder)
- commit 872983d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0037-fbdev-sbus-Forward-declare-all-necessary-structures-.patch (drm-backport-placeholder)
- commit 6107103
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0036-fbdev-sbus-Build-sbuslib.o-if-CONFIG_FB_SBUS-has-bee.patch (drm-backport-placeholder)
- commit c02a04e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0035-drm-tests-Add-KUnit-tests-for-drm_fb_memcpy.patch (drm-backport-placeholder)
- commit 30ced55
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0034-drm-tests-Add-multi-plane-support-to-conversion_buf_.patch (drm-backport-placeholder)
- commit 37c58f1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0033-drm-tests-Add-KUnit-tests-for-drm_fb_build_fourcc_li.patch (drm-backport-placeholder)
- commit e54e04c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0032-drm-tests-Add-KUnit-tests-for-drm_fb_clip_offset.patch (drm-backport-placeholder)
- commit 7691fe4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0031-drm-tests-Add-KUnit-tests-for-drm_fb_swab.patch (drm-backport-placeholder)
- commit 28f7d63
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0030-drm-tests-Test-default-pitch-fallback.patch (drm-backport-placeholder)
- commit 960d721
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0029-drm-repaper-fix-Wvoid-pointer-to-enum-cast-warning.patch (drm-backport-placeholder)
- commit 45cf471
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0028-drm-gma500-Remove-unused-declarations.patch (drm-backport-placeholder)
- commit 329ba2c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-gma500-Fix-call-trace-when-psb_gem_mm_init-fails.patch (drm-backport-placeholder)
- commit bdd3dd5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0026-drm-gma500-remove-duplicate-macro-definitions.patch (drm-backport-placeholder)
- commit 529a672
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0025-doc-uapi-Add-document-describing-dma-buf-semantics.patch (drm-backport-placeholder)
- commit 7ca2906
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0024-drm-panfrost-Do-not-check-for-0-return-after-calling.patch (drm-backport-placeholder)
- commit d7572a1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-Fix-kernel-doc-typo-in-desc-of-output_bus.patch (drm-backport-placeholder)
- commit 69d132d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0022-drm-panel-Add-driver-for-JDI-LPM102A188A.patch (drm-backport-placeholder)
- commit b5a1a00
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0021-drm-panel-JDI-LT070ME05000-drop-broken-link.patch (drm-backport-placeholder)
- commit 6cdc67e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0020-drm-panel-simple-Add-support-for-Mitsubishi-AA084XE0.patch (drm-backport-placeholder)
- commit 0083a3e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0019-drm-bridge-panel-Add-a-device-link-between-drm-devic.patch (drm-backport-placeholder)
- commit bc1d184
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop2-Add-missing-call-to-crtc-reset-hel.patch (drm-backport-placeholder)
- commit b19bda7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop2-Don-t-crash-for-invalid-duplicate_.patch (drm-backport-placeholder)
- commit e03015c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop-Fix-call-to-crtc-reset-helper.patch (drm-backport-placeholder)
- commit 6b09458
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0015-drm-rockchip-vop-Use-cleanup-helper-directly-as-dest.patch (drm-backport-placeholder)
- commit 1d9908f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop-Fix-reset-of-state-in-duplicate-sta.patch (drm-backport-placeholder)
- commit fa53a2c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-loongson-Fix-error-handling-in-lsdc_pixel_pll_se.patch (drm-backport-placeholder)
- commit a059163
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0012-drm-bridge-lvds-codec-Implement-atomic_get_input_bus.patch (drm-backport-placeholder)
- commit 7671113
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-samsung-dsim-Fix-waiting-for-empty-cmd-tr.patch (drm-backport-placeholder)
- commit 6ad19e1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-for-GENERIC_PHY_MIPI_DPHY-also-select-GEN.patch (drm-backport-placeholder)
- commit 2122ed8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0008-accel-ivpu-Document-DRM_IVPU_PARAM_CAPABILITIES.patch (drm-backport-placeholder)
- commit 8af2cf0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0007-drm-rockchip-dsi-Add-rv1126-MIPI-DSI-support.patch (drm-backport-placeholder)
- commit f605056
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0006-drm-rockchip-vop-Add-rv1126-vop_lite-support.patch (drm-backport-placeholder)
- commit 3f99f13
* Wed Oct  2 2024 tiwai@suse.de
- ALSA: hda/generic: Unconditionally prefer preferred_dacs pairs
  (bsc#1219803).
- commit 020b49a
* Tue Oct  1 2024 msuchanek@suse.de
- powerpc/code-patching: Add generic memory patching
  (bsc#1194869).
- powerpc/code-patching: Perform hwsync in __patch_instruction()
  in case of failure (bsc#1194869).
- commit 33b01a6
* Tue Oct  1 2024 oneukum@suse.com
- usbnet: fix cyclical race on disconnect with work queue
  (git-fixes).
- Refresh
  patches.suse/0002-Add-a-void-suse_kabi_padding-placeholder-to-some-USB.patch.
- commit 8272f2d
* Tue Oct  1 2024 dsterba@suse.com
- apparmor: fix possible NULL pointer dereference (CVE-2024-46721 bsc#1230710)
- commit 2d35a7c
* Tue Oct  1 2024 oneukum@suse.com
- i3c: master: support to adjust first broadcast address speed
  (jsc#PED-10702).
- commit 192a460
* Tue Oct  1 2024 msuchanek@suse.de
- blacklist.conf: ff2e185cf73d powerpc/pseries: Enforce hcall result
  buffer validity and size
  Only works with clang
- commit cd964d8
* Tue Oct  1 2024 oneukum@suse.com
- i3c: master: Enhance i3c_bus_type visibility for device
  searching & event monitoring (jsc#PED-10702).
- commit a2f0df9
* Tue Oct  1 2024 oneukum@suse.com
- i3c: Make i3c_bus_type const (jsc#PED-10702).
- commit f58db15
* Tue Oct  1 2024 oneukum@suse.com
- i3c: master: Enable runtime PM for master controller
  (jsc#PED-10702).
- commit e01c1d7
* Tue Oct  1 2024 oneukum@suse.com
- i3c: master: add enable(disable) hot join in sys entry
  (jsc#PED-10702).
- commit 2bff927
* Tue Oct  1 2024 oneukum@suse.com
- i3c: master: Fix build error (jsc#PED-10702).
- commit f6f86c8
* Tue Oct  1 2024 oneukum@suse.com
- i3c: Add fallback method for GETMXDS CCC (jsc#PED-10702).
- commit 3ce09f9
* Tue Oct  1 2024 msuchanek@suse.de
- powerpc/64: Convert patch_instruction() to patch_u32()
  (bsc#1194869).
- powerpc/boot: Only free if realloc() succeeds (bsc#1194869).
- powerpc/boot: Handle allocation failure in simple_realloc()
  (bsc#1194869).
- powerpc/xics: Check return value of kasprintf in
  icp_native_map_one_cpu (bsc#1194869).
- powerpc/vdso: Fix VDSO data access when running in a non-root
  time namespace (bsc#1194869).
- commit 0dec2e8
* Tue Oct  1 2024 tbogendoerfer@suse.de
- net: mana: Improve mana_set_channels() in low mem conditions
  (bsc#1230289).
- net: mana: Implement get_ringparam/set_ringparam for mana
  (bsc#1229891).
- net: dpaa: Pad packets to ETH_ZLEN (CVE-2024-46854 bsc#1231084).
- ice: move netif_queue_set_napi to rtnl-protected sections
  (CVE-2024-46766 bsc#1230762).
- ice: Add netif_device_attach/detach into PF reset flow
  (CVE-2024-46770 bsc#1230763).
- bonding: change ipsec_lock from spin lock to mutex
  (CVE-2024-46678 bsc#1230550).
- bonding: extract the use of real_device into local variable
  (CVE-2024-46678 bsc#1230550).
- bonding: implement xdo_dev_state_free and call it after deletion
  (CVE-2024-46678 bsc#1230550).
- commit 9ee67ad
* Tue Oct  1 2024 oneukum@suse.com
- i3c: Add support for bus enumeration & notification
  (jsc#PED-10702).
- commit 6812158
* Tue Oct  1 2024 oneukum@suse.com
- i3c: master: Inherit DMA masks and parameters from parent device
  (jsc#PED-10702).
- commit e40b49d
* Tue Oct  1 2024 pmladek@suse.com
- printk: Export match_devname_and_update_preferred_console()
  (bsc#1229741).
- commit 1ad32a8
* Tue Oct  1 2024 oneukum@suse.com
- i3c: master: Fix SETDASA process (jsc#PED-10702).
- commit 41b03a5
* Tue Oct  1 2024 msuchanek@suse.de
- powerpc/xmon: Fix disassembly CPU feature checks (bsc#1065729).
- commit c675509
* Tue Oct  1 2024 oneukum@suse.com
- power: supply: sbs-manager: Remove class argument from
  i2c_mux_add_adapter() (jsc#PED-10702).
- commit d070c7f
* Tue Oct  1 2024 tiwai@suse.de
- ACPICA: executer/exsystem: Don't nag user about every Stall()
  violating the spec (git-fixes).
- ACPICA: Implement ACPI_WARNING_ONCE and ACPI_ERROR_ONCE
  (stable-fixes).
- commit f94e799
* Tue Oct  1 2024 tiwai@suse.de
- platform/x86: int3472: make common part a separate module
  (git-fixes).
- supported.conf:
- commit 2169815
* Tue Oct  1 2024 tiwai@suse.de
- serial: 8250: omap: Cleanup on error in request_irq (git-fixes).
- Bluetooth: btintel_pcie: Allocate memory for driver private data
  (git-fixes).
- wifi: mac80211: Check for missing VHT elements only for 5 GHz
  (git-fixes).
- wifi: iwlwifi: mvm: allow ESR when we the ROC expires
  (git-fixes).
- ASoC: Intel: soc-acpi-intel-mtl-match: add missing empty item
  (git-fixes).
- ASoC: Intel: soc-acpi-intel-lnl-match: add missing empty item
  (git-fixes).
- commit 2a26c38
* Tue Oct  1 2024 lhenriques@suse.de
- cachefiles: fix dentry leak in cachefiles_open_file()
  (bsc#1231183).
- ceph: remove the incorrect Fw reference check when dirtying
  pages (bsc#1231182).
- commit ba82da7
* Tue Oct  1 2024 schwab@suse.de
- rpm/check-for-config-changes: add HAVE_RUST and RUSTC_SUPPORTS_ to IGNORED_CONFIGS_RE
  They depend on SHADOW_CALL_STACK.
- commit 65fa52b
* Tue Oct  1 2024 nik.borisov@suse.com
- x86/fred: Enable FRED right after init_mem_mapping() (git-fixes).
- commit 50422f5
* Tue Oct  1 2024 nik.borisov@suse.com
- x86/fred: Move FRED RSP initialization into a separate function (git-fixes).
- commit 202a097
* Tue Oct  1 2024 nik.borisov@suse.com
- x86/fred: Parse cmdline param "fred=" in cpu_parse_early_param() (git-fixes).
- commit 11cf3ac
* Tue Oct  1 2024 nik.borisov@suse.com
- x86/ioremap: Improve iounmap() address range checks (jsc#PED-10334).
- commit 4db5304
* Tue Oct  1 2024 tiwai@suse.de
- serial: 8250: omap: Cleanup on error in request_irq (git-fixes).
- Bluetooth: btintel_pcie: Allocate memory for driver private data
  (git-fixes).
- wifi: mac80211: Check for missing VHT elements only for 5 GHz
  (git-fixes).
- wifi: iwlwifi: mvm: allow ESR when we the ROC expires
  (git-fixes).
- ASoC: Intel: soc-acpi-intel-mtl-match: add missing empty item
  (git-fixes).
- ASoC: Intel: soc-acpi-intel-lnl-match: add missing empty item
  (git-fixes).
- commit 68827c1
* Tue Oct  1 2024 tiwai@suse.de
- can: mcp251xfd: move mcp251xfd_timestamp_start()/stop() into
  mcp251xfd_chip_start/stop() (stable-fixes).
- Refresh
  patches.suse/can-mcp251xfd-clarify-the-meaning-of-timestamp.patch.
- commit 6779985
* Tue Oct  1 2024 tiwai@suse.de
- USB: serial: pl2303: add device id for Macrosilicon MS3020
  (stable-fixes).
- powercap/intel_rapl: Add support for AMD family 1Ah
  (stable-fixes).
- ASoC: amd: yc: Add a quirk for MSI Bravo 17 (D7VEK)
  (stable-fixes).
- ASoC: tda7419: fix module autoloading (stable-fixes).
- ASoC: intel: fix module autoloading (stable-fixes).
- ASoC: Intel: soc-acpi-cht: Make Lenovo Yoga Tab 3 X90F DMI
  match less strict (stable-fixes).
- ALSA: hda: add HDMI codec ID for Intel PTL (stable-fixes).
- drm: komeda: Fix an issue related to normalized zpos
  (stable-fixes).
- can: mcp251xfd: mcp251xfd_ring_init(): check TX-coalescing
  configuration (stable-fixes).
- spi: spidev: Add missing spi_device_id for jg10309-01
  (git-fixes).
- spi: bcm63xx: Enable module autoloading (stable-fixes).
- spi: spidev: Add an entry for elgin,jg10309-01 (stable-fixes).
- hwmon: (asus-ec-sensors) remove VRM temp X570-E GAMING
  (stable-fixes).
- wifi: iwlwifi: clear trans->state earlier upon error
  (stable-fixes).
- wifi: mac80211: free skb on error path in
  ieee80211_beacon_get_ap() (stable-fixes).
- wifi: iwlwifi: mvm: don't wait for tx queues if firmware is dead
  (stable-fixes).
- wifi: iwlwifi: mvm: pause TCM when the firmware is stopped
  (stable-fixes).
- wifi: iwlwifi: mvm: fix iwl_mvm_max_scan_ie_fw_cmd_room()
  (stable-fixes).
- wifi: iwlwifi: mvm: fix iwl_mvm_scan_fits() calculation
  (stable-fixes).
- wifi: iwlwifi: lower message level for FW buffer destination
  (stable-fixes).
- platform/x86: x86-android-tablets: Make Lenovo Yoga Tab 3 X90F
  DMI match less strict (stable-fixes).
- pinctrl: at91: make it work with current gpiolib (stable-fixes).
- can: mcp251xfd: properly indent labels (stable-fixes).
- commit a530f31
* Mon Sep 30 2024 dwagner@suse.de
- nvme-fabrics: use reserved tag for reg read/write command
  (bsc#1228620 CVE-2024-41082).
- commit 239456c
* Mon Sep 30 2024 oneukum@suse.com
- i2c: Convert to platform remove callback returning void
  (jsc#PED-10702).
- Refresh
  patches.suse/i2c-synquacer-Fix-an-error-handling-path-in-synquace.patch.
- Refresh
  patches.suse/i2c-wmt-Fix-an-error-handling-path-in-wmt_i2c_probe.patch.
- Refresh patches.suse/i2c-wmt-split-out-common-files.patch.
- commit f88ec74
* Mon Sep 30 2024 oneukum@suse.com
- i2c: dev: Check for I2C_FUNC_I2C before calling i2c_transfer
  (jsc#PED-10702).
- commit 9352566
* Mon Sep 30 2024 pmladek@suse.com
- kthread: Fix task state in kthread worker if being frozen
  (bsc#1231146).
- commit fe88a62
* Mon Sep 30 2024 jroedel@suse.de
- x86/sev: Move sev_guest.h into common SEV header (jsc#PED-5865).
- Update
  patches.suse/0017-KVM-SEV-Provide-support-for-SNP_GUEST_REQUEST-NAE-ev.patch
  (jsc#PED-5865).
- Update
  patches.suse/0018-KVM-SEV-Provide-support-for-SNP_EXTENDED_GUEST_REQUE.patch
  (jsc#PED-5865).
- Update
  patches.suse/0019-crypto-ccp-Add-the-SNP_VLEK_LOAD-command.patch
  (jsc#PED-5865).
- commit 66856e5
* Mon Sep 30 2024 tiwai@suse.de
- supported.conf: mark adiantum and xctr crypto modules as supported (bsc#1231035)
- commit 59d03d7
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Remove usage of I2C_CLASS_SPD (jsc#PED-10702).
- commit 52c282e
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Fix missing Kconfig dependency (jsc#PED-10702).
- Update config files.
- commit f954df0
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Call i2c_register_spd for muxed child segments
  (jsc#PED-10702).
- commit 45dec67
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Fix a refactoring that broke a touchpad on Lenovo P1
  (jsc#PED-10702).
- commit b2a9cae
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Fix using mux_pdev before it's set (jsc#PED-10702).
- commit 4b2d99f
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Add helper i801_get_block_len (jsc#PED-10702).
- commit a3ae321
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Add SMBUS_LEN_SENTINEL (jsc#PED-10702).
- commit 554ac99
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Split i801_block_transaction (jsc#PED-10702).
- commit 89fb647
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Add helper i801_check_and_clear_pec_error
  (jsc#PED-10702).
- commit f8c7e2f
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Remove unused argument from tco functions
  (jsc#PED-10702).
- commit 5d5a3e6
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Simplify class-based client device instantiation
  (jsc#PED-10702).
- commit 9d8598a
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: add helper i801_restore_regs (jsc#PED-10702).
- commit 3910abf
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Remove #ifdef guards for PM related functions
  (jsc#PED-10702).
- commit f44e603
* Mon Sep 30 2024 petr.pavlu@suse.com
- Refresh
  patches.suse/bpf-kprobe-remove-unused-declaring-of-bpf_kprobe_override.patch.
- commit 5a0b269
* Mon Sep 30 2024 petr.pavlu@suse.com
- bpf: Fix use-after-free in bpf_uprobe_multi_link_attach()
  (git-fixes).
- commit 1884922
* Mon Sep 30 2024 petr.pavlu@suse.com
- tracing: Avoid possible softlockup in tracing_iter_reset()
  (git-fixes).
- commit d5df75c
* Mon Sep 30 2024 petr.pavlu@suse.com
- tracing: Fix overflow in get_free_elt() (git-fixes
  CVE-2024-43890 bsc#1229764).
- commit ceb524e
* Mon Sep 30 2024 iivanov@suse.de
- arm64: acpi: Harden get_cpu_for_acpi_id() against missing CPU entry (bsc#1231120 CVE-2024-46822)
- commit cc6d7b5
* Mon Sep 30 2024 oneukum@suse.com
- i2c: smbus: Support DDR5 and LPDDR5 SPD EEPROMs (jsc#PED-10702).
- commit 9364afd
* Mon Sep 30 2024 oneukum@suse.com
- i2c: mux: Remove class argument from i2c_mux_add_adapter()
  (jsc#PED-10702).
- commit 9543eba
* Mon Sep 30 2024 tiwai@suse.de
- mailbox: bcm2835: Fix timeout during suspend mode (git-fixes).
- mailbox: rockchip: fix a typo in module autoloading (git-fixes).
- i2c: designware: fix controller is holding SCL low while ENABLE
  bit is disabled (git-fixes).
- drm/amd/display: handle nulled pipe context in DCE110's
  set_drr() (git-fixes).
- drm/amdgpu: Fix get each xcp macro (git-fixes).
- tomoyo: fallback to realpath if symlink's pathname does not
  exist (git-fixes).
- cxl/pci: Fix to record only non-zero ranges (git-fixes).
- ata: libata-scsi: Fix ata_msense_control() CDL page reporting
  (git-fixes).
- firmware_loader: Block path traversal (git-fixes).
- driver core: Fix a potential null-ptr-deref in
  module_add_driver() (git-fixes).
- driver core: Fix error handling in driver API device_rename()
  (git-fixes).
- ep93xx: clock: Fix off by one in ep93xx_div_recalc_rate()
  (git-fixes).
- iio: magnetometer: ak8975: Fix reading for ak099xx sensors
  (git-fixes).
- iio: chemical: bme680: Fix read/write ops to device by adding
  mutexes (git-fixes).
- ABI: testing: fix admv8818 attr description (git-fixes).
- iio: adc: ad7606: fix standby gpio state to match the
  documentation (git-fixes).
- iio: adc: ad7606: fix oversampling gpio array (git-fixes).
- tty: rp2: Fix reset with non forgiving PCIe host bridges
  (git-fixes).
- USB: class: CDC-ACM: fix race between get_serial and set_serial
  (git-fixes).
- usb: dwc2: drd: fix clock gating on USB role switch (git-fixes).
- usb: cdnsp: Fix incorrect usb_request status (git-fixes).
- USB: usbtmc: prevent kernel-usb-infoleak (git-fixes).
- USB: serial: kobil_sct: restore initial terminal settings
  (git-fixes).
- xhci: Set quirky xHC PCI hosts to D3 _after_ stopping and
  freeing them (git-fixes).
- usb: dwc2: Skip clock gating on Broadcom SoCs (git-fixes).
- spi: atmel-quadspi: Avoid overwriting delay register settings
  (git-fixes).
- spi: spi-fsl-lpspi: Undo runtime PM changes at driver exit time
  (git-fixes).
- spi: atmel-quadspi: Undo runtime PM changes at driver exit time
  (git-fixes).
- rtc: at91sam9: fix OF node leak in probe() error path
  (git-fixes).
- i3c: master: svc: Fix use after free vulnerability in
  svc_i3c_master Driver Due to Race Condition (git-fixes).
- remoteproc: k3-r5: Fix error handling when power-up failed
  (git-fixes).
- remoteproc: imx_rproc: Initialize workqueue earlier (git-fixes).
- remoteproc: imx_rproc: Correct ddr alias for i.MX8M (git-fixes).
- KEYS: prevent NULL pointer dereference in find_asymmetric_key()
  (git-fixes).
- media: i2c: ar0521: Use cansleep version of gpiod_set_value()
  (git-fixes).
- media: ov5675: Fix power on/off delay timings (git-fixes).
- media: sun4i_csi: Implement link validate for sun4i_csi subdev
  (git-fixes).
- media: platform: rzg2l-cru: rzg2l-csi2: Add missing
  MODULE_DEVICE_TABLE (git-fixes).
- media: venus: fix use after free bug in venus_remove due to
  race condition (git-fixes).
- media: uapi/linux/cec.h: cec_msg_set_reply_to: zero flags
  (git-fixes).
- clk: ti: dra7-atl: Fix leak of of_nodes (git-fixes).
- watchdog: imx_sc_wdt: Don't disable WDT in suspend (git-fixes).
- pinctrl: single: fix missing error code in pcs_probe()
  (git-fixes).
- xz: cleanup CRC32 edits from 2018 (git-fixes).
- ata: pata_macio: Use WARN instead of BUG (stable-fixes).
- commit c5ab3ca
* Mon Sep 30 2024 oneukum@suse.com
- i2c: mux: reg: Remove class-based device auto-detection support
  (jsc#PED-10702).
- commit 8000ff4
* Mon Sep 30 2024 oneukum@suse.com
- i2c: mux: gpio: remove support for class-based device
  instantiation (jsc#PED-10702).
- commit 6024383
* Mon Sep 30 2024 oneukum@suse.com
- i2c: mux: gpio: don't fiddle with GPIOLIB internals
  (jsc#PED-10702).
- commit 2656e30
* Mon Sep 30 2024 oneukum@suse.com
- i2c: mux: gpio: adhere to coding style (jsc#PED-10702).
- commit ad61f98
* Mon Sep 30 2024 tiwai@suse.de
- Move upstreamed SCSI patches into sorted section
- commit aba5747
* Mon Sep 30 2024 hare@suse.de
- kcm: Serialise kcm_sendmsg() for the same socket (CVE-2024-44946
  bsc#1230015).
- commit 4310760
* Mon Sep 30 2024 hare@suse.de
- nvme-multipath: avoid hang on inaccessible namespaces
  (bsc#1228244).
- kcm: Serialise kcm_sendmsg() for the same socket
  (CVE-2024-44946,bsc#1230015).
- commit a84ca87
* Mon Sep 30 2024 hare@suse.de
- nvme-multipath: system fails to create generic nvme device
  (bsc#1228244).
- commit 4fc57d2
* Mon Sep 30 2024 ailiop@suse.com
- erofs: fix incorrect symlink detection in fast symlink
  (git-fixes).
- commit 2e1ae75
* Mon Sep 30 2024 ailiop@suse.com
- afs: Don't cross .backup mountpoint from backup volume
  (git-fixes).
- commit f35dae1
* Mon Sep 30 2024 ailiop@suse.com
- afs: Revert "afs: Hide silly-rename files from userspace"
  (git-fixes).
- commit 11353bb
* Fri Sep 27 2024 mwilck@suse.com
- scsi: sd: Fix off-by-one error in
  sd_read_block_characteristics() (bsc#1223848).
- commit 621f2fb
* Fri Sep 27 2024 mwilck@suse.com
- scsi: ibmvfc: Add max_sectors module parameter (bsc#1216223).
- commit af0ff0f
* Fri Sep 27 2024 dsterba@suse.com
- drm/amd/display: Check denominator crb_pipes before used (CVE-2024-46772 bsc#1230772)
- commit 322be4a
* Fri Sep 27 2024 dsterba@suse.com
- blacklist.conf: CVE-2024-46727 bsc#1230707: not applicable
  No OTG code and all return values from
  resource_get_otg_master_for_stream() are checked before use.
- commit f44b1e7
* Fri Sep 27 2024 oneukum@suse.com
- treewide: rename pinctrl_gpio_request_new() (jsc#PED-10702).
- commit 7aa99b3
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: remove pinctrl_gpio_set_config() (jsc#PED-10702).
- commit 8c0560c
* Fri Sep 27 2024 oneukum@suse.com
- gpiolib: add gpio_device_get_base() stub for !GPIOLIB
  (jsc#PED-10702).
- commit 037f285
* Fri Sep 27 2024 oneukum@suse.com
- gpiolib: add gpiod_to_gpio_device() stub for !GPIOLIB
  (jsc#PED-10702).
- commit 7bb9cad
* Fri Sep 27 2024 oneukum@suse.com
- gpiolib: Fix scope-based gpio_device refcounting
  (jsc#PED-10702).
- commit 7f441f3
* Fri Sep 27 2024 oneukum@suse.com
- gpiolib: sysfs: Do unexport GPIO when user asks for it
  (jsc#PED-10702).
- Refresh
  patches.suse/gpio-sysfs-extend-the-critical-section-for-unregiste.patch.
- commit d142469
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: remove pinctrl_gpio_direction_output() (jsc#PED-10702).
- commit 77e2df6
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: cirrus: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 4aa1b74
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: remove pinctrl_gpio_direction_input() (jsc#PED-10702).
- commit be63631
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: cy8c95x0: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 9e924b8
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: mediatek: paris: use new pinctrl GPIO helpers
  (jsc#PED-10702).
- commit d7689d1
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: ingenic: use new pinctrl GPIO helpers (jsc#PED-10702).
- pinctrl: mediatek: common: use new pinctrl GPIO helpers
  (jsc#PED-10702).
- pinctrl: mediatek: moore: use new pinctrl GPIO helpers
  (jsc#PED-10702).
- commit c8be469
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: axp209: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit e10a506
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: axp209: Add support for GPIO3 on the AXP209
  (jsc#PED-10702).
- commit 8e0ba86
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: as3722: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 31022c4
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: st: use new pinctrl GPIO helpers (jsc#PED-10702).
- pinctrl: rk805: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 8127e74
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: allwinner: h616: Add r_i2c pinctrl nodes
  (git-fixes).
- commit 642d7e6
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: imx8-ss-dma: Fix adc0 closing brace location
  (git-fixes).
- commit 970cc49
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: Correct vendor prefix for Hardkernel
  ODROID-M1 (git-fixes).
- commit 87f0ae6
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: ocelot: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 419ff06
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: vt8500: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 6b62bb0
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: Raise Pinebook Pro's panel backlight
  PWM frequency (git-fixes).
- commit 1582b94
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: intel: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 3674192
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: intel: refine ->irq_set_type() hook (jsc#PED-10702).
- commit 0b317a9
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: cherryview: use new pinctrl GPIO helpers
  (jsc#PED-10702).
- commit 9ec7d21
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: cherryview: reduce scope of
  PIN_CONFIG_BIAS_HIGH_IMPEDANCE case (jsc#PED-10702).
- commit 3b105e2
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: lynxpoint: use new pinctrl GPIO helpers
  (jsc#PED-10702).
- commit 2f166c6
* Fri Sep 27 2024 oneukum@suse.com
- gpio: vf610: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 3db46cf
* Fri Sep 27 2024 oneukum@suse.com
- gpio: rockchip: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 8f6bb80
* Fri Sep 27 2024 oneukum@suse.com
- gpio: pxa: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit d6b6f8b
* Fri Sep 27 2024 oneukum@suse.com
- gpio: mvebu: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 362264e
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: Correct the Pinebook Pro battery design
  capacity (git-fixes).
- commit 3b2ebbf
* Fri Sep 27 2024 oneukum@suse.com
- gpio: Use device_get_match_data() (jsc#PED-10702).
- commit 005bb99
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: exynos: exynos7885-jackpotlte: Correct RAM amount
  to 4GB (git-fixes).
- commit 1059c29
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: remove pinctrl_gpio_free() (jsc#PED-10702).
- commit 71dc629
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: signal: Fix some under-bracketed UAPI macros (git-fixes).
- commit 9704ff3
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: override BIOS_DISABLE signal via GPIO
  hog on RK3399 Puma (git-fixes).
- commit 6052a8c
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: fix eMMC/SPI corruption when audio has
  been used on RK3399 Puma (git-fixes).
- commit 8b3743b
* Fri Sep 27 2024 msuchanek@suse.de
- Update
  patches.suse/powerpc-pseries-make-max-polling-consistent-for-long.patch
  (bsc#1215199 jsc#PED-10954).
- Update
  patches.suse/security-integrity-fix-pointer-to-ESL-data-and-.patch
  (bsc#1012628 jsc#PED-5085 jsc#PED-10954).
- commit ec9be2c
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: fix PMIC interrupt pin in pinctrl for
  ROCK Pi E (git-fixes).
- commit 7527015
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: acpi: Move get_cpu_for_acpi_id() to a header (git-fixes).
- commit 42389f0
* Fri Sep 27 2024 iivanov@suse.de
- ipmi:ssif: Improve detecting during probing (bsc#1228771)
  Move patch into the sorted section.
- commit 77cf6fc
* Fri Sep 27 2024 jslaby@suse.cz
- Update
  patches.suse/ASoC-Intel-Boards-Fix-NULL-pointer-deref-in-BYT-CHT--0cc6548.patch
  (git-fixes CVE-2024-46793 bsc#1230824).
- Update
  patches.suse/ASoC-cs-amp-lib-Fix-NULL-pointer-crash-if-efi.get_va.patch
  (jsc#PED-9993 jsc#PED-10202 CVE-2024-43896 bsc#1229751).
- Update
  patches.suse/ASoc-PCM6240-Return-directly-after-a-failed-devm_kza.patch
  (jsc#PED-9993 jsc#PED-10202 CVE-2024-43822 bsc#1229343).
- Update
  patches.suse/Bluetooth-btnxpuart-Fix-random-crash-seen-while-remo.patch
  (jsc#PED-10412 CVE-2024-46680 bsc#1230557).
- commit 7894abc
* Fri Sep 27 2024 jslaby@suse.cz
- Update patches.suse/ALSA-line6-Fix-racy-access-to-midibuf.patch
  (stable-fixes CVE-2024-44954 bsc#1230176).
- Update
  patches.suse/ASoC-dapm-Fix-UAF-for-snd_soc_pcm_runtime-object.patch
  (git-fixes CVE-2024-46798 bsc#1230830).
- Update
  patches.suse/Bluetooth-btnxpuart-Fix-Null-pointer-dereference-in-.patch
  (stable-fixes CVE-2024-46749 bsc#1230780).
- Update
  patches.suse/Bluetooth-btnxpuart-Shutdown-timer-and-prevent-rearm.patch
  (stable-fixes CVE-2024-44962 bsc#1230213).
- Update
  patches.suse/HID-amd_sfh-free-driver_data-after-destroying-hid-de.patch
  (stable-fixes CVE-2024-46746 bsc#1230751).
- Update
  patches.suse/HID-cougar-fix-slab-out-of-bounds-Read-in-cougar_rep.patch
  (stable-fixes CVE-2024-46747 bsc#1230752).
- Update patches.suse/Input-MT-limit-max-slots.patch (stable-fixes
  CVE-2024-45008 bsc#1230248).
- Update
  patches.suse/Input-uinput-reject-requests-with-unreasonable-numbe.patch
  (stable-fixes CVE-2024-46745 bsc#1230748).
- Update
  patches.suse/KVM-arm64-Make-ICC_-SGI-_EL1-undef-in-the-absence-of.patch
  (git-fixes CVE-2024-46707 bsc#1230582).
- Update
  patches.suse/KVM-s390-fix-validity-interception-issue-when-gisa-is-switched-off.patch
  (git-fixes bsc#1229167 CVE-2024-45005 bsc#1230173).
- Update
  patches.suse/PCI-Add-missing-bridge-lock-to-pci_bus_lock.patch
  (stable-fixes CVE-2024-46750 bsc#1230783).
- Update
  patches.suse/Squashfs-sanity-check-symbolic-link-size.patch
  (git-fixes CVE-2024-46744 bsc#1230747).
- Update
  patches.suse/VMCI-Fix-use-after-free-when-removing-resource-in-vm.patch
  (git-fixes CVE-2024-46738 bsc#1230731).
- Update
  patches.suse/bpf-Fix-a-kernel-verifier-crash-in-stacksafe.patch
  (bsc#1225903 CVE-2024-45020 bsc#1230433).
- Update
  patches.suse/btrfs-fix-race-between-direct-IO-write-and-fsync-whe.patch
  (git-fixes CVE-2024-46734 bsc#1230726).
- Update
  patches.suse/can-bcm-Remove-proc-entry-when-dev-is-unregistered.patch
  (git-fixes CVE-2024-46771 bsc#1230766).
- Update
  patches.suse/can-mcp251x-fix-deadlock-if-an-interrupt-occurs-duri.patch
  (git-fixes CVE-2024-46791 bsc#1230821).
- Update
  patches.suse/char-xillybus-Check-USB-endpoints-when-probing-devic.patch
  (git-fixes CVE-2024-45011 bsc#1230440).
- Update
  patches.suse/char-xillybus-Don-t-destroy-workqueue-from-work-item.patch
  (stable-fixes CVE-2024-45007 bsc#1230175).
- Update
  patches.suse/dmaengine-altera-msgdma-properly-free-descriptor-in-.patch
  (stable-fixes CVE-2024-46716 bsc#1230715).
- Update
  patches.suse/driver-core-Fix-uevent_show-vs-driver-detach-race.patch
  (git-fixes CVE-2024-44952 bsc#1230178).
- Update
  patches.suse/driver-iio-add-missing-checks-on-iio_info-s-callback.patch
  (stable-fixes CVE-2024-46715 bsc#1230700).
- Update
  patches.suse/drm-amd-display-Assign-linear_pitch_alignment-even-f.patch
  (stable-fixes CVE-2024-46732 bsc#1230711).
- Update
  patches.suse/drm-amd-display-Check-UnboundedRequestEnabled-s-valu.patch
  (stable-fixes CVE-2024-46778 bsc#1230776).
- Update
  patches.suse/drm-amd-display-Check-denominator-pbn_div-before-use.patch
  (stable-fixes CVE-2024-46773 bsc#1230791).
- Update
  patches.suse/drm-amd-display-Check-index-for-aux_rd_interval-befo.patch
  (stable-fixes CVE-2024-46728 bsc#1230703).
- Update
  patches.suse/drm-amd-display-Ensure-array-index-tg_inst-won-t-be-.patch
  (stable-fixes CVE-2024-46730 bsc#1230701).
- Update
  patches.suse/drm-amd-display-Ensure-index-calculation-will-not-ov.patch
  (stable-fixes CVE-2024-46726 bsc#1230706).
- Update
  patches.suse/drm-amd-display-Run-DC_LOG_DC-after-checking-link-li.patch
  (stable-fixes CVE-2024-46776 bsc#1230775).
- Update
  patches.suse/drm-amd-display-Skip-wbscl_set_scaler_filter-if-filt.patch
  (stable-fixes CVE-2024-46714 bsc#1230699).
- Update
  patches.suse/drm-amd-display-avoid-using-null-object-of-framebuff.patch
  (git-fixes CVE-2024-46694 bsc#1230511).
- Update
  patches.suse/drm-amd-pm-fix-the-Out-of-bounds-read-warning.patch
  (stable-fixes CVE-2024-46731 bsc#1230709).
- Update
  patches.suse/drm-amdgpu-Fix-out-of-bounds-read-of-df_v1_7_channel.patch
  (stable-fixes CVE-2024-46724 bsc#1230725).
- Update
  patches.suse/drm-amdgpu-Fix-out-of-bounds-write-warning.patch
  (stable-fixes CVE-2024-46725 bsc#1230705).
- Update
  patches.suse/drm-amdgpu-Forward-soft-recovery-errors-to-userspace.patch
  (stable-fixes CVE-2024-44961 bsc#1230207).
- Update patches.suse/drm-amdgpu-Validate-TA-binary-size.patch
  (stable-fixes CVE-2024-44977 bsc#1230217).
- Update
  patches.suse/drm-amdgpu-fix-dereference-after-null-check.patch
  (stable-fixes CVE-2024-46720 bsc#1230724).
- Update
  patches.suse/drm-amdgpu-fix-mc_data-out-of-bounds-read-warning.patch
  (stable-fixes CVE-2024-46722 bsc#1230712).
- Update
  patches.suse/drm-amdgpu-fix-ucode-out-of-bounds-read-warning.patch
  (stable-fixes CVE-2024-46723 bsc#1230702).
- Update
  patches.suse/drm-mgag200-Bind-I2C-lifetime-to-DRM-device.patch
  (git-fixes CVE-2024-44967 bsc#1230224).
- Update
  patches.suse/drm-msm-dpu-cleanup-FB-if-dpu_format_populate_layout.patch
  (git-fixes CVE-2024-44982 bsc#1230204).
- Update
  patches.suse/drm-msm-dpu-move-dpu_encoder-s-connector-assignment-.patch
  (git-fixes CVE-2024-45015 bsc#1230444).
- Update
  patches.suse/drm-vmwgfx-Fix-prime-with-external-buffers.patch
  (git-fixes CVE-2024-46709 bsc#1230539).
- Update
  patches.suse/fs-netfs-fscache_cookie-add-missing-n_accesses-check.patch
  (bsc#1229455 CVE-2024-45000 bsc#1230170).
- Update
  patches.suse/fscache-delete-fscache_cookie_lru_timer-when-fscache-.patch
  (bsc#1230602 CVE-2024-46786 bsc#1230813).
- Update
  patches.suse/fuse-Initialize-beyond-EOF-page-contents-before-setti.patch
  (bsc#1229456 CVE-2024-44947).
- Update
  patches.suse/hwmon-adc128d818-Fix-underflows-seen-when-writing-li.patch
  (stable-fixes CVE-2024-46759 bsc#1230814).
- Update
  patches.suse/hwmon-lm95234-Fix-underflows-seen-when-writing-limit.patch
  (stable-fixes CVE-2024-46758 bsc#1230812).
- Update
  patches.suse/hwmon-nct6775-core-Fix-underflows-seen-when-writing-.patch
  (stable-fixes CVE-2024-46757 bsc#1230809).
- Update
  patches.suse/hwmon-w83627ehf-Fix-underflows-seen-when-writing-lim.patch
  (stable-fixes CVE-2024-46756 bsc#1230806).
- Update
  patches.suse/media-dvb-usb-v2-af9035-Fix-null-ptr-deref-in-af9035.patch
  (git-fixes CVE-2023-52915 bsc#1230270).
- Update
  patches.suse/misc-fastrpc-Fix-double-free-of-buf-in-error-path.patch
  (git-fixes CVE-2024-46741 bsc#1230749).
- Update
  patches.suse/mmc-mmc_test-Fix-NULL-dereference-on-allocation-fail.patch
  (git-fixes CVE-2024-45028 bsc#1230450).
- Update
  patches.suse/msft-hv-3046-uio_hv_generic-Fix-kernel-NULL-pointer-dereference-i.patch
  (git-fixes CVE-2024-46739 bsc#1230732).
- Update
  patches.suse/msft-hv-3048-net-mana-Fix-error-handling-in-mana_create_txq-rxq-s.patch
  (git-fixes CVE-2024-46784 bsc#1230771).
- Update
  patches.suse/net-ethernet-mtk_wed-fix-use-after-free-panic-in-mtk.patch
  (git-fixes CVE-2024-44997 bsc#1230232).
- Update
  patches.suse/net-mana-Fix-RX-buf-alloc_size-alignment-and-atomic-.patch
  (bsc#1229086 CVE-2024-45001 bsc#1230244).
- Update
  patches.suse/net-phy-Fix-missing-of_node_put-for-leds.patch
  (git-fixes CVE-2024-46767 bsc#1230787).
- Update
  patches.suse/nfc-pn533-Add-poll-mod-list-filling-check.patch
  (git-fixes CVE-2024-46676 bsc#1230535).
- Update
  patches.suse/nilfs2-fix-missing-cleanup-on-rollforward-recovery-error.patch
  (git-fixes CVE-2024-46781 bsc#1230768).
- Update
  patches.suse/nilfs2-protect-references-to-superblock-parameters-exposed-in-sysfs.patch
  (git-fixes CVE-2024-46780 bsc#1230808).
- Update
  patches.suse/nouveau-firmware-use-dma-non-coherent-allocator.patch
  (git-fixes CVE-2024-45012 bsc#1230441).
- Update
  patches.suse/nvmet-tcp-fix-kernel-crash-if-commands-allocation-fa.patch
  (git-fixes CVE-2024-46737 bsc#1230730).
- Update
  patches.suse/pci-hotplug-pnv_php-Fix-hotplug-driver-crash-on-Powe.patch
  (stable-fixes CVE-2024-46761 bsc#1230761).
- Update patches.suse/perf-Fix-event-leak-upon-exit.patch
  (git-fixes CVE-2024-43870 bsc#1229494).
- Update
  patches.suse/pinctrl-single-fix-potential-NULL-dereference-in-pcs.patch
  (git-fixes CVE-2024-46685 bsc#1230515).
- Update
  patches.suse/powerpc-qspinlock-Fix-deadlock-in-MCS-queue.patch
  (bac#1230295 ltc#206656 CVE-2024-46797 bsc#1230831).
- Update
  patches.suse/powerpc-rtas-Prevent-Spectre-v1-gadget-construction-.patch
  (bsc#1227487 CVE-2024-46774 bsc#1230767).
- Update
  patches.suse/s390-dasd-fix-error-recovery-leading-to-data-corruption-on-ESE-devices.patch
  (git-fixes bsc#1229452 CVE-2024-45026 bsc#1230454).
- Update
  patches.suse/s390-sclp-Prevent-release-of-buffer-in-I-O.patch
  (git-fixes bsc#1229169 CVE-2024-44969 bsc#1230200).
- Update
  patches.suse/soc-qcom-cmd-db-Map-shared-memory-as-WC-not-WB.patch
  (git-fixes CVE-2024-46689 bsc#1230524).
- Update
  patches.suse/thunderbolt-Mark-XDomain-as-unplugged-when-router-is.patch
  (stable-fixes CVE-2024-46702 bsc#1230589).
- Update
  patches.suse/tty-serial-fsl_lpuart-mark-last-busy-before-uart_add.patch
  (git-fixes CVE-2024-46706 bsc#1230580).
- Update
  patches.suse/usb-dwc3-core-Prevent-USB-core-invalid-event-buffer-.patch
  (stable-fixes CVE-2024-46675 bsc#1230533).
- Update
  patches.suse/usb-dwc3-st-fix-probed-platform-device-ref-count-on-.patch
  (git-fixes CVE-2024-46674 bsc#1230507).
- Update
  patches.suse/usb-gadget-core-Check-for-unset-descriptor.patch
  (git-fixes CVE-2024-44960 bsc#1230191).
- Update
  patches.suse/usb-typec-ucsi-Fix-null-pointer-dereference-in-trace.patch
  (stable-fixes CVE-2024-46719 bsc#1230722).
- Update
  patches.suse/wifi-brcmfmac-cfg80211-Handle-SSID-based-pmksa-delet.patch
  (git-fixes CVE-2024-46672 bsc#1230459).
- Update
  patches.suse/wifi-mwifiex-Do-not-return-unused-priv-in-mwifiex_ge.patch
  (stable-fixes CVE-2024-46755 bsc#1230802).
- Update
  patches.suse/wifi-rtw88-usb-schedule-rx-work-after-everything-is-.patch
  (stable-fixes CVE-2024-46760 bsc#1230753).
- Update
  patches.suse/x86-mm-Fix-pti_clone_pgtable-alignment-assumption.patch
  (git-fixes CVE-2024-44965 bsc#1230221).
- Update
  patches.suse/x86-mtrr-Check-if-fixed-MTRRs-exist-before-saving-them.patch
  (git-fixes CVE-2024-44948 bsc#1230174).
- Update
  patches.suse/xhci-Fix-Panther-point-NULL-pointer-deref-at-full-sp.patch
  (git-fixes CVE-2024-45006 bsc#1230247).
- commit 6da06c4
* Fri Sep 27 2024 glass.su@suse.com
- Update patches.suse/gfs2-Fix-NULL-pointer-dereference-in-gfs2_log_flush.patch (bsc#1230948)
- commit cc71a7c
* Thu Sep 26 2024 vbabka@suse.cz
- userfaultfd: fix checks for huge PMDs (CVE-2024-46787
  bsc#1230815).
- commit a236c90
* Thu Sep 26 2024 lhenriques@suse.de
- cachefiles: Fix non-taking of sb_writers around set/removexattr
  (bsc#1231008).
- commit 1b01b3e
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: remove pinctrl_gpio_request() (jsc#PED-10702).
- commit ff2404a
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: remove pinctrl_gpio_can_use_line() (jsc#PED-10702).
- commit 7918d0b
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: starfive: jh7100: use new pinctrl GPIO helpers
  (jsc#PED-10702).
- commit 0ccc078
* Thu Sep 26 2024 oneukum@suse.com
- gpio: cdev: use pinctrl_gpio_can_use_line_new() (jsc#PED-10702).
- commit 1b88aa5
* Thu Sep 26 2024 oneukum@suse.com
- gpio: cdev: open-code to_gpio_chardev_data() (jsc#PED-10702).
- commit 6b3af87
* Thu Sep 26 2024 oneukum@suse.com
- gpio: aspeed: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 4441498
* Thu Sep 26 2024 oneukum@suse.com
- gpio: em: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 134cfbd
* Thu Sep 26 2024 nmorey@suse.com
- RDMA/rtrs-clt: Reset cid to con_num - 1 to stay in bounds (git-fixes)
- commit a6683f0
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: nuvoton: npcm7xx: use new pinctrl GPIO helpers
  (jsc#PED-10702).
- commit 3daa651
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: renesas: rzg2l: Use devm_clk_get_enabled() helper
  (jsc#PED-10702).
- commit 4301336
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: stm32: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit c9b46df
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: bcm: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 3f31e9c
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: spear: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 05adea8
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: starfive: jh7110: use new pinctrl GPIO helpers
  (jsc#PED-10702).
- commit 4850715
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: starfive: jh7110: Add system pm ops to save and
  restore context (jsc#PED-10702).
- commit 31eec21
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: renesas: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit adfbb33
* Thu Sep 26 2024 oneukum@suse.com
- gpio: tegra: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 75680fc
* Thu Sep 26 2024 jslaby@suse.cz
- PCI: dwc: Expose dw_pcie_ep_exit() to module (git-fixes).
- Refresh
  patches.suse/PCI-dwc-endpoint-Introduce-.pre_init-and-.deinit.patch.
- commit 34c9950
* Thu Sep 26 2024 oneukum@suse.com
- gpio: rcar: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 71715fc
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: provide new GPIO-to-pinctrl glue helpers
  (jsc#PED-10702).
- commit c3fc58c
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: remove unneeded extern specifiers from consumer.h
  (jsc#PED-10702).
- commit ca7fbca
* Thu Sep 26 2024 jslaby@suse.cz
- PCI: xilinx-nwl: Clean up clock on probe failure/removal
  (git-fixes).
- PCI: xilinx-nwl: Fix off-by-one in INTx IRQ handler (git-fixes).
- PCI: qcom-ep: Enable controller resources like PHY only after
  refclk is available (git-fixes).
- PCI: kirin: Fix buffer overflow in kirin_pcie_parse_port()
  (git-fixes).
- PCI: keystone: Fix if-statement expression in ks_pcie_quirk()
  (git-fixes).
- PCI: imx6: Fix missing call to phy_power_off() in error handling
  (git-fixes).
- PCI: dra7xx: Fix error handling when IRQ request fails in probe
  (git-fixes).
- PCI: dra7xx: Fix threaded IRQ request for "dra7xx-pcie-main"
  IRQ (git-fixes).
- PCI: Wait for Link before restoring Downstream Buses
  (git-fixes).
- commit 1528eee
* Wed Sep 25 2024 dsterba@suse.com
- WIP DO NOT PUSH btrfs: fix a use-after-free when hitting errors inside btrfs_submit_chunk() (CVE-2024-46687 bsc#1230518)
- commit 17b4a47
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: generic: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 28e520e
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: provide gpio_device_get_base() (jsc#PED-10702).
- commit ba12b28
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: provide gpiod_to_gpio_device() (jsc#PED-10702).
- commit 4315666
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: provide gpio_device_to_device() (jsc#PED-10702).
- commit ce5fe76
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: provide gpio_device_find_by_fwnode() (jsc#PED-10702).
- commit 6fb73ed
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: replace find_chip_by_name() with
  gpio_device_find_by_label() (jsc#PED-10702).
- commit b6fb644
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: reluctantly provide gpio_device_get_chip()
  (jsc#PED-10702).
- commit d57e161
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: provide gpio_device_get_desc() (jsc#PED-10702).
- Refresh
  patches.suse/gpio-prevent-potential-speculation-leaks-in-gpio_dev.patch.
- commit 741b92b
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: make gpiochip_get_desc() public (jsc#PED-10702).
- commit 35e1b77
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: extend the critical sections of lookup tables
  (jsc#PED-10702).
- commit 8d2f2d0
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: unexport gpiod_set_transitory() (jsc#PED-10702).
- commit 72adbe3
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: provide and use gpiod_line_state_notify()
  (jsc#PED-10702).
- commit d536b6a
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: add a second blocking notifier to struct gpio_device
  (jsc#PED-10702).
- commit 6f4079d
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: rename the gpio_device notifier (jsc#PED-10702).
- Refresh
  patches.suse/gpiolib-cdev-fix-use-after-free-in-lineinfo_changed_notify.patch.
- commit 6e12643
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: Replace open coded
  gpiochip_irqchip_add_allocated_domain() (jsc#PED-10702).
- commit 142fd0e
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: Split out gpiochip_irqchip_add_allocated_domain()
  helper (jsc#PED-10702).
- commit 68fd22e
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: Do not assign error pointer to the GPIO IRQ chip domain
  (jsc#PED-10702).
- commit aa812c2
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: Factor out gpiochip_simple_create_domain()
  (jsc#PED-10702).
- commit 400479d
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: Make gpiochip_hierarchy_add_domain() return domain
  (jsc#PED-10702).
- commit 11e0548
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: Do not alter GPIO chip fwnode member (jsc#PED-10702).
- commit 086cbe7
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: Do not unexport GPIO on freeing (jsc#PED-10702).
- commit 5249893
* Wed Sep 25 2024 ailiop@suse.com
- exfat: fix memory leak in exfat_load_bitmap() (git-fixes).
- commit 9f477b0
* Wed Sep 25 2024 sjaeckel@suse.de
- net: ip_tunnel: prevent perpetual headroom growth
  (CVE-2024-26804 bsc#1222629).
- commit 0ca3b23
* Wed Sep 25 2024 oneukum@suse.com
- Input: ps2-gpio - use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- commit 45cee3b
* Wed Sep 25 2024 oneukum@suse.com
- blacklist.conf: too risky
- commit f0e13c3
* Wed Sep 25 2024 oneukum@suse.com
- Input: ilitek_ts_i2c - avoid wrong input subsystem sync
  (git-fixes).
- commit e5e587b
* Wed Sep 25 2024 oneukum@suse.com
- Input: tsc2004/5 - fix reset handling on probe (git-fixes).
- commit 1366de4
* Wed Sep 25 2024 oneukum@suse.com
- Input: tsc2004/5 - do not hard code interrupt trigger
  (git-fixes).
- commit 110dbdb
* Wed Sep 25 2024 oneukum@suse.com
- Input: tsc2004/5 - use device core to create driver-specific
  device attributes (git-fixes).
- commit 958966c
* Wed Sep 25 2024 oneukum@suse.com
- Input: adp5588-keys - fix check on return code (git-fixes).
- commit d15133c
* Wed Sep 25 2024 tzimmermann@suse.com
- drm/amd/display: Fix incorrect size calculation for loop (bsc#1230704 CVE-2024-46729)
- commit 55d78a7
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix ah error counter in sw stat not increasing (git-fixes)
- commit d7bebcf
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/mlx5: Fix MR cache temp entries cleanup (git-fixes)
- commit b0aa848
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/mlx5: Drop redundant work canceling from clean_keys() (git-fixes)
- commit 6800d7e
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/irdma: fix error message in irdma_modify_qp_roce() (git-fixes)
- commit dcf63e1
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/cxgb4: Added NULL check for lookup_atid (git-fixes)
- commit 23d3195
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/mlx5: Obtain upper net device only when needed (git-fixes)
- commit ca2d8dc
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix restricted __le16 degrades to integer issue (git-fixes)
- commit 4481358
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Optimize hem allocation performance (git-fixes)
- commit 7afe440
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix 1bit-ECC recovery address in non-4K OS (git-fixes)
- commit 25e36c2
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix VF triggering PF reset in abnormal interrupt handler (git-fixes)
- commit a18704a
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix spin_unlock_irqrestore() called with IRQs enabled (git-fixes)
- commit 7b15e64
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix the overflow risk of hem_list_calc_ba_range() (git-fixes)
- commit 60eb35c
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix Use-After-Free of rsv_qp on HIP08 (git-fixes)
- commit 3ab1ca2
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Don't modify rq next block addr in HIP09 QPC (git-fixes)
- commit 7100eb8
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/mlx5: Limit usage of over-sized mkeys from the MR cache (git-fixes)
- commit 914ed66
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/mlx5: Fix counter update on MR cache mkey creation (git-fixes)
- commit 60e75bb
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/erdma: Return QP state in erdma_query_qp (git-fixes)
- commit 09a59c3
* Wed Sep 25 2024 nmorey@suse.com
- IB/core: Fix ib_cache_setup_one error flow cleanup (git-fixes)
- commit 38bf526
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/rtrs: Reset hb_missed_cnt after receiving other traffic from peer (git-fixes)
- commit c4f28a8
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/iwcm: Fix WARNING:at_kernel/workqueue.c:#check_flush_dependency (git-fixes)
- commit 0456b72
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/core: Remove unused declaration rdma_resolve_ip_route() (git-fixes)
- commit 4cb7201
* Wed Sep 25 2024 jslaby@suse.cz
- blacklist.conf: add one for clang and one PCI git-fixes
- commit b26aea4
* Wed Sep 25 2024 jslaby@suse.cz
- Revert "PCI: Extend ACS configurability (bsc#1228090)." (bsc#1229019)
  This reverts commit 571e4310e81312c847a5caee7e45e66aeea2a169. It breaks
  ACS on certain platforms. Even 6.11 is affected. So drop for now and
  investigate.
- commit 3b92a44
* Tue Sep 24 2024 dsterba@suse.com
- blacklist.conf: CVE-2024-44972 bsc#1230212: not applicable
  Subpage code exists but zoned mode is not enabled being hidden behind
  CONFIG_BTRFS_DEBUG.
- commit ed17920
* Tue Sep 24 2024 dsterba@suse.com
- btrfs: handle errors from btrfs_dec_ref() properly (CVE-2024-46753 bsc#1230796)
- commit 3e3b2cb
* Tue Sep 24 2024 oneukum@suse.com
- net: pse-pd: Use EOPNOTSUPP error code instead of ENOTSUPP
  (git-fixes).
- blacklist.conf: kABI not yet an issue in SP7
- commit c18dd33
* Tue Sep 24 2024 oneukum@suse.com
- blacklist.conf: kABI
- commit 05421bb
* Tue Sep 24 2024 oneukum@suse.com
- media: vicodec: allow en/decoder cmd w/o CAPTURE (git-fixes).
- commit 62ef4d1
* Tue Sep 24 2024 oneukum@suse.com
- media: qcom: camss: Remove use_count guard in stop_streaming
  (git-fixes).
- commit ef85228
* Tue Sep 24 2024 oneukum@suse.com
- Revert "media: tuners: fix error return code of
  hybrid_tuner_request_state()" (git-fixes).
- drivers: media: dvb-frontends/rtl2830: fix an out-of-bounds
  write error (git-fixes).
- drivers: media: dvb-frontends/rtl2832: fix an out-of-bounds
  write error (git-fixes).
- commit 48dc3a9
* Tue Sep 24 2024 sjaeckel@suse.de
- net: bridge: xmit: make sure we have at least eth header len
  bytes (CVE-2024-38538 bsc#1226606).
- commit 2548071
* Tue Sep 24 2024 jlee@suse.com
- PKCS#7: Check codeSigning EKU of certificates in PKCS#7
  (bsc#1226666).
- commit dbae63e
* Mon Sep 23 2024 jgross@suse.com
- xen/swiotlb: fix allocated size (git-fixes).
- commit 199871d
* Mon Sep 23 2024 jgross@suse.com
- xen/swiotlb: add alignment check for dma buffers (bsc#1229928).
- commit 0ffbc04
* Mon Sep 23 2024 jgross@suse.com
- xen: tolerate ACPI NVS memory overlapping with Xen allocated
  memory (bsc#1226003).
- commit 3dc14d8
* Mon Sep 23 2024 jgross@suse.com
- xen: allow mapping ACPI data using a different physical address
  (bsc#1226003).
- commit 0928eec
* Mon Sep 23 2024 dsterba@suse.com
- x86/tdx: Fix data leak in mmio_read() (CVE-2024-46794 bsc#1230825)
- commit 9a2a1c2
* Mon Sep 23 2024 dsterba@suse.com
- tcp_bpf: fix return value of tcp_bpf_sendmsg() (CVE-2024-46783 bsc#1230810)
- commit eb9d143
* Mon Sep 23 2024 dwagner@suse.de
- nvme: fix namespace removal list (git-fixes).
- commit b45d192
* Mon Sep 23 2024 dsterba@suse.com
- ublk_drv: fix NULL pointer dereference in ublk_ctrl_start_recovery() (CVE-2024-46735 bsc#1230727)
- commit 23e039f
* Mon Sep 23 2024 dsterba@suse.com
- Update references for patches.suse/nvmet-tcp-fix-kernel-crash-if-commands-allocation-fa.patch (CVE-2024-46737 bsc#1230730)
- commit 8ce7f58
* Mon Sep 23 2024 jgross@suse.com
- xen: add capability to remap non-RAM pages to different PFNs
  (bsc#1226003).
- commit 47109fd
* Mon Sep 23 2024 dwagner@suse.de
- nvme: fix error-handling for io_uring nvme-passthrough
  (git-fixes).
  Refresh:
  - patches.suse/nvme-use-bio_integrity_map_user.patch
- commit ff79e52
* Mon Sep 23 2024 dsterba@suse.com
- net/mlx5e: SHAMPO, Fix incorrect page release (CVE-2024-46717 bsc#1230719)
- commit d6a30a9
* Mon Sep 23 2024 jgross@suse.com
- xen: move max_pfn in xen_memory_setup() out of function scope
  (bsc#1226003).
- commit 2750357
* Mon Sep 23 2024 jgross@suse.com
- xen: move checks for e820 conflicts further up (bsc#1226003).
- commit 191a602
* Mon Sep 23 2024 jgross@suse.com
- xen: introduce generic helper checking for memory map conflicts
  (bsc#1226003).
- commit eb57cec
* Mon Sep 23 2024 jgross@suse.com
- xen: use correct end address of kernel for conflict checking
  (bsc#1226003).
- commit c40fc6b
* Mon Sep 23 2024 dwagner@suse.de
- scsi: lpfc: Copyright updates for 14.4.0.4 patches (bsc#1229429
  jsc#PED-9899).
- scsi: lpfc: Update lpfc version to 14.4.0.4 (bsc#1229429
  jsc#PED-9899).
- scsi: lpfc: Update PRLO handling in direct attached topology
  (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Fix unsolicited FLOGI kref imbalance when in direct
  attached topology (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Fix unintentional double clearing of vmid_flag
  (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Validate hdwq pointers before dereferencing in
  reset/errata paths (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Remove redundant vport assignment when building
  an abort request (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Change diagnostic log flag during receipt of
  unknown ELS cmds (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Fix overflow build issue (bsc#1229429 jsc#PED-9899).
- commit 18ec475
* Mon Sep 23 2024 tzimmermann@suse.com
- drm/vmwgfx: Prevent unmapping active read buffers (bsc#1230540 CVE-2024-46710)
- commit 84f019d
* Mon Sep 23 2024 dwagner@suse.de
- nvme-tcp: fix link failure for TCP auth (git-fixes).
- nvmet: Identify-Active Namespace ID List command should reject
  invalid nsid (git-fixes).
- nvme-pci: Add sleep quirk for Samsung 990 Evo (git-fixes).
- nvme-pci: allocate tagset on reset if necessary (git-fixes).
- nvmet-tcp: fix kernel crash if commands allocation fails
  (git-fixes).
- nvme/pci: Add APST quirk for Lenovo N60z laptop (git-fixes).
- nvme: use srcu for iterating namespace list (git-fixes).
  Refresh:
  - patches.suse/nvme-tcp-sanitize-tls-key-handling.patch
- nvmet-rdma: fix possible bad dereference when freeing rsps
  (git-fixes).
- nvmet-tcp: do not continue for invalid icreq (git-fixes).
- nvme: clear caller pointer on identify failure (git-fixes).
- nvmet-trace: avoid dereferencing pointer too early (git-fixes).
- commit 7382ad4
* Mon Sep 23 2024 jslaby@suse.cz
- Update
  patches.suse/KVM-arm64-vgic-v2-Check-for-non-NULL-vCPU-in-vgic_v2.patch
  (git-fixes CVE-2024-36953 bsc#1225812).
- Update
  patches.suse/vfio-pci-fix-potential-memory-leak-in-vfio_intx_enab.patch
  (git-fixes CVE-2024-38632 bsc#1226860).
  Add CVE references.
- commit c9c3b6f
* Mon Sep 23 2024 jslaby@suse.cz
- Update
  patches.suse/ALSA-scarlett2-Add-missing-mutex-lock-around-get-met.patch
  (jsc#PED-9993 jsc#PED-10202 CVE-2023-52689 bsc#1224684).
- Update
  patches.suse/ASoC-mediatek-mt8195-Add-platform-entry-for-ETDM1_OU.patch
  (jsc#PED-9993 jsc#PED-10202 CVE-2024-42088 bsc#1228451).
- Update
  patches.suse/Bluetooth-L2CAP-Fix-div-by-zero-in-l2cap_le_flowctl_.patch
  (jsc#PED-10412 CVE-2024-36968 bsc#1226130).
- Update patches.suse/Bluetooth-btusb-Fix-memory-leak.patch
  (jsc#PED-10412 CVE-2024-26887 bsc#1223123).
- Update
  patches.suse/Bluetooth-btusb-mediatek-Fix-double-free-of-skb-in-c.patch
  (jsc#PED-10412 CVE-2024-35856 bsc#1224695).
- Update patches.suse/Bluetooth-msft-Fix-memory-leak.patch
  (jsc#PED-10412 CVE-2024-26888 bsc#1223124).
- Update
  patches.suse/Bluetooth-qca-fix-info-leak-when-fetching-board-id.patch
  (jsc#PED-10412 CVE-2024-36033 bsc#1225721).
- Update
  patches.suse/clk-bcm-dvp-Assign-num-before-accessing-hws.patch
  (git-fixes CVE-2024-39462 bsc#1227094).
- Update
  patches.suse/clk-bcm-rpi-Assign-num-before-accessing-hws.patch
  (git-fixes CVE-2024-39461 bsc#1227093).
  Add CVE references.
- commit f5acd18
* Sun Sep 22 2024 ailiop@suse.com
- nilfs2: fix potential oob read in nilfs_btree_check_delete()
  (git-fixes).
- commit cc0f59d
* Sun Sep 22 2024 ailiop@suse.com
- nilfs2: determine empty node blocks as corrupted (git-fixes).
- commit 3244e52
* Sun Sep 22 2024 ailiop@suse.com
- nilfs2: fix potential null-ptr-deref in nilfs_btree_insert()
  (git-fixes).
- commit 90f4e49
* Fri Sep 20 2024 dsterba@suse.com
- media: mtk-vcodec: potential null pointer deference in SCP (CVE-2024-40973 bsc#1227890)
- commit ce5074d
* Fri Sep 20 2024 fdmanana@suse.com
- btrfs: don't BUG_ON() when 0 reference count at
  btrfs_lookup_extent_info() (bsc#1230786 CVE-2024-46751).
- btrfs: reduce nesting for extent processing at
  btrfs_lookup_extent_info() (bsc#1230794 CVE-2024-46752).
- btrfs: remove superfluous metadata check at
  btrfs_lookup_extent_info() (bsc#1230794 CVE-2024-46752).
- btrfs: replace BUG_ON() with error handling at
  update_ref_for_cow() (bsc#1230794 CVE-2024-46752).
- btrfs: simplify setting the full backref flag at
  update_ref_for_cow() (bsc#1230794 CVE-2024-46752).
- btrfs: remove NULL transaction support for
  btrfs_lookup_extent_info() (bsc#1230794 CVE-2024-46752).
- btrfs: remove level argument from btrfs_set_block_flags
  (bsc#1230794 CVE-2024-46752).
- commit a1c1176
* Fri Sep 20 2024 msuchanek@suse.de
- powerpc/pseries/dlpar: Add device tree nodes for DLPAR IO add
  (jsc#PED-10566 jsc#PED-9919).
- powerpc/pseries/dlpar: Remove device tree node for DLPAR IO
  remove (jsc#PED-10566 jsc#PED-9919).
- powerpc/pseries: Use correct data types from pseries_hp_errorlog
  struct (jsc#PED-10566 jsc#PED-9919).
- commit d53773b
* Fri Sep 20 2024 fdmanana@suse.com
- btrfs: send: allow cloning non-aligned extent if it ends at
  i_size (bsc#1230854).
- commit e9cad4b
* Fri Sep 20 2024 oneukum@suse.com
- blacklist.conf: kABI
- commit 5244a06
* Fri Sep 20 2024 ailiop@suse.com
- ocfs2: cancel dqi_sync_work before freeing oinfo (git-fixes).
- commit 1f37ac4
* Fri Sep 20 2024 ailiop@suse.com
- ocfs2: fix possible null-ptr-deref in ocfs2_set_buffer_uptodate
  (git-fixes).
- commit b7bf7eb
* Fri Sep 20 2024 ailiop@suse.com
- ocfs2: remove unreasonable unlock in ocfs2_read_blocks
  (git-fixes).
- commit e2cb129
* Fri Sep 20 2024 ailiop@suse.com
- ocfs2: fix null-ptr-deref when journal load failed (git-fixes).
- commit b463b02
* Fri Sep 20 2024 ailiop@suse.com
- jfs: fix out-of-bounds in dbNextAG() and diAlloc() (git-fixes).
- commit d948d87
* Fri Sep 20 2024 tiwai@suse.de
- of/irq: Prevent device address out-of-bounds read in interrupt
  map walk (CVE-2024-46743 bsc#1230756).
- commit 300f40a
* Fri Sep 20 2024 tiwai@suse.de
- i2c: qcom-geni: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- i2c: isch: Add missed 'else' (git-fixes).
- i2c: xiic: Wait for TX empty to avoid missed TX NAKs
  (git-fixes).
- i2c: aspeed: Update the stop sw state when the bus recovery
  occurs (git-fixes).
- resource: fix region_intersects() vs add_memory_driver_managed()
  (git-fixes).
- drivers:drm:exynos_drm_gsc:Fix wrong assignment in gsc_bind()
  (git-fixes).
- drm/msm: fix %%s null argument error (git-fixes).
- drm/msm/dsi: correct programming sequence for SM8350 / SM8450
  (git-fixes).
- drm/msm/a5xx: workaround early ring-buffer emptiness check
  (git-fixes).
- drm/msm/a5xx: fix races in preemption evaluation stage
  (git-fixes).
- drm/msm/a5xx: properly clear preemption records on resume
  (git-fixes).
- drm/msm/a5xx: disable preemption in submits by default
  (git-fixes).
- drm/msm: Fix incorrect file name output in adreno_request_fw()
  (git-fixes).
- drm/mediatek: ovl_adaptor: Add missing of_node_put()
  (git-fixes).
- drm: omapdrm: Add missing check for alloc_ordered_workqueue
  (git-fixes).
- drm/radeon/evergreen_cs: fix int overflow errors in cs track
  offsets (git-fixes).
- drm/amd/amdgpu: Properly tune the size of struct (git-fixes).
- drm/radeon: properly handle vbios fake edid sizing (git-fixes).
- drm/amdgpu: properly handle vbios fake edid sizing (git-fixes).
- drm/amd/display: Add null check for set_output_gamma in
  dcn30_set_output_transfer_func (git-fixes).
- drm/amdgpu: fix a possible null pointer dereference (git-fixes).
- drm/radeon: fix null pointer dereference in
  radeon_add_common_modes (git-fixes).
- drm/vc4: hdmi: Handle error case of pm_runtime_resume_and_get
  (git-fixes).
- drm/bridge: lontium-lt8912b: Validate mode in
  drm_bridge_funcs::mode_valid() (git-fixes).
- drm/rockchip: dw_hdmi: Fix reading EDID when using a forced mode
  (git-fixes).
- drm/rockchip: vop: Allow 4096px width scaling (git-fixes).
- drm/rockchip: vop: enable VOP_FEATURE_INTERNAL_RGB on RK3066
  (git-fixes).
- drm/rockchip: vop: clear DMA stop bit on RK3066 (git-fixes).
- drm/stm: ltdc: check memory returned by devm_kzalloc()
  (git-fixes).
- drm/stm: Fix an error handling path in stm_drm_platform_probe()
  (git-fixes).
- ata: libata: Clear DID_TIME_OUT for ATA PT commands with sense
  data (git-fixes).
- HID: wacom: Do not warn about dropped packets for first packet
  (git-fixes).
- HID: wacom: Support sequence numbers smaller than 16-bit
  (git-fixes).
- tpm: Clean up TPM space after command failure (git-fixes).
- ipmi: docs: don't advertise deprecated sysfs entries
  (git-fixes).
- commit b4e4911
* Fri Sep 20 2024 tonyj@suse.de
- blacklist.conf: temp blacklist commit to allow merge to checkin w/out git-fixes error
- commit 3a3266a
* Thu Sep 19 2024 dsterba@suse.com
- smb/client: avoid dereferencing rdata=NULL in smb2_new_read_req() (CVE-2024-46686 bsc#1230517)
- commit a155846
* Thu Sep 19 2024 dsterba@suse.com
- firmware: qcom: scm: Mark get_wq_ctx() as atomic call (CVE-2024-46692 bsc#1230520)
- commit ee65da0
* Thu Sep 19 2024 dsterba@suse.com
- scsi: aacraid: Fix double-free on probe failure (CVE-2024-46673 bsc#1230506)
- commit 49aab2b
* Thu Sep 19 2024 dsterba@suse.com
- gtp: fix a potential NULL pointer dereference (CVE-2024-46677 bsc#1230549)
- commit 9cdd14b
* Thu Sep 19 2024 dsterba@suse.com
- blacklist.conf: CVE-2024-46711 bsc#1230542: code partially present, fix part of refactoring and fix series
  The patch to backport is one in a number of about 30 patches refactoring
  and reworking MPTCP subflow handling. Several other patches are needed
  just to apply it cleanly but also change some of the logic where the
  actual fix would apply.
- commit 1a03613
* Thu Sep 19 2024 dsterba@suse.com
- ethtool: check device is present when getting link settings (CVE-2024-46679 bsc#1230556)
- commit 68643d1
* Thu Sep 19 2024 colyli@suse.de
- md/raid5: avoid BUG_ON() while continue reshape after
  reassembling (bsc#1229790, CVE-2024-43914).
- commit bfb799a
* Thu Sep 19 2024 oneukum@suse.com
- gpiolib: demote the hogging log messages to debug
  (jsc#PED-10702).
- commit 485f7f1
* Thu Sep 19 2024 oneukum@suse.com
- gpiolib: Unify allocation and initialization of GPIO valid mask
  (jsc#PED-10702).
- commit 4cf06e5
* Thu Sep 19 2024 oneukum@suse.com
- gpiolib: Consolidate the allocated mask freeing APIs
  (jsc#PED-10702).
- commit 14e44d5
* Thu Sep 19 2024 oneukum@suse.com
- gpiolib: provide gpio_device_find_by_label() (jsc#PED-10702).
- commit 6d0f598
* Thu Sep 19 2024 oneukum@suse.com
- gpiolib: add support for scope-based management to gpio_device
  (jsc#PED-10702).
- commit dcb8397
* Thu Sep 19 2024 oneukum@suse.com
- gpiolib: remove unnecessary extern specifiers from the driver
  header (jsc#PED-10702).
- Refresh
  patches.suse/gpiolib-make-gpio_device_get-and-gpio_device_put-pub.patch.
- Refresh patches.suse/gpiolib-provide-gpio_device_find.patch.
- commit 18fd820
* Thu Sep 19 2024 oneukum@suse.com
- gpiolib: remove stray newline in gpio/driver.h (jsc#PED-10702).
- commit 17cdd18
* Thu Sep 19 2024 oneukum@suse.com
- gpiolib: Drop unused domain_ops memeber of GPIO IRQ chip
  (jsc#PED-10702).
- commit 60c45ca
* Thu Sep 19 2024 ailiop@suse.com
- xfs: restrict when we try to align cow fork delalloc to cowextsz
  hints (git-fixes).
- commit 96ac1b7
* Thu Sep 19 2024 jdelvare@suse.de
- clk: Provide !COMMON_CLK dummy for devm_clk_rate_exclusive_get()
  (bsc#1227885).
- commit bf3362b
* Thu Sep 19 2024 colyli@suse.de
- Replace git-fixes tag by bsc#1226507,
  patches.suse/md-Don-t-wait-for-MD_RECOVERY_NEEDED-for-HOT_REMOVE_DISK-ioctl-a1fd.patch
  (bsc#1226507).
- commit b04e0cb
* Thu Sep 19 2024 colyli@suse.de
- closures: Change BUG_ON() to WARN_ON() (bsc#1229004,
  CVE-2024-42252).
- commit 84b7984
* Thu Sep 19 2024 jdelvare@suse.de
- clk: Add a devm variant of clk_rate_exclusive_get()
  (bsc#1227885).
- commit b6fb747
* Thu Sep 19 2024 oneukum@suse.com
- r8152: add vendor/device ID pair for D-Link DUB-E250
  (git-fixes).
- Refresh
  patches.suse/r8152-add-vendor-device-ID-pair-for-ASUS-USB-C2500.patch.
- commit 0c077ab
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: fix carrier detection in modes 1 and 4
  (git-fixes).
- commit 591cebb
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: do not stop RX on failing RX callback
  (git-fixes).
- commit c58c483
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: drop RX URBs with no payload (git-fixes).
- commit 73a78e2
* Thu Sep 19 2024 jgross@suse.com
- KVM: arm64: Disallow copying MTE to guest memory while KVM is
  dirty logging (git-fixes).
- commit 3cf4c02
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: remove extraneous rx URB length check
  (git-fixes).
- commit 507443a
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: add CDC NCM support (git-fixes).
- commit 1bf1d1e
* Thu Sep 19 2024 jgross@suse.com
- KVM: arm64: Release pfn, i.e. put page, if copying MTE tags
  hits ZONE_DEVICE (git-fixes).
- commit 64bccd6
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: transmit URBs without trailing padding
  (git-fixes).
- usbnet: ipheth: fix risk of NULL pointer deallocation
  (git-fixes).
- commit d804072
* Thu Sep 19 2024 jgross@suse.com
- KVM: arm64: Invalidate EL1&0 TLB entries for all VMIDs in nvhe
  hyp init (git-fixes).
- commit 30df9d2
* Thu Sep 19 2024 tiwai@suse.de
- drm/amd/display: Solve mst monitors blank out problem after
  resume (git-fixes).
- commit cd94b30
* Thu Sep 19 2024 jgross@suse.com
- virtio-net: synchronize probe with ndo_set_features (git-fixes).
- commit 1a471dd
* Thu Sep 19 2024 tiwai@suse.de
- fbdev: hpfb: Fix an error handling path in hpfb_dio_probe()
  (git-fixes).
- hwmon: (ntc_thermistor) fix module autoloading (git-fixes).
- hwmon: (max16065) Fix overflows seen when writing limits
  (git-fixes).
- mtd: powernv: Add check devm_kasprintf() returned value
  (git-fixes).
- mtd: slram: insert break after errors in parsing the map
  (git-fixes).
- power: supply: hwmon: Fix missing temp1_max_alarm attribute
  (git-fixes).
- power: supply: Drop use_cnt check from
  power_supply_property_is_writeable() (git-fixes).
- power: supply: max17042_battery: Fix SOC threshold calc w/
  no current sense (git-fixes).
- power: supply: axp20x_battery: Remove design from min and max
  voltage (git-fixes).
- pinctrl: meteorlake: Add Arrow Lake-H/U ACPI ID (stable-fixes).
- drm/amdgpu/atomfirmware: Silence UBSAN warning (stable-fixes).
- drm/amd/display: Avoid race between dcn10_set_drr() and
  dc_state_destruct() (git-fixes).
- Input: synaptics - enable SMBus for HP Elitebook 840 G2
  (stable-fixes).
- Input: ads7846 - ratelimit the spi_sync error message
  (stable-fixes).
- drm/msm/adreno: Fix error return if missing firmware-name
  (stable-fixes).
- scripts: kconfig: merge_config: config files: add a trailing
  newline (stable-fixes).
- platform/surface: aggregator_registry: Add support for Surface
  Laptop Go 3 (stable-fixes).
- platform/surface: aggregator_registry: Add Support for Surface
  Pro 10 (stable-fixes).
- HID: multitouch: Add support for GT7868Q (stable-fixes).
- drm/mediatek: Set sensible cursor width/height values to fix
  crash (stable-fixes).
- drm: panel-orientation-quirks: Add quirk for Ayn Loki Max
  (stable-fixes).
- drm: panel-orientation-quirks: Add quirk for Ayn Loki Zero
  (stable-fixes).
- wifi: mt76: mt7921: fix NULL pointer access in
  mt7921_ipv6_addr_change (stable-fixes).
- net: phy: vitesse: repair vsc73xx autonegotiation
  (stable-fixes).
- cxl/core: Fix incorrect vendor debug UUID define (git-fixes).
- drm/amd/display: Fix FEC_READY write on DP LT (stable-fixes).
- drm/amd/display: Defer handling mst up request in resume
  (stable-fixes).
- drm/amd/display: Disable error correction if it's not supported
  (stable-fixes).
- commit 040b0ea
* Wed Sep 18 2024 jdelvare@suse.de
- i2c: lpi2c: Avoid calling clk_get_rate during transfer
  (bsc#1227885 CVE-2024-40965).
- commit abb755c
* Wed Sep 18 2024 oneukum@suse.com
- i2c: viai2c: turn common code into a proper module
  (jsc#PED-10702).
- commit 2525cea
* Wed Sep 18 2024 oneukum@suse.com
- i2c: Drop explicit initialization of struct
  i2c_device_id::driver_data to 0 (jsc#PED-10702).
- commit 5e7368b
* Wed Sep 18 2024 oneukum@suse.com
- i2c: add zhaoxin i2c controller driver (jsc#PED-10702).
- Update config files.
- commit d9e10dd
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: add platform type VIAI2C_PLAT_WMT (jsc#PED-10702).
- commit 843b44e
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: fix a bug when thread blocked (jsc#PED-10702).
- commit b5caac9
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: rename something (jsc#PED-10702).
- commit da8d7e1
* Wed Sep 18 2024 mhocko@suse.com
- x86/mm/ident_map: Use gbpages only where full GB page should
  be mapped (bsc#1220382).
- x86/kexec: Add EFI config table identity mapping for kexec
  kernel (bsc#1220382).
- commit 26eab5b
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: split out common files (jsc#PED-10702).
- commit ab5ccfd
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: create wmt_i2c_init for general init (jsc#PED-10702).
- commit 5b953d9
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: Reduce redundant: REG_CR setting (jsc#PED-10702).
- commit a6c2c70
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: Reduce redundant: function parameter (jsc#PED-10702).
- commit 87e02ca
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: Reduce redundant: clock mode setting (jsc#PED-10702).
- commit d15699a
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: Reduce redundant: wait event complete (jsc#PED-10702).
- commit 5c1072c
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: Reduce redundant: bus busy check (jsc#PED-10702).
- commit b2876cf
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: Use devm_platform_get_and_ioremap_resource()
  (jsc#PED-10702).
- commit 7ba3be9
* Wed Sep 18 2024 oneukum@suse.com
- i2c: sprd: Convert to platform remove callback returning void
  (jsc#PED-10702).
- commit 63b19e9
* Wed Sep 18 2024 oneukum@suse.com
- i2c: smbus: Prepare i2c_register_spd for usage on muxed segments
  (jsc#PED-10702).
- commit 316ba78
* Wed Sep 18 2024 oneukum@suse.com
- i2c: constify the struct device_type usage (jsc#PED-10702).
- commit 50d3674
* Wed Sep 18 2024 oneukum@suse.com
- i2c: Remove redundant comparison in npcm_i2c_reg_slave
  (jsc#PED-10702).
- commit 12000a2
* Wed Sep 18 2024 oneukum@suse.com
- i2c: npcm7xx: move to per-adapter debugfs directory
  (jsc#PED-10702).
- commit 27840f8
* Wed Sep 18 2024 oneukum@suse.com
- i2c: gpio: move to per-adapter debugfs directory
  (jsc#PED-10702).
- commit d2bd050
* Wed Sep 18 2024 oneukum@suse.com
- i2c: gpio: remove error checks with debugfs (jsc#PED-10702).
- commit 5663caa
* Wed Sep 18 2024 oneukum@suse.com
- i2c: create debugfs entry per adapter (jsc#PED-10702).
- commit f86c829
* Wed Sep 18 2024 oneukum@suse.com
- i2c: core: fix lockdep warning for sparsely nested adapter chain
  (jsc#PED-10702).
- commit cca2d59
* Wed Sep 18 2024 oneukum@suse.com
- i2c: Add support for Intel LJCA USB I2C driver (jsc#PED-10702).
- commit 992beec
* Wed Sep 18 2024 oneukum@suse.com
- i2c: Annotate struct i2c_atr with __counted_by (jsc#PED-10702).
- commit 51b2022
* Wed Sep 18 2024 tiwai@suse.de
- Move upstreamed nvme patches into sorted section
- commit 1e42d2f
* Wed Sep 18 2024 tiwai@suse.de
- ASoC: tas2781-i2c: Drop weird GPIO code (git-fixes).
- ASoC: tas2781: Fix a compiling warning reported by robot kernel
  test due to adding tas2563_dvc_table (git-fixes).
- commit 3498c94
* Wed Sep 18 2024 tiwai@suse.de
- spi: ppc4xx: Avoid returning 0 when failed to parse and map IRQ
  (git-fixes).
- commit 1cec71a
* Wed Sep 18 2024 tiwai@suse.de
- ASoC: meson: Remove unused declartion in header file
  (git-fixes).
- ASoC: soc-ac97: Fix the incorrect description (git-fixes).
- ASoC: rt5682: Return devm_of_clk_add_hw_provider to transfer
  the error (git-fixes).
- ASoC: tas2781-i2c: Get the right GPIO line (git-fixes).
- ASoC: cs42l42: Convert comma to semicolon (git-fixes).
- ASoC: rt5682s: Return devm_of_clk_add_hw_provider to transfer
  the error (git-fixes).
- ALSA: hda: cs35l41: fix module autoloading (git-fixes).
- selftests: lib: remove strscpy test (git-fixes).
- scripts: sphinx-pre-install: remove unnecessary double check
  for $cur_version (git-fixes).
- Documentation: ioctl: document 0x07 ioctl code (git-fixes).
- module: Fix KCOV-ignored file name (git-fixes).
- reset: k210: fix OF node leak in probe() error path (git-fixes).
- reset: berlin: fix OF node leak in probe() error path
  (git-fixes).
- bus: integrator-lm: fix OF node leak in probe() (git-fixes).
- soc: fsl: cpm1: tsa: Fix tsa_write8() (git-fixes).
- firmware: tegra: bpmp: Drop unused mbox_client_to_bpmp()
  (git-fixes).
- firmware: arm_scmi: Fix double free in OPTEE transport
  (git-fixes).
- soc: versatile: integrator: fix OF node leak in probe() error
  path (git-fixes).
- memory: mtk-smi: Use devm_clk_get_enabled() (git-fixes).
- memory: tegra186-emc: drop unused to_tegra186_emc() (git-fixes).
- spi: bcm63xx: Fix module autoloading (git-fixes).
- spi: rpc-if: Add missing MODULE_DEVICE_TABLE (git-fixes).
- spi: meson-spicc: convert comma to semicolon (git-fixes).
- spi: ppc4xx: handle irq_of_parse_and_map() errors (git-fixes).
- regulator: core: Fix regulator_is_supported_voltage() kerneldoc
  return value (git-fixes).
- regulator: core: Fix short description for
  _regulator_check_status_enabled() (git-fixes).
- regulator: Return actual error in of_regulator_bulk_get_all()
  (git-fixes).
- regulator: rt5120: Convert comma to semicolon (git-fixes).
- regulator: wm831x-isink: Convert comma to semicolon (git-fixes).
- clocksource/drivers/qcom: Add missing iounmap() on errors in
  msm_dt_timer_init() (git-fixes).
- commit 994b020
* Tue Sep 17 2024 oneukum@suse.com
- i2c: dev: make i2c_dev_class a static const structure
  (jsc#PED-10702).
- commit b52ab37
* Tue Sep 17 2024 oneukum@suse.com
- i2c: tiny-usb: check usb base class before assuming the
  interface on device is for this driver (jsc#PED-10702).
- commit 2db0283
* Tue Sep 17 2024 oneukum@suse.com
- media: i2c: add I2C Address Translator (ATR) support
  (jsc#PED-10702).
- commit 7a422ed
* Tue Sep 17 2024 tiwai@suse.de
- wifi: mac80211_hwsim: drop owner assignment (bsc#1230505).
- wifi: mac80211_hwsim: add support for BSS color (bsc#1230505).
- wifi: mac80211_hwsim: Use wider regulatory for custom for 6GHz
  tests (bsc#1230505).
- wifi: mac80211_hwsim: Declare HE/EHT capabilities support for
  P2P interfaces (bsc#1230505).
- wifi: mac80211_hwsim: move skip_beacons to be per link
  (bsc#1230505).
- wifi: mac80211_hwsim: set link ID information during Rx
  (bsc#1230505).
- wifi: mac80211_hwsim: add support for switch_vif_chanctx
  callback (bsc#1230505).
- wifi: mac80211_hwsim: Add 160MHz bw range to regdom_custom_04
  (bsc#1230505).
- wifi: mac80211_hwsim: add missing kernel-doc (bsc#1230505).
- wifi: mac80211_hwsim: enable all links only in MLO
  (bsc#1230505).
- wifi: mac80211_hwsim: add control to skip beacons (bsc#1230505).
- wifi: mac80211_hwsim: advertise 15 simultaneous links
  (bsc#1230505).
- wifi: mac80211_hwsim: advertise AP-side EMLSR/EMLMR capa
  (bsc#1230505).
- wifi: mac80211_hwsim: Declare support for negotiated TTLM
  (bsc#1230505).
- wifi: mac80211_hwsim: handle BSS_CHANGED_MLD_TTLM (bsc#1230505).
- wifi: mac80211_hwsim: handle TID to link mapping neg request
  (bsc#1230505).
- wifi: mac80211_hwsim: Add custom reg for DFS concurrent
  (bsc#1230505).
- wifi: mac80211_hwsim: support HE 40 MHz in 2.4 GHz band
  (bsc#1230505).
- wifi: mac80211_hwsim: Handle BSS_CHANGED_VALID_LINKS
  (bsc#1230505).
- wifi: mac80211_hwsim: move kernel-doc description (bsc#1230505).
- wifi: mac80211_hwsim: clean up kernel-doc (bsc#1230505).
- Revert "wifi: mac80211_hwsim: check the return value of
  nla_put_u32" (bsc#1230505).
- wifi: mac80211_hwsim: avoid calling nlmsg_free() in IRQ or
  IRQ disabled (bsc#1230505).
- wifi: mac80211_hwsim: Don't access vif valid links directly
  (bsc#1230505).
- wifi: mac80211_hwsim: check the return value of nla_put_u32
  (bsc#1230505).
- wifi: mac80211_hwsim: avoid warning with MLO PS stations
  (bsc#1230505).
- commit 097ca80
* Tue Sep 17 2024 oneukum@suse.com
- Update
  patches.suse/thunderbolt-Fix-uninitialized-variable-in-tb_tunnel_.patch
  (jsc#PED-10361).
  fix malformed references tag
- commit 86b9590
* Tue Sep 17 2024 tiwai@suse.de
- cpufreq: ti-cpufreq: Introduce quirks to handle syscon fails
  appropriately (git-fixes).
- ACPI: CPPC: Fix MASK_VAL() usage (git-fixes).
- ACPI: PMIC: Remove unneeded check in
  tps68470_pmic_opregion_probe() (git-fixes).
- ACPI: sysfs: validate return type of _STR method (git-fixes).
- crypto: ccp - do not request interrupt on cmd completion when
  irqs disabled (git-fixes).
- hwrng: mtk - Use devm_pm_runtime_enable (git-fixes).
- crypto: ccp - Properly unregister /dev/sev on sev
  PLATFORM_STATUS failure (git-fixes).
- hwrng: cctrng - Add missing clk_disable_unprepare in
  cctrng_resume (git-fixes).
- hwrng: bcm2835 - Add missing clk_disable_unprepare in
  bcm2835_rng_init (git-fixes).
- crypto: iaa - Fix potential use after free bug (git-fixes).
- crypto: xor - fix template benchmarking (git-fixes).
- can: m_can: m_can_close(): stop clocks after device has been
  shut down (git-fixes).
- can: m_can: enable NAPI before enabling interrupts (git-fixes).
- can: bcm: Clear bo->bcm_proc_read after remove_proc_entry()
  (git-fixes).
- Bluetooth: btusb: Fix not handling ZPL/short-transfer
  (git-fixes).
- Bluetooth: hci_sync: Ignore errors from
  HCI_OP_REMOTE_NAME_REQ_CANCEL (git-fixes).
- Bluetooth: hci_core: Fix sending MGMT_EV_CONNECT_FAILED
  (git-fixes).
- wifi: mt76: mt7925: fix a potential array-index-out-of-bounds
  issue for clc (git-fixes).
- wifi: mt76: mt7615: check devm_kasprintf() returned value
  (git-fixes).
- wifi: mt76: mt7921: Check devm_kasprintf() returned value
  (git-fixes).
- wifi: mt76: mt7915: check devm_kasprintf() returned value
  (git-fixes).
- wifi: mt76: mt7996: fix uninitialized TLV data (git-fixes).
- wifi: mt76: mt7915: fix rx filter setting for bfee functionality
  (git-fixes).
- wifi: mt76: mt7603: fix mixed declarations and code (git-fixes).
- wifi: mt76: connac: fix checksum offload fields of connac3 RXD
  (git-fixes).
- wifi: mt76: mt7996: fix NULL pointer dereference in
  mt7996_mcu_sta_bfer_he (git-fixes).
- wifi: mt76: mt7996: fix EHT beamforming capability check
  (git-fixes).
- wifi: mt76: mt7996: fix HE and EHT beamforming capabilities
  (git-fixes).
- wifi: mt76: mt7996: fix wmm set of station interface to 3
  (git-fixes).
- wifi: mt76: mt7996: fix traffic delay when switching back to
  working channel (git-fixes).
- wifi: mt76: mt7996: use hweight16 to get correct tx antenna
  (git-fixes).
- wifi: mt76: mt7921: fix wrong UNII-4 freq range check for the
  channel usage (git-fixes).
- wifi: mt76: mt7915: fix oops on non-dbdc mt7986 (git-fixes).
- wifi: rtw88: remove CPT execution branch never used (git-fixes).
- wifi: wilc1000: fix potential RCU dereference issue in
  wilc_parse_join_bss_param (git-fixes).
- wifi: mac80211: use two-phase skb reclamation in
  ieee80211_do_stop() (git-fixes).
- wifi: cfg80211: fix two more possible UBSAN-detected off-by-one
  errors (git-fixes).
- wifi: cfg80211: fix UBSAN noise in cfg80211_wext_siwscan()
  (git-fixes).
- wifi: mac80211: fix the comeback long retry times (git-fixes).
- wifi: cfg80211: fix bug of mapping AF3x to incorrect User
  Priority (git-fixes).
- wifi: iwlwifi: mvm: increase the time between ranging
  measurements (git-fixes).
- wifi: mac80211: don't use rate mask for offchannel TX either
  (git-fixes).
- wifi: ath12k: fix invalid AMPDU factor calculation in
  ath12k_peer_assoc_h_he() (git-fixes).
- wifi: ath12k: match WMI BSS chan info structure with firmware
  definition (git-fixes).
- wifi: ath12k: fix BSS chan info request WMI command (git-fixes).
- wifi: ath9k: Remove error checks when creating debugfs entries
  (git-fixes).
- wifi: rtw88: always wait for both firmware loading attempts
  (git-fixes).
- wifi: rtw88: 8822c: Fix reported RX band width (git-fixes).
- wifi: brcmfmac: introducing fwil query functions (git-fixes).
- can: j1939: use correct function name in comment (git-fixes).
- commit ffce0ad
* Mon Sep 16 2024 jgross@suse.com
- net: tighten bad gso csum offset check in virtio_net_hdr
  (git-fixes).
- commit 6b94c45
* Mon Sep 16 2024 jgross@suse.com
- blacklist.conf: add 840b2d39a2dc ("virtio_ring: fix KMSAN error for premapped mode")
- commit 2b97440
* Mon Sep 16 2024 jgross@suse.com
- KVM: SVM: fix emulation of msr reads/writes of MSR_FS_BASE
  and MSR_GS_BASE (git-fixes).
- commit aeba695
* Mon Sep 16 2024 oneukum@suse.com
- thunderbolt: Fix kernel-doc for tb_tunnel_alloc_dp()
  (jsc#PED-10361).
- commit f42247a
* Mon Sep 16 2024 oneukum@suse.com
- thunderbolt: Fix uninitialized variable in
  tb_tunnel_alloc_usb3() (jsc#-PED10361).
- commit 6326f6a
* Mon Sep 16 2024 oneukum@suse.com
- thunderbolt: No need to loop over all retimers if access fails
  (jsc#PED-10361).
- commit 5f68f33
* Mon Sep 16 2024 oneukum@suse.com
- thunderbolt: Increase sideband access polling delay
  (jsc#PED-10361).
- commit fa4b1b4
* Mon Sep 16 2024 jgross@suse.com
- blacklist.conf: add 611ff1b1ae98 ("xen: privcmd: Fix possible access to a freed kirqfd instance")
- commit d91e53f
* Mon Sep 16 2024 oneukum@suse.com
- thunderbolt: Get rid of TB_CFG_PKG_PREPARE_TO_SLEEP
  (jsc#PED-10361).
- commit 24dfc42
* Mon Sep 16 2024 oneukum@suse.com
- thunderbolt: Use correct error code with ERROR_NOT_SUPPORTED
  (jsc#PED-10361).
- commit b232ba1
* Mon Sep 16 2024 oneukum@suse.com
- thunderbolt: Allow USB3 bandwidth to be lower than maximum
  supported (jsc#PED-10361).
- commit b924604
* Mon Sep 16 2024 lhenriques@suse.de
- fscache: delete fscache_cookie_lru_timer when fscache exits
  to avoid  UAF (bsc#1230602).
- commit d2c95a5
* Mon Sep 16 2024 sjaeckel@suse.de
- Update
  patches.suse/virtio_net-Fix-napi_skb_cache_put-warning.patch
  (git-fixes CVE-2024-43835 bsc#1229289).
- commit b9542fb
* Mon Sep 16 2024 ohering@suse.de
- x86/hyperv: fix kexec crash due to VP assist page corruption
  (git-fixes).
- Drivers: hv: vmbus: Fix the misplaced function description
  (git-fixes).
- commit c60d936
* Mon Sep 16 2024 ddiss@suse.de
- Update references
  patches.suse/selinux-smack-don-t-bypass-permissions-check-in-inod.patch
  (stable-fixes CVE-2024-46695 bsc#1230519).
- commit 2a7bb57
* Mon Sep 16 2024 neilb@suse.de
- NFSv4: Add missing rescheduling points in
  nfs_client_return_marked_delegations (git-fixes).
- commit a563f31
* Mon Sep 16 2024 neilb@suse.de
- nfsd: Don't leave work of closing files to a work queue
  (bsc#1228140).
- Refresh
  patches.suse/nfsd-use-__fput_sync-to-avoid-delayed-closing-of-fil.patch.
- commit 83ce74a
* Sun Sep 15 2024 tiwai@suse.de
- ASoC: meson: axg-card: fix 'use-after-free' (git-fixes).
- ASoC: codecs: avoid possible garbage value in peb2466_reg_read()
  (git-fixes).
- commit 5a67afd
* Sat Sep 14 2024 tiwai@suse.de
- kABI workaround for soc-qcom pmic_glink changes (CVE-2024-46693
  bsc#1230521).
- commit 9a06e25
* Sat Sep 14 2024 tiwai@suse.de
- usb: typec: ucsi: Move unregister out of atomic section
  (CVE-2024-46691 bsc#1230526).
- soc: qcom: pmic_glink: Fix race during initialization
  (CVE-2024-46693 bsc#1230521).
- commit 26dd9b4
* Sat Sep 14 2024 tiwai@suse.de
- spi: nxp-fspi: fix the KASAN report out-of-bounds bug
  (git-fixes).
- drm/syncobj: Fix syncobj leak in drm_syncobj_eventfd_ioctl
  (git-fixes).
- drm/nouveau/fb: restore init() for ramgp102 (git-fixes).
- dma-buf: heaps: Fix off-by-one in CMA heap fault handler
  (git-fixes).
- drm/i915/guc: prevent a possible int overflow in wq offsets
  (git-fixes).
- usbnet: ipheth: race between ipheth_close and error handling
  (stable-fixes).
- commit 8d8bf2f
* Sat Sep 14 2024 colyli@suse.de
- md/raid1: Fix data corruption for degraded array with slow disk
  (bsc#1230455, CVE-2024-45023).
- commit 34cd7b5
* Fri Sep 13 2024 tonyj@suse.de
- perf/x86/intel: Limit the period on Haswell (git-fixes).
- perf/x86: Fix smp_processor_id()-in-preemptible warnings
  (git-fixes).
- perf/x86/intel/cstate: Add pkg C2 residency counter for Sierra
  Forest (git-fixes).
- ARM: 9406/1: Fix callchain_trace() return value (git-fixes).
- bpf, events: Use prog to emit ksymbol event for main program
  (git-fixes).
- perf/x86/intel: Add a distinct name for Granite Rapids
  (git-fixes).
- perf/x86/intel/ds: Fix non 0 retire latency on Raptorlake
  (git-fixes).
- perf/x86/intel/uncore: Fix the bits of the CHA extended umask
  for SPR (git-fixes).
- perf: Fix event leak upon exit (git-fixes).
- perf/x86/intel/cstate: Fix Alderlake/Raptorlake/Meteorlake
  (git-fixes).
- perf: Fix default aux_watermark calculation (git-fixes).
- perf: Prevent passing zero nr_pages to rb_alloc_aux()
  (git-fixes).
- perf: Fix perf_aux_size() for greater-than 32-bit size
  (git-fixes).
- perf/x86/intel/pt: Fix pt_topa_entry_for_page() address
  calculation (git-fixes).
- perf/x86/intel/pt: Fix a topa_entry base address calculation
  (git-fixes).
- perf/x86/intel/pt: Fix topa_entry base length (git-fixes).
- perf/x86: Serialize set_attr_rdpmc() (git-fixes).
- perf/core: Fix missing wakeup when waiting for context reference
  (git-fixes).
- perf/x86/intel: Factor out the initialization code for SPR
  (git fixes).
- perf/x86/intel: Use the common uarch name for the shared
  functions (git fixes).
- commit bb48e43
* Fri Sep 13 2024 tonyj@suse.de
- blacklist.conf: Add perf git-fix that won't be backported
- commit fbbd522
* Fri Sep 13 2024 dsterba@suse.com
- nvme: move stopping keep-alive into nvme_uninit_ctrl() (CVE-2024-45013 bsc#1230442)
- commit ce739c4
* Fri Sep 13 2024 dsterba@suse.com
- i2c: tegra: Do not mark ACPI devices as irq safe (CVE-2024-45029 bsc#1230451)
- commit 2870112
* Fri Sep 13 2024 dsterba@suse.com
- netfilter: flowtable: initialise extack before use (CVE-2024-45018 bsc#1230431)
- commit 8b44b15
* Fri Sep 13 2024 dsterba@suse.com
- net/mlx5e: Take state lock during tx timeout reporter (CVE-2024-45019 bsc#1230432)
- commit 2552371
* Fri Sep 13 2024 dsterba@suse.com
- net/mlx5: Fix IPsec RoCE MPV trace call (CVE-2024-45017 bsc#1230430)
- commit 60aac02
* Fri Sep 13 2024 dsterba@suse.com
- igb: cope with large MAX_SKB_FRAGS (CVE-2024-45030 bsc#1230457)
- commit d2d3c69
* Fri Sep 13 2024 tiwai@suse.de
- Move s390 kabi patch into the kabi section
- commit 4ab5d36
* Fri Sep 13 2024 jgross@suse.com
- KVM: x86: don't fall through case statements without annotations
  (git-fixes).
- commit 8367b93
* Fri Sep 13 2024 mfranc@suse.cz
- s390/uv: Don't call folio_wait_writeback() without a folio
  reference (git-fixes bsc#1229380 CVE-2024-43832).
- s390/mm: Convert gmap_make_secure to use a folio (git-fixes
  bsc#1230562).
- s390/mm: Convert make_page_secure to use a folio (git-fixes
  bsc#1230563).
- s390: allow pte_offset_map_lock() to fail (git-fixes
  bsc#1230564).
- commit 7069eb7
* Fri Sep 13 2024 jgross@suse.com
- KVM: x86: Only advertise KVM_CAP_READONLY_MEM when supported
  by VM (git-fixes).
- commit f4e22b2
* Fri Sep 13 2024 mhocko@suse.com
- mm/vmalloc: fix page mapping if vm_area_alloc_pages() with
  high order fallback to order 0 (CVE-2024-45022 bsc#1230435).
- commit cc8880a
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm/sparsemem: fix race in accessing memory_section->usage"
  This reverts commit 6aa8957889611fbe7f06353f917cfb3d9620a680 to fix a regression (bsc#1230413)
- commit 720e36b
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm, kmsan: fix infinite recursion due to RCU critical section"
  This reverts commit 16ad73a9f4c2888f3bc28513f5e9a88d753f8741 to fix a regression (bsc#1230413)
- commit 2fd5290
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm: prevent derefencing NULL ptr in pfn_section_valid()"
  This reverts commit 35f619d3c421219e07bc89d2d6a37fbff25519fe to fix a refression
  (bsc#1230413)
- commit 7e5afd7
* Fri Sep 13 2024 mhocko@suse.com
- memcg_write_event_control(): fix a user-triggerable oops
  (CVE-2024-45021 bsc#1230434).
- commit 99a85a8
* Fri Sep 13 2024 tiwai@suse.de
- platform/x86: panasonic-laptop: Allocate 1 entry extra in the
  sinf array (git-fixes).
- platform/x86: panasonic-laptop: Fix SINF array out of bounds
  accesses (git-fixes).
- usb: dwc3: core: update LC timer as per USB Spec V3.2
  (stable-fixes).
- lib/generic-radix-tree.c: Fix rare race in
  __genradix_ptr_alloc() (stable-fixes).
- kselftests: dmabuf-heaps: Ensure the driver name is
  null-terminated (stable-fixes).
- regmap: maple: work around gcc-14.1 false-positive warning
  (stable-fixes).
- phy: zynqmp: Take the phy mutex in xlate (stable-fixes).
- pcmcia: Use resource_size function on resource object
  (stable-fixes).
- pci/hotplug/pnv_php: Fix hotplug driver crash on Powernv
  (stable-fixes).
- PCI: keystone: Add workaround for Errata #i2037 (AM65x SR 1.0)
  (stable-fixes).
- PCI: Add missing bridge lock to pci_bus_lock() (stable-fixes).
- usb: gadget: aspeed_udc: validate endpoint index for ast udc
  (stable-fixes).
- usb: uas: set host status byte on data completion error
  (stable-fixes).
- media: qcom: camss: Add check for v4l2_fwnode_endpoint_parse
  (stable-fixes).
- media: vivid: don't set HDMI TX controls if there are no HDMI
  outputs (stable-fixes).
- media: vivid: fix wrong sizeimage value for mplane
  (stable-fixes).
- leds: spi-byte: Call of_node_put() on error path (stable-fixes).
- wifi: rtw88: usb: schedule rx work after everything is set up
  (stable-fixes).
- wifi: rtw89: wow: prevent to send unexpected H2C during download
  Firmware (stable-fixes).
- wifi: mwifiex: Do not return unused priv in
  mwifiex_get_priv_by_id() (stable-fixes).
- wifi: ath12k: fix firmware crash due to invalid peer nss
  (stable-fixes).
- wifi: ath12k: fix uninitialize symbol error on
  ath12k_peer_assoc_h_he() (stable-fixes).
- wifi: brcmsmac: advertise MFP_CAPABLE to enable WPA3
  (stable-fixes).
- wifi: iwlwifi: mvm: use IWL_FW_CHECK for link ID check
  (stable-fixes).
- commit 3b57fa8
* Fri Sep 13 2024 ailiop@suse.com
- Squashfs: sanity check symbolic link size (git-fixes).
- commit fa6af4a
* Fri Sep 13 2024 tiwai@suse.de
- hwmon: (pmbus) Conditionally clear individual status bits for
  pmbus rev >= 1.2 (git-fixes).
- Input: uinput - reject requests with unreasonable number of
  slots (stable-fixes).
- HID: amd_sfh: free driver_data after destroying hid device
  (stable-fixes).
- HID: cougar: fix slab-out-of-bounds Read in cougar_report_fixup
  (stable-fixes).
- i3c: mipi-i3c-hci: Error out instead on BUG_ON() in IBI DMA
  setup (stable-fixes).
- Input: ili210x - use kvmalloc() to allocate buffer for firmware
  update (stable-fixes).
- drm/amdgpu: reject gang submit on reserved VMIDs (stable-fixes).
- drm/amdgpu: Set no_hw_access when VF request full GPU fails
  (stable-fixes).
- drm/amdgpu/display: handle gfx12 in
  amdgpu_dm_plane_format_mod_supported (stable-fixes).
- drm/amdgpu: handle gfx12 in amdgpu_display_verify_sizes
  (stable-fixes).
- drm/amdgpu: check for LINEAR_ALIGNED correctly in
  check_tiling_flags_gfx6 (stable-fixes).
- drm/amd/display: Check denominator pbn_div before used
  (stable-fixes).
- drm/amdgpu: clear RB_OVERFLOW bit when enabling interrupts
  (stable-fixes).
- drm/amdgpu: Fix smatch static checker warning (stable-fixes).
- drm/amdgpu: add missing error handling in function
  amdgpu_gmc_flush_gpu_tlb_pasid (stable-fixes).
- drm/amd/display: Check HDCP returned status (stable-fixes).
- hwmon: (w83627ehf) Fix underflows seen when writing limit
  attributes (stable-fixes).
- hwmon: (nct6775-core) Fix underflows seen when writing limit
  attributes (stable-fixes).
- hwmon: (lm95234) Fix underflows seen when writing limit
  attributes (stable-fixes).
- hwmon: (adc128d818) Fix underflows seen when writing limit
  attributes (stable-fixes).
- commit 2fa929e
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm/sparsemem: fix race in accessing memory_section->usage"
  This reverts commit 6aa8957889611fbe7f06353f917cfb3d9620a680.
- commit 5376e5a
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm, kmsan: fix infinite recursion due to RCU critical section"
  This reverts commit 16ad73a9f4c2888f3bc28513f5e9a88d753f8741.
- commit 505329c
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm: prevent derefencing NULL ptr in pfn_section_valid()"
  This reverts commit 35f619d3c421219e07bc89d2d6a37fbff25519fe.
- commit 937414d
* Fri Sep 13 2024 tiwai@suse.de
- ata: libata: Fix memory leak for error path in ata_host_alloc()
  (git-fixes).
- devres: Initialize an uninitialized struct member
  (stable-fixes).
- ASoc: TAS2781: replace beXX_to_cpup with get_unaligned_beXX
  for potentially broken alignment (stable-fixes).
- ASoC: topology: Properly initialize soc_enum values
  (stable-fixes).
- ALSA: hda: Add input value sanity checks to HDMI channel map
  controls (stable-fixes).
- ALSA: control: Apply sanity check of input values for user
  elements (stable-fixes).
- crypto: qat - fix unintentional re-enabling of error interrupts
  (stable-fixes).
- drm/amd/display: Run DC_LOG_DC after checking link->link_enc
  (stable-fixes).
- drm/amd/display: Check UnboundedRequestEnabled's value
  (stable-fixes).
- drm/amd: Add gfx12 swizzle mode defs (stable-fixes).
- Bluetooth: btnxpuart: Fix Null pointer dereference in
  btnxpuart_flush() (stable-fixes).
- can: mcp251xfd: rx: add workaround for erratum DS80000789E 6
  of mcp2518fd (stable-fixes).
- can: mcp251xfd: rx: prepare to workaround broken RX FIFO head
  index erratum (stable-fixes).
- can: mcp251xfd: mcp251xfd_handle_rxif_ring_uinc(): factor out
  in separate function (stable-fixes).
- can: mcp251xfd: clarify the meaning of timestamp (stable-fixes).
- can: kvaser_pciefd: Skip redundant NULL pointer check in ISR
  (stable-fixes).
- ACPI: processor: Fix memory leaks in error paths of
  processor_add() (stable-fixes).
- ACPI: processor: Return an error if acpi_processor_get_info()
  fails in processor_add() (stable-fixes).
- cpufreq: amd-pstate: fix the highest frequency issue which
  limits performance (git-fixes).
- cpufreq: amd-pstate: Enable amd-pstate preferred core support
  (stable-fixes).
- ACPI: CPPC: Add helper to get the highest performance value
  (stable-fixes).
- Bluetooth: hci_sync: Add helper functions to manipulate cmd_sync
  queue (stable-fixes).
- Bluetooth: hci_event: Use HCI error defines instead of magic
  values (stable-fixes).
- commit 96be389
* Thu Sep 12 2024 jgross@suse.com
- virtio_net: Fix napi_skb_cache_put warning (git-fixes).
- commit 860ef0a
* Thu Sep 12 2024 jgross@suse.com
- virtio_net: fixing XDP for fully checksummed packets handling
  (git-fixes).
- commit 77fb9e7
* Thu Sep 12 2024 mkoutny@suse.com
- randomize_kstack: Improve stack alignment codegen (bsc#1224478).
- commit d06c22b
* Thu Sep 12 2024 mfranc@suse.cz
- s390/dasd: Fix redundant /proc/dasd* entries removal
  (bsc#1227694).
- commit b66530a
* Thu Sep 12 2024 mkoutny@suse.com
- randomize_kstack: Remove non-functional per-arch entropy
  filtering (bsc#1224478).
- commit 1136c03
* Thu Sep 12 2024 tiwai@suse.de
- Move upstreamed input patch into sorted section
- commit e197a51
* Thu Sep 12 2024 jgross@suse.com
- blacklist.conf: add db5247d9bf5c ("vhost_task: Handle SIGKILL by flushing work and exiting")
- commit 7acfcbb
* Thu Sep 12 2024 jgross@suse.com
- KVM: SVM: Don't advertise Bus Lock Detect to guest if SVM
  support is missing (git-fixes).
- commit 42f7b0c
* Thu Sep 12 2024 jgross@suse.com
- KVM: x86: Acquire kvm->srcu when handling KVM_SET_VCPU_EVENTS
  (git-fixes).
- commit 610cfdd
* Thu Sep 12 2024 mkoutny@suse.com
- randomize_kstack: Improve entropy diffusion (bsc#1224478).
- blacklist.conf: Unblacklist above commit
- commit 4fdf8b0
* Thu Sep 12 2024 mkoutny@suse.com
- cgroup: Move rcu_head up near the top of cgroup_root
  (bsc#1222254).
- blacklist.conf: Unblacklist above commit
- commit 3ecdba8
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: Make ICC_*SGI*_EL1 undef in the absence of a vGICv3
  (git-fixes).
- commit bae7627
* Thu Sep 12 2024 jroedel@suse.de
- kABI: Workaround kABI change in
  patches.suse/iommu-dma-Trace-bounce-buffer-usage-when-mapping-buf.patch
  (git-fixes).
- Refresh
  patches.suse/iommu-dma-Trace-bounce-buffer-usage-when-mapping-buf.patch.
- commit d37ca1f
* Thu Sep 12 2024 jgross@suse.com
- blacklist.conf: add 778c350eb580 ("Revert KVM: async_pf: avoid recursive flushing of work items")
- commit 3ff1683
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: Do not re-initialize the KVM lock (git-fixes).
- commit b05c6c8
* Thu Sep 12 2024 mfranc@suse.cz
- s390/dasd: Remove DMA alignment (LTC#208933 bsc#1230426
  git-fixes).
- commit 5b1f3c2
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: vgic-v2: Check for non-NULL vCPU in
  vgic_v2_parse_attr() (git-fixes).
- commit 4ccaaf2
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: Don't pass a TLBI level hint when zapping table
  entries (git-fixes).
- commit e3cb3e5
* Thu Sep 12 2024 jgross@suse.com
- blacklist.conf: add f62d4c3eb687 ("KVM: arm64: Don't defer TLB invalidation when zapping table entries")
- commit 80a75dc
* Thu Sep 12 2024 jgross@suse.com
- blacklist.conf: add c60d847be7b8 ("KVM: arm64: Fix double-free following kvm_pgtable_stage2_free_unlinked()")
- commit 518faac
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: nvhe: Ignore SVE hint in SMCCC function ID
  (git-fixes).
- commit 9d7939a
* Thu Sep 12 2024 tiwai@suse.de
- blacklist.conf: move SP7-specific entries into the own section
- commit 887ee3c
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: Block unsafe FF-A calls from the host (git-fixes).
- commit 6327e50
* Thu Sep 12 2024 tiwai@suse.de
- minmax: reduce min/max macro expansion in atomisp driver
  (git-fixes).
- commit 6d37707
* Thu Sep 12 2024 dsterba@suse.com
- net: dsa: bcm_sf2: Fix a possible memory leak in bcm_sf2_mdio_register() (CVE-2024-44971 bsc#1230211)
- commit f262d95
* Thu Sep 12 2024 dsterba@suse.com
- tcp: prevent concurrent execution of tcp_sk_exit_batch (CVE-2024-44991 bsc#1230195)
- commit 179b01d
* Wed Sep 11 2024 dsterba@suse.com
- bonding: fix xfrm real_dev null pointer dereference (CVE-2024-44989 bsc#1230193)
- commit 5caf0d2
* Wed Sep 11 2024 tonyj@suse.de
- perf arch events: Fix duplicate RISC-V SBI firmware event name
  (git-fixes).
- commit 4570763
* Wed Sep 11 2024 tonyj@suse.de
- perf tool: fix dereferencing NULL al->maps (git-fixes).
- commit 5e4751b
* Wed Sep 11 2024 tonyj@suse.de
- perf intel-pt: Fix exclude_guest setting (git-fixes).
- commit e69b63b
* Wed Sep 11 2024 tonyj@suse.de
- perf intel-pt: Fix aux_watermark calculation for 64-bit size
  (git-fixes).
- commit e3b3bca
* Wed Sep 11 2024 tonyj@suse.de
- perf report: Fix condition in sort__sym_cmp() (git-fixes).
- commit c3e65ee
* Wed Sep 11 2024 tonyj@suse.de
- perf pmus: Fixes always false when compare duplicates aliases
  (git-fixes).
- commit 8eeac69
* Wed Sep 11 2024 tonyj@suse.de
- tools/perf: Fix the string match for "/tmp/perf-$PID.map"
  files in dso__load (git-fixes).
- commit 9a7d0fb
* Wed Sep 11 2024 krisman@suse.de
- bonding: fix null pointer deref in bond_ipsec_offload_ok
  (CVE-2024-44990 bsc#1230194).
- media: aspeed: Fix memory overwrite if timing is 1600x900
  (CVE-2023-52916 bsc#1230269).
- commit 7cce3c7
* Wed Sep 11 2024 tonyj@suse.de
- perf test: Make test_arm_callgraph_fp.sh more robust
  (git-fixes).
- commit 8d430e5
* Wed Sep 11 2024 tonyj@suse.de
- perf stat: Fix the hard-coded metrics calculation on the hybrid
  (git-fixes).
- commit 0fe6062
* Wed Sep 11 2024 tonyj@suse.de
- perf pmu: Assume sysfs events are always the same case
  (git-fixes).
- Refresh
  patches.suse/perf-pmu-Count-sys-and-cpuid-JSON-events-separately.patch.
- commit 0eb9b05
* Wed Sep 11 2024 krisman@suse.de
- rtla/osnoise: Prevent NULL dereference in error handling
  (CVE-2024-45002 bsc#1230169).
- net/mlx5e: SHAMPO, Fix invalid WQ linked list unlink
  (CVE-2024-44970 bsc#1230209).
- commit 33e2b5d
* Wed Sep 11 2024 iivanov@suse.de
- config/arm64: Disable platforms which are unsupported in SP7 (jsc#PED-10480)
  Disable platforms enabled because of openSUSE Leap.
  Disabling SoC also automatically disables all leaf
  drivers which directly depends on it.
    Actions Semi SoCs
    Allwinner SoCs
    Annapurna Labs Alpine platform
    Apple Silicon SoC family
    Marvell Berlin SoC Family
    Bitmain SoC Platforms
    Samsung Exynos SoC family
    Microchip Sparx5 SoC Family
    LG Electronics LG1K SoC Family
    Keem Bay SoC
    MediaTek SoC Family
    Amlogic Platforms
    Nuvoton NPCM Architecture
    Qualcomm Platforms
    Realtek Platforms
    Intel SoCFPGA ARMv8 Families
    Spreadtrum SoC platform
    Toshiba Visconti SoC Family
- commit 365bc0b
* Wed Sep 11 2024 oneukum@suse.com
- lirc: rc_dev_get_from_fd(): fix file leak (git-fixes).
- commit b3b20de
* Wed Sep 11 2024 oneukum@suse.com
- thunderbolt: Fix calculation of consumed USB3 bandwidth on a
  path (git-fixes).
- commit c3642e6
* Wed Sep 11 2024 marco.crivellari@suse.com
- Move fixes into sorted section (bsc#1230119)
- commit c8d5e3a
* Wed Sep 11 2024 tiwai@suse.de
- Refresh patches.suse/Bluetooth-qca-Set-both-WIDEBAND_SPEECH-and-LE_STATES.patch
  Correct the chunk after merge conflicts
- commit 0345510
* Wed Sep 11 2024 tiwai@suse.de
- power: sequencing: fix an invalid pointer dereference in error
  path (jsc#PED-10412).
- commit ba2b760
* Wed Sep 11 2024 tiwai@suse.de
- Refresh
  patches.suse/Bluetooth-Fix-double-free-in-hci_conn_cleanup.patch.
- Refresh
  patches.suse/Bluetooth-hci_conn-Only-do-ACL-connections-sequentia.patch.
  Recover the original context after backporting other fixes
- commit 4e1042e
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: MGMT: Fix not generating command complete for
  MGMT_OP_DISCONNECT (jsc#PED-10412).
- Bluetooth: hci_sync: Introduce
  hci_cmd_sync_run/hci_cmd_sync_run_once (jsc#PED-10412).
- Bluetooth: qca: If memdump doesn't work, re-enable IBS
  (jsc#PED-10412).
- Bluetooth: btnxpuart: Fix random crash seen while removing
  driver (jsc#PED-10412).
- Bluetooth: btintel: Allow configuring drive strength of BRI
  (jsc#PED-10412).
- Bluetooth: HCI: Invert LE State quirk to be opt-out rather
  then opt-in (jsc#PED-10412).
- Bluetooth: hci_qca: fix a NULL-pointer derefence at shutdown
  (jsc#PED-10412).
- Bluetooth: hci_qca: fix QCA6390 support on non-DT platforms
  (jsc#PED-10412).
- commit 913dd38
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_qca: don't call pwrseq_power_off() twice for
  QCA6390 (jsc#PED-10412).
- Bluetooth: hci_event: Fix setting DISCOVERY_FINDING for passive
  scanning (jsc#PED-10412).
- Bluetooth: btmtk: remove #ifdef around declarations
  (jsc#PED-10412).
- Bluetooth: btmtk: Fix btmtk.c undefined reference build error
  harder (jsc#PED-10412).
- Bluetooth: btmtk: Fix btmtk.c undefined reference build error
  (jsc#PED-10412).
- Bluetooth: btmtk: Fix kernel crash when entering
  btmtk_usb_suspend (jsc#PED-10412).
- Bluetooth: btmtk: Mark all stub functions as inline
  (jsc#PED-10412).
- Bluetooth: hci_qca: Fix build error (jsc#PED-10412).
- commit 9db9c08
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_qca: use the power sequencer for wcn7850 and
  wcn6855 (jsc#PED-10412).
- Bluetooth: hci_qca: make pwrseq calls the default if available
  (jsc#PED-10412).
- Bluetooth: hci_qca: unduplicate calls to
  hci_uart_register_device() (jsc#PED-10412).
- Bluetooth: hci_qca: schedule a devm action for disabling the
  clock (jsc#PED-10412).
- Bluetooth: btnxpuart: Fix warnings for suspend and resume
  functions (jsc#PED-10412).
- Bluetooth: btnxpuart: Add system suspend and resume handlers
  (jsc#PED-10412).
- Bluetooth: btnxpuart: Add support for IW615 chipset
  (jsc#PED-10412).
- Bluetooth: btnxpuart: Add support for AW693 A1 chipset
  (jsc#PED-10412).
- Bluetooth: btintel: Add support for Whale Peak2 (jsc#PED-10412).
- Bluetooth: btintel: Add support for BlazarU core
  (jsc#PED-10412).
- commit 6b69188
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btusb: mediatek: add ISO data transmission functions
  (jsc#PED-10412).
- Bluetooth: btmtk: move btusb_recv_acl_mtk to btmtk.c
  (jsc#PED-10412).
- Bluetooth: btmtk: move btusb_mtk_[setup, shutdown] to btmtk.c
  (jsc#PED-10412).
- Bluetooth: btmtk: move btusb_mtk_hci_wmt_sync to btmtk.c
  (jsc#PED-10412).
- Bluetooth: btusb: add callback function in btusb suspend/resume
  (jsc#PED-10412).
- Bluetooth: btmtk: rename btmediatek_data (jsc#PED-10412).
- Bluetooth: btusb: mediatek: return error for failed reg access
  (jsc#PED-10412).
- Bluetooth: btusb: mediatek: remove the unnecessary goto tag
  (jsc#PED-10412).
- Bluetooth: Remove hci_request.{c,h} (jsc#PED-10412).
- Bluetooth: hci_sync: Remove remaining dependencies of
  hci_request (jsc#PED-10412).
- commit 73094c1
* Wed Sep 11 2024 tiwai@suse.de
- Update config and supported files: CONFIG_POWER_SEQUENCING (jsc#PED-10412)
- commit 8cfbade
* Wed Sep 11 2024 oneukum@suse.com
- thunderbolt: Constify the struct device_type usage
  (jsc#PED-10361).
- commit c0f552c
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_sync: Move handling of interleave_scan
  (jsc#PED-10412).
- Bluetooth: hci_core: Don't use hci_prepare_cmd (jsc#PED-10412).
- Bluetooth: hci_core: Remove usage of hci_req_sync
  (jsc#PED-10412).
- Bluetooth: hci_core: cleanup struct hci_dev (jsc#PED-10412).
- Bluetooth: btintel: Fix the sfi name for BlazarU
  (jsc#PED-10412).
- Bluetooth: qca: don't disable power management for QCA6390
  (jsc#PED-10412).
- Bluetooth: hci: fix build when POWER_SEQUENCING=m
  (jsc#PED-10412).
- Bluetooth: btintel: Fix spelling of *intermediate* in comment
  (jsc#PED-10412).
- Bluetooth: qca: use the power sequencer for QCA6390
  (jsc#PED-10412).
- Bluetooth: btintel: Add firmware ID to firmware name
  (jsc#PED-10412).
- power: sequencing: implement the pwrseq core (jsc#PED-10412).
- commit ef3a45d
* Wed Sep 11 2024 oneukum@suse.com
- thunderbolt: Add trace events support for the control channel
  (jsc#PED-10361).
- commit 7c01a94
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_core, hci_sync: cleanup struct discovery_state
  (jsc#PED-10412).
- Bluetooth: btnxpuart: Update firmware names (jsc#PED-10412).
- Bluetooth: hci_bcm4377: Add BCM4388 support (jsc#PED-10412).
- Bluetooth: Add vendor-specific packet classification for ISO
  data (jsc#PED-10412).
- Bluetooth: iso: remove unused struct 'iso_list_data'
  (jsc#PED-10412).
- Bluetooth: btintel_pcie: Remove unnecessary memset(0) calls
  (jsc#PED-10412).
- Bluetooth: Use sizeof(*pointer) instead of sizeof(type)
  (jsc#PED-10412).
- Bluetooth: MGMT: Uninitialized variable in load_conn_param()
  (jsc#PED-10412).
- Bluetooth/nokia: Remove unused struct 'hci_nokia_radio_hdr'
  (jsc#PED-10412).
- tty: rfcomm: prefer array indexing over pointer arithmetic
  (jsc#PED-10412).
- commit da8d18e
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_core: Prefer array indexing over pointer
  arithmetic (jsc#PED-10412).
- Bluetooth: hci_core: Prefer struct_size over open coded
  arithmetic (jsc#PED-10412).
- Bluetooth: btintel_pcie: Fix irq leak (jsc#PED-10412).
- Bluetooth: btintel_pcie: Print Firmware Sequencer information
  (jsc#PED-10412).
- Bluetooth: btusb: mediatek: add MT7922 subsystem reset
  (jsc#PED-10412).
- Bluetooth: btusb: mediatek: reset the controller before
  downloading the fw (jsc#PED-10412).
- Bluetooth: btusb: mediatek: refactor the function
  btusb_mtk_reset (jsc#PED-10412).
- Bluetooth: btmtk: apply the common btmtk_fw_get_filename
  (jsc#PED-10412).
- Bluetooth: btmtk: add the function to get the fw name
  (jsc#PED-10412).
- commit 1069025
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btnxpuart: Handle FW Download Abort scenario
  (jsc#PED-10412).
- Bluetooth: btnxpuart: Enable status prints for firmware download
  (jsc#PED-10412).
- Bluetooth: btnxpuart: Fix Null pointer dereference in
  btnxpuart_flush() (jsc#PED-10412).
- Bluetooth: hci_bcm4377: Increase boot timeout (jsc#PED-10412).
- Bluetooth: MGMT: Make MGMT_OP_LOAD_CONN_PARAM update existing
  connection (jsc#PED-10412).
- Bluetooth: btintel_pcie: Fix REVERSE_INULL issue reported by
  coverity (jsc#PED-10412).
- Bluetooth: Add quirk to ignore reserved PHY bits in LE Extended
  Adv Report (jsc#PED-10412).
- Bluetooth: hci_sync: Fix not using correct handle
  (jsc#PED-10412).
- bluetooth: virtio: drop owner assignment (jsc#PED-10412).
- commit 62febf1
* Wed Sep 11 2024 tiwai@suse.de
- Update config and supported files: CONFIG_BT_INTEL_PCIE (jsc#PED-10412)
- commit d0ed0d6
* Wed Sep 11 2024 oneukum@suse.com
- thunderbolt: Keep the domain powered when USB4 port is in
  redrive mode (jsc#PED-10361).
- Refresh
  patches.suse/new-paddings-for-the-new-features-of-TB.patch.
- commit 9b79c66
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btmtksdio: drop driver owner initialization
  (jsc#PED-10412).
- Bluetooth: btmrvl_sdio: drop driver owner initialization
  (jsc#PED-10412).
- Bluetooth: btintel_pcie: Refactor and code cleanup
  (jsc#PED-10412).
- Bluetooth: btintel_pcie: Fix warning reported by sparse
  (jsc#PED-10412).
- Bluetooth: hci_core: Fix not handling hdev->le_num_of_adv_sets=1
  (jsc#PED-10412).
- Bluetooth: btintel: Fix compiler warning for multi_v7_defconfig
  config (jsc#PED-10412).
- Bluetooth: btintel_pcie: Fix compiler warnings (jsc#PED-10412).
- Bluetooth: btintel_pcie: Add *setup* function to download
  firmware (jsc#PED-10412).
- Bluetooth: btintel_pcie: Add support for PCIe transport
  (jsc#PED-10412).
- Bluetooth: btintel: Export few static functions (jsc#PED-10412).
- commit 240b2e1
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: L2CAP: Fix div-by-zero in l2cap_le_flowctl_init()
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-Ignore-too-large-handle-values-in-BIG.patch.
- Refresh
  patches.suse/bluetooth-hci-disallow-setting-handle-bigger-than-HC.patch.
- commit 7babf5a
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: compute LE flow credits based on recvbuf space
  (jsc#PED-10412).
- Refresh patches.suse/Bluetooth-L2CAP-Fix-deadlock.patch.
- Refresh
  patches.suse/bluetooth-l2cap-sync-sock-recv-cb-and-release.patch.
- commit f2065ca
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_conn: Use __counted_by() and avoid -Wfamnae
  warning (jsc#PED-10412).
- Bluetooth: btintel: Add support for Filmore Peak2 (BE201)
  (jsc#PED-10412).
- Bluetooth: btintel: Add support for BlazarI (jsc#PED-10412).
- LE Create Connection command timeout increased to 20 secs
  (jsc#PED-10412).
- Bluetooth: hci_sync: Use cmd->num_cis instead of magic number
  (jsc#PED-10412).
- Bluetooth: hci_conn: Use struct_size() in
  hci_le_big_create_sync() (jsc#PED-10412).
- Bluetooth: qca: clean up defines (jsc#PED-10412).
- Bluetooth: qca: drop bogus module version (jsc#PED-10412).
- commit fab50f1
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: qca: drop bogus edl header checks (jsc#PED-10412).
- Bluetooth: hci_conn: Use __counted_by() to avoid -Wfamnae
  warning (jsc#PED-10412).
- Bluetooth: hci_conn, hci_sync: Use __counted_by() to avoid
  - Wfamnae warnings (jsc#PED-10412).
- Bluetooth: btusb: Sort usb_device_id table by the ID
  (jsc#PED-10412).
- Bluetooth: btusb: Add USB HW IDs for MT7921/MT7922/MT7925
  (jsc#PED-10412).
- Bluetooth: qca: Support downloading board id specific NVM for
  WCN7850 (jsc#PED-10412).
- Bluetooth: Populate hci_set_hw_info for Intel and Realtek
  (jsc#PED-10412).
- Bluetooth: Remove 3 repeated macro definitions (jsc#PED-10412).
- Bluetooth: hci_conn: Remove a redundant check for HFP offload
  (jsc#PED-10412).
- Bluetooth: btusb: Correct timeout macro argument used to
  receive control message (jsc#PED-10412).
- commit 70d6028
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: ISO: Handle PA sync when no BIGInfo reports are
  generated (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-hci_event-Set-QoS-encryption-from-BIGInfo-.patch.
- commit 68729b6
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btusb: Fix the patch for MT7920 the affected to
  MT7921 (jsc#PED-10412).
- Bluetooth: hci_bcm: Limit bcm43455 baudrate to 2000000
  (jsc#PED-10412).
- Bluetooth: L2CAP: Avoid -Wflex-array-member-not-at-end warnings
  (jsc#PED-10412).
- Bluetooth: hci_intel: Fix multiple issues reported by
  checkpatch.pl (jsc#PED-10412).
- Bluetooth: ISO: Make iso_get_sock_listen generic
  (jsc#PED-10412).
- Bluetooth: hci_event: Set DISCOVERY_FINDING on SCAN_ENABLED
  (jsc#PED-10412).
- Bluetooth: Add proper definitions for scan interval and window
  (jsc#PED-10412).
- Bluetooth: hci_intel: Convert to platform remove callback
  returning void (jsc#PED-10412).
- Bluetooth: hci_bcm: Convert to platform remove callback
  returning void (jsc#PED-10412).
- commit c4cc5d0
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btqcomsmd: Convert to platform remove callback
  returning void (jsc#PED-10412).
- Bluetooth: Add support for MediaTek MT7922 device
  (jsc#PED-10412).
- Bluetooth: btintel: Add support to download intermediate loader
  (jsc#PED-10412).
- Bluetooth: btintel: Define macros for image types
  (jsc#PED-10412).
- Bluetooth: qca: fix info leak when fetching board id
  (jsc#PED-10412).
- Bluetooth: qca: generalise device address check (jsc#PED-10412).
- Bluetooth: qca: fix wcn3991 device address check
  (jsc#PED-10412).
- Bluetooth: btusb: mediatek: Fix double free of skb in coredump
  (jsc#PED-10412).
- Bluetooth: qca: fix invalid device address check
  (jsc#PED-10412).
- commit b071de5
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_sync: Use advertised PHYs on
  hci_le_ext_create_conn_sync (jsc#PED-10412).
- Revert "Bluetooth: hci_qca: Set BDA quirk bit if fwnode exists
  in DT" (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-qca-fix-device-address-endianness.patch.
- commit c8b7a54
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_sync: Fix UAF in hci_acl_create_conn_sync
  (jsc#PED-10412).
- Bluetooth: mgmt: remove NULL check in
  add_ext_adv_params_complete() (jsc#PED-10412).
- Bluetooth: mgmt: remove NULL check in
  mgmt_set_connectable_complete() (jsc#PED-10412).
- Bluetooth: btusb: Add support Mediatek MT7920 (jsc#PED-10412).
- Bluetooth: ISO: Clean up returns values in iso_connect_ind()
  (jsc#PED-10412).
- Bluetooth: fix use-after-free in accessing skb after sending it
  (jsc#PED-10412).
- Bluetooth: btusb: Fix memory leak (jsc#PED-10412).
- commit 18e7427
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btintel: Print Firmware Sequencer information
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-btintel-Fail-setup-on-error.patch.
- commit fd6652b
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: msft: Fix memory leak (jsc#PED-10412).
- Bluetooth: hci_sync: Fix overwriting request callback
  (jsc#PED-10412).
- Bluetooth: hci_sync: Use address filtering when HCI_PA_SYNC
  is set (jsc#PED-10412).
- Bluetooth: ISO: Reassemble PA data for bcast sink
  (jsc#PED-10412).
- Bluetooth: ISO: Add hcon for listening bis sk (jsc#PED-10412).
- Bluetooth: hci_sync: Fix UAF on create_le_conn_complete
  (jsc#PED-10412).
- Bluetooth: hci_sync: Fix UAF on hci_abort_conn_sync
  (jsc#PED-10412).
- Bluetooth: constify the struct device_type usage
  (jsc#PED-10412).
- Bluetooth: btbcm: Use devm_kstrdup() (jsc#PED-10412).
- commit 22de4dc
* Wed Sep 11 2024 oneukum@suse.com
- thunderbolt: Improve DisplayPort tunnel setup process to be
  more robust (jsc#PED-10361).
- commit 4f4f6b4
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_sync: Attempt to dequeue connection attempt
  (jsc#PED-10412).
- Refresh patches.suse/Bluetooth-HCI-Remove-HCI_AMP-support.patch.
- commit c43a167
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_conn: Only do ACL connections sequentially
  (jsc#PED-10412).
- commit a159377
* Wed Sep 11 2024 oneukum@suse.com
- thunderbolt: Calculate DisplayPort tunnel bandwidth after DPRX
  capabilities read (jsc#PED-10361).
- commit 96d3bbc
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btbcm: Use strreplace() (jsc#PED-10412).
- Bluetooth: hci_sync: Add helper functions to manipulate cmd_sync
  queue (jsc#PED-10412).
- Bluetooth: hci_conn: Fix UAF Write in
  __hci_acl_create_connection_sync (jsc#PED-10412).
- Bluetooth: hci_conn: Always use sk_timeo as conn_timeout
  (jsc#PED-10412).
- Bluetooth: Remove pending ACL connection attempts
  (jsc#PED-10412).
- Bluetooth: btusb: Add new VID/PID 13d3/3602 for MT7925
  (jsc#PED-10412).
- Bluetooth: hci_event: Use HCI error defines instead of magic
  values (jsc#PED-10412).
- Bluetooth: Disconnect connected devices before rfkilling adapter
  (jsc#PED-10412).
- commit 8446296
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btrtl: Add the support for RTL8852BT/RTL8852BE-VT
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-btusb-Add-RTL8852BE-device-0489-e125-to-de.patch.
- commit b25587c
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: Add new state HCI_POWERING_DOWN (jsc#PED-10412).
- Bluetooth: btnxpuart: Resolve TX timeout error in power save
  stress test (jsc#PED-10412).
- Bluetooth: qca: Fix triggering coredump implementation
  (jsc#PED-10412).
- commit 84f0df9
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_qca: Set BDA quirk bit if fwnode exists in DT
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-qca-fix-device-address-endianness.patch.
- commit 743b80e
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btnxpuart: remove useless assignment (jsc#PED-10412).
- Bluetooth: qca: Support HFP offload for QCA2066 (jsc#PED-10412).
- commit ba64060
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btintel: Print firmware SHA1 (jsc#PED-10412).
- Bluetooth: hci_core: Remove le_restart_scan work
  (jsc#PED-10412).
- Bluetooth: Add documentation to exported functions in lib
  (jsc#PED-10412).
- Bluetooth: btusb: Don't suspend when there are connections
  (jsc#PED-10412).
- Bluetooth: ISO: Reassociate a socket with an active BIS
  (jsc#PED-10412).
- Bluetooth: ISO: Allow binding a PA sync socket (jsc#PED-10412).
- Bluetooth: Do not include crypto/algapi.h (jsc#PED-10412).
- Bluetooth: btmtksdio: enable bluetooth wakeup in system suspend
  (jsc#PED-10412).
- Bluetooth: ISO: Copy BASE if service data matches
  EIR_BAA_SERVICE_UUID (jsc#PED-10412).
- Bluetooth: ISO: Fix bcast listener cleanup (jsc#PED-10412).
- commit d0b79ad
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: qca: add support for QCA2066 (jsc#PED-10412).
- blacklist.conf: drop the backported entry
- Refresh
  patches.suse/Bluetooth-qca-fix-info-leak-when-fetching-fw-build-i.patch.
- commit ec94898
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: msft: __hci_cmd_sync() doesn't return NULL
  (jsc#PED-10412).
- Bluetooth: ISO: Match QoS adv handle with BIG handle
  (jsc#PED-10412).
- Bluetooth: ISO: Allow binding a bcast listener to 0 bises
  (jsc#PED-10412).
- Bluetooth: ISO: Set CIS bit only for devices with CIS support
  (jsc#PED-10412).
- Bluetooth: Add support ITTIM PE50-M75C (jsc#PED-10412).
- commit 4aa9f8a
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: rfcomm: remove casts from tty->driver_data
  (jsc#PED-10412).
- Bluetooth: ISO: Add support for periodic adv reports processing
  (jsc#PED-10412).
- commit 34add37
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_core: Fix missing instances using
  HCI_MAX_AD_LENGTH (jsc#PED-10412).
- Refresh patches.suse/Bluetooth-Fix-eir-name-length.patch.
- commit cbae469
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: qca: add support for WCN7850 (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-hci_qca-don-t-use-IS_ERR_OR_NULL-with-gpio.patch.
- Refresh
  patches.suse/Bluetooth-qca-fix-device-address-endianness.patch.
- Refresh
  patches.suse/Bluetooth-qca-set-power_ctrl_enabled-on-NULL-returne.patch.
- commit a63e12d
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: qca: use switch case for soc type behavior
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-hci_qca-don-t-use-IS_ERR_OR_NULL-with-gpio.patch.
- Refresh
  patches.suse/Bluetooth-qca-fix-device-address-endianness.patch.
- commit 895c11d
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btnxpuart: Improve inband Independent Reset handling
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-btnxpuart-fix-recv_buf-return-value.patch.
- commit 564a779
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_conn: Fix sending
  BT_HCI_CMD_LE_CREATE_CONN_CANCEL (jsc#PED-10412).
- commit 6f9f45a
* Wed Sep 11 2024 oneukum@suse.com
- thunderbolt: Reserve released DisplayPort bandwidth for a
  group for 10 seconds (jsc#PED-10361).
- commit 130bf14
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btnxpuart: Add support for IW624 chipset
  (jsc#PED-10412).
- Bluetooth: btnxpuart: Remove check for CTS low after FW download
  (jsc#PED-10412).
- Bluetooth: hci_conn: avoid checking uninitialized CIG/CIS ids
  (jsc#PED-10412).
- Bluetooth: Remove unnecessary NULL check before vfree()
  (jsc#PED-10412).
- commit e6aa8ab
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_core: Make hci_is_le_conn_scanning public
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-hci_sync-Use-QoS-to-determine-which-PHY-to.patch.
- commit 458c1e2
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_sync: Fix handling of HCI_OP_CREATE_CONN_CANCEL
  (jsc#PED-10412).
- commit 1ed4d51
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: ISO: handle bound CIS cleanup via hci_conn
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-ISO-Use-defer-setup-to-separate-PA-sync-an.patch.
- commit 920025f
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btqca: Add WCN3988 support (jsc#PED-10412).
- Bluetooth: btnxpuart: Add support for AW693 chipset
  (jsc#PED-10412).
- bluetooth: Explicitly include correct DT includes
  (jsc#PED-10412).
- Bluetooth: btbcm: add default address for BCM43430A1
  (jsc#PED-10412).
- Bluetooth: btmtk: Fix kernel crash when processing coredump
  (jsc#PED-10412).
- Bluetooth: hci_debugfs: Use kstrtobool() instead of strtobool()
  (jsc#PED-10412).
- Bluetooth: MGMT: Fix always using HCI_MAX_AD_LENGTH
  (jsc#PED-10412).
- Bluetooth: msft: Fix error code in
  msft_cancel_address_filter_sync() (jsc#PED-10412).
- Bluetooth: btusb: mediatek: add MediaTek devcoredump support
  (jsc#PED-10412).
- Bluetooth: btmtk: introduce btmtk reset work (jsc#PED-10412).
- Bluetooth: btusb: mediatek: readx_poll_timeout replaces open
  coding (jsc#PED-10412).
- Bluetooth: btmtk: add printing firmware information
  (jsc#PED-10412).
- Bluetooth: hci_sync: Enable events for BIS capable devices
  (jsc#PED-10412).
- commit 1c732d6
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: msft: Extended monitor tracking by address filter
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-HCI-Introduce-HCI_QUIRK_BROKEN_LE_CODED.patch.
- Refresh
  patches.suse/Bluetooth-msft-fix-slab-use-after-free-in-msft_do_cl.patch.
- commit f5005b6
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btusb: Add support Mediatek MT7925 (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-btmtk-Add-MODULE_FIRMWARE-for-MT7922.patch.
- commit ff226e0
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: ISO: Support multiple BIGs (jsc#PED-10412).
- Refresh patches.suse/Bluetooth-ISO-Fix-BIS-cleanup.patch.
- commit ea5b8bb
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_sock: Forward credentials to monitor
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-af_bluetooth-Make-BT_PKT_STATUS-generic.patch.
- commit e0517ad
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_qca: Add qcom devcoredump support
  (jsc#PED-10412).
- Bluetooth: hci_qca: Add qcom devcoredump sysfs support
  (jsc#PED-10412).
- Bluetooth: Init sk_peer_* on bt_sock_alloc (jsc#PED-10412).
- Bluetooth: Consolidate code around sk_alloc into a helper
  function (jsc#PED-10412).
- Bluetooth: Check for ISO support in controller (jsc#PED-10412).
- commit 1901fd5
* Wed Sep 11 2024 tiwai@suse.de
- Refresh patches.suse/ipmi-ssif-Improve-detecting-during-probing.patch
  Add commit id and move away from out-of-tree section
- commit ceb6869
* Wed Sep 11 2024 tiwai@suse.de
- Move upstreamed kaslr patch into sorted section
- commit 554594b
* Wed Sep 11 2024 pjakobsson@suse.de
- blacklist.conf: 28083ff18d3f accel/ivpu: Fix DevTLB errors on suspend/resume and recovery
- commit 195a7fc
* Wed Sep 11 2024 dsterba@suse.com
- net: dsa: mv88e6xxx: Fix out-of-bound access (CVE-2024-44988 bsc#1230192)
- commit 5ca3065
* Wed Sep 11 2024 dsterba@suse.com
- ipv6: prevent UAF in ip6_send_skb() (CVE-2024-44987 bsc#1230185)
- commit 075c292
* Wed Sep 11 2024 tonyj@suse.de
- perf tools: Add/use PMU reverse lookup from config to name
  (git-fixes).
- commit 62632fc
* Wed Sep 11 2024 tonyj@suse.de
- perf tools: Use pmus to describe type from attribute
  (git-fixes).
- commit 3dc616b
* Wed Sep 11 2024 tonyj@suse.de
- perf: script: add raw|disasm arguments to --insn-trace option
  (git-fixes).
- Refresh
  patches.suse/perf-script-Show-also-errors-for-insn-trace-option.patch.
- commit f716aa4
* Wed Sep 11 2024 tonyj@suse.de
- perf annotate: Use global annotation_options (git-fixes).
- Refresh
  patches.suse/perf-annotate-Fix-annotation_calc_lines-to-pass-correct-address-to-get_srcline.patch.
- commit b70a6bc
* Wed Sep 11 2024 tonyj@suse.de
- perf top: Convert to the global annotation_options (git-fixes).
- commit c12ae1d
* Wed Sep 11 2024 tonyj@suse.de
- perf report: Convert to the global annotation_options
  (git-fixes).
- commit e5bcc3a
* Wed Sep 11 2024 tonyj@suse.de
- perf annotate: Introduce global annotation_options (git-fixes).
- commit b458961
* Wed Sep 11 2024 tonyj@suse.de
- perf maps: Move symbol maps functions to maps.c (git-fixes).
- Refresh
  patches.suse/perf-symbols-Fix-ownership-of-string-in-dso__load_vmlinux.patch.
- commit 93caf35
* Wed Sep 11 2024 tonyj@suse.de
- perf annotate: Split branch stack cycles information out of
  'struct annotation_line' (git-fixes).
- commit 733d4c0
* Wed Sep 11 2024 tonyj@suse.de
- perf machine thread: Remove exited threads by default
  (git-fixes).
- commit 3c4b077
* Wed Sep 11 2024 dsterba@suse.com
- Update references for patches.suse/ipv6-fix-possible-UAF-in-ip6_finish_output2.patch (CVE-2024-44986 bsc#1230230 bsc#1230206)
- commit 814e7ee
* Wed Sep 11 2024 dsterba@suse.com
- bnxt_en: Fix double DMA unmapping for XDP_REDIRECT (CVE-2024-44984 bsc#1230240)
- commit 43e2e07
* Wed Sep 11 2024 dsterba@suse.com
- gtp: pull network headers in gtp_dev_xmit() (CVE-2024-44999 bsc#1230233)
- commit 057aaf8
* Tue Sep 10 2024 tonyj@suse.de
- perf record: Lazy load kernel symbols (git-fixes).
- commit 84efd43
* Tue Sep 10 2024 tonyj@suse.de
- Detect memory allocation failure in
  annotated_source__alloc_histograms (bsc#1227962).
- commit 6424d7a
* Tue Sep 10 2024 tonyj@suse.de
- Add alternate commit id for git-fixes.
  Refresh
  patches.suse/perf-evlist-Fix-evlist__new_default-for-1-core-PMU.patch.
- commit 3b7c481
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: There are only 5 basic router registers in pre-USB4
  routers (git-fixes).
- commit 065ac58
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Introduce tb_tunnel_direction_downstream()
  (jsc#PED-10361).
- commit ba7c759
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Re-order bandwidth group functions (jsc#PED-10361).
- commit d12ba0d
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Fail the failed bandwidth request properly
  (jsc#PED-10361).
- commit caec991
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Log an error if DPTX request is not cleared
  (jsc#PED-10361).
- commit 0e05631
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Handle bandwidth allocation mode disable request
  (jsc#PED-10361).
- commit 5ad8932
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Re-calculate estimated bandwidth when allocation
  mode is enabled (jsc#PED-10361).
- commit 4ff0de4
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Use DP_LOCAL_CAP for maximum bandwidth calculation
  (jsc#PED-10361).
- commit ae9bf79
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Correct typo in host_reset parameter
  (jsc#PED-10361).
- commit ef318a9
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Skip discovery also in USB4 v2 host
  (jsc#PED-10361).
- commit 7ae281c
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Remove usage of the deprecated ida_simple_xx()
  API (jsc#PED-10361).
- commit a696c4b
* Tue Sep 10 2024 oneukum@suse.com
- Documentation: core-api: Drop :export: for int_log.h
  (jsc#PED-8643).
- commit 8ef6285
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Fix rollback in tb_port_lane_bonding_enable()
  for lane 1 (git-fixes).
- commit 108e81e
* Tue Sep 10 2024 iivanov@suse.de
- ipmi:ssif: Improve detecting during probing (bsc#1228771)
- commit db0a09e
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Fix XDomain rx_lanes_show and tx_lanes_show
  (git-fixes).
- commit b11c099
* Tue Sep 10 2024 tiwai@suse.de
- Drop soundwire patch that caused a regression (bsc#1230350)
  Deleted:
  patches.suse/soundwire-stream-fix-programming-slave-ports-for-non.patch
- commit 5c05eeb
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Reset topology created by the boot firmware
  (jsc#PED-10361).
- commit fd7acbb
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Reduce retry timeout to speed up boot for some
  devices (jsc#PED-10232).
- commit 1dfc48d
* Tue Sep 10 2024 fdmanana@suse.com
- btrfs: fix race between direct IO write and fsync when using
  same fd (git-fixes).
- commit dc59ebc
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: make tb_bus_type const (jsc#PED-10232).
- commit 04ab8d9
* Tue Sep 10 2024 pjakobsson@suse.de
- clk: bcm: rpi: Assign ->num before accessing ->hws (git-fixes).
- commit 860d52d
* Tue Sep 10 2024 pjakobsson@suse.de
- clk: bcm: dvp: Assign ->num before accessing ->hws (git-fixes).
- commit c22e6ac
* Tue Sep 10 2024 pjakobsson@suse.de
- accel/ivpu: Don't enable any tiles by default on VPU40xx (git-fixes).
- commit 67e76ed
* Tue Sep 10 2024 pjakobsson@suse.de
- accel/ivpu: Disable PLL after VPU IP reset during FLR (git-fixes).
- commit f64a3b8
* Tue Sep 10 2024 pjakobsson@suse.de
- mm: fix VMA heap bounds checking (git-fixes).
- commit e4218bb
* Tue Sep 10 2024 pjakobsson@suse.de
- accel/ivpu/37xx: Fix hangs related to MMIO reset (git-fixes).
- commit 94760b1
* Tue Sep 10 2024 vbabka@suse.cz
- mm/swap: fix race when skipping swapcache (CVE-2024-26759
  bsc#1230340).
- commit 990c0c6
* Tue Sep 10 2024 dwagner@suse.de
- blacklist: drop 1147dd050356 ("nvme: fix error-handling for io_uring
  nvme-passthrough")
  The nvme subsystem will be updated to latest upstream version (jsc#120381).
  Thus remove this fix from the blacklist.
- commit d92abec
* Tue Sep 10 2024 davide.benini@suse.com
- blacklist.conf: remove entry for "netrom: no security implications in reading
  the value - WONTFIX - CVE-2024-27419 - bsc#1224759"
  The CVE was marked as WONTFIX in a previous version, as there were no security
  implications with it.
  As it is not a breaker, I am now removing the entry from the blacklist
- commit 03b7aa4
* Tue Sep 10 2024 tiwai@suse.de
- wifi: iwlwifi: remove fw_running op (stable-fixes).
- commit 2a8c267
* Tue Sep 10 2024 tiwai@suse.de
- kABI workaround for cros_ec stuff (git-fixes).
- commit cb01b4e
* Tue Sep 10 2024 tiwai@suse.de
- platform/chrome: cros_ec_lpc: MEC access can use an AML mutex
  (stable-fixes).
- commit d9de020
* Mon Sep  9 2024 ohering@suse.de
- Drivers: hv: vmbus: Fix rescind handling in uio_hv_generic
  (git-fixes).
- uio_hv_generic: Fix kernel NULL pointer dereference in
  hv_uio_rescind (git-fixes).
- net: mana: Fix error handling in mana_create_txq/rxq's NAPI
  cleanup (git-fixes).
- commit 27572d4
* Mon Sep  9 2024 jgross@suse.com
- x86/pat: Fix W^X violation false-positives when running as
  Xen PV guest (bsc#1221527).
- commit 9acf0ca
* Mon Sep  9 2024 jgross@suse.com
- x86/pat: Restructure _lookup_address_cpa() (bsc#1221527).
- commit 56f7c9c
* Mon Sep  9 2024 nik.borisov@suse.com
- x86/resctrl: Fix uninitialized memory read when last CPU of domain  goes offline (git-fixes).
- commit 11e8cdf
* Mon Sep  9 2024 nik.borisov@suse.com
- x86/resctrl: Fix arch_mbm_* array overrun on SNC (git-fixes).
- commit 34a43df
* Mon Sep  9 2024 nik.borisov@suse.com
- x86/resctrl: Don't try to free nonexistent RMIDs (git-fixes).
- commit 26fde78
* Mon Sep  9 2024 nik.borisov@suse.com
- x86/cpu/intel: Drop stray FAM6 check with new Intel CPU model defines (git-fixes).
- Refresh patches.suse/ASoC-Intel-avs-es8336-Switch-to-new-Intel-CPU-model-define.patch.
- commit a41e10c
* Mon Sep  9 2024 msuchanek@suse.de
- powerpc/qspinlock: Fix deadlock in MCS queue (bac#1230295
  ltc#206656).
- commit c4a2ba1
* Mon Sep  9 2024 mwilck@suse.com
- Refresh
  patches.kabi/kabi-dm_blk_ioctl-implement-path-failover-for-SG_IO.patch.
- Refresh
  patches.suse/dm_blk_ioctl-implement-path-failover-for-SG_IO.patch.
- commit 73c5a36
* Mon Sep  9 2024 tiwai@suse.de
- ASoC: Intel: Boards: Fix NULL pointer deref in BYT/CHT boards
  harder (git-fixes).
- commit 8bf5c93
* Mon Sep  9 2024 jgross@suse.com
- x86/mm: Use lookup_address_in_pgd_attr() in show_fault_oops()
  (bsc#1221527).
- commit 84d383c
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu/37xx: Fix missing VPUIP interrupts (drm-backport-placeholder)
- commit fb067bc
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Extend address range for MMU mmap (drm-backport-placeholder)
- commit 5833592
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Don't enter d0i3 during FLR (drm-backport-placeholder)
- commit f877c9b
* Mon Sep  9 2024 pjakobsson@suse.de
- fbdev: mmp: Annotate struct mmp_path with __counted_by (drm-backport-placeholder)
- commit 9259874
* Mon Sep  9 2024 pjakobsson@suse.de
- fbdev: mmp: Annotate struct mmphw_ctrl with __counted_by (drm-backport-placeholder)
- commit 5688792
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu/40xx: Fix missing VPUIP interrupts (drm-backport-placeholder)
- commit 46a2194
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu/40xx: Disable frequency change interrupt (drm-backport-placeholder)
- commit 0c31759
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu/40xx: Ensure clock resource ownership Ack before Power-Up (drm-backport-placeholder)
- commit 825debe
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Add Arrow Lake pci id (drm-backport-placeholder)
- commit 5066621
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu/40xx: Fix buttress interrupt handling (drm-backport-placeholder)
- commit 87d77b6
* Mon Sep  9 2024 jgross@suse.com
- x86/pat: Introduce lookup_address_in_pgd_attr() (bsc#1221527).
- commit 09ca5ca
* Mon Sep  9 2024 pjakobsson@suse.de
- drm/i915/gvt: Drop final dependencies on KVM internal details (drm-backport-placeholder).
- Refresh patches.suse/0566-drm-i915-gvt-remove-unused-to_gvt-and-reduce-include.patch.
- commit 40d8f09
* Mon Sep  9 2024 pjakobsson@suse.de
- clk: Annotate struct clk_hw_onecell_data with __counted_by (drm-backport-placeholder)
- commit 73504c4
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Add initial support for VPU 4 (drm-backport-placeholder)
- commit 66b70a3
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Refactor memory ranges logic (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 357f874
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Switch to generation based FW names (drm-backport-placeholder)
- commit c33f7f9
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Use generation based function and registers names (drm-backport-placeholder)
- commit ea56e2d
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Rename sources to use generation based names (drm-backport-placeholder)
- commit 1fa8cfd
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/qaic: remove redundant pointer pexec (drm-backport-placeholder)
- commit 7c25d6c
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Add fw_name file to debugfs (drm-backport-placeholder)
- commit 890f7b1
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Print firmware name and version (drm-backport-placeholder)
- commit d14887a
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Add debugfs files for testing device reset (drm-backport-placeholder)
- commit 994d046
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Add firmware tracing support (drm-backport-placeholder)
- commit 2afc9cd
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Initial debugfs support (drm-backport-placeholder)
- commit 89efe4b
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Mark 64 kB contiguous areas as contiguous in PTEs (drm-backport-placeholder)
- commit 857f841
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Rename and cleanup MMU600 page tables (drm-backport-placeholder)
- commit 39c8cf5
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Make DMA bit mask HW specific (drm-backport-placeholder)
- commit 134f6b3
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Add MMU support for 4 level page mappings (drm-backport-placeholder)
- commit c21d3f1
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Remove configuration of MMU TBU1 and TBU3 (drm-backport-placeholder)
- commit ace013a
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Use struct_size() (drm-backport-placeholder)
- commit 9163143
* Mon Sep  9 2024 pjakobsson@suse.de
- drm/amdkfd: use vma_is_initial_stack() and vma_is_initial_heap() (drm-backport-placeholder)
- commit 4163224
* Mon Sep  9 2024 pjakobsson@suse.de
- mm: factor out VMA stack and heap checks (drm-backport-placeholder)
- commit eab730c
* Mon Sep  9 2024 nik.borisov@suse.com
- x86/tsc_msr: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit bbbc536
* Mon Sep  9 2024 nik.borisov@suse.com
- tools/power/turbostat: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit cac6e9d
* Mon Sep  9 2024 nik.borisov@suse.com
- Documentation/x86: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit cc064d5
* Mon Sep  9 2024 nik.borisov@suse.com
- peci, hwmon: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 7fef22b
* Mon Sep  9 2024 nik.borisov@suse.com
- media: atomisp: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit de81d9e
* Mon Sep  9 2024 nik.borisov@suse.com
- ACPI: x86: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 3a6f10e
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86/intel/ifs: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 134570d
* Mon Sep  9 2024 nik.borisov@suse.com
- PCI/PM: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit cbdf496
* Mon Sep  9 2024 nik.borisov@suse.com
- thermal: intel: intel_soc_dts_thermal: Switch to new Intel CPU model  defines (jsc#PED-10246,jsc#PED-10350).
- commit 32eefc8
* Mon Sep  9 2024 nik.borisov@suse.com
- powercap: intel_rapl: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit b9580b6
* Mon Sep  9 2024 nik.borisov@suse.com
- powercap: intel_rapl_msr: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit ca14f1d
* Mon Sep  9 2024 nik.borisov@suse.com
- thermal: intel: intel_tcc_cooling: Switch to new Intel CPU model  defines (jsc#PED-10246,jsc#PED-10350).
- commit c8ce5de
* Mon Sep  9 2024 nik.borisov@suse.com
- intel_idle: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 7b2aaa6
* Mon Sep  9 2024 nik.borisov@suse.com
- cpufreq: intel_pstate: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit e12554f
* Mon Sep  9 2024 nik.borisov@suse.com
- cpufreq: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 89a6ffd
* Mon Sep  9 2024 nik.borisov@suse.com
- ACPI: LPSS: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 1669d2e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1373-drm-amd-Disable-ASPM-for-VI-w-all-Intel-systems.patch (drm-backport-placeholder)
- commit 9b53da2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1372-drm-i915-pmu-Check-if-pmu-is-closed-before-stopping-.patch (drm-backport-placeholder)
- commit 413c4bc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1371-drm-i915-mcr-Hold-GT-forcewake-during-steering-opera.patch (drm-backport-placeholder)
- commit cc1ab52
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1370-drm-i915-perf-Determine-context-valid-in-OA-reports.patch (drm-backport-placeholder)
- commit 2f2faeb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1369-drm-logicvc-Kconfig-select-REGMAP-and-REGMAP_MMIO.patch (drm-backport-placeholder)
- commit b6470ad
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1368-drm-amdkfd-reserve-a-fence-slot-while-locking-the-BO.patch (drm-backport-placeholder)
- commit b974cec
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1367-drm-amdgpu-Remove-redundant-call-to-priority_is_vali.patch (drm-backport-placeholder)
- commit dcc4165
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1366-drm-dp_mst-Fix-NULL-deref-in-get_mst_branch_device_b.patch (drm-backport-placeholder)
- commit 61f074a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1365-drm-amdgpu-ignore-duplicate-BOs-again.patch (drm-backport-placeholder)
- commit b94fad1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1364-drm-mediatek-Correctly-free-sg_table-in-gem-prime-vm.patch (drm-backport-placeholder)
- commit e11ca26
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1363-drm-i915-Retry-gtt-fault-when-out-of-fence-registers.patch (drm-backport-placeholder)
- commit 55a2bbd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1362-drm-i915-cx0-Only-clear-set-the-Pipe-Reset-bit-of-th.patch (drm-backport-placeholder)
- commit 28c51c6
* Mon Sep  9 2024 nik.borisov@suse.com
- tpm: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 153217e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1361-gpu-drm-Eliminate-DRM_SCHED_PRIORITY_UNSET.patch (drm-backport-placeholder)
- commit 6bf2051
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1360-drm-amdgpu-Unset-context-priority-is-now-invalid.patch (drm-backport-placeholder)
- commit 9301174
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1359-drm-edid-add-8-bpc-quirk-to-the-BenQ-GW2765.patch (drm-backport-placeholder)
- commit e1edd05
* Mon Sep  9 2024 nik.borisov@suse.com
- KVM: VMX: Switch to new Intel CPU model infrastructure (jsc#PED-10246,jsc#PED-10350).
- commit eb9c8a3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1358-drm-ttm-Reorder-sys-manager-cleanup-step.patch (drm-backport-placeholder)
- commit 48b5379
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1357-drm-nouveau-disp-fix-DP-capable-DSM-connectors.patch (drm-backport-placeholder)
- commit bff79b4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1356-drm-nouveau-exec-fix-ioctl-kernel-doc-warning.patch (drm-backport-placeholder)
- commit 9b07d5b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1355-drm-panel-Move-AUX-B116XW03-out-of-panel-edp-back-to.patch (drm-backport-placeholder)
- commit 4f7a6ed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1354-drm-bridge-ti-sn65dsi86-Associate-DSI-device-lifetim.patch (drm-backport-placeholder)
- commit 7f905cd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1353-drm-amdgpu-Reserve-fences-for-VM-update.patch (drm-backport-placeholder)
- commit ff660a2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1351-fbdev-core-syscopyarea-fix-sloppy-typing.patch (drm-backport-placeholder)
- commit c3cb853
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1350-fbdev-core-cfbcopyarea-fix-sloppy-typing.patch (drm-backport-placeholder)
- commit 5d19887
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1349-fbdev-uvesafb-Call-cn_del_callback-at-the-end-of-uve.patch (drm-backport-placeholder)
- commit 7b0bf51
* Mon Sep  9 2024 nik.borisov@suse.com
- KVM: x86/pmu: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 6947c06
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1348-fbdev-uvesafb-Remove-uvesafb_exec-prototype-from-inc.patch (drm-backport-placeholder)
- commit c553785
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1347-fbdev-sa1100fb-mark-sa1100fb_init-static.patch (drm-backport-placeholder)
- commit aad041f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1346-fbdev-omapfb-fix-some-error-codes.patch (drm-backport-placeholder)
- commit 43ead21
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1345-fbdev-atyfb-only-use-ioremap_uc-on-i386-and-ia64.patch (drm-backport-placeholder)
- commit 3b57ca4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1344-drm-amdgpu-fix-SI-failure-due-to-doorbells-allocatio.patch (drm-backport-placeholder)
- commit 6ff6ffb
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86: intel_scu_wdt: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 0f741cc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1343-drm-amdgpu-add-missing-NULL-check.patch (drm-backport-placeholder)
- commit 4edfbec
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1342-drm-amd-display-Don-t-set-dpms_off-for-seamless-boot.patch (drm-backport-placeholder)
- commit 138bd7c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1341-drm-msm-dpu-fail-dpu_plane_atomic_check-based-on-mdp.patch (drm-backport-placeholder)
- commit 966790c
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86: intel_speed_select_if: Switch to new Intel CPU model  defines (jsc#PED-10246,jsc#PED-10350).
- commit a04d8a1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1340-drm-msm-dp-Add-newlines-to-debug-printks.patch (drm-backport-placeholder)
- commit 73a6703
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1339-drm-msm-dpu-change-_dpu_plane_calc_bw-to-use-u64-to-.patch (drm-backport-placeholder)
- commit d8b61f6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1338-drm-msm-dsi-fix-irq_of_parse_and_map-error-checking.patch (drm-backport-placeholder)
- commit 7aebf3d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1337-drm-msm-dsi-skip-the-wait-for-video-mode-done-if-not.patch (drm-backport-placeholder)
- commit be54b87
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1336-drm-msm-mdss-fix-highest-bank-bit-for-msm8998.patch (drm-backport-placeholder)
- commit 0a1b54d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1335-drm-msm-dp-do-not-reinitialize-phy-unless-retry-duri.patch (drm-backport-placeholder)
- commit 7164e4d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1334-drm-tiny-correctly-print-struct-resource-on-error.patch (drm-backport-placeholder)
- commit 9d4eaaf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1333-drm-atomic-helper-relax-unregistered-connector-check.patch (drm-backport-placeholder)
- commit 405dfe2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1332-drm-panel-boe-tv101wum-nl6-Completely-pull-GPW-to-VG.patch (drm-backport-placeholder)
- commit 2520377
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0001-drm-vmwgfx-Keep-a-gem-reference-to-user-bos-in-surfa.patch (drm-backport-placeholder)
- commit 7c169da
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86: intel-uncore-freq: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 6d966d3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1330-drm-vmwgfx-fix-typo-of-sizeof-argument.patch (drm-backport-placeholder)
- commit b71907e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1329-dma-buf-add-dma_fence_timestamp-helper.patch (drm-backport-placeholder)
- commit 72a9e5f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1328-drm-nouveau-exec-report-max-pushs-through-getparam.patch (drm-backport-placeholder)
- commit 158cf3e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1327-drm-nouveau-chan-use-channel-class-definitions.patch (drm-backport-placeholder)
- commit 8ce7b79
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1326-drm-nouveau-chan-use-struct-nvif_mclass.patch (drm-backport-placeholder)
- commit d7b4fc4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1325-drm-panel-orientation-quirks-Add-quirk-for-One-Mix-2.patch (drm-backport-placeholder)
- commit b2406aa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1324-drm-tests-Fix-kunit_release_action-ctx-argument.patch (drm-backport-placeholder)
- commit 8870625
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1323-drm-amd-display-apply-edge-case-DISPCLK-WDIVIDER-cha.patch (drm-backport-placeholder)
- commit cb73def
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1322-drm-amd-Fix-detection-of-_PR3-on-the-PCIe-root-port.patch (drm-backport-placeholder)
- commit cab59c8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1321-drm-amd-Fix-logic-error-in-sienna_cichlid_update_pci.patch (drm-backport-placeholder)
- commit 7083b49
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1320-drm-amdgpu-Fix-a-memory-leak.patch (drm-backport-placeholder)
- commit 64d7348
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1319-drm-amd-pm-add-unique_id-for-gc-11.0.3.patch (drm-backport-placeholder)
- commit 72c746f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1318-drm-i915-Invalidate-the-TLBs-on-each-GT.patch (drm-backport-placeholder)
- commit af8b7f7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1317-drm-i915-Register-engines-early-to-avoid-type-confus.patch (drm-backport-placeholder)
- commit d409c9c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1316-drm-i915-Don-t-set-PIPE_CONTROL_FLUSH_L3-for-aux-inv.patch (drm-backport-placeholder)
- commit 298c303
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1315-i915-guc-Get-runtime-pm-in-busyness-worker-only-if-a.patch (drm-backport-placeholder)
- commit 68a3a4e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1314-drm-i915-gt-Fix-reservation-address-in-ggtt_reserve_.patch (drm-backport-placeholder)
- commit 6851ff4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1313-drm-amdkfd-Use-gpu_offset-for-user-queue-s-wptr.patch (drm-backport-placeholder)
- commit 97beeee
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-the-ability-to-use-lower-resolut.patch (drm-backport-placeholder)
- commit 5de1824
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1311-drm-amdgpu-fix-a-memory-leak-in-amdgpu_ras_feature_e.patch (drm-backport-placeholder)
- commit 4110332
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1310-Revert-drm-amdgpu-Report-vbios-version-instead-of-PN.patch (drm-backport-placeholder)
- commit 3dca1ff
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1309-drm-amd-display-Fix-MST-recognizes-connected-display.patch (drm-backport-placeholder)
- commit 7f098ab
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/i915-pmu-Move-execlist-stats-initialization-to-execl.patch (drm-backport-placeholder)
- commit bb3d876
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1307-drm-i915-gt-Prevent-error-pointer-dereference.patch (drm-backport-placeholder)
- commit 4f4eb8f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1306-fbdev-sh7760fb-Depend-on-FB-y.patch (drm-backport-placeholder)
- commit 8b1e9ec
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-virtio-clean-out_fence-on-complete_submit.patch (drm-backport-placeholder)
- commit 9293fe5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-meson-fix-memory-leak-on-hpd_notify-callback.patch (drm-backport-placeholder)
- commit 9a50bc2
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86: intel_ips: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 3ed03cd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1303-nouveau-u_memcpya-fix-NULL-vs-error-pointer-bug.patch (drm-backport-placeholder)
- commit 83c6407
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1302-nouveau-u_memcpya-use-vmemdup_user.patch (drm-backport-placeholder)
- commit 4fc4169
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1301-drm-nouveau-sched-fix-leaking-memory-of-timedout-job.patch (drm-backport-placeholder)
- commit f8a51fa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1300-drm-nouveau-fence-fix-type-cast-warning-in-nouveau_f.patch (drm-backport-placeholder)
- commit 89da4cf
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86: intel_turbo_max_3: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 5a7c76a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1299-drm-fix-up-fbdev-Kconfig-defaults.patch (drm-backport-placeholder)
- commit d18d43b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-tests-Fix-incorrect-argument-in-drm_test_mm_inse.patch (drm-backport-placeholder)
- commit cb51ae8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-tests-helpers-Avoid-a-driver-uaf.patch (drm-backport-placeholder)
- commit 8a6f77e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1296-Revert-drm-vkms-Fix-race-condition-between-the-hrtim.patch (drm-backport-placeholder)
- commit 581dd19
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86: p2sb: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 5bf30af
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-make-fence-wait-in-suballocator-uninterrr.patch (drm-backport-placeholder)
- commit 7ec8d6c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Only-check-eDP-HPD-when-AUX-CH-is-shared.patch (drm-backport-placeholder)
- commit 8bbc3d8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1293-drm-amdkfd-Insert-missing-TLB-flush-on-GFX10-and-lat.patch (drm-backport-placeholder)
- commit 0dc8333
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1292-drm-amd-display-Fix-2nd-DPIA-encoder-Assignment.patch (drm-backport-placeholder)
- commit fbd9db4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1291-drm-amd-display-Add-DPIA-Link-Encoder-Assignment-Fix.patch (drm-backport-placeholder)
- commit 8a0ef27
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1290-drm-amd-display-fix-replay_mode-kernel-doc-warning.patch (drm-backport-placeholder)
- commit d72d34c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1289-drm-amdgpu-Handle-null-atom-context-in-VBIOS-info-io.patch (drm-backport-placeholder)
- commit aede40b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1288-drm-amdkfd-Checkpoint-and-restore-queues-on-GFX11.patch (drm-backport-placeholder)
- commit b4116c0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1287-drm-amd-display-Adjust-the-MST-resume-flow.patch (drm-backport-placeholder)
- commit 716e403
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1286-drm-amdgpu-fallback-to-old-RAS-error-message-for-aqu.patch (drm-backport-placeholder)
- commit bfd74a6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1285-drm-amdgpu-nbio4.3-set-proper-rmmio_remap.reg_offset.patch (drm-backport-placeholder)
- commit 625c9f1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1284-drm-amdgpu-soc21-don-t-remap-HDP-registers-for-SR-IO.patch (drm-backport-placeholder)
- commit c4c8940
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1283-drm-amd-display-Don-t-check-registers-if-using-AUX-B.patch (drm-backport-placeholder)
- commit 98777e6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1282-drm-amdgpu-fix-retry-loop-test.patch (drm-backport-placeholder)
- commit 842edb1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1281-drm-amd-display-Add-dirty-rect-support-for-Replay.patch (drm-backport-placeholder)
- commit f32b64f
* Mon Sep  9 2024 nik.borisov@suse.com
- x86/platform/atom: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 90cf751
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1280-Revert-drm-amd-Disable-S-G-for-APUs-when-64GB-or-mor.patch (drm-backport-placeholder)
- commit 1e62f43
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-the-white-screen-issue-when-64GB.patch (drm-backport-placeholder)
- commit a07ec01
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1278-drm-amdkfd-Update-CU-masking-for-GFX-9.4.3.patch (drm-backport-placeholder)
- commit e3f3bf0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1277-drm-amdkfd-Update-cache-info-reporting-for-GFX-v9.4..patch (drm-backport-placeholder)
- commit 390994d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1276-drm-amdgpu-Store-CU-info-from-all-XCCs-for-GFX-v9.4..patch (drm-backport-placeholder)
- commit 13866f1
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86: intel_telemetry: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit d3d4006
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1275-drm-amdkfd-Fix-unaligned-64-bit-doorbell-warning.patch (drm-backport-placeholder)
- commit a4fb78e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1274-drm-amdkfd-Fix-reg-offset-for-setting-CWSR-grace-per.patch (drm-backport-placeholder)
- commit 7f62bd1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-gm12u320-Fix-the-timeout-usage-for-usb_bulk_msg.patch (drm-backport-placeholder)
- commit c177b9b
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86/intel/pmc: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 50e924b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Make-fence-wait-in-suballocator-uninterrupti.patch (drm-backport-placeholder)
- commit 442b0e2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1271-drm-drm_connector-Provide-short-description-of-param.patch (drm-backport-placeholder)
- commit c13de16
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1270-drm-drm_exec-Work-around-a-WW-mutex-lockdep-oddity.patch (drm-backport-placeholder)
- commit dfae0da
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1269-drm-ci-docs-fix-build-warning-add-missing-escape.patch (drm-backport-placeholder)
- commit a62683e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1268-drm-Add-initial-ci-subdirectory.patch (drm-backport-placeholder)
- commit 6ae2380
* Mon Sep  9 2024 nik.borisov@suse.com
- crypto: x86/poly1305 - Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 0977105
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1267-drm-amdgpu-Restrict-bootloader-wait-to-SMUv13.0.6.patch (drm-backport-placeholder)
- commit 19100ee
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-prevent-potential-division-by-zero-e.patch (drm-backport-placeholder)
- commit f6440ae
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-enable-cursor-degamma-for-DCN3-DRM-l.patch (drm-backport-placeholder)
- commit 9362b42
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1264-drm-amd-display-limit-the-v_startup-workaround-to-AS.patch (drm-backport-placeholder)
- commit 04c91c2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amd-display-Remove-v_startup-workaround-f.patch (drm-backport-placeholder)
- commit 4cdceb1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1262-drm-amdgpu-fix-amdgpu_cs_p1_user_fence.patch (drm-backport-placeholder)
- commit 91ea284
* Mon Sep  9 2024 nik.borisov@suse.com
- crypto: x86/twofish - Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit aefad1a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1261-Revert-Revert-drm-amd-display-Implement-zpos-propert.patch (drm-backport-placeholder)
- commit 2d2701c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1260-drm-amdkfd-Add-missing-gfx11-MQD-manager-callbacks.patch (drm-backport-placeholder)
- commit a0065aa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1259-drm-amdgpu-Free-ras-cmd-input-buffer-properly.patch (drm-backport-placeholder)
- commit cca3134
* Mon Sep  9 2024 nik.borisov@suse.com
- ASoC: Intel: avs: es8336: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit e8181fb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1258-drm-amdgpu-Hide-xcp-partition-sysfs-under-SRIOV.patch (drm-backport-placeholder)
- commit 5a75596
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1257-drm-amdgpu-use-read-modify-write-mode-for-gfx-v9_4_3.patch (drm-backport-placeholder)
- commit 2135367
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1256-drm-amdkfd-use-mask-to-get-v9-interrupt-sq-data-bits.patch (drm-backport-placeholder)
- commit 73117b1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1255-drm-amdgpu-Allocate-coredump-memory-in-a-nonblocking.patch (drm-backport-placeholder)
- commit ce187e3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1254-drm-amdgpu-Support-query-ecc-cap-for-aqua_vanjaram.patch (drm-backport-placeholder)
- commit 870b1d3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1253-drm-amdgpu-Add-umc_info-v4_0-structure.patch (drm-backport-placeholder)
- commit d928f04
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-always-switch-off-ODM-before-committ.patch (drm-backport-placeholder)
- commit a0f94ea
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Remove-wait-while-locked.patch (drm-backport-placeholder)
- commit 1b13939
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1250-drm-amd-display-update-blank-state-on-ODM-changes.patch (drm-backport-placeholder)
- commit 0ecafeb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-smu-write-msg-id-fail-retry-proc.patch (drm-backport-placeholder)
- commit ad1cdc1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1248-drm-amdgpu-Add-SMU-v13.0.6-default-reset-methods.patch (drm-backport-placeholder)
- commit ee9cecf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1247-Partially-revert-drm-amd-display-update-add-plane-to.patch (drm-backport-placeholder)
- commit ded2897
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-register-edp_backlight_control-for-D.patch (drm-backport-placeholder)
- commit e1cef22
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1245-drm-amdgpu-Add-bootloader-wait-for-PSP-v13.patch (drm-backport-placeholder)
- commit b348a02
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1244-drm-amdgpu-register-a-dirty-framebuffer-callback-for.patch (drm-backport-placeholder)
- commit adb201f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1243-drm-amdgpu-Updated-TCP-UTCL1-programming.patch (drm-backport-placeholder)
- commit d59d0c2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1242-drm-amd-pm-fix-debugfs-pm_info-output.patch (drm-backport-placeholder)
- commit 039be93
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1241-drm-amdgpu-Fix-the-return-for-gpu-mode1_reset.patch (drm-backport-placeholder)
- commit 2eaf1a4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1240-drm-amd-display-fix-static-screen-detection-setting.patch (drm-backport-placeholder)
- commit 1f10bad
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-mode-scaling-RMX_.patch (drm-backport-placeholder)
- commit 25be854
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1238-drm-amd-pm-Fix-critical-temp-unit-of-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit 28bde79
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1237-drm-amdgpu-Remove-SRAM-clock-gater-override-by-drive.patch (drm-backport-placeholder)
- commit ff52f33
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1236-drm-amdgpu-Add-bootloader-status-check.patch (drm-backport-placeholder)
- commit e18cec0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1235-drm-amdkfd-use-correct-method-to-get-clock-under-SRI.patch (drm-backport-placeholder)
- commit 59b1fb5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1234-drm-amdgpu-Unset-baco-dummy-mode-on-nbio-v7.9.patch (drm-backport-placeholder)
- commit c7aef6a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1233-drm-amd-display-set-minimum-of-VBlank_nom.patch (drm-backport-placeholder)
- commit e5af6b6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1232-drm-amd-display-Correct-unit-conversion-for-vstartup.patch (drm-backport-placeholder)
- commit 0e89681
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1231-drm-amd-display-Roll-back-unit-correction.patch (drm-backport-placeholder)
- commit 0c7b575
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1230-drm-amdgpu-Enable-ras-for-mp0-v13_0_6-sriov.patch (drm-backport-placeholder)
- commit 967163d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1229-drm-amdkfd-retry-after-EBUSY-is-returned-from-hmm_ra.patch (drm-backport-placeholder)
- commit 83c62bc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1228-drm-amdgpu-jpeg-skip-change-of-power-gating-state-fo.patch (drm-backport-placeholder)
- commit d5ce212
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1227-drm-amd-pm-Add-critical-temp-for-GC-v9.4.3.patch (drm-backport-placeholder)
- commit 4bc24ac
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1226-drm-amd-pm-Update-SMUv13.0.6-PMFW-headers.patch (drm-backport-placeholder)
- commit b08c2cf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1225-drm-amdgpu-update-gc_info-v2_1-from-discovery.patch (drm-backport-placeholder)
- commit 29300aa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1224-drm-amdgpu-update-mall-info-v2-from-discovery.patch (drm-backport-placeholder)
- commit 2e6016f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1223-drm-amdgpu-Only-support-RAS-EEPROM-on-dGPU-platform.patch (drm-backport-placeholder)
- commit b9bf33d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1222-Documentation-gpu-Update-amdgpu-documentation.patch (drm-backport-placeholder)
- commit 70056d2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1221-drm-amdgpu-pm-Add-notification-for-no-DC-support.patch (drm-backport-placeholder)
- commit 4e13ab1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1220-drm-amd-display-Enable-Replay-for-static-screen-use-.patch (drm-backport-placeholder)
- commit 56d22cb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mark-requests-for-GuC-virtual-engines-to-av.patch (drm-backport-placeholder)
- commit 9c892c5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1218-drm-nouveau-fence-fix-undefined-fence-state-after-em.patch (drm-backport-placeholder)
- commit 1628e73
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/accel-ivpu-refactor-deprecated-strncpy.patch (drm-backport-placeholder)
- commit c506064
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-Protect-gfn-hash-table-with-vgpu_lock.patch (drm-backport-placeholder)
- commit 56f1767
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-Drop-unused-helper-intel_vgpu_reset_gtt.patch (drm-backport-placeholder)
- commit 598b396
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-Don-t-rely-on-KVM-s-gfn_to_pfn-to-query.patch (drm-backport-placeholder)
- commit 5cd2916
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-Error-out-on-an-attempt-to-shadowing-an.patch (drm-backport-placeholder)
- commit 25c3702
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-Explicitly-check-that-vGPU-is-attached-.patch (drm-backport-placeholder)
- commit bf052e6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-Put-the-page-reference-obtained-by-KVM-.patch (drm-backport-placeholder)
- commit 3914b4b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-Verify-hugepages-are-contiguous-in-phys.patch (drm-backport-placeholder)
- commit e3c6f1b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-remove-interface-intel_gvt_is_valid_gfn.patch (drm-backport-placeholder)
- commit 1724f5b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-Verify-pfn-is-valid-before-dereferencin.patch (drm-backport-placeholder)
- commit 11b3b91
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1205-backlight-led_bl-Remove-redundant-of_match_ptr.patch (drm-backport-placeholder)
- commit d2c6349
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1204-backlight-lp855x-Drop-ret-variable-in-brightness-cha.patch (drm-backport-placeholder)
- commit 096ede3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/backlight-gpio_backlight-Drop-output-GPIO-direction-.patch (drm-backport-placeholder)
- commit 3c65d96
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1202-backlight-lp855x-Catch-errors-when-changing-brightne.patch (drm-backport-placeholder)
- commit 68f2b64
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/backlight-lp855x-Initialize-PWM-state-on-first-brigh.patch (drm-backport-placeholder)
- commit 617d59e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1200-backlight-qcom-wled-Explicitly-include-correct-DT-in.patch (drm-backport-placeholder)
- commit 39133ad
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1199-fbdev-g364fb-fix-build-failure-with-mips.patch (drm-backport-placeholder)
- commit e2d2d9c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-Update-fbdev-source-file-paths.patch (drm-backport-placeholder)
- commit 3a9b567
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1197-fbdev-ssd1307fb-Use-bool-for-ssd1307fb_deviceinfo-fl.patch (drm-backport-placeholder)
- commit 053597d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1196-fbdev-neofb-Shorten-Neomagic-product-name-in-info-st.patch (drm-backport-placeholder)
- commit c7c703e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1195-fbdev-mx3fb-Remove-the-driver.patch (drm-backport-placeholder)
- commit 9677355
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1194-fbdev-core-Use-list_for_each_entry-helper.patch (drm-backport-placeholder)
- commit 9b786d0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1193-mei-make-mei_class-a-static-const-structure.patch (drm-backport-placeholder)
- commit 25e94c1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1192-mei-gsc-add-module-description.patch (drm-backport-placeholder)
- commit 1d4b194
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1191-mei-pxp-Keep-a-const-qualifier-when-calling-mei_clde.patch (drm-backport-placeholder)
- commit 308f277
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1190-mei-obtain-firmware-version-only-on-gsc.patch (drm-backport-placeholder)
- commit 6424faa
* Mon Sep  9 2024 tiwai@suse.de
- drm/amd/display: Replace dm_execute_dmub_cmd with
  dc_wake_and_execute_dmub_cmd (git-fixes).
- commit 6d87705
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1189-mei-bus-enable-asynchronous-suspend.patch (drm-backport-placeholder)
- commit d276bb7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1188-mei-log-firmware-status-on-hw_start-failure.patch (drm-backport-placeholder)
- commit 933ee42
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1187-tty-sysrq-switch-sysrq-handlers-from-int-to-u8.patch (drm-backport-placeholder)
- commit 6fa4c82
* Mon Sep  9 2024 tiwai@suse.de
- wifi: cfg80211: make hash table duplicates more survivable
  (stable-fixes).
- Refresh patches.kabi/wireless-kabi-workaround.patch.
- commit 62f6e12
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1186-PCI-VGA-Fix-typos.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit f4e4bed
* Mon Sep  9 2024 tiwai@suse.de
- VMCI: Fix use-after-free when removing resource in
  vmci_resource_remove() (git-fixes).
- misc: fastrpc: Fix double free of 'buf' in error path
  (git-fixes).
- iio: fix scale application in
  iio_convert_raw_to_processed_unlocked (git-fixes).
- iio: adc: ad7124: fix config comparison (git-fixes).
- iio: adc: ad7124: fix chip ID mismatch (git-fixes).
- iio: buffer-dmaengine: fix releasing dma channel on error
  (git-fixes).
- iio: adc: ad7606: remove frstdata check for serial mode
  (git-fixes).
- staging: iio: frequency: ad9834: Validate frequency parameter
  value (git-fixes).
- usb: dwc3: Avoid waking up gadget during startxfer (git-fixes).
- net: usb: qmi_wwan: add MeiG Smart SRM825L (stable-fixes).
- drm/gpuvm: fix missing dependency to DRM_EXEC (git-fixes).
- drm: panel-orientation-quirks: Add quirk for OrangePi Neo
  (stable-fixes).
- drm/fb-helper: Don't schedule_work() to flush frame buffer
  during panic() (stable-fixes).
- PCI: al: Check IORESOURCE_BUS existence during probe
  (stable-fixes).
- usb: typec: ucsi: Fix null pointer dereference in trace
  (stable-fixes).
- usbip: Don't submit special requests twice (stable-fixes).
- media: uvcvideo: Enforce alignment of frame and interval
  (stable-fixes).
- wifi: ath12k: initialize 'ret' in
  ath12k_dp_rxdma_ring_sel_config_wcn7850() (stable-fixes).
- wifi: ath11k: initialize 'ret' in
  ath11k_qmi_load_file_target_mem() (stable-fixes).
- wifi: ath12k: initialize 'ret' in
  ath12k_qmi_load_file_target_mem() (stable-fixes).
- wifi: rtw89: ser: avoid multiple deinit on same CAM
  (stable-fixes).
- wifi: mac80211: check ieee80211_bss_info_change_notify()
  against MLD (stable-fixes).
- wifi: cfg80211: restrict operation during radar detection
  (stable-fixes).
- pwm: xilinx: Fix u32 overflow issue in 32-bit width PWM mode
  (stable-fixes).
- hwmon: (k10temp) Check return value of amd_smn_read()
  (stable-fixes).
- regmap: spi: Fix potential off-by-one when calculating reserved
  size (stable-fixes).
- commit 73bbd93
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1181-PCI-VGA-Replace-full-MIT-license-text-with-SPDX-iden.patch (drm-backport-placeholder)
- commit c1ec740
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-Use-RMW-accessors-for-changing-LNKCTL.patch (drm-backport-placeholder)
- commit 447cf45
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Use-RMW-accessors-for-changing-LNKCTL.patch (drm-backport-placeholder)
- commit a9642cf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1178-drm-i915-Fix-TLB-Invalidation-seqno-store.patch (drm-backport-placeholder)
- commit 6c5aa73
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1177-drm-gpuva_mgr-remove-unused-prev-pointer-in-__drm_gp.patch (drm-backport-placeholder)
- commit edd069b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1176-drm-tests-drm_kunit_helpers-Place-correct-function-n.patch (drm-backport-placeholder)
- commit 8aeea98
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1175-drm-nouveau-uapi-don-t-pass-NO_PREFETCH-flag-implici.patch (drm-backport-placeholder)
- commit e1b65f7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1174-drm-nouveau-uvmm-fix-unset-region-pointer-on-remap.patch (drm-backport-placeholder)
- commit 83ea442
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1173-drm-nouveau-sched-avoid-job-races-between-entities.patch (drm-backport-placeholder)
- commit 902f181
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1172-drm-ttm-tests-Fix-type-conversion-in-ttm_pool_test.patch (drm-backport-placeholder)
- commit a91bb57
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1171-drm-msm-a6xx-Bail-out-early-if-setting-GPU-OOB-fails.patch (drm-backport-placeholder)
- commit e94232e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1170-drm-msm-a6xx-Move-LLC-accessors-to-the-common-header.patch (drm-backport-placeholder)
- commit c950ec1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1169-drm-msm-a6xx-Introduce-a6xx_llc_read.patch (drm-backport-placeholder)
- commit 646728a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1168-drm-msm-adreno-Add-missing-MODULE_FIRMWARE-macros.patch (drm-backport-placeholder)
- commit 4f8857f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1167-drm-msm-gpu-Push-gpu-lock-down-past-runpm.patch (drm-backport-placeholder)
- commit daf6f71
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a690-Switch-to-a660_gmu.bin.patch (drm-backport-placeholder)
- commit 99cd428
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1165-drm-msm-Remove-vma-use-tracking.patch (drm-backport-placeholder)
- commit 543b279
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1164-drm-msm-Take-lru-lock-once-per-submit_pin_objects.patch (drm-backport-placeholder)
- commit 33500e0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1163-drm-msm-Use-drm_gem_object-in-submit-bos-table.patch (drm-backport-placeholder)
- commit 4ab71c2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1162-drm-msm-Take-lru-lock-once-per-job_run.patch (drm-backport-placeholder)
- commit fb7b5b7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1161-drm-msm-adreno-adreno_gpu-Switch-to-memdup_user_nul-.patch (drm-backport-placeholder)
- commit 9b48b44
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1160-drm-msm-Disallow-relocs-on-a6xx.patch (drm-backport-placeholder)
- commit 3fa1415
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a6xx-Fix-GMU-lockdep-splat.patch (drm-backport-placeholder)
- commit 231416e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a2xx-Call-adreno_gpu_init-earlier.patch (drm-backport-placeholder)
- commit 28ed5fc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1157-drm-msm-a6xx-Fix-up-GMU-region-reservations.patch (drm-backport-placeholder)
- commit 32ef75b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1156-drm-msm-a6xx-Improve-GMU-force-shutdown-sequence.patch (drm-backport-placeholder)
- commit 91e2dcc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1155-drm-msm-a6xx-Ensure-clean-GMU-state-in-a6xx_gmu_fw_s.patch (drm-backport-placeholder)
- commit fec6328
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1154-drm-msm-a6xx-Skip-empty-protection-ranges-entries.patch (drm-backport-placeholder)
- commit 12b4306
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1153-drm-msm-a6xx-Use-descriptive-bitfield-names-for-CP_P.patch (drm-backport-placeholder)
- commit 05e27e2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1152-drm-msm-a6xx-Add-some-missing-header-definitions.patch (drm-backport-placeholder)
- commit 9afd2e3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1151-drm-msm-a6xx-Fix-misleading-comment.patch (drm-backport-placeholder)
- commit a46b46c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1150-drm-msm-adreno-Switch-to-chip-id-for-identifying-GPU.patch (drm-backport-placeholder)
- commit 7dc3b1e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1149-drm-msm-adreno-Move-adreno-info-to-config.patch (drm-backport-placeholder)
- commit d424a51
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1148-drm-msm-adreno-Add-helper-for-formating-chip-id.patch (drm-backport-placeholder)
- commit af38c47
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1147-drm-msm-adreno-Add-adreno-family.patch (drm-backport-placeholder)
- commit 48bede5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1146-drm-msm-adreno-Bring-the-a630-family-together.patch (drm-backport-placeholder)
- commit 82bbd16
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1145-drm-msm-adreno-Move-speedbin-mapping-to-device-table.patch (drm-backport-placeholder)
- commit 8206cbc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1144-drm-msm-adreno-Allow-SoC-specific-gpu-device-table-e.patch (drm-backport-placeholder)
- commit 8680298
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1143-drm-msm-adreno-Use-quirk-to-identify-cached-coherent.patch (drm-backport-placeholder)
- commit 5b3a291
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1142-drm-msm-adreno-Use-quirk-identify-hw_apriv.patch (drm-backport-placeholder)
- commit 8c73a72
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1141-drm-msm-adreno-Remove-redundant-revn-param.patch (drm-backport-placeholder)
- commit 30083e1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1140-drm-msm-adreno-Remove-redundant-gmem-size-param.patch (drm-backport-placeholder)
- commit f85b5aa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1139-drm-msm-adreno-Remove-GPU-name.patch (drm-backport-placeholder)
- commit 61ee3f4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-fix-the-irq-index-in-dpu_encoder_phys_wb.patch (drm-backport-placeholder)
- commit a4c00e1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1137-drm-msm-dpu-initialise-clk_rate-to-0-in-_dpu_core_pe.patch (drm-backport-placeholder)
- commit bbfeaff
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1136-drm-msm-dpu-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 7533493
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-mdp5-Don-t-leak-some-plane-state.patch (drm-backport-placeholder)
- commit 963a004
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1134-drm-msm-dpu-Drop-encoder-vsync_event.patch (drm-backport-placeholder)
- commit 943c0f7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1133-drm-msm-dpu-fix-DSC-1.2-enc-subblock-length.patch (drm-backport-placeholder)
- commit 7dff825
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1132-drm-msm-dpu-fix-DSC-1.2-block-lengths.patch (drm-backport-placeholder)
- commit af644f7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-increase-memtype-count-to-16-for-sm8550.patch (drm-backport-placeholder)
- commit 5477c00
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1130-drm-msm-dpu-drop-dpu_core_perf_destroy.patch (drm-backport-placeholder)
- commit 84a66f4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1129-drm-msm-dpu-move-max-clock-decision-to-dpu_kms.patch (drm-backport-placeholder)
- commit fb91e7f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1128-drm-msm-dpu-remove-extra-clk_round_rate-call.patch (drm-backport-placeholder)
- commit 9540baa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1127-drm-msm-dpu-remove-unused-fields-from-struct-dpu_cor.patch (drm-backport-placeholder)
- commit f7b75e9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1126-drm-msm-dpu-use-dpu_perf_cfg-in-DPU-core_perf-code.patch (drm-backport-placeholder)
- commit 0452580
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1125-drm-msm-dpu-drop-the-dpu_core_perf_crtc_update-s-sto.patch (drm-backport-placeholder)
- commit 098e2f8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1124-drm-msm-dpu-rework-indentation-in-dpu_core_perf.patch (drm-backport-placeholder)
- commit 003549b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1123-drm-msm-dpu-drop-separate-dpu_core_perf_tune-overrid.patch (drm-backport-placeholder)
- commit 45bc2cd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1122-drm-msm-dpu-bail-from-_dpu_core_perf_crtc_update_bus.patch (drm-backport-placeholder)
- commit ee5ea86
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1121-drm-msm-dpu-drop-BWC-features-from-DPU_MDP_foo-names.patch (drm-backport-placeholder)
- commit 99bee9d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1120-drm-msm-dpu-drop-UBWC-configuration.patch (drm-backport-placeholder)
- commit 856caed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1119-drm-msm-dpu-use-MDSS-data-for-programming-SSPP.patch (drm-backport-placeholder)
- commit af73ce9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1118-drm-msm-mdss-populate-missing-data.patch (drm-backport-placeholder)
- commit 33ec412
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1117-drm-msm-mdss-export-UBWC-data.patch (drm-backport-placeholder)
- commit 0de045e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1116-drm-msm-mdss-rename-ubwc_version-to-ubwc_enc_version.patch (drm-backport-placeholder)
- commit 444a0b4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1115-drm-msm-dpu-drop-compatibility-INTR-defines.patch (drm-backport-placeholder)
- commit 3f59aed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1114-drm-msm-dpu-drop-now-unused-mdss_irqs-field-from-hw-.patch (drm-backport-placeholder)
- commit 8148879
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1113-drm-msm-dpu-autodetect-supported-interrupts.patch (drm-backport-placeholder)
- commit b076895
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1112-drm-msm-dpu-split-interrupt-address-arrays.patch (drm-backport-placeholder)
- commit 3d2958c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1111-drm-msm-dpu-inline-__intr_offset.patch (drm-backport-placeholder)
- commit 4d7289f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1110-drm-msm-Remove-redundant-DRM_DEV_ERROR.patch (drm-backport-placeholder)
- commit 2db944c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1109-drm-msm-dsi-Reuse-QCM2290-14nm-DSI-PHY-configuration.patch (drm-backport-placeholder)
- commit 83edcff
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1108-drm-msm-mdss-Add-SM6125-support.patch (drm-backport-placeholder)
- commit 90d92f4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1107-drm-msm-dpu-Add-SM6125-support.patch (drm-backport-placeholder)
- commit b9901a8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1106-drm-msm-dpu-drop-DPU_INTF_DATA_COMPRESS-from-dpu-cat.patch (drm-backport-placeholder)
- commit 1aa489c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1105-drm-msm-dpu-rename-enable_compression-to-program_int.patch (drm-backport-placeholder)
- commit f2bbc7a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1104-drm-msm-dpu-rename-all-hw_intf-structs-to-have-dpu_h.patch (drm-backport-placeholder)
- commit 94f35bb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1103-drm-msm-dpu-use-dpu-core-s-major-version-to-enable-d.patch (drm-backport-placeholder)
- commit 7e62023
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1102-drm-msm-dpu-re-introduce-dpu-core-revision-to-the-ca.patch (drm-backport-placeholder)
- commit ab3ae22
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1101-drm-msm-dsi-Enable-BURST_MODE-for-command-mode-for-D.patch (drm-backport-placeholder)
- commit d2c7b86
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1100-drm-msm-dpu-Update-dev-core-dump-to-dump-registers-o.patch (drm-backport-placeholder)
- commit 87209eb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1099-drm-msm-dpu-Refactor-printing-of-main-blocks-in-devi.patch (drm-backport-placeholder)
- commit ca8c395
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1098-drm-msm-dpu-Remove-redundant-prefix-suffix-in-name-o.patch (drm-backport-placeholder)
- commit f8951f9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1097-drm-msm-dpu-Define-names-for-unnamed-sblks.patch (drm-backport-placeholder)
- commit 660f9d3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1096-drm-msm-dpu-Drop-unused-num-argument-from-relevant-m.patch (drm-backport-placeholder)
- commit 2fa100c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-Update-dev-core-dump-to-not-print-backwards.patch (drm-backport-placeholder)
- commit 8d11890
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1094-drm-msm-dpu-drop-empty-features-mask-INTF_SDM845_MAS.patch (drm-backport-placeholder)
- commit d4fb057
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1093-drm-msm-dpu-drop-empty-features-mask-MERGE_3D_SM8150.patch (drm-backport-placeholder)
- commit 6aabae1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1092-drm-msm-dpu-inline-INTF_BLK-and-INTF_BLK_DSI_TE-macr.patch (drm-backport-placeholder)
- commit 7a0402a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1091-drm-msm-dpu-inline-WB_BLK-macros.patch (drm-backport-placeholder)
- commit f1990c3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1090-drm-msm-dpu-inline-various-PP_BLK_-macros.patch (drm-backport-placeholder)
- commit 5651d5b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1089-drm-msm-dpu-inline-MERGE_3D_BLK-macros.patch (drm-backport-placeholder)
- commit 6b2248d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1088-drm-msm-dpu-inline-DSC_BLK-and-DSC_BLK_1_2-macros.patch (drm-backport-placeholder)
- commit 7655e48
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1087-drm-msm-dpu-inline-LM_BLK-macros.patch (drm-backport-placeholder)
- commit c778ae5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1086-drm-msm-dpu-inline-DSPP_BLK-macros.patch (drm-backport-placeholder)
- commit 66e34de
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1085-drm-msm-dpu-inline-SSPP_BLK-macros.patch (drm-backport-placeholder)
- commit 23b9752
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1084-drm-msm-dpu-correct-indentation-for-CTL-definitions.patch (drm-backport-placeholder)
- commit 12924de
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1083-drm-msm-dpu-drop-zero-features-from-dpu_ctl_cfg-data.patch (drm-backport-placeholder)
- commit 0844ec3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1082-drm-msm-dpu-drop-zero-features-from-dpu_mdp_cfg-data.patch (drm-backport-placeholder)
- commit 7787286
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1081-drm-msm-dpu-expand-.clk_ctrls-definitions.patch (drm-backport-placeholder)
- commit 10bb6a8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1080-drm-msm-dpu-drop-enum-dpu_mdp-and-MDP_TOP-value.patch (drm-backport-placeholder)
- commit 6c42ada
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1079-drm-msm-dpu-drop-dpu_mdss_cfg-mdp_count-field.patch (drm-backport-placeholder)
- commit 35de06a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1078-drm-msm-dpu-simplify-peer-LM-handling.patch (drm-backport-placeholder)
- commit a99fcbb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1077-drm-msm-dpu-always-use-MSM_DP-DSI_CONTROLLER_n.patch (drm-backport-placeholder)
- commit a2d3309
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1076-drm-msm-enumerate-DSI-interfaces.patch (drm-backport-placeholder)
- commit b4a0b10
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1075-drm-msm-dsi-Hook-up-refgen-regulator.patch (drm-backport-placeholder)
- commit f73f361
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1074-drm-msm-dpu-remove-struct-drm_dsc_config-from-struct.patch (drm-backport-placeholder)
- commit cf4debe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1073-drm-msm-dpu-retrieve-DSI-DSC-struct-through-priv-dsi.patch (drm-backport-placeholder)
- commit 024eef1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1072-drm-msm-stop-storing-the-array-of-CRTCs-in-struct-ms.patch (drm-backport-placeholder)
- commit 70d706a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1071-drm-msm-dpu1-Rename-sm8150_dspp_blk-to-sdm845_dspp_b.patch (drm-backport-placeholder)
- commit 15bf96f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1070-drm-amdgpu-Add-memory-vendor-information.patch (drm-backport-placeholder)
- commit 9d48c46
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1069-drm-amdgpu-Remove-gfxoff-check-in-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit 8c937df
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1068-drm-amd-pm-Update-pci-link-speed-for-smu-v13.0.6.patch (drm-backport-placeholder)
- commit 9bc4d7d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1067-drm-amd-pm-allow-the-user-to-force-BACO-on-smu-v13.0.patch (drm-backport-placeholder)
- commit 708403a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1066-drm-amdgpu-vcn-Skip-vcn-power-gating-change-for-srio.patch (drm-backport-placeholder)
- commit f5db22a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1065-drm-amd-display-Handle-Replay-related-hpd-irq.patch (drm-backport-placeholder)
- commit df6ce97
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1064-drm-amdgpu-jpeg-sriov-support-for-jpeg_v4_0_3.patch (drm-backport-placeholder)
- commit 7fd56cb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1063-drm-amd-display-Update-adaptive-sync-infopackets-for.patch (drm-backport-placeholder)
- commit 26b8049
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1062-drm-amd-display-Promote-DAL-to-3.2.247.patch (drm-backport-placeholder)
- commit 1e9fdc8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1061-drm-amd-display-FW-Promotion-Release-0.0.179.0.patch (drm-backport-placeholder)
- commit 44fe689
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1060-drm-amdgpu-Replace-ternary-operator-with-min-in-amdg.patch (drm-backport-placeholder)
- commit 6a301bb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1059-drm-amd-display-Replace-ternary-operator-with-min-in.patch (drm-backport-placeholder)
- commit 6937640
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1058-drm-amd-Hide-unsupported-power-attributes.patch (drm-backport-placeholder)
- commit b9e3ff5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1057-drm-amd-Rename-AMDGPU_PP_SENSOR_GPU_POWER.patch (drm-backport-placeholder)
- commit 6ba9eb2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1056-drm-amd-Show-both-power-attributes-for-vega20.patch (drm-backport-placeholder)
- commit 20332c5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1055-drm-amd-Fix-the-return-for-average-power-on-aldebara.patch (drm-backport-placeholder)
- commit a0972b8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1054-drm-amd-Drop-unnecessary-helper-for-aldebaran.patch (drm-backport-placeholder)
- commit b3428fd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1053-drm-amd-Fix-SMU-13.0.4-13.0.11-GPU-metrics-average-p.patch (drm-backport-placeholder)
- commit ed03a66
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1052-drm-radeon-Use-pci_dev_id-to-simplify-the-code.patch (drm-backport-placeholder)
- commit 0df0536
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1051-drm-amdgpu-Remove-duplicated-includes.patch (drm-backport-placeholder)
- commit 83c0fca
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1050-drm-amd-pm-Clean-up-errors-in-amdgpu_smu.h.patch (drm-backport-placeholder)
- commit 5b711fd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1049-drm-amd-display-enable-low-power-mode-for-VGA-memory.patch (drm-backport-placeholder)
- commit 1ae7235
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1048-drm-amd-pm-Clean-up-errors-in-smu_v11_0_pptable.h.patch (drm-backport-placeholder)
- commit 3f4af9f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1047-drm-amdgpu-expand-runpm-parameter.patch (drm-backport-placeholder)
- commit 5431262
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1046-drm-amd-Introduce-AMDGPU_PP_SENSOR_GPU_INPUT_POWER.patch (drm-backport-placeholder)
- commit 34fddfb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1045-drm-amd-Remove-freesync-video-mode-amdgpu-parameter.patch (drm-backport-placeholder)
- commit 6bf6ed6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1044-drm-amd-Add-a-new-hwmon-attribute-for-instantaneous-.patch (drm-backport-placeholder)
- commit 39cdb9a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1043-drm-amdgpu-vcn-sriov-support-for-vcn_v4_0_3.patch (drm-backport-placeholder)
- commit 1b7132c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1042-drm-amdgpu-Replace-ternary-operator-with-min-in-amdg.patch (drm-backport-placeholder)
- commit 9e7e091
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1041-drm-amd-display-Add-some-missing-register-definition.patch (drm-backport-placeholder)
- commit 6372820
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1040-drm-amd-display-avoid-crash-and-add-z8_marks-related.patch (drm-backport-placeholder)
- commit 2b01ffb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1039-drm-amd-display-implement-pipe-type-definition-and-a.patch (drm-backport-placeholder)
- commit b2ae4a1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1038-drm-amd-display-Enable-8k60hz-mode-on-single-display.patch (drm-backport-placeholder)
- commit 73d9888
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1037-drm-amd-display-fix-incorrect-stream_res-allocation-.patch (drm-backport-placeholder)
- commit 1a2148d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1036-drm-amd-display-Gamut-remap-only-changes-missed.patch (drm-backport-placeholder)
- commit 8044833
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1035-drm-amd-display-PMFW-to-wait-for-DMCUB-ack-for-FPO-c.patch (drm-backport-placeholder)
- commit d560528
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1034-drm-amd-display-Enable-subvp-high-refresh-up-to-175h.patch (drm-backport-placeholder)
- commit 41fe710
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1033-drm-amdgpu-vcn-change-end-doorbell-index-for-vcn_v4_.patch (drm-backport-placeholder)
- commit 54c3435
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1032-drm-amdkfd-workaround-address-watch-clearing-bug-for.patch (drm-backport-placeholder)
- commit 5b2bd11
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1031-drm-amd-display-disable-clock-gating-logic-reversed-.patch (drm-backport-placeholder)
- commit 4160b86
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1030-drm-amd-display-Support-Compliance-Test-Pattern-Gene.patch (drm-backport-placeholder)
- commit 13565a8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1029-drm-amdgpu-jpeg-mmsch_v4_0_3-requires-doorbell-on-32.patch (drm-backport-placeholder)
- commit c3ee981
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1028-drm-radeon-Remove-unnecessary-NULL-values.patch (drm-backport-placeholder)
- commit 19a4b74
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1027-drm-amd-display-Remove-unnecessary-NULL-values.patch (drm-backport-placeholder)
- commit cf4ee39
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1026-drm-amdgpu-vcn-mmsch_v4_0_3-requires-doorbell-on-32-.patch (drm-backport-placeholder)
- commit 3f8132b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1025-drm-amdkfd-Remove-unnecessary-NULL-values.patch (drm-backport-placeholder)
- commit d81a2cc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1024-drm-amd-display-dmub_replay-don-t-use-kernel-doc-mar.patch (drm-backport-placeholder)
- commit f40e79f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1023-drm-amd-Add-amdgpu_hwmon_get_sensor_generic.patch (drm-backport-placeholder)
- commit a1e36a0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1022-drm-amdgpu-vcn-Add-MMSCH-v4_0_3-support-for-sriov.patch (drm-backport-placeholder)
- commit 30479ba
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1021-drm-amdgpu-Add-I2C-EEPROM-support-on-smu-v13_0_6.patch (drm-backport-placeholder)
- commit 876a7ba
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1020-drm-amd-pm-bump-SMU-v13.0.5-driver_if-header-version.patch (drm-backport-placeholder)
- commit f540534
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1019-drm-amd-pm-correct-the-logics-for-retreiving-SMU13-O.patch (drm-backport-placeholder)
- commit a1d6343
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1018-drm-amd-pm-correct-the-way-for-checking-custom-OD-se.patch (drm-backport-placeholder)
- commit a9b9658
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1017-drm-amd-Use-pci_dev_id-to-simplify-the-code.patch (drm-backport-placeholder)
- commit fa782d1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1016-drm-amdkfd-fix-double-assign-skip-process-context-cl.patch (drm-backport-placeholder)
- commit 3e13ebe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1015-drm-amd-display-Update-replay-for-clk_mgr-optimizati.patch (drm-backport-placeholder)
- commit b9920c1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1014-drm-amdgpu-Fix-identifier-names-to-function-definiti.patch (drm-backport-placeholder)
- commit 2208d1e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1013-drm-amdgpu-mode1-reset-needs-to-recover-mp1-for-mp0-.patch (drm-backport-placeholder)
- commit 8209478
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1012-drm-amd-pm-avoid-driver-getting-empty-metrics-table-.patch (drm-backport-placeholder)
- commit 4d24b42
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1011-drm-amdkfd-Use-memdup_user-rather-than-duplicating-i.patch (drm-backport-placeholder)
- commit e5f2e22
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1010-drm-amdgpu-Remove-unnecessary-ras-cap-check.patch (drm-backport-placeholder)
- commit 70af3d2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1009-drm-amdkfd-fix-build-failure-without-CONFIG_DYNAMIC_.patch (drm-backport-placeholder)
- commit af7fa8f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1008-drm-radeon-Fix-multiple-line-dereference-in-atom_iio.patch (drm-backport-placeholder)
- commit b79ce2f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1007-drm-amd-pm-Add-vclk-and-dclk-sysnode-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit ffa506c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1006-drm-amdkfd-Add-missing-tba_hi-programming-on-aldebar.patch (drm-backport-placeholder)
- commit 8971d9b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1005-drm-amdgpu-Fix-missing-comment-for-mb-in-amdgpu_devi.patch (drm-backport-placeholder)
- commit ecc9e26
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1004-drm-amd-display-Add-Replay-supported-enabled-checks.patch (drm-backport-placeholder)
- commit aa3b056
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1003-drm-ttm-tests-Require-MMU-when-testing.patch (drm-backport-placeholder)
- commit f0e7cef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1002-drm-panel-simple-Fix-Innolux-G156HCE-L01-LVDS-clock.patch (drm-backport-placeholder)
- commit ca1b506
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1001-drm-etnaviv-fix-error-code-in-event_alloc.patch (drm-backport-placeholder)
- commit ef0c599
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1000-drm-etnaviv-expedited-MMU-fault-handling.patch (drm-backport-placeholder)
- commit aca1c61
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0999-drm-etnaviv-drop-GPU-initialized-property.patch (drm-backport-placeholder)
- commit e41b436
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0998-drm-etnaviv-better-track-GPU-state.patch (drm-backport-placeholder)
- commit 13a4d10
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0997-drm-etnaviv-avoid-runtime-PM-usage-in-etnaviv_gpu_bi.patch (drm-backport-placeholder)
- commit d9e067d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0996-drm-etnaviv-make-clock-handling-symetric-between-run.patch (drm-backport-placeholder)
- commit c02f12e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0995-drm-etnaviv-move-runtime-PM-handling-to-events.patch (drm-backport-placeholder)
- commit 4be1786
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0994-drm-etnaviv-free-events-the-usual-way-in-recover-wor.patch (drm-backport-placeholder)
- commit add0c86
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0993-drm-etnaviv-move-down-etnaviv_gpu_recover_hang-in-fi.patch (drm-backport-placeholder)
- commit 1a75b21
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0992-drm-etnaviv-add-HWDB-entry-for-GC520-r5341-c204.patch (drm-backport-placeholder)
- commit 8aa86bc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0991-drm-etnaviv-add-HWDB-entry-for-VIP8000-Nano-r8002.patch (drm-backport-placeholder)
- commit 051e093
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-etnaviv-fix-dumping-of-active-MMU-context.patch (drm-backport-placeholder)
- commit ce39579
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0989-drm-etnaviv-slow-down-FE-idle-polling.patch (drm-backport-placeholder)
- commit 494aaf7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0988-drm-etnaviv-Replace-of_platform.h-with-explicit-incl.patch (drm-backport-placeholder)
- commit 626d238
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0987-drm-amdgpu-don-t-allow-userspace-to-create-a-doorbel.patch (drm-backport-placeholder)
- commit ad3253d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0986-drm-amdkfd-rename-device_queue_manager_init_v10_navi.patch (drm-backport-placeholder)
- commit 955ab22
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0985-drm-amdkfd-drop-IOMMUv2-support.patch (drm-backport-placeholder)
- commit 2ca405d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0984-drm-amdgpu-Use-local64_try_cmpxchg-in-amdgpu_perf_re.patch (drm-backport-placeholder)
- commit b8447fe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0983-drm-amdgpu-Add-pci-usage-to-nbio-v7.9.patch (drm-backport-placeholder)
- commit 1c6025e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0982-drm-amdgpu-Add-pcie-usage-callback-to-nbio.patch (drm-backport-placeholder)
- commit 3f89501
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0981-drm-amdgpu-Extend-poison-mode-check-to-SDMA-VCN-JPEG.patch (drm-backport-placeholder)
- commit cfa8775
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0980-drm-buddy-Fix-drm-buddy-info-output-format.patch (drm-backport-placeholder)
- commit c24933a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0979-drm-amdgpu-irq-Move-irq-resume-to-the-beginning.patch (drm-backport-placeholder)
- commit 91dc641
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0978-drm-amdgpu-add-RAS-fatal-error-handler-for-NBIO-v7.9.patch (drm-backport-placeholder)
- commit 0d57d45
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0977-drm-amdgpu-Fix-identation-issues-in-kgd_gfx_v9_progr.patch (drm-backport-placeholder)
- commit 3542c55
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0976-drm-amd-display-Get-replay-info-from-VSDB.patch (drm-backport-placeholder)
- commit 60285cf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0975-drm-amdgpu-Add-FRU-sysfs-nodes-only-if-needed.patch (drm-backport-placeholder)
- commit 03fd80d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0974-drm-amd-pm-Clean-up-errors-in-smu73_discrete.h.patch (drm-backport-placeholder)
- commit a070da6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0973-drm-amdgpu-Clean-up-errors-in-vcn_v3_0.c.patch (drm-backport-placeholder)
- commit 472e031
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0972-drm-amdgpu-Clean-up-errors-in-tonga_ih.c.patch (drm-backport-placeholder)
- commit 5a0bfdf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0971-drm-amdgpu-Clean-up-errors-in-gfx_v7_0.c.patch (drm-backport-placeholder)
- commit 41866e6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0970-drm-amdgpu-Clean-up-errors-in-vcn_v4_0.c.patch (drm-backport-placeholder)
- commit 5400f96
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0969-drm-amdgpu-Clean-up-errors-in-uvd_v3_1.c.patch (drm-backport-placeholder)
- commit 7f87eb0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0968-drm-amdgpu-Clean-up-errors-in-mxgpu_vi.c.patch (drm-backport-placeholder)
- commit 83545e3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0967-drm-amdgpu-Clean-up-errors-in-nv.c.patch (drm-backport-placeholder)
- commit 6890789
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0966-drm-amdgpu-Clean-up-errors-in-amdgpu_virt.c.patch (drm-backport-placeholder)
- commit 9ca2070
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0965-drm-amdgpu-Clean-up-errors-in-amdgpu_ring.h.patch (drm-backport-placeholder)
- commit aef4dd6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0964-drm-amdgpu-Clean-up-errors-in-amdgpu_trace.h.patch (drm-backport-placeholder)
- commit 5db2631
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0963-drm-amdgpu-Clean-up-errors-in-mes_v11_0.c.patch (drm-backport-placeholder)
- commit 07dac1d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0962-drm-amdgpu-Clean-up-errors-in-amdgpu_atombios.h.patch (drm-backport-placeholder)
- commit 2061b3c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0961-drm-amdgpu-Clean-up-errors-in-soc21.c.patch (drm-backport-placeholder)
- commit d247801
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0960-drm-amdgpu-Clean-up-errors-in-dce_v8_0.c.patch (drm-backport-placeholder)
- commit 67b2a93
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0959-drm-amdgpu-jpeg-Clean-up-errors-in-vcn_v1_0.c.patch (drm-backport-placeholder)
- commit 0635b12
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0958-drm-amdgpu-Clean-up-errors-in-mxgpu_nv.c.patch (drm-backport-placeholder)
- commit a793ce1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0957-drm-amdgpu-Clean-up-errors-in-dce_v10_0.c.patch (drm-backport-placeholder)
- commit 2911290
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0956-drm-jpeg-Clean-up-errors-in-jpeg_v2_0.c.patch (drm-backport-placeholder)
- commit dff9791
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0955-drm-amdgpu-Clean-up-errors-in-uvd_v7_0.c.patch (drm-backport-placeholder)
- commit 2ad7755
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0954-drm-amdgpu-atomfirmware-Clean-up-errors-in-amdgpu_at.patch (drm-backport-placeholder)
- commit cfea29b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0953-drm-amdgpu-Clean-up-errors-in-mmhub_v9_4.c.patch (drm-backport-placeholder)
- commit a492d85
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0952-drm-amdgpu-Clean-up-errors-in-vega20_ih.c.patch (drm-backport-placeholder)
- commit 20f0a89
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0951-drm-amdgpu-Clean-up-errors-in-ih_v6_0.c.patch (drm-backport-placeholder)
- commit 8d848ee
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0950-drm-amdgpu-Clean-up-errors-in-amdgpu_psp.h.patch (drm-backport-placeholder)
- commit 31540df
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0949-drm-amdgpu-Clean-up-errors-in-vce_v3_0.c.patch (drm-backport-placeholder)
- commit d0ed6ef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0948-drm-amdgpu-Clean-up-errors-in-cik_ih.c.patch (drm-backport-placeholder)
- commit 6141cb1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0947-drm-amd-display-Clean-up-errors-in-dce_clk_mgr.c.patch (drm-backport-placeholder)
- commit 6b7a9af
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0946-drm-amd-display-Clean-up-errors-in-display_mode_vba_.patch (drm-backport-placeholder)
- commit bfc7101
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0945-drm-amd-display-Clean-up-errors-in-dcn10_dpp_dscl.c.patch (drm-backport-placeholder)
- commit 587df9a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0944-drm-amd-display-Clean-up-errors-in-dc_stream.c.patch (drm-backport-placeholder)
- commit 32d62ac
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0943-drm-amd-display-Clean-up-errors-in-bios_parser2.c.patch (drm-backport-placeholder)
- commit 2ff55a0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0942-drm-amd-display-Clean-up-errors-in-dcn316_smu.c.patch (drm-backport-placeholder)
- commit f82fd0f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0941-drm-amd-display-Clean-up-errors-in-dcn316_clk_mgr.c.patch (drm-backport-placeholder)
- commit 30e0110
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0940-drm-amd-display-Clean-up-errors-in-dcn315_smu.c.patch (drm-backport-placeholder)
- commit 949aba5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0939-drm-amd-display-Clean-up-errors-in-dce112_hw_sequenc.patch (drm-backport-placeholder)
- commit 148711d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0938-drm-amd-display-Clean-up-errors-in-dce110_hw_sequenc.patch (drm-backport-placeholder)
- commit e64508c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0937-drm-amd-display-Clean-up-errors-in-dce110_timing_gen.patch (drm-backport-placeholder)
- commit 8e61f85
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0936-drm-amd-dc-Clean-up-errors-in-hpd_regs.h.patch (drm-backport-placeholder)
- commit a3f8bef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0935-drm-amd-display-Clean-up-errors-in-ddc_regs.h.patch (drm-backport-placeholder)
- commit ed9fcfc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0934-drm-amd-display-Clean-up-errors-in-color_gamma.c.patch (drm-backport-placeholder)
- commit 3425643
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0933-drm-amd-pm-Clean-up-errors-in-amdgpu_pm.c.patch (drm-backport-placeholder)
- commit 382e671
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0932-drm-amd-pm-Clean-up-errors-in-sislands_smc.h.patch (drm-backport-placeholder)
- commit 3347dcd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0931-drm-amd-pm-Clean-up-errors-in-r600_dpm.h.patch (drm-backport-placeholder)
- commit 5453fc7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0930-drivers-amd-pm-Clean-up-errors-in-smu8_smumgr.h.patch (drm-backport-placeholder)
- commit e7d307a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0929-drm-amd-pm-Clean-up-errors-in-smu75.h.patch (drm-backport-placeholder)
- commit 56e07ec
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0928-drm-amd-pm-Clean-up-errors-in-smu73.h.patch (drm-backport-placeholder)
- commit 9248508
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0927-drm-amd-pm-Clean-up-errors-in-hwmgr.h.patch (drm-backport-placeholder)
- commit feec25a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0926-drm-amd-pm-Clean-up-errors-in-hardwaremanager.h.patch (drm-backport-placeholder)
- commit fe81f34
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0925-drm-amd-pm-Clean-up-errors-in-pp_thermal.h.patch (drm-backport-placeholder)
- commit 7ddea22
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0924-drm-amd-pm-Clean-up-errors-in-smu7.h.patch (drm-backport-placeholder)
- commit 2d34929
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0923-drm-amd-pm-Clean-up-errors-in-smu7_fusion.h.patch (drm-backport-placeholder)
- commit 6551c00
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0922-drm-amd-pm-Clean-up-errors-in-smu71.h.patch (drm-backport-placeholder)
- commit 9060e02
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0921-drm-amd-pm-Remove-many-unnecessary-NULL-values.patch (drm-backport-placeholder)
- commit f2cf5a5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0920-drm-amd-pm-Clean-up-errors-in-smu9_driver_if.h.patch (drm-backport-placeholder)
- commit 00465e3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0919-drm-amd-pm-Clean-up-errors-in-polaris_baco.c.patch (drm-backport-placeholder)
- commit 128b82f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0918-drm-amd-pm-Clean-up-errors-in-vega20_pptable.h.patch (drm-backport-placeholder)
- commit 5c23baf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0917-drm-amd-pm-Clean-up-errors-in-vega12_hwmgr.h.patch (drm-backport-placeholder)
- commit 90e5319
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0916-drm-amd-pm-powerplay-hwmgr-hwmgr-Clean-up-errors-in-.patch (drm-backport-placeholder)
- commit c0ffa57
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0915-drm-amd-pm-Clean-up-errors-in-tonga_baco.c.patch (drm-backport-placeholder)
- commit 0abb9b0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0914-gpu-amd-Clean-up-errors-in-ppatomfwctrl.h.patch (drm-backport-placeholder)
- commit 5e44a22
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0913-drm-amdgpu-powerplay-Clean-up-errors-in-vega20_hwmgr.patch (drm-backport-placeholder)
- commit a65fc4b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0912-drm-amdgpu-Clean-up-errors-in-vega20_baco.c.patch (drm-backport-placeholder)
- commit 5dd7af9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0911-drm-amd-pm-Clean-up-errors-in-vega20_hwmgr.h.patch (drm-backport-placeholder)
- commit 3f371ab
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0910-drm-amdgpu-powerplay-Clean-up-errors-in-smu_helper.h.patch (drm-backport-placeholder)
- commit dd5564a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0909-drm-amd-Clean-up-errors-in-vega10_processpptables.c.patch (drm-backport-placeholder)
- commit 1e9d38c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0908-drm-amd-Clean-up-errors-in-pptable_v1_0.h.patch (drm-backport-placeholder)
- commit 1b8b832
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0907-drm-amd-Clean-up-errors-in-smu7_hwmgr.c.patch (drm-backport-placeholder)
- commit 1c47b87
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0906-drm-amd-pm-Clean-up-errors-in-vega10_pptable.h.patch (drm-backport-placeholder)
- commit adabeda
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0905-drm-amdgpu-Clean-up-errors-in-ppatomctrl.h.patch (drm-backport-placeholder)
- commit aa8763d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0904-drm-amdgpu-Clean-up-errors-in-ci_baco.c.patch (drm-backport-placeholder)
- commit ba6ada4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0903-drm-amdgpu-Clean-up-errors-in-smu_helper.c.patch (drm-backport-placeholder)
- commit 50e073c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0902-drm-amdgpu-Clean-up-errors-in-common_baco.c.patch (drm-backport-placeholder)
- commit 045b873
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0901-drm-amdgpu-Clean-up-errors-in-smu7_powertune.c.patch (drm-backport-placeholder)
- commit 7ae3c0a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0900-drm-amd-pm-Clean-up-errors-in-vega12_baco.c.patch (drm-backport-placeholder)
- commit 319a41e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0899-drm-amd-pm-Clean-up-errors-in-vega12_pptable.h.patch (drm-backport-placeholder)
- commit 4ab3bc2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0898-drm-amd-pm-Clean-up-errors-in-vega10_powertune.c.patch (drm-backport-placeholder)
- commit 5a7dd18
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0897-drm-amd-pm-Clean-up-errors-in-fiji_baco.c.patch (drm-backport-placeholder)
- commit c4e0e6c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0896-drm-amd-pm-Clean-up-errors-in-smu10_hwmgr.c.patch (drm-backport-placeholder)
- commit d506d6b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0895-drm-amd-pm-powerplay-hwmgr-ppevvmath-Clean-up-errors.patch (drm-backport-placeholder)
- commit 8fa41af
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0894-drm-amd-pm-Clean-up-errors-in-vega12_hwmgr.c.patch (drm-backport-placeholder)
- commit 15b88e5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0893-drm-amd-pm-Clean-up-errors-in-vega10_baco.c.patch (drm-backport-placeholder)
- commit 598f081
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0892-drm-amd-pm-Clean-up-errors-in-amd_powerplay.c.patch (drm-backport-placeholder)
- commit 2bd854a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0891-drm-amd-pm-Clean-up-errors-in-amdgpu_smu.c.patch (drm-backport-placeholder)
- commit a5132ed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0890-drm-amd-Clean-up-errors-in-smu_v13_0_5_ppt.c.patch (drm-backport-placeholder)
- commit 7013790
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0889-drm-amd-pm-Clean-up-errors-in-smu_v13_0_5_ppt.c.patch (drm-backport-placeholder)
- commit 706c5c4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0888-drm-amd-pm-Clean-up-errors-in-smu_v13_0_6_ppt.c.patch (drm-backport-placeholder)
- commit 69b34c5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0887-drm-amd-pm-Clean-up-errors-in-aldebaran_ppt.c.patch (drm-backport-placeholder)
- commit 4c95899
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0886-drm-amd-pm-Clean-up-errors-in-smu_v13_0.c.patch (drm-backport-placeholder)
- commit 15516d0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0885-drm-amd-pm-Clean-up-errors-in-smu_v13_0_7_ppt.c.patch (drm-backport-placeholder)
- commit 8360a95
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0884-drm-amd-pm-Clean-up-errors-in-smu_v11_0.h.patch (drm-backport-placeholder)
- commit 22f6667
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0883-drm-amdgpu-Remove-a-lot-of-unnecessary-ternary-opera.patch (drm-backport-placeholder)
- commit f82de86
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0882-drm-amd-display-Return-value-of-function.patch (drm-backport-placeholder)
- commit 0bb1176
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0881-drm-amdgpu-Report-vbios-version-instead-of-PN.patch (drm-backport-placeholder)
- commit 50b7994
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0880-drm-amd-display-Promote-DAL-to-3.2.246.patch (drm-backport-placeholder)
- commit ee7ca9f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0879-drm-amd-display-Change-HDCP-update-sequence-for-DM.patch (drm-backport-placeholder)
- commit 129c176
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0878-drm-amd-display-rename-acquire_idle_pipe_for_layer-t.patch (drm-backport-placeholder)
- commit 67a0699
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0877-drm-amd-display-move-idle-pipe-allocation-logic-into.patch (drm-backport-placeholder)
- commit fb6952a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0876-drm-amd-display-Use-max-memclk-variable-when-setting.patch (drm-backport-placeholder)
- commit d8928bb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0875-drm-amd-display-Add-vendor-Id-for-reference.patch (drm-backport-placeholder)
- commit fe87fb1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0874-drm-amd-display-Blocking-invalid-420-modes-on-HDMI-T.patch (drm-backport-placeholder)
- commit fcf7385
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0873-drm-amd-display-Blocking-invalid-420-modes-on-HDMI-T.patch (drm-backport-placeholder)
- commit 8c0557c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0872-drm-amd-display-Revert-drm-amd-display-Read-down-spr.patch (drm-backport-placeholder)
- commit 8e1674b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0871-drm-amd-display-do-not-treat-clip_rect-size-change-a.patch (drm-backport-placeholder)
- commit 4e348fb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0870-drm-amd-display-adjust-visual-confirm-dpp-height-off.patch (drm-backport-placeholder)
- commit f098e9d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0869-drm-amd-display-update-add-plane-to-context-logic-wi.patch (drm-backport-placeholder)
- commit 4f708c6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0868-drm-amd-display-always-acquire-MPO-pipe-for-every-bl.patch (drm-backport-placeholder)
- commit adbbd1a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0867-drm-amd-display-support-plane-clip-with-zero-recout-.patch (drm-backport-placeholder)
- commit 8c6cf0f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0866-drm-amd-display-Use-DTBCLK-as-refclk-instead-of-DPRE.patch (drm-backport-placeholder)
- commit a1c622e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0865-drm-amd-display-Set-Stream-Update-Flags-in-commit_st.patch (drm-backport-placeholder)
- commit e55a94f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0864-drm-amd-display-Make-mpc32-functions-available-to-fu.patch (drm-backport-placeholder)
- commit 7cb5457
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0863-drm-amd-display-Fix-a-bug-when-searching-for-insert_.patch (drm-backport-placeholder)
- commit dc3d4bb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0862-drm-amd-display-Enable-DPIA-trace-with-DC-debug-mask.patch (drm-backport-placeholder)
- commit 08e7cd7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0861-drm-amd-display-Add-interface-to-enable-DPIA-trace.patch (drm-backport-placeholder)
- commit 98a24aa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0860-drm-amd-display-fix-a-regression-in-blank-pixel-data.patch (drm-backport-placeholder)
- commit 59c21da
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0859-drm-amdgpu-cleanup-MES-process-level-doorbells.patch (drm-backport-placeholder)
- commit afbd336
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0858-drm-amdgpu-use-doorbell-mgr-for-MES-kernel-doorbells.patch (drm-backport-placeholder)
- commit 86d56f7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0857-drm-amdgpu-remove-unused-functions-and-variables.patch (drm-backport-placeholder)
- commit 7f641a9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-ensure-async-flips-are-only-accepted.patch (drm-backport-placeholder)
- commit 1eee13f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0855-drm-amdgpu-use-doorbell-mgr-for-kfd-process-doorbell.patch (drm-backport-placeholder)
- commit 7559853
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0854-drm-amdgpu-use-doorbell-mgr-for-kfd-kernel-doorbells.patch (drm-backport-placeholder)
- commit e30abb2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0853-drm-amd-display-Read-replay-data-from-sink.patch (drm-backport-placeholder)
- commit c201369
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0852-drm-amd-display-Add-Freesync-Panel-DM-code.patch (drm-backport-placeholder)
- commit c1128c1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0851-drm-amd-pm-update-smu_v13_0_6-message-vf-flag.patch (drm-backport-placeholder)
- commit 5f8c4d7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0850-drm-amdgpu-Report-Missing-MES-Firmware-Versions-with.patch (drm-backport-placeholder)
- commit 6a13c7d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0849-drm-amdgpu-get-absolute-offset-from-doorbell-index.patch (drm-backport-placeholder)
- commit 61d08b3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0848-drm-amdgpu-create-kernel-doorbell-pages.patch (drm-backport-placeholder)
- commit f4e5ebe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0847-drm-amdgpu-Use-nbio-callback-for-nv-and-soc21.patch (drm-backport-placeholder)
- commit 7693aa9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-fix-variable-dereferenced-issue-in-amdgpu.patch (drm-backport-placeholder)
- commit 4bd8ace
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0845-drm-amdgpu-Add-pci-replay-count-to-nbio-v7.9.patch (drm-backport-placeholder)
- commit 56d5885
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0844-drm-amdgpu-initialize-ttm-for-doorbells.patch (drm-backport-placeholder)
- commit 3b4acbe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0843-drm-amdgpu-accommodate-DOMAIN-PL_DOORBELL.patch (drm-backport-placeholder)
- commit e1d8f26
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0842-drm-amdkfd-Sign-extend-TMA-address-in-trap-handler.patch (drm-backport-placeholder)
- commit 7e1102f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0841-drm-amdkfd-Relocate-TBA-TMA-to-opposite-side-of-VM-h.patch (drm-backport-placeholder)
- commit f3fe0a2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0840-drm-amdkfd-Sync-trap-handler-binaries-with-source.patch (drm-backport-placeholder)
- commit 13c2949
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0839-drm-amdgpu-add-UAPI-for-allocating-doorbell-memory.patch (drm-backport-placeholder)
- commit 1777e2d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0838-drm-amdgpu-don-t-modify-num_doorbells-for-mes.patch (drm-backport-placeholder)
- commit 5dcb365
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0837-drm-amdgpu-Add-pcie-replay-count-callback-to-nbio.patch (drm-backport-placeholder)
- commit 147148b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0836-drm-amd-display-Promote-DC-to-2.3.245.patch (drm-backport-placeholder)
- commit 4d77524
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0835-Revert-drm-amd-display-Implement-zpos-property.patch (drm-backport-placeholder)
- commit 76ce5de
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0834-drm-amd-display-Implement-interface-for-notify-curso.patch (drm-backport-placeholder)
- commit 86f00c2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0833-drm-amdgpu-Prefer-pr_err-_warn-_notice-over-printk-i.patch (drm-backport-placeholder)
- commit 03bfe9f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0832-drm-amd-display-Temporary-Disable-MST-DP-Colorspace-.patch (drm-backport-placeholder)
- commit 2c3dc47
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0831-Revert-drm-amdgpu-Prefer-dev_-variant-over-printk-in.patch (drm-backport-placeholder)
- commit b8a8afc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0830-drm-amd-display-Clean-up-flip-pending-timeout-handli.patch (drm-backport-placeholder)
- commit 566c702
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0829-drm-amdgpu-init-TA-microcode-for-SRIOV-VF-when-MP0-I.patch (drm-backport-placeholder)
- commit 30ceed4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0828-drm-amdgpu-remove-SRIOV-VF-FB-location-programming.patch (drm-backport-placeholder)
- commit a336ee6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0827-drm-amd-display-Add-Functions-to-enable-Freesync-Pan.patch (drm-backport-placeholder)
- commit 3197401
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0826-drm-amdgpu-enable-SDMA-MGCG-for-SDMA-5.2.x.patch (drm-backport-placeholder)
- commit 789b90c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0825-drm-amdgpu-Issue-ras-enable_feature-for-gfx-ip-only.patch (drm-backport-placeholder)
- commit 91b5d61
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0824-drm-amdgpu-Remove-gfx-v11_0_3-ras_late_init-call.patch (drm-backport-placeholder)
- commit ed053ef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0823-drm-amdgpu-Clean-up-style-problems-in-mmhub_v2_3.c.patch (drm-backport-placeholder)
- commit 074dd22
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0822-drm-amdgpu-Move-vram-gtt-flash-defines-to-amdgpu_-tt.patch (drm-backport-placeholder)
- commit 19f8e87
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0821-Revert-drm-radeon-Prefer-dev_-variant-over-printk.patch (drm-backport-placeholder)
- commit 41f39e0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0820-drm-amdgpu-Apply-poison-mode-check-to-GFX-IP-only.patch (drm-backport-placeholder)
- commit 1ba32ac
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0819-drm-amdgpu-Only-create-err_count-sysfs-when-hw_op-is.patch (drm-backport-placeholder)
- commit 2421b19
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0818-drm-amd-display-Add-structs-for-Freesync-Panel-Repla.patch (drm-backport-placeholder)
- commit 58a0875
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0817-drm-amdgpu-Sort-the-includes-in-amdgpu-amdgpu_drv.c.patch (drm-backport-placeholder)
- commit 8a90f79
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0816-drm-amdgpu-Cleanup-amdgpu-amdgpu_cgs.c.patch (drm-backport-placeholder)
- commit da2d11c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0815-drm-amdgpu-Fix-style-issues-in-amdgpu_psp.c.patch (drm-backport-placeholder)
- commit f00f2dd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0814-drm-amdgpu-Fix-style-issues-in-amdgpu_debugfs.c.patch (drm-backport-placeholder)
- commit 428dfc4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0813-drm-amd-pm-fix-pp_dpm_sclk-node-not-displaying-corre.patch (drm-backport-placeholder)
- commit 1cddc91
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0812-drm-amdkfd-avoid-unmap-dma-address-when-svm_ranges-a.patch (drm-backport-placeholder)
- commit 19b5453
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0811-drm-amd-display-Fix-typo-in-enable-and-disable-symcl.patch (drm-backport-placeholder)
- commit b806d68
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0810-drm-amd-display-Add-symclk-enable-disable-during-str.patch (drm-backport-placeholder)
- commit 5353ff0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0809-drm-amdgpu-discovery-add-ih-6.1.0-support.patch (drm-backport-placeholder)
- commit 734b621
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0808-drm-amdgpu-add-ih-6.1-support.patch (drm-backport-placeholder)
- commit decf520
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0807-drm-amdgpu-add-ih-6.1-registers.patch (drm-backport-placeholder)
- commit 433491a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0806-drm-amdgpu-discovery-add-smuio-14.0.0-support.patch (drm-backport-placeholder)
- commit 34c7e62
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0805-drm-amdgpu-discovery-add-hdp-6.1.0-support.patch (drm-backport-placeholder)
- commit 8eb8324
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0804-drm-amdgpu-discovery-enable-sdma6-for-SDMA-6.1.0.patch (drm-backport-placeholder)
- commit 3db1776
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0803-drm-amdgpu-sdma6-initialize-sdma-6.1.0.patch (drm-backport-placeholder)
- commit ca2305e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0802-drm-rcar-du-Enable-ABGR-and-XBGR-formats.patch (drm-backport-placeholder)
- commit c8b5bee
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0801-drm-rcar-du-Add-more-formats-to-DRM_MODE_BLEND_PIXEL.patch (drm-backport-placeholder)
- commit 2dc98f6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0800-drm-renesas-Convert-to-devm_platform_ioremap_resourc.patch (drm-backport-placeholder)
- commit d4ed383
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0799-drm-rcar-du-Use-dev_err_probe-to-record-cause-of-KMS.patch (drm-backport-placeholder)
- commit 2bc29e7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0798-drm-rcar-du-Replace-DRM_INFO-with-drm_info.patch (drm-backport-placeholder)
- commit 607c806
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0797-drm-mediatek-mtk_disp_ccorr-Remove-half-completed-in.patch (drm-backport-placeholder)
- commit 048579e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0796-drm-mediatek-mtk_disp_aal-Remove-half-completed-inco.patch (drm-backport-placeholder)
- commit 6055c51
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-void-pointer-to-enum-cast-warning.patch (drm-backport-placeholder)
- commit 5df31cf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-potential-memory-leak-if-vmap-fail.patch (drm-backport-placeholder)
- commit 6ebb4d4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-dereference-before-null-check.patch (drm-backport-placeholder)
- commit cd2d7e7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Add-cnt-checking-for-coverity-issue.patch (drm-backport-placeholder)
- commit 897fa6a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Remove-freeing-not-dynamic-allocated-me.patch (drm-backport-placeholder)
- commit b1ff4de
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0790-drm-mediatek-Convert-to-platform-remove-callback-ret.patch (drm-backport-placeholder)
- commit a1ce9ab
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0789-drm-mediatek-Do-not-check-for-0-return-after-calling.patch (drm-backport-placeholder)
- commit e619593
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0788-drm-mediatek-dp-Don-t-register-HPD-interrupt-handler.patch (drm-backport-placeholder)
- commit 481c70f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0787-drm-mediatek-dp-Add-.wait_hpd_asserted-for-AUX-bus.patch (drm-backport-placeholder)
- commit e5de611
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0786-drm-mediatek-dp-Add-support-for-embedded-DisplayPort.patch (drm-backport-placeholder)
- commit e5e7ee9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0785-drm-mediatek-dp-Move-PHY-registration-to-new-functio.patch (drm-backport-placeholder)
- commit c448503
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0784-drm-mediatek-dp-Avoid-mutex-locks-if-audio-is-not-su.patch (drm-backport-placeholder)
- commit 77231e2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0783-drm-mediatek-dp-Enable-event-interrupt-only-when-bri.patch (drm-backport-placeholder)
- commit 7509cbd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0782-drm-mediatek-dp-Move-AUX_P0-setting-to-mtk_dp_initia.patch (drm-backport-placeholder)
- commit c5980ed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0781-drm-mediatek-dp-Use-devm-variant-of-drm_bridge_add.patch (drm-backport-placeholder)
- commit a70f5f3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0780-drm-mediatek-dp-Change-logging-to-dev-for-mtk_dp_aux.patch (drm-backport-placeholder)
- commit 398660a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0779-drm-mediatek-dp-Move-AUX-and-panel-poweron-off-seque.patch (drm-backport-placeholder)
- commit 54b028c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-dp-Add-missing-error-checks-in-mtk_dp_p.patch (drm-backport-placeholder)
- commit 10d8172
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0777-drm-mediatek-mtk_dpi-Compress-struct-of_device_id-en.patch (drm-backport-placeholder)
- commit 4b79106
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0776-drm-mediatek-mtk_dpi-Use-devm_platform_ioremap_resou.patch (drm-backport-placeholder)
- commit 876c66e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0775-drm-mediatek-mtk_dpi-Switch-to-.remove_new-void-call.patch (drm-backport-placeholder)
- commit 99fea98
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0774-drm-mediatek-mtk_dpi-Switch-to-devm_drm_of_get_bridg.patch (drm-backport-placeholder)
- commit 42d6611
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0773-drm-mediatek-mtk_dpi-Simplify-with-dev_err_probe.patch (drm-backport-placeholder)
- commit c6b4b47
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0772-drm-mediatek-mtk_dpi-Simplify-with-devm_drm_bridge_a.patch (drm-backport-placeholder)
- commit 38eef0d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-uninitialized-symbol.patch (drm-backport-placeholder)
- commit 614ea4b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0770-drm-i915-guc-Fix-potential-null-pointer-deref-in-GuC.patch (drm-backport-placeholder)
- commit 54614ae
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0769-drm-i915-gt-Apply-workaround-22016122933-correctly.patch (drm-backport-placeholder)
- commit f7417cd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0768-drm-i915-Make-i915_coherent_map_type-GT-centric.patch (drm-backport-placeholder)
- commit cd98413
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0767-drm-i915-gt-Simplify-shmem_create_from_object-map_ty.patch (drm-backport-placeholder)
- commit 5fa3008
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0766-drm-i915-irq-move-all-PCH-irq-postinstall-calls-to-d.patch (drm-backport-placeholder)
- commit 4d31968
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0765-drm-i915-irq-add-ilk_de_irq_postinstall.patch (drm-backport-placeholder)
- commit 51a13d0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0764-drm-i915-irq-add-dg1_de_irq_postinstall.patch (drm-backport-placeholder)
- commit 4670e27
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0763-drm-i915-irq-add-dedicated-intel_display_irq_init.patch (drm-backport-placeholder)
- commit 7a13ce0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0762-drm-i915-debug-log-when-GMD-ID-indicates-there-s-no-.patch (drm-backport-placeholder)
- commit 0b28afa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0761-drm-i915-display-pre-initialize-some-values-in-probe.patch (drm-backport-placeholder)
- commit 215df9f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0760-drm-i915-adls-s-ADLS_RPLS-RAPTORLAKE_S-in-platform-a.patch (drm-backport-placeholder)
- commit 5e9b82d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0759-drm-i915-adln-s-ADLP-ALDERLAKE_P-in-ADLN-defines.patch (drm-backport-placeholder)
- commit 1bff397
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0758-drm-i915-rplu-s-ADLP_RPLU-RAPTORLAKE_U-in-RPLU-defin.patch (drm-backport-placeholder)
- commit ed1dd9f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0757-drm-i915-rplp-s-ADLP_RPLP-RAPTORLAKE_P-for-RPLP-defi.patch (drm-backport-placeholder)
- commit b5d59fa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0756-drm-i915-adlp-s-ADLP-ALDERLAKE_P-for-display-and-gra.patch (drm-backport-placeholder)
- commit 8b94cf1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0755-drm-i915-tgl-s-TGL-TIGERLAKE-for-platform-subplatfor.patch (drm-backport-placeholder)
- commit 3d70f27
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0754-drm-i915-jsl-s-JSL-JASPERLAKE-for-platform-subplatfo.patch (drm-backport-placeholder)
- commit 70db4bf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0753-drm-i915-rkl-s-RKL-ROCKETLAKE-for-platform-subplatfo.patch (drm-backport-placeholder)
- commit f6454a8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0752-drm-i915-cml-s-CML-COMETLAKE-for-platform-subplatfor.patch (drm-backport-placeholder)
- commit 3b1ada9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0751-drm-i915-cfl-s-CFL-COFFEELAKE-for-platform-subplatfo.patch (drm-backport-placeholder)
- commit 8a0355b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0750-drm-i915-kbl-s-KBL-KABYLAKE-for-platform-subplatform.patch (drm-backport-placeholder)
- commit 3209b59
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0749-drm-i915-skl-s-SKL-SKYLAKE-for-platform-subplatform-.patch (drm-backport-placeholder)
- commit 8f46a64
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0748-drm-i915-bdw-s-BDW-BROADWELL-for-platform-subplatfor.patch (drm-backport-placeholder)
- commit 836a5c1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0747-drm-i915-hsw-s-HSW-HASWELL-for-platform-subplatform-.patch (drm-backport-placeholder)
- commit 7c1c739
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0746-drm-i915-fbc-Moved-fence-related-code-away-from-inte.patch (drm-backport-placeholder)
- commit c183ac8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0745-drm-i915-fbc-Make-FBC-check-stolen-at-use-time.patch (drm-backport-placeholder)
- commit f997bae
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0744-drm-i915-Move-stolen-memory-handling-into-i915_gem_s.patch (drm-backport-placeholder)
- commit 089918c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0743-drm-i915-sdvo-ignore-returned-broken-edid-on-intel_s.patch (drm-backport-placeholder)
- commit e980227
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0742-drm-ttm-Remove-two-unused-function-declarations.patch (drm-backport-placeholder)
- commit 2c58f03
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0741-drm-test-drm_exec-fix-memory-leak-on-object-prepare.patch (drm-backport-placeholder)
- commit d10f34f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0740-drm-atmel-hlcdc-Support-inverting-the-pixel-clock-po.patch (drm-backport-placeholder)
- commit a920b79
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0739-drm-panfrost-Sync-IRQ-by-job-s-timeout-handler.patch (drm-backport-placeholder)
- commit 8cdeaa1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0738-drm-exec-add-test-case-for-using-a-drm_exec-multiple.patch (drm-backport-placeholder)
- commit df1dd23
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0737-drm-exec-use-unique-instead-of-local-label.patch (drm-backport-placeholder)
- commit 3e07384
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0736-drm-ttm-tests-Add-tests-for-ttm_pool.patch (drm-backport-placeholder)
- commit 811e290
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0735-drm-ttm-tests-Add-tests-for-ttm_device.patch (drm-backport-placeholder)
- commit 717b305
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0734-drm-ttm-Introduce-KUnit-test.patch (drm-backport-placeholder)
- commit 5aede33
* Mon Sep  9 2024 pjakobsson@suse.de
- Delete patches.suse/0733-accel-ivpu-Refactor-memory-ranges-logic.patch.
- commit 27ec5bd
* Mon Sep  9 2024 tiwai@suse.de
- clocksource/drivers/imx-tpm: Fix next event not taking effect
  sometime (git-fixes).
- clocksource/drivers/imx-tpm: Fix return -ETIME when delta
  exceeds INT_MAX (git-fixes).
- dma-debug: avoid deadlock between dma debug vs printk and
  netconsole (stable-fixes).
- drm/amdgpu: fix contiguous handling for IB parsing v2
  (git-fixes).
- dmaengine: altera-msgdma: properly free descriptor in
  msgdma_free_descriptor (stable-fixes).
- dmaengine: altera-msgdma: use irq variant of spin_lock/unlock
  while invoking callbacks (stable-fixes).
- driver: iio: add missing checks on iio_info's callback access
  (stable-fixes).
- drm/amd/display: Skip wbscl_set_scaler_filter if filter is null
  (stable-fixes).
- drm/amd/display: Check BIOS images before it is used
  (stable-fixes).
- drm/amd/display: Avoid overflow from uint32_t to uint8_t
  (stable-fixes).
- drm/amd/display: use preferred link settings for dp signal only
  (stable-fixes).
- drm/amd/display: Remove register from DCN35 DMCUB diagnostic
  collection (stable-fixes).
- drm/amd/display: Correct the defined value for
  AMDGPU_DMUB_NOTIFICATION_MAX (stable-fixes).
- drm/amd/display: added NULL check at start of dc_validate_stream
  (stable-fixes).
- drm/amd/display: Wake DMCUB before sending a command for replay
  feature (stable-fixes).
- drm/amd/display: Don't use fsleep for PSR exit waits on dmub
  replay (stable-fixes).
- drm/amdgpu: fix overflowed constant warning in
  mmhub_set_clockgating() (stable-fixes).
- drm/amdgpu: add lock in kfd_process_dequeue_from_device
  (stable-fixes).
- drm/amdgpu: add lock in amdgpu_gart_invalidate_tlb
  (stable-fixes).
- drm/amdgpu: add skip_hw_access checks for sriov (stable-fixes).
- drm/bridge: tc358767: Check if fully initialized before
  signalling HPD event via IRQ (stable-fixes).
- drm/meson: plane: Add error handling (stable-fixes).
- drm/drm-bridge: Drop conditionals around of_node pointers
  (stable-fixes).
- drm/amd/display: Add null checks for 'stream' and 'plane'
  before dereferencing (stable-fixes).
- drm/amdgu: fix Unintentional integer overflow for mall size
  (stable-fixes).
- drm/amdgpu: update type of buf size to u32 for eeprom functions
  (stable-fixes).
- drm/amd/display: Fix pipe addition logic in
  calc_blocks_to_ungate DCN35 (stable-fixes).
- drm/kfd: Correct pinned buffer handling at kfd restore and
  validate process (stable-fixes).
- drm/amd/pm: check negtive return for table entries
  (stable-fixes).
- drm/amdgpu: the warning dereferencing obj for nbio_v7_4
  (stable-fixes).
- drm/amd/pm: check specific index for smu13 (stable-fixes).
- drm/amd/pm: check specific index for aldebaran (stable-fixes).
- drm/amdgpu: fix the waring dereferencing hive (stable-fixes).
- drm/amdgpu: fix dereference after null check (stable-fixes).
- drm/amdgpu: Fix the warning division or modulo by zero
  (stable-fixes).
- drm/amdgpu/pm: Check input value for CUSTOM profile mode
  setting on legacy SOCs (stable-fixes).
- drm/amdkfd: Reconcile the definition and use of oem_id in
  struct kfd_topology_device (stable-fixes).
- drm/amdgpu: fix mc_data out-of-bounds read warning
  (stable-fixes).
- drm/amdgpu: fix ucode out-of-bounds read warning (stable-fixes).
- drm/amdgpu: Fix uninitialized variable warning in
  amdgpu_info_ioctl (stable-fixes).
- drm/amdgpu: Fix out-of-bounds read of df_v1_7_channel_number
  (stable-fixes).
- drm/amdkfd: Check debug trap enable before write dbg_ev_file
  (stable-fixes).
- drm/amdgpu: Fix out-of-bounds write warning (stable-fixes).
- drm/amdgpu: Fix the uninitialized variable warning
  (stable-fixes).
- drm/amdgpu/pm: Fix uninitialized variable agc_btc_response
  (stable-fixes).
- drm/amdgpu/pm: Fix uninitialized variable warning for smu10
  (stable-fixes).
- drm/amd/pm: fix uninitialized variable warnings for vangogh_ppt
  (stable-fixes).
- drm/amd/amdgpu: Check tbo resource pointer (stable-fixes).
- drm/amd/display: Fix index may exceed array range within
  fpu_update_bw_bounding_box (stable-fixes).
- drm/amd/display: Skip inactive planes within
  ModeSupportAndSystemConfiguration (stable-fixes).
- drm/amd/display: Ensure index calculation will not overflow
  (stable-fixes).
- drm/amd/display: Fix Coverity INTEGER_OVERFLOW within
  decide_fallback_link_setting_max_bw_policy (stable-fixes).
- drm/amd/display: Spinlock before reading event (stable-fixes).
- drm/amd/display: Fix Coverity INTEGER_OVERFLOW within
  dal_gpio_service_create (stable-fixes).
- drm/amd/display: Fix Coverity INTERGER_OVERFLOW within
  construct_integrated_info (stable-fixes).
- drm/amd/display: Check msg_id before processing transcation
  (stable-fixes).
- drm/amd/display: Check num_valid_sets before accessing
  reader_wm_sets[] (stable-fixes).
- drm/amd/display: Add array index check for hdcp ddc access
  (stable-fixes).
- drm/amd/display: Check index for aux_rd_interval before using
  (stable-fixes).
- drm/amd/display: Stop amdgpu_dm initialize when stream nums
  greater than 6 (stable-fixes).
- drm/amd/display: Check gpio_id before used as array index
  (stable-fixes).
- drm/amd/display: Ensure array index tg_inst won't be -1
  (stable-fixes).
- drm/amdgpu: avoid reading vf2pf info size from FB
  (stable-fixes).
- drm/amd/pm: fix uninitialized variable warnings for vega10_hwmgr
  (stable-fixes).
- drm/amdgpu: fix uninitialized scalar variable warning
  (stable-fixes).
- drm/amd/pm: fix the Out-of-bounds read warning (stable-fixes).
- drm/amd/pm: Fix negative array index read (stable-fixes).
- drm/amd/pm: fix warning using uninitialized value of
  max_vid_step (stable-fixes).
- drm/amd/pm: fix uninitialized variable warning for smu8_hwmgr
  (stable-fixes).
- drm/amd/pm: fix uninitialized variable warning (stable-fixes).
- drm/amdgpu/pm: Check the return value of smum_send_msg_to_smc
  (stable-fixes).
- drm/amdgpu: fix overflowed array index read warning
  (stable-fixes).
- drm/amdgpu: Handle sg size limit for contiguous allocation
  (stable-fixes).
- drm/amd/display: Assign linear_pitch_alignment even for VM
  (stable-fixes).
- drm/amd/display: Handle the case which quad_part is equal 0
  (stable-fixes).
- drm/amdgpu: Fix uninitialized variable warning in
  amdgpu_afmt_acr (stable-fixes).
- cpufreq: scmi: Avoid overflow of target_freq in fast switch
  (stable-fixes).
- commit e23c4dc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0732-accel-ivpu-Extend-get_param-ioctl-to-identify-capabi.patch (drm-backport-placeholder)
- commit daf8ae2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0731-drm-nouveau-sched-Don-t-pass-user-flags-to-drm_synco.patch (drm-backport-placeholder)
- commit a0f8d0f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0730-drm-nouveau-uvmm-remove-dedicated-VM-pointer-from-VM.patch (drm-backport-placeholder)
- commit c792730
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0729-drm-nouveau-uvmm-remove-incorrect-calls-to-mas_unloc.patch (drm-backport-placeholder)
- commit 46cb200
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0728-drm-nouveau-remove-incorrect-__user-annotations.patch (drm-backport-placeholder)
- commit dc4898f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0727-drm-nouveau-nvkm-vmm-silence-warning-from-cast.patch (drm-backport-placeholder)
- commit 05f4773
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0726-nouveau-dmem-fix-copy-paste-error-in-nouveau_dmem_mi.patch (drm-backport-placeholder)
- commit 2671a3a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0725-drm-mcde-remove-redundant-of_match_ptr.patch (drm-backport-placeholder)
- commit 8a23500
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0724-drm-tve200-remove-redundant-of_match_ptr.patch (drm-backport-placeholder)
- commit 1f16a14
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0723-drm-nouveau-debugfs-implement-DRM-GPU-VA-debugfs.patch (drm-backport-placeholder)
- commit ec924f0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0722-drm-nouveau-implement-new-VM_BIND-uAPI.patch (drm-backport-placeholder)
- commit da8a88f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0721-drm-nouveau-nvkm-vmm-implement-raw-ops-to-manage-uvm.patch (drm-backport-placeholder)
- commit d50e2b2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0720-drm-nouveau-chan-provide-nouveau_channel_kill.patch (drm-backport-placeholder)
- commit c8d4946
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0719-drm-nouveau-fence-fail-to-emit-when-fence-context-is.patch (drm-backport-placeholder)
- commit 4ba7338
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0718-drm-nouveau-fence-separate-fence-alloc-and-emit.patch (drm-backport-placeholder)
- commit b262d4d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0717-drm-nouveau-move-usercopy-helpers-to-nouveau_drv.h.patch (drm-backport-placeholder)
- commit 0464665
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0716-drm-nouveau-bo-initialize-GEM-GPU-VA-interface.patch (drm-backport-placeholder)
- commit 9d29c03
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0715-drm-nouveau-get-vmm-via-nouveau_cli_vmm.patch (drm-backport-placeholder)
- commit d9fffbd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0714-drm-nouveau-new-VM_BIND-uAPI-interfaces.patch (drm-backport-placeholder)
- commit 01b4c6d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0713-drm-nouveau-fixup-the-uapi-header-file.patch (drm-backport-placeholder)
- commit 3f372fc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0712-drm-gem-fix-lockdep-check-for-dma-resv-lock.patch (drm-backport-placeholder)
- commit 9729e0a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0711-drm-Drop-select-FRAMEBUFFER_CONSOLE-for-DRM_FBDEV_EM.patch (drm-backport-placeholder)
- commit a81d489
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0710-fbdev-xilinxfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit dffe03c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0709-fbdev-vesafb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 92915da
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0708-fbdev-valkyriefb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 03f5de7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0707-fbdev-uvesafb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit ad21fe8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0706-fbdev-sunxvr2500-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 97ea29f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0705-fbdev-sunxvr1000-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit bdc8efb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0704-fbdev-sstfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 9688afe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0703-fbdev-simplefb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 2315352
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0702-fbdev-sh7760fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 58e9f13
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0701-fbdev-s3cfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit a8b50e7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0700-fbdev-q40fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit efa7bf6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0699-fbdev-pxafb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 3d7dd89
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0698-fbdev-pxa168fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 88dbe53
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0697-fbdev-pmagb-b-fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 2d94053
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0696-fbdev-pmag-ba-fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 7102c00
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0695-fbdev-pmag-aa-fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit dace2b1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0694-fbdev-platinumfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit fd9036b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0693-fbdev-omapfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 5fbfe7a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0692-fbdev-offb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit ca46039
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0691-fbdev-ocfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit ae6acd2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0690-fbdev-mx3fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 9e57505
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0689-fbdev-mmpfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 6f5c282
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0688-fbdev-mb862xxfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 80c05e4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0687-fbdev-maxinefb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit e31d47e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0686-fbdev-macfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 10f1fe4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0685-fbdev-kyro-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 6399c3f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0684-fbdev-imxfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 3b377bd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0683-fbdev-i740fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit a0293a1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0682-fbdev-gxt4500-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 1b7fb4f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0681-fbdev-grvga-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 7f51035
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0680-fbdev-goldfishfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit a796df0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0679-fbdev-geode-lxfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 80b9fdd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0678-fbdev-geode-gxfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit fa29215
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0677-fbdev-geode-gx1fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 2e84317
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0676-fbdev-g364fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit a3ac5b0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0675-fbdev-fsl-diu-fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit a772b79
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0674-fbdev-fm2fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 8ed75b6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0673-fbdev-efifb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 68e9bf0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0672-fbdev-da8xx-fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 94073c7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0671-fbdev-chipsfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 0b3d940
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0670-fbdev-carminefb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 7d3a7f5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0669-fbdev-aty128fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit f5ceff2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0668-fbdev-atmel_lcdfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 6968c53
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0667-fbdev-asiliantfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 59b1ea0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0666-fbdev-acornfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 6d5acf9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0665-drm-panel-sitronix-st7789v-add-jasonic-jt240mhqs-hwt.patch (drm-backport-placeholder)
- commit e94fcd7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0664-drm-panel-sitronix-st7789v-add-support-for-partial-m.patch (drm-backport-placeholder)
- commit a011863
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0663-drm-panel-sitronix-st7789v-add-panel-orientation-sup.patch (drm-backport-placeholder)
- commit 0b1c77b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0662-drm-panel-sitronix-st7789v-fix-indentation-in-drm_pa.patch (drm-backport-placeholder)
- commit 9b99f56
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0661-drm-bridge-dw_hdmi-Fix-ELD-is-not-updated-issue.patch (drm-backport-placeholder)
- commit 6eeec03
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0660-drm-loongson-Add-a-check-for-lsdc_bo_create-errors.patch (drm-backport-placeholder)
- commit 3852d27
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0659-drm-doc-fix-underline-for-section-DRM-Sync-Objects.patch (drm-backport-placeholder)
- commit 8d9fd30
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0658-drm-exynos-remove-redundant-of_match_ptr.patch (drm-backport-placeholder)
- commit b04ac3f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0657-drm-exynos-fix-a-possible-null-pointer-dereference-d.patch (drm-backport-placeholder)
- commit cce8fcf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0656-drm-i915-Remove-unnecessary-include.patch (drm-backport-placeholder)
- commit eb3afc1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0655-drm-i915-Invalidate-the-TLBs-on-each-GT.patch (drm-backport-placeholder)
- commit 0916f98
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0654-i915-drm-gt-Move-the-gt-defines-in-the-gt-directory.patch (drm-backport-placeholder)
- commit fcb4594
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0653-drm-i915-gt-Move-TLB-invalidation-to-its-own-file.patch (drm-backport-placeholder)
- commit 0587223
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0652-drm-i915-selftest-gsc-Ensure-GSC-Proxy-init-complete.patch (drm-backport-placeholder)
- commit aa91310
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0651-drm-i915-Use-the-i915_vma_flush_writes-helper.patch (drm-backport-placeholder)
- commit f54d806
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0650-drm-i915-Replace-i915-gt0-with-to_gt-i915.patch (drm-backport-placeholder)
- commit 83556c2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0649-drm-i915-use-direct-alias-for-i915-in-requests.patch (drm-backport-placeholder)
- commit 2e4df67
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0648-drm-i915-huc-check-HuC-and-GuC-version-compatibility.patch (drm-backport-placeholder)
- commit bf10259
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0647-drm-i915-Expose-RPS-thresholds-in-sysfs.patch (drm-backport-placeholder)
- commit 5eda5a3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0646-drm-i915-Add-helpers-for-managing-rps-thresholds.patch (drm-backport-placeholder)
- commit db7a3d4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0645-drm-i915-Record-default-rps-threshold-values.patch (drm-backport-placeholder)
- commit 3b34127
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0644-drm-i915-Move-setting-of-rps-thresholds-to-init.patch (drm-backport-placeholder)
- commit 26e1ab2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0643-drm-i915-gt-Do-not-use-stolen-on-MTL.patch (drm-backport-placeholder)
- commit 94917d6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0642-drm-i915-mtl-Update-cache-coherency-setting-for-cont.patch (drm-backport-placeholder)
- commit 9a8e498
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0641-drm-i915-guc-Dump-perf_limit_reasons-for-debug.patch (drm-backport-placeholder)
- commit 49b1320
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0640-drm-i915-Remove-some-dead-code.patch (drm-backport-placeholder)
- commit 22db1a7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0639-drm-i915-gt-Also-check-set-bits-in-clr_set.patch (drm-backport-placeholder)
- commit ef8a159
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0638-drm-i915-gt-Remove-bogus-comment-on-IVB_FBC_RT_BASE_.patch (drm-backport-placeholder)
- commit 2f9f840
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0637-drm-i915-gt-Enable-read-back-on-XEHP_FF_MODE2.patch (drm-backport-placeholder)
- commit 3ae3c5c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0636-drm-i915-gt-Drop-read-from-GEN8_L3CNTLREG-in-ICL-wor.patch (drm-backport-placeholder)
- commit 8b7ffed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0635-drm-i915-gt-Fix-context-workarounds-with-non-masked-.patch (drm-backport-placeholder)
- commit 49463ca
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0634-drm-i915-gt-Clear-all-bits-from-GEN12_FF_MODE2.patch (drm-backport-placeholder)
- commit af1b467
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0633-drm-i915-gt-Move-wal_get_fw_for_rmw.patch (drm-backport-placeholder)
- commit 2ad1981
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0632-drm-i915-Replace-kmap-with-kmap_local_page.patch (drm-backport-placeholder)
- commit 70f80e9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0631-drm-i915-Extend-Wa_14015795083-platforms.patch (drm-backport-placeholder)
- commit f4ece12
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0630-drm-i915-mtl-Update-workaround-14018778641.patch (drm-backport-placeholder)
- commit 3f2d024
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0629-drm-i915-gsc-Fix-intel_gsc_uc_fw_proxy_init_done-wit.patch (drm-backport-placeholder)
- commit bd62e12
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0628-drm-i915-mtl-gsc-Add-a-gsc_info-debugfs.patch (drm-backport-placeholder)
- commit 3be97bd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0627-drm-i915-mtl-gsc-query-the-GSC-FW-for-its-compatibil.patch (drm-backport-placeholder)
- commit 83121f9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0626-drm-i915-mtl-gsc-extract-release-and-security-versio.patch (drm-backport-placeholder)
- commit 11bc5e8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0625-drm-i915-gsc-fixes-and-updates-for-GSC-memory-alloca.patch (drm-backport-placeholder)
- commit d3ecb28
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0624-drm-i915-Fix-a-VMA-UAF-for-multi-gt-platform.patch (drm-backport-placeholder)
- commit 752cdfe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0623-drm-i915-uncore-fix-race-around-i915-params.mmio_deb.patch (drm-backport-placeholder)
- commit 8a65d14
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0622-drm-i915-uncore-split-unclaimed_reg_debug-to-header-.patch (drm-backport-placeholder)
- commit 08423f6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0621-drm-i915-Add-function-to-clear-scanout-flag-for-vmas.patch (drm-backport-placeholder)
- commit 9b9b7a0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0620-drm-i915-display-Remove-i915_gem_object_types.h-from.patch (drm-backport-placeholder)
- commit 7b8fdb0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0619-drm-i915-Add-getter-setter-for-i915_gem_object-front.patch (drm-backport-placeholder)
- commit f4c721a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0618-drm-i915-Add-macros-to-get-i915-device-from-i915_gem.patch (drm-backport-placeholder)
- commit 96b8663
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0617-drm-i915-color-Downscale-degamma-lut-values-read-fro.patch (drm-backport-placeholder)
- commit 4c2b32a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0616-drm-i915-color-Upscale-degamma-values-for-MTL.patch (drm-backport-placeholder)
- commit 793d862
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0615-drm-i915-hotplug-Reduce-SHPD_FILTER-to-250us.patch (drm-backport-placeholder)
- commit 7554d94
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0614-drm-i915-Simplify-expression-to_i915-dev-drm.patch (drm-backport-placeholder)
- commit 8eb25fc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0613-drm-i915-Start-using-plane-scale-factor-for-relative.patch (drm-backport-placeholder)
- commit 762f4bd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0612-drm-i915-display-Do-not-use-stolen-on-MTL.patch (drm-backport-placeholder)
- commit 08a6765
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0611-drm-i915-vdsc-Remove-FIXME-in-intel_dsc_compute_conf.patch (drm-backport-placeholder)
- commit 63ff4ce
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0610-drm-i915-dsc-Add-rc_range_parameter-calculation-for-.patch (drm-backport-placeholder)
- commit 5538b7c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0609-drm-i915-drm-Fix-comment-for-YCbCr20-qp-table-declar.patch (drm-backport-placeholder)
- commit 4a78c48
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0608-drm-i915-dsc-Move-rc-param-calculation-for-native_42.patch (drm-backport-placeholder)
- commit 1f8f79f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0607-i915-display-hotplug-use-drm_kms_helper_connector_ho.patch (drm-backport-placeholder)
- commit 6c0584d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0606-drm-i915-Don-t-rely-that-2-VDSC-engines-are-always-e.patch (drm-backport-placeholder)
- commit 167483e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0605-drm-i915-Add-helper-function-for-getting-number-of-V.patch (drm-backport-placeholder)
- commit 6864c1d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0604-drm-i915-Try-to-initialize-DDI-ICL-DSI-ports-for-eve.patch (drm-backport-placeholder)
- commit d999de3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0603-drm-i915-bios-Extract-intel_bios_encoder_port.patch (drm-backport-placeholder)
- commit cae162f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0602-drm-i915-Remove-AUX-CH-sanitation.patch (drm-backport-placeholder)
- commit 4ce0f87
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0601-drm-i915-Remove-DDC-pin-sanitation.patch (drm-backport-placeholder)
- commit 19bf625
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0600-drm-i915-Only-populate-aux_ch-if-really-needed.patch (drm-backport-placeholder)
- commit 6f8ace8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0599-drm-i915-Initialize-dig_port-aux_ch-to-NONE-to-be-su.patch (drm-backport-placeholder)
- commit 4342efa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0598-drm-i915-Fail-if-DSC-compression-requirement-is-less.patch (drm-backport-placeholder)
- commit fe6cd8d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0597-drm-i915-dram-replace-__raw_uncore_read32-with-intel.patch (drm-backport-placeholder)
- commit 4e28f0a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0596-drm-i915-uncore-add-intel_uncore_regs-helper.patch (drm-backport-placeholder)
- commit 2e326c2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0595-drm-i915-make-device-info-a-const-pointer-to-rodata.patch (drm-backport-placeholder)
- commit 8a437fe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0594-drm-i915-move-display-device-and-runtime-info-to-str.patch (drm-backport-placeholder)
- commit d5be46f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0593-drm-i915-fix-display-info-usage.patch (drm-backport-placeholder)
- commit 609bf3a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0592-drm-i915-separate-display-info-printing-from-the-res.patch (drm-backport-placeholder)
- commit bf2cda5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0591-drm-i915-move-platform_engine_mask-and-memory_region.patch (drm-backport-placeholder)
- commit 4fbb3f4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0590-drm-i915-Remove-prototype-for-intel_cx0_phy_ddi_vswi.patch (drm-backport-placeholder)
- commit 492d09f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0589-drm-doc-fix-duplicate-declaration-warning.patch (drm-backport-placeholder)
- commit 6974d72
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0588-drm-i915-Prevent-needless-toggling-of-DC-states-duri.patch (drm-backport-placeholder)
- commit 8a5bd9f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0587-drm-i915-Add-way-to-specify-the-power-off-delay-of-a.patch (drm-backport-placeholder)
- commit 74602b4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0586-drm-i915-Remove-redundant-forward-declarations-from-.patch (drm-backport-placeholder)
- commit 242129e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0585-drm-i915-hdcp-Add-a-debug-statement-at-hdcp2-capabil.patch (drm-backport-placeholder)
- commit c3671c7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0584-drm-i915-mtl-Skip-using-vbt-hdmi_level_shifter-selec.patch (drm-backport-placeholder)
- commit f297119
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0583-drm-i915-mtl-Add-new-vswing-table-for-C20-phy-to-sup.patch (drm-backport-placeholder)
- commit 1d1d9aa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0582-drm-i915-mtl-update-DP-2.0-vswing-table-for-C20-phy.patch (drm-backport-placeholder)
- commit 5675da8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0581-drm-i915-Convert-HSW-BDW-to-use-port_mask-for-DDI-pr.patch (drm-backport-placeholder)
- commit fa51810
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0580-drm-i915-Init-DDI-outputs-based-on-port_mask-on-skl.patch (drm-backport-placeholder)
- commit 0582a36
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0579-drm-i915-Beef-up-SDVO-HDMI-port-checks.patch (drm-backport-placeholder)
- commit 8a87ee0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0578-drm-i915-Assert-that-the-port-being-initialized-is-v.patch (drm-backport-placeholder)
- commit f40bec2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0577-drm-i915-Assert-that-device-info-bitmasks-have-enoug.patch (drm-backport-placeholder)
- commit f101762
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0576-drm-i915-Introduce-device-info-port_mask.patch (drm-backport-placeholder)
- commit f839d7d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0575-drm-i915-Remove-bogus-DDI-F-from-hsw-bdw-output-init.patch (drm-backport-placeholder)
- commit 005b1f9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0574-drm-i915-psr-Re-enable-PSR1-on-hsw-bdw.patch (drm-backport-placeholder)
- commit 4426b32
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0573-drm-i915-psr-Allow-PSR-with-sprite-enabled-on-hsw-bd.patch (drm-backport-placeholder)
- commit a2f2b36
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0572-drm-i915-psr-Don-t-skip-both-TP1-and-TP2-3-on-hsw-bd.patch (drm-backport-placeholder)
- commit 534299f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0571-drm-i915-psr-Do-no-mask-display-register-writes-on-h.patch (drm-backport-placeholder)
- commit 13afbfe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0570-drm-i915-psr-Implement-WaPsrDPRSUnmaskVBlankInSRD-hs.patch (drm-backport-placeholder)
- commit 82c9162
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0569-drm-i915-psr-Implement-WaPsrDPAMaskVBlankInSRD-hsw.patch (drm-backport-placeholder)
- commit 1046d62
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0568-drm-i915-psr-Restore-PSR-interrupt-handler-for-HSW.patch (drm-backport-placeholder)
- commit bb5336a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0567-drm-i915-psr-HSW-BDW-have-no-PSR2.patch (drm-backport-placeholder)
- commit aa8b617
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0566-drm-i915-psr-Bring-back-HSW-BDW-PSR-AUX-CH-registers.patch (drm-backport-placeholder)
- commit c5616b0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0565-drm-i915-psr-Reintroduce-HSW-PSR1-registers.patch (drm-backport-placeholder)
- commit 937da89
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0564-drm-i915-psr-Wrap-PSR1-register-with-functions.patch (drm-backport-placeholder)
- commit 005d69d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0563-drm-i915-Re-init-clock-gating-on-coming-out-of-PC8.patch (drm-backport-placeholder)
- commit 1afbb59
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0562-drm-i915-mtl-Cleanup-usage-of-phy-lane-reset.patch (drm-backport-placeholder)
- commit 0206e6c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0561-drm-i915-hdcp-Modify-hdcp_gsc_message-msg-sending-me.patch (drm-backport-placeholder)
- commit a1ae694
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0560-drm-i915-dsi-Remove-weird-has_pch_encoder-asserts.patch (drm-backport-placeholder)
- commit 04864c9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0559-drm-i915-dsi-Grab-the-crtc-from-the-customary-place.patch (drm-backport-placeholder)
- commit c301526
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0558-drm-i915-dsi-Move-panel-reset-power-off-to-be-the-la.patch (drm-backport-placeholder)
- commit 01200b4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0557-drm-i915-dsi-Respect-power_off_delay-on-icl.patch (drm-backport-placeholder)
- commit cbed895
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0556-drm-i915-dsi-Do-DSC-scaler-disable-earlier-on-icl.patch (drm-backport-placeholder)
- commit c838aba
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0555-drm-i915-dsi-Move-most-things-from-.disable-into-.po.patch (drm-backport-placeholder)
- commit 63bb3d6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0554-drm-i915-dsi-Implement-encoder-shutdown-for-icl.patch (drm-backport-placeholder)
- commit 843ee46
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0553-drm-i915-dsi-Respect-power-cycle-delay-on-icl.patch (drm-backport-placeholder)
- commit 491ad03
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0552-drm-i915-dsi-Gate-DSI-clocks-earlier.patch (drm-backport-placeholder)
- commit 09a0405
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0551-drm-i915-dsi-Split-icl-D-PHY-vs.-DSI-timing-steps.patch (drm-backport-placeholder)
- commit d02b104
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0550-drm-i915-dsi-Print-the-VBT-MIPI-sequence-delay-durat.patch (drm-backport-placeholder)
- commit 3d42b70
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0549-drm-i915-dsi-Do-display-on-sequence-later-on-icl.patch (drm-backport-placeholder)
- commit bfe91de
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0548-drm-i915-dsi-Do-panel-power-on-reset-deassert-earlie.patch (drm-backport-placeholder)
- commit e73e691
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0547-drm-i915-gmch-avoid-unused-variable-warning.patch (drm-backport-placeholder)
- commit 2cfd123
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0546-fbdev-ps3fb-Build-without-kernel-device.patch (drm-backport-placeholder)
- commit f34b3a0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0545-drm-doc-document-that-PRIME-import-export-is-always-.patch (drm-backport-placeholder)
- commit 417cb7e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0544-drm-doc-document-drm_event-and-its-types.patch (drm-backport-placeholder)
- commit fcdf3b4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0543-drm-doc-add-warning-about-connector_type_id-stabilit.patch (drm-backport-placeholder)
- commit a61bef0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0542-drm-doc-use-proper-cross-references-for-sections.patch (drm-backport-placeholder)
- commit 87387b8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0541-fbcon-Make-fbcon_registered_fb-and-fbcon_num_registe.patch (drm-backport-placeholder)
- commit 6f1a5ea
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0540-drm-drm_plane.h-fix-grammar-of-the-comment.patch (drm-backport-placeholder)
- commit d221d2c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0539-drm-bridge-dw_hdmi-Add-cec-suspend-resume-functions.patch (drm-backport-placeholder)
- commit 00464b5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0538-drm-panel-simple-Add-Innolux-G156HCE-L01-panel-entry.patch (drm-backport-placeholder)
- commit b35d420
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0537-drm-panel-Fix-todo-indentation-for-panel-prepared-en.patch (drm-backport-placeholder)
- commit 455471a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0536-drm-panel-Fix-kernel-doc-typo-for-follower_lock.patch (drm-backport-placeholder)
- commit 3b5a136
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0535-drm-tiny-panel-mipi-dbi-Allow-sharing-the-D-C-GPIO.patch (drm-backport-placeholder)
- commit c3575b0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0534-drm-mipi-dbi-Lock-SPI-bus-before-setting-D-C-GPIO.patch (drm-backport-placeholder)
- commit b75b594
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0533-drm-bridge-Add-debugfs-print-for-bridge-chains.patch (drm-backport-placeholder)
- commit 0504632
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0532-drm-panel-Add-a-way-for-other-devices-to-follow-pane.patch (drm-backport-placeholder)
- commit 33db8e2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0531-drm-panel-Check-for-already-prepared-enabled-in-drm_.patch (drm-backport-placeholder)
- commit be0da84
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0530-drm-panel-edp-Add-enable-timings-for-N140HCA-EAC-pan.patch (drm-backport-placeholder)
- commit 77c6401
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0529-drm-panel-sitronix-st7789v-Check-display-ID.patch (drm-backport-placeholder)
- commit da3d3ca
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0528-drm-panel-sitronix-st7789v-Add-EDT-ET028013DMA-panel.patch (drm-backport-placeholder)
- commit 186a5d3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0527-drm-panel-sitronix-st7789v-Clarify-a-definition.patch (drm-backport-placeholder)
- commit 849c7d8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0526-drm-panel-sitronix-st7789v-Use-9-bits-per-spi-word-b.patch (drm-backport-placeholder)
- commit 8ff2713
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0525-drm-panel-sitronix-st7789v-add-Inanbo-T28CP45TN89-su.patch (drm-backport-placeholder)
- commit b3e00c3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0524-drm-panel-sitronix-st7789v-avoid-hardcoding-polarity.patch (drm-backport-placeholder)
- commit 162f58e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0523-drm-panel-sitronix-st7789v-avoid-hardcoding-invert-m.patch (drm-backport-placeholder)
- commit 5f85128
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0522-drm-panel-sitronix-st7789v-add-media-bus-format.patch (drm-backport-placeholder)
- commit b812289
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0521-drm-panel-sitronix-st7789v-avoid-hardcoding-panel-si.patch (drm-backport-placeholder)
- commit 2408e6d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0520-drm-panel-sitronix-st7789v-avoid-hardcoding-mode-inf.patch (drm-backport-placeholder)
- commit 101cbc2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0519-drm-panel-sitronix-st7789v-improve-error-handling.patch (drm-backport-placeholder)
- commit 1180a45
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0518-drm-panel-sitronix-st7789v-simplify-st7789v_spi_writ.patch (drm-backport-placeholder)
- commit d705ff7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0517-drm-panel-sitronix-st7789v-make-reset-GPIO-optional.patch (drm-backport-placeholder)
- commit 33bc203
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0516-drm-panel-sitronix-st7789v-remove-unused-constants.patch (drm-backport-placeholder)
- commit 22ccb28
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0515-drm-panel-sitronix-st7789v-add-SPI-ID-table.patch (drm-backport-placeholder)
- commit b8937af
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0514-drm-tests-Alloc-drm_device-on-drm_exec-tests.patch (drm-backport-placeholder)
- commit 83b0073
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0513-drm-virtio-Support-sync-objects.patch (drm-backport-placeholder)
- commit 20a492a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0512-fbdev-Align-deferred-I-O-with-naming-of-helpers.patch (drm-backport-placeholder)
- commit 0620394
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0511-fbdev-Use-_DMAMEM_-infix-for-DMA-memory-helpers.patch (drm-backport-placeholder)
- commit 4ddc96a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0510-fbdev-Use-_SYSMEM_-infix-for-system-memory-helpers.patch (drm-backport-placeholder)
- commit 557ebf0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0509-fbdev-Use-_IOMEM_-infix-for-I-O-memory-helpers.patch (drm-backport-placeholder)
- commit b484c71
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-simple-Add-missing-connector-type-and-pixe.patch (drm-backport-placeholder)
- commit 382d311
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0507-drm-panel-Support-for-startek-kd070fhfid015-MIPI-DSI.patch (drm-backport-placeholder)
- commit 92f5098
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0506-drm-panel-ilitek-ili9881c-Add-TDO-TL050HDV35-LCD-pan.patch (drm-backport-placeholder)
- commit 9f6c9ac
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0505-drm-panel-simple-specify-bpc-for-powertip_ph800480t0.patch (drm-backport-placeholder)
- commit 94c92cb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0504-drm-panel-r66451-select-CONFIG_DRM_DISPLAY_DP_HELPER.patch (drm-backport-placeholder)
- commit 7fbbac9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0503-drm-vc4-tests-pv-muxing-Document-test-scenario.patch (drm-backport-placeholder)
- commit 766785e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0502-drm-vc4-tests-Switch-to-atomic-state-allocation-help.patch (drm-backport-placeholder)
- commit fe316d5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0501-drm-vc4-tests-pv-muxing-Switch-to-managed-locking-in.patch (drm-backport-placeholder)
- commit 864746d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0500-drm-vc4-tests-mock-Use-a-kunit-action-to-unregister-.patch (drm-backport-placeholder)
- commit a0282b9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0499-drm-vc4-tests-pv-muxing-Remove-call-to-drm_kunit_hel.patch (drm-backport-placeholder)
- commit 6d078f2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0498-drm-tests-helpers-Create-a-helper-to-allocate-an-ato.patch (drm-backport-placeholder)
- commit dd71b68
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0497-drm-tests-helpers-Create-a-helper-to-allocate-a-lock.patch (drm-backport-placeholder)
- commit 4ed48d1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0496-drm-tests-probe-helper-Remove-call-to-drm_kunit_help.patch (drm-backport-placeholder)
- commit 8d5fd53
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0495-drm-tests-modes-Remove-call-to-drm_kunit_helper_free.patch (drm-backport-placeholder)
- commit 00eff51
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0494-drm-tests-client-modeset-Remove-call-to-drm_kunit_he.patch (drm-backport-placeholder)
- commit 915c2ed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0493-drm-tests-helpers-Switch-to-kunit-actions.patch (drm-backport-placeholder)
- commit 6ba40f7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-fix-Wunused-const-variable-warning.patch (drm-backport-placeholder)
- commit 32eb1dc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0491-drm-ssd130x-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit bbbd32d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0490-drm-Fix-references-to-drm_plane_helper_check_state.patch (drm-backport-placeholder)
- commit 38d62ed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-Remove-references-to-removed-transitional-helper.patch (drm-backport-placeholder)
- commit c9f35ca
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0488-drm-todo-Convert-list-of-fbconv-links-to-footnotes.patch (drm-backport-placeholder)
- commit ff9960a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0487-drm-todo-Add-atomic-modesetting-references.patch (drm-backport-placeholder)
- commit e038f43
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-repaper-Reduce-temporary-buffer-size-in-repaper_.patch (drm-backport-placeholder)
- commit 227b0a7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-armada-Fix-off-by-one-error-in-armada_overlay_ge.patch (drm-backport-placeholder)
- commit 00453d9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0484-drm-Spelling-s-randevouz-rendez-vous.patch (drm-backport-placeholder)
- commit 844eda3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0483-drm-Spelling-s-sempahore-semaphore.patch (drm-backport-placeholder)
- commit 3880a6d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0482-drm-udl-Convert-to-drm_crtc_helper_atomic_check.patch (drm-backport-placeholder)
- commit 3dfd211
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0481-drm-bridge_connector-Handle-drm_connector_init_with_.patch (drm-backport-placeholder)
- commit e05ace7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0480-gpu-ipu-v3-prg-Convert-to-devm_platform_ioremap_reso.patch (drm-backport-placeholder)
- commit 722caeb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0479-gpu-ipu-v3-pre-Convert-to-devm_platform_ioremap_reso.patch (drm-backport-placeholder)
- commit 2f3f91f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0478-drm-imx-ipuv3-ipuv3-plane-reuse-local-variable-heigh.patch (drm-backport-placeholder)
- commit fef788b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-ast-report-connection-status-on-Display-Port.patch (drm-backport-placeholder)
- commit 1151d67
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-ast-Add-BMC-virtual-connector.patch (drm-backport-placeholder)
- commit 63bbebc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0475-drm-imx-dcss-Use-dev_err_probe.patch (drm-backport-placeholder)
- commit 400886f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0474-drm-panel-simple-Simplify-matching-using-of_device_g.patch (drm-backport-placeholder)
- commit c0c633e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0473-video-logo-LOGO-should-depend-on-FB_CORE-i.s.o.-FB.patch (drm-backport-placeholder)
- commit bc69180
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0472-Revert-fbcon-Use-kzalloc-in-fbcon_prepare_logo.patch (drm-backport-placeholder)
- commit 3d0d988
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-gem-fb-helper-Consistenly-use-drm_dbg_kms.patch (drm-backport-placeholder)
- commit a4ee009
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-atomic-helper-Update-reference-to-drm_crtc_force.patch (drm-backport-placeholder)
- commit 4d560ef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0469-drm-vkms-Fix-race-condition-between-the-hrtimer-and-.patch (drm-backport-placeholder)
- commit 05485be
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0468-drm-vkms-Add-support-to-1D-gamma-LUT.patch (drm-backport-placeholder)
- commit f4d9a1b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0467-drm-tegra-sor-Convert-to-devm_platform_ioremap_resou.patch (drm-backport-placeholder)
- commit 58c3f8a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0466-drm-tegra-hdmi-Convert-to-devm_platform_ioremap_reso.patch (drm-backport-placeholder)
- commit 29678e0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-tegra-dpaux-Fix-incorrect-return-value-of-platfo.patch (drm-backport-placeholder)
- commit 038b0cf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0464-drm-tegra-output-hdmi-Support-bridge-connector.patch (drm-backport-placeholder)
- commit c1aa0d2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0463-drm-tegra-Enable-runtime-PM-during-probe.patch (drm-backport-placeholder)
- commit f1ab8b1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0462-drm-tegra-dpaux-Use-devm_platform_ioremap_resource.patch (drm-backport-placeholder)
- commit 84aa5ab
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0461-gpu-host1x-Return-error-when-context-device-not-atta.patch (drm-backport-placeholder)
- commit ffff45a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0460-drm-tegra-Add-error-check-for-NVDEC-firmware-memory-.patch (drm-backport-placeholder)
- commit 2ffffb6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0459-drm-i915-Avoid-Wconstant-logical-operand-in-nsecs_to.patch (drm-backport-placeholder)
- commit 89c3abe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0458-drm-v3d-Avoid-Wconstant-logical-operand-in-nsecs_to_.patch (drm-backport-placeholder)
- commit a9fa424
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0457-drm-ssd130x-Use-shadow-buffer-helpers-when-managing-.patch (drm-backport-placeholder)
- commit 14ac6cb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0456-drm-xlnx-zynqmp_dpsub-Use-devm_platform_ioremap_reso.patch (drm-backport-placeholder)
- commit 39edc31
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0455-drm-xlnx-zynqmp_dpsub-Use-dev_err_probe-instead-of-d.patch (drm-backport-placeholder)
- commit 1c226e6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-xlnx-zynqmp_dpsub-Add-missing-check-for-dma_set_.patch (drm-backport-placeholder)
- commit df91f0c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0453-drm-xlnx-zynqmp_dp-Fix-function-name-zynqmp_dp_link_.patch (drm-backport-placeholder)
- commit 22c6628
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0452-drm-amdgpu-correct-vmhub-index-in-GMC-v10-11.patch (drm-backport-placeholder)
- commit e8609da
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0451-drm-amdgpu-Fix-non-standard-format-specifiers-in-amd.patch (drm-backport-placeholder)
- commit 2465eb4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0450-drm-amdgpu-set-completion-status-as-preempted-for-th.patch (drm-backport-placeholder)
- commit 5e1a2e2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0449-drm-radeon-Fix-ENOSYS-with-better-fitting-error-code.patch (drm-backport-placeholder)
- commit cc2f1d6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0448-drm-radeon-Remove-unnecessary-NULL-test-before-kfree.patch (drm-backport-placeholder)
- commit c2997ec
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0447-drm-amdgpu-Use-parentheses-for-sizeof-numa_info-in-a.patch (drm-backport-placeholder)
- commit d115e5b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0446-drm-amdgpu-Fix-unnecessary-else-after-return-in-amdg.patch (drm-backport-placeholder)
- commit 8b5c9b6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0445-drm-amdgpu-discovery-enable-PSP-14.0.0-support.patch (drm-backport-placeholder)
- commit 06bfa13
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0444-drm-amdgpu-add-PSP-14.0.0-support.patch (drm-backport-placeholder)
- commit 425adaf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0443-drm-radeon-Fix-format-error.patch (drm-backport-placeholder)
- commit b58752f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0442-drm-amdkfd-fix-and-enable-ttmp-setup-for-gfx11.patch (drm-backport-placeholder)
- commit 1553f25
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0441-drm-amdgpu-Move-externs-to-amdgpu.h-file-from-amdgpu.patch (drm-backport-placeholder)
- commit aec1b99
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0440-drm-amdgpu-Prefer-dev_-variant-over-printk-in-amdgpu.patch (drm-backport-placeholder)
- commit fac7f6b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0439-drm-amdgpu-Fix-no-new-typedefs-for-enum-_AMDGPU_DOOR.patch (drm-backport-placeholder)
- commit 8dc1aa3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0438-drm-amdgpu-Fix-ENOSYS-means-invalid-syscall-nr-in-am.patch (drm-backport-placeholder)
- commit d994483
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0437-drm-amdgpu-remove-repeat-code-for-mes_add_queue_pkt.patch (drm-backport-placeholder)
- commit 3d0cd0a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0436-drm-amdgpu-Checkpoint-and-Restore-VRAM-BOs-without-V.patch (drm-backport-placeholder)
- commit a560420
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0435-drm-amdgpu-enable-trap-of-each-kfd-vmid-for-gfx-v9.4.patch (drm-backport-placeholder)
- commit 9e45e24
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0434-drm-amd-pm-open-brace-following-struct-go-on-the-sam.patch (drm-backport-placeholder)
- commit efa0d5e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0433-drm-amd-pm-open-brace-following-function-definitions.patch (drm-backport-placeholder)
- commit ab2e746
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0432-drm-amd-pm-that-open-brace-should-be-on-the-previous.patch (drm-backport-placeholder)
- commit 50d4b01
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0431-drm-amd-pm-Clean-up-errors-in-arcturus_ppt.c.patch (drm-backport-placeholder)
- commit 7bdcdc9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0430-drm-amd-pm-Clean-up-errors-in-arcturus_ppt.c.patch (drm-backport-placeholder)
- commit 75232c1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0429-drm-amd-pm-Clean-up-errors-in-navi10_ppt.c.patch (drm-backport-placeholder)
- commit 7efcd68
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0428-drm-amd-pm-add-missing-spaces-before.patch (drm-backport-placeholder)
- commit 64281c7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0427-drm-radeon-Move-assignment-outside-if-condition.patch (drm-backport-placeholder)
- commit c2abc5b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0426-drm-radeon-that-open-brace-should-be-on-the-previous.patch (drm-backport-placeholder)
- commit 57093a7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0425-drm-radeon-that-open-brace-should-be-on-the-previous.patch (drm-backport-placeholder)
- commit 984b348
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0424-drm-radeon-add-missing-spaces-after-and-else-should-.patch (drm-backport-placeholder)
- commit 2378d67
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0423-drm-radeon-add-missing-spaces-before.patch (drm-backport-placeholder)
- commit 8167539
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0422-drm-radeon-si_dpm-open-brace-following-struct-go-on-.patch (drm-backport-placeholder)
- commit 847a852
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0421-drm-amd-pm-Vangogh-Add-new-gpu_metrics_v2_4-to-acqui.patch (drm-backport-placeholder)
- commit 9a76949
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0420-drm-amdgpu-load-sdma-ucode-in-the-guest-machine.patch (drm-backport-placeholder)
- commit 02cbe55
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0419-drm-amdgpu-Use-seq_puts-instead-of-seq_printf.patch (drm-backport-placeholder)
- commit b8773ee
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Update-min-to-min_t-in-amdgpu_info_ioctl.patch (drm-backport-placeholder)
- commit 9cfd958
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0417-drm-amdgpu-Remove-else-after-return-in-is_fru_eeprom.patch (drm-backport-placeholder)
- commit 43ce21e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0416-drm-amd-display-Remove-else-after-return-in-dm_vblan.patch (drm-backport-placeholder)
- commit d4bba6a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0415-drm-amdgpu-Add-ENOMEM-error-handling-when-there-is-n.patch (drm-backport-placeholder)
- commit 5b5a0c3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0414-drm-amdgpu-Check-APU-flag-to-disable-RAS.patch (drm-backport-placeholder)
- commit 1b782ac
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0413-drm-amdgpu-fix-the-indexing-issue-during-rlcg-access.patch (drm-backport-placeholder)
- commit d96b3a0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0412-drm-amdgpu-add-VISIBLE-info-in-amdgpu_bo_print_info.patch (drm-backport-placeholder)
- commit 7ac52b2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0411-drm-amdkfd-avoid-svm-dump-when-dynamic-debug-disable.patch (drm-backport-placeholder)
- commit c83bf2a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0410-drm-radeon-ERROR-foo-bar-should-be-foo-bar.patch (drm-backport-placeholder)
- commit cf517c9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0409-drm-amdgpu-open-brace-following-struct-go-on-the-sam.patch (drm-backport-placeholder)
- commit e1c75bf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0408-drm-amd-pm-open-brace-following-struct-go-on-the-sam.patch (drm-backport-placeholder)
- commit 2c50706
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0407-drm-amd-open-brace-following-struct-go-on-the-same-l.patch (drm-backport-placeholder)
- commit 76cdf29
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0406-drm-amd-display-3.2.244.patch (drm-backport-placeholder)
- commit 3db419b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0405-drm-amd-display-Fix-underflow-issue-on-175hz-timing.patch (drm-backport-placeholder)
- commit abfedb0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0404-drm-amd-display-Add-interface-to-modify-DMUB-panel-p.patch (drm-backport-placeholder)
- commit 1d32e6e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0403-drm-amd-display-Rearrange-dmub_cmd-defs-order.patch (drm-backport-placeholder)
- commit b28e047
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0402-drm-amd-display-Remove-check-for-default-eDP-panel_m.patch (drm-backport-placeholder)
- commit 79c905e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0401-drm-amdgpu-Fix-style-issues-in-amdgpu_gem.c.patch (drm-backport-placeholder)
- commit 6e2631c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0400-drm-amd-display-Add-new-sequence-for-4-lane-HBR3-on-.patch (drm-backport-placeholder)
- commit 7e5f45e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0399-drm-amd-display-Update-DPG-test-pattern-programming.patch (drm-backport-placeholder)
- commit 73a2c72
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0398-drm-amd-display-Correct-unit-conversion-for-vstartup.patch (drm-backport-placeholder)
- commit ca839d2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0397-drm-amd-display-Refactor-recout-calculation-with-a-m.patch (drm-backport-placeholder)
- commit d09461b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0396-drm-amd-display-Read-down-spread-percentage-from-lut.patch (drm-backport-placeholder)
- commit e503f63
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0395-drm-amd-display-Prevent-invalid-pipe-connections.patch (drm-backport-placeholder)
- commit 0130229
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0394-drm-amdgpu-Update-ring-scheduler-info-as-needed.patch (drm-backport-placeholder)
- commit 309a621
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0393-drm-amdgpu-Enabling-FW-workaround-through-shared-mem.patch (drm-backport-placeholder)
- commit 98bee64
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0392-drm-amd-display-Add-VESA-SCR-case-for-default-aux-ba.patch (drm-backport-placeholder)
- commit e4940a3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0391-drm-radeon-Prefer-dev_-variant-over-printk.patch (drm-backport-placeholder)
- commit 2b0a935
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0390-drm-radeon-Fix-style-issues-in-radeon-_encoders.c-_g.patch (drm-backport-placeholder)
- commit c22aa14
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0389-drm-amd-amdgpu-Fix-warnings-in-amdgpu-amdgpu_display.patch (drm-backport-placeholder)
- commit 088d659
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0388-drm-radeon-Avoid-externs-do-not-initialize-globals-t.patch (drm-backport-placeholder)
- commit 7fb7ff6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0387-drm-amd-display-Correct-grammar-mistakes.patch (drm-backport-placeholder)
- commit 1d3bccd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0386-drm-amdgpu-Return-ENOMEM-when-there-is-no-memory-in-.patch (drm-backport-placeholder)
- commit 1eb3cd3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0385-drm-amdgpu-Fix-do-not-add-new-typedefs-in-amdgpu_fw_.patch (drm-backport-placeholder)
- commit fef19b4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0384-drm-amdgpu-Prefer-if-IS_ENABLED-over-if-defined-in-a.patch (drm-backport-placeholder)
- commit 1be0219
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0383-drm-amdkfd-enable-cooperative-groups-for-gfx11.patch (drm-backport-placeholder)
- commit 5d25dcc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0382-drm-amdgpu-set-sw-state-to-gfxoff-after-SR-IOV-reset.patch (drm-backport-placeholder)
- commit 29f9ffb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0381-drm-amdgpu-Fix-one-kernel-doc-comment.patch (drm-backport-placeholder)
- commit 4b0d079
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0380-drm-amdgpu-Program-xcp_ctl-registers-as-needed.patch (drm-backport-placeholder)
- commit 55eeae8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0379-drm-amd-display-Allow-building-DC-with-clang-on-RISC.patch (drm-backport-placeholder)
- commit 8b3577c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0378-drm-amd-display-remove-an-unused-file.patch (drm-backport-placeholder)
- commit 4740697
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0377-drm-radeon-Prefer-pr_err-_info-over-printk.patch (drm-backport-placeholder)
- commit 677e858
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0376-drm-amdgpu-allow-secure-submission-on-VCN4-ring.patch (drm-backport-placeholder)
- commit 8a6e5ba
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0375-drm-amd-Avoid-reading-the-VBIOS-part-number-twice.patch (drm-backport-placeholder)
- commit 2c9204e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0374-drm-amdgpu-Add-RLCG-interface-driver-implementation-.patch (drm-backport-placeholder)
- commit 11d018a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0373-drm-amd-display-Promote-DAL-to-3.2.243.patch (drm-backport-placeholder)
- commit a4ddadd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0372-drm-amd-display-Add-missing-triggers-for-full-update.patch (drm-backport-placeholder)
- commit f6eadb8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0371-drm-amd-display-ABM-pause-toggle.patch (drm-backport-placeholder)
- commit da18e2c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0370-drm-amd-display-Fix-ASIC-check-in-aux-timeout-workar.patch (drm-backport-placeholder)
- commit cd5cb0d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0369-drm-amd-display-Add-link-encoding-to-timing-BW-calcu.patch (drm-backport-placeholder)
- commit 9df3eac
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0368-drm-amd-display-Add-stream-overhead-in-BW-calculatio.patch (drm-backport-placeholder)
- commit a64e227
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0367-drm-amd-display-Initialize-necessary-uninitialized-v.patch (drm-backport-placeholder)
- commit 7bd1f68
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0366-drm-amd-display-Add-helpers-to-get-DMUB-FW-boot-opti.patch (drm-backport-placeholder)
- commit 4efd421
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0365-drm-amd-display-Promote-DAL-to-3.2.242.patch (drm-backport-placeholder)
- commit 25d4d8c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0364-drm-amd-display-Update-128b-132b-downspread-factor-t.patch (drm-backport-placeholder)
- commit 5122f47
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0363-drm-amd-display-Fix-race-condition-when-turning-off-.patch (drm-backport-placeholder)
- commit b1d0aa6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0362-drm-amd-display-add-additional-refresh-rate-conditio.patch (drm-backport-placeholder)
- commit 0d3d6c2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0361-drm-amd-display-refine-to-decide-the-verified-link-s.patch (drm-backport-placeholder)
- commit 3c6be77
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0360-drm-amd-display-Fix-DP2-link-training-failure-with-R.patch (drm-backport-placeholder)
- commit 209ec71
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0359-drm-amd-display-Cache-backlight_millinits-in-link-st.patch (drm-backport-placeholder)
- commit bc5e135
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0358-drm-amd-display-Reenable-all-root-clock-gating-optio.patch (drm-backport-placeholder)
- commit 54343df
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0357-drm-amd-display-Update-SW-cursor-fallback-for-subvp-.patch (drm-backport-placeholder)
- commit d27db72
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0356-drm-amd-display-Skip-querying-caps-when-DMCUB-emulat.patch (drm-backport-placeholder)
- commit e2d0300
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0355-drm-amd-display-Update-scaler-recout-data-for-visual.patch (drm-backport-placeholder)
- commit 93a0a5f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0354-drm-amd-display-Skip-enabling-DMCUB-when-using-emula.patch (drm-backport-placeholder)
- commit b7e4b01
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0353-drm-amd-display-Reduce-stack-size.patch (drm-backport-placeholder)
- commit eadd0d9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0352-drm-amd-display-Hardcode-vco_freq-for-dcn316.patch (drm-backport-placeholder)
- commit e44b846
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0351-drm-amd-display-Add-missing-static.patch (drm-backport-placeholder)
- commit aed3557
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0350-drm-amd-display-Remove-unused-function.patch (drm-backport-placeholder)
- commit 992c5ef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0349-drm-amd-display-Improve-the-include-of-header-file.patch (drm-backport-placeholder)
- commit 65b1cf3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0348-drm-amd-display-Re-add-aux-intercept-disable-delay-g.patch (drm-backport-placeholder)
- commit 390f455
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0347-drm-amd-display-Use-is_dig_enable-function-instead-o.patch (drm-backport-placeholder)
- commit 8425a41
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0346-drm-amd-display-Setup-stream-encoder-before-link-ena.patch (drm-backport-placeholder)
- commit fd227f4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0345-drm-amdgpu-create-a-new-file-for-doorbell-manager.patch (drm-backport-placeholder)
- commit 65d3e05
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0344-drm-amdgpu-Add-dcdebugmask-option-to-enable-DPIA-tra.patch (drm-backport-placeholder)
- commit e2dce57
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0343-drm-amdgpu-Disable-RAS-by-default-on-APU-flatform.patch (drm-backport-placeholder)
- commit 776e010
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0342-drm-amdgpu-Enable-aqua-vanjaram-RAS.patch (drm-backport-placeholder)
- commit 88eb8e7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0341-drm-amdgpu-Avoid-possiblity-of-kernel-crash-in-gmc_v.patch (drm-backport-placeholder)
- commit bc6d4f4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0340-drm-amd-display-Eliminate-warnings-in-amdgpu_dm_help.patch (drm-backport-placeholder)
- commit 291105a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0339-drm-amd-display-Clean-up-style-problems-in-amdgpu_dm.patch (drm-backport-placeholder)
- commit 488bb0a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0338-drm-amd-display-Implement-zpos-property.patch (drm-backport-placeholder)
- commit cf9b2f9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0337-drm-amd-display-Enable-3-plane-for-DCN-3.01.patch (drm-backport-placeholder)
- commit e391675
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0336-drm-amd-display-Expose-more-formats-for-overlay-plan.patch (drm-backport-placeholder)
- commit 54c98c3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0335-Revert-drm-amdgpu-update-kernel-vcn-ring-test.patch (drm-backport-placeholder)
- commit 7c533f9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0334-Revert-drm-amdgpu-update-kernel-vcn-ring-test.patch (drm-backport-placeholder)
- commit 11ba5d9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0333-drm-amdgpu-Fix-error-warnings-in-gmc_v8_0.c.patch (drm-backport-placeholder)
- commit 16cdbc2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-dc.h-eliminate-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit c0f864d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0331-drm-amdgpu-Rename-to-amdgpu_vm_tlb_seq_struct.patch (drm-backport-placeholder)
- commit 07a1fd2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0330-drm-amdkfd-Fix-stack-size-in-amdgpu_amdkfd_unmap_hiq.patch (drm-backport-placeholder)
- commit 103c15d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0329-drm-amdkfd-report-dispatch-id-always-saved-in-ttmps-.patch (drm-backport-placeholder)
- commit 62f989a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0328-drm-amdgpu-update-kernel-vcn-ring-test.patch (drm-backport-placeholder)
- commit 80b12ed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0327-drm-amdgpu-update-kernel-vcn-ring-test.patch (drm-backport-placeholder)
- commit fa9157a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0326-drm-amdgpu-add-watchdog-timer-enablement-for-gfx_v9_.patch (drm-backport-placeholder)
- commit fbc3e60
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0325-drm-amdkfd-Update-CWSR-grace-period-for-GFX9.4.3.patch (drm-backport-placeholder)
- commit 54128db
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0324-drm-radeon-ERROR-foo-should-be-foo.patch (drm-backport-placeholder)
- commit 7f2061b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0323-drm-radeon-ERROR-that-open-brace-should-be-on-the-pr.patch (drm-backport-placeholder)
- commit 0f06e85
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0322-drm-radeon-ERROR-foo-should-be-foo.patch (drm-backport-placeholder)
- commit d2facc6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0321-drm-radeon-ERROR-foo-should-be-foo.patch (drm-backport-placeholder)
- commit 7fc36d8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0320-drm-radeon-ERROR-foo-bar-should-be-foo-bar.patch (drm-backport-placeholder)
- commit 07f09fe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0319-drm-amdgpu-use-psp_execute_load_ip_fw-instead.patch (drm-backport-placeholder)
- commit b2cda63
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0318-drm-amdgpu-rename-psp_execute_non_psp_fw_load-and-ma.patch (drm-backport-placeholder)
- commit 34049bd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0317-drm-amdkfd-add-multi-process-debugging-support-for-G.patch (drm-backport-placeholder)
- commit 8f7e0f6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0316-drm-amdkfd-enable-watch-points-globally-for-gfx943.patch (drm-backport-placeholder)
- commit bdee0e6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0315-drm-amdkfd-restore-debugger-additional-info-for-gfx-.patch (drm-backport-placeholder)
- commit f1468c1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0314-drm-amdkfd-add-kfd2kgd-debugger-callbacks-for-GC-v9..patch (drm-backport-placeholder)
- commit 3a20936
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-avoid-integer-overflow-warning-in-amdgpu_.patch (drm-backport-placeholder)
- commit dd2cab9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0312-drm-amdgpu-Increase-soft-IH-ring-size.patch (drm-backport-placeholder)
- commit 0be8f2a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0311-drm-amdgpu-gfx10-move-update_spm_vmid-out-of-rlc_ini.patch (drm-backport-placeholder)
- commit 2662fa2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0310-drm-amdgpu-gfx9-move-update_spm_vmid-out-of-rlc_init.patch (drm-backport-placeholder)
- commit 6d6b952
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0309-drm-amdgpu-Fix-errors-warnings-in-gfx_v10_0.c.patch (drm-backport-placeholder)
- commit dbbd0ee
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0308-drm-amdgpu-Fix-warnings-in-gfxhub_-v3_0-v3_0_3.c.patch (drm-backport-placeholder)
- commit f2f0971
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0307-drm-amdgpu-Fix-warnings-in-gmc_v8_0.c.patch (drm-backport-placeholder)
- commit 83f588f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0306-drm-amd-pm-disbale-dcefclk-device-sysnode-on-GFX-v9..patch (drm-backport-placeholder)
- commit 405fe92
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0305-drm-amdgpu-vkms-drop-redundant-set-of-fb_modifiers_n.patch (drm-backport-placeholder)
- commit 651ad3a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0304-drm-amdgpu-Remove-else-after-return-statement-in-gfx.patch (drm-backport-placeholder)
- commit b19bd20
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0303-drm-amdgpu-Fix-warnings-in-gmc_v11_0.c.patch (drm-backport-placeholder)
- commit d562361
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0302-drm-amdgpu-Remove-else-after-return-statement-in-gmc.patch (drm-backport-placeholder)
- commit 604b940
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0301-drm-amdgpu-Fix-warnings-in-gfxhub_v2_1.c.patch (drm-backport-placeholder)
- commit 1e4f470
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0300-drm-amdgpu-Fix-errors-warnings-in-gmc_-v6_0-v7_0.c.patch (drm-backport-placeholder)
- commit e497b0b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0299-drm-amdgpu-Fix-warnings-in-gmc_v10_0.c.patch (drm-backport-placeholder)
- commit c0c5ec9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0298-drm-amdgpu-Prefer-dev_warn-over-printk.patch (drm-backport-placeholder)
- commit 3ebedaa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0297-drm-amdgpu-Fix-warnings-in-gfxhub_v2_0.c.patch (drm-backport-placeholder)
- commit 8654196
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0296-drm-amdgpu-Remove-redundant-GFX-v9.4.3-sequence.patch (drm-backport-placeholder)
- commit 7c53802
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0295-drm-amdgpu-Fix-warnings-in-gfxhub_-v1_0-v1_2.c.patch (drm-backport-placeholder)
- commit 89a6e20
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0294-drm-amd-display-Block-optimize-on-consecutive-FAMS-e.patch (drm-backport-placeholder)
- commit d4c1338
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Do-not-set-drr-on-pipe-commit.patch (drm-backport-placeholder)
- commit b48dbcd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0292-drm-amdgpu-Fix-error-warnings-in-gmc_v9_0.c.patch (drm-backport-placeholder)
- commit f4af06b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0291-drm-amdgpu-Change-golden-settings-for-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit 5bb44f4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0290-drm-amdkfd-Skip-handle-mapping-SVM-range-with-no-GPU.patch (drm-backport-placeholder)
- commit 2bf9f0b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0289-drm-amd-amdgpu-Add-cu_occupancy-sysfs-file-to-GFX9.4.patch (drm-backport-placeholder)
- commit 8a866e6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0288-drm-amdgpu-have-bos-for-PDs-PTS-cpu-accessible-when-.patch (drm-backport-placeholder)
- commit 7b65c08
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0287-drm-amdkfd-Use-KIQ-to-unmap-HIQ.patch (drm-backport-placeholder)
- commit bf99e96
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0286-drm-amd-display-Clean-up-warnings-in-amdgpu_dm-_mst_.patch (drm-backport-placeholder)
- commit 3b8dba7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0285-drm-amd-display-Remove-unnecessary-casts-in-amdgpu_d.patch (drm-backport-placeholder)
- commit e70756c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0284-drm-amd-display-Clean-up-warnings-in-amdgpu_dm_pp_sm.patch (drm-backport-placeholder)
- commit e46fe51
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0283-drm-amdgpu-skip-address-adjustment-for-GFX-RAS-injec.patch (drm-backport-placeholder)
- commit 39e8c7d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0282-drm-amdgpu-Update-invalid-PTE-flag-setting.patch (drm-backport-placeholder)
- commit 5571416
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0281-drm-amdgpu-return-an-error-if-query_video_caps-is-no.patch (drm-backport-placeholder)
- commit c0d9660
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0280-drm-amdkfd-Access-gpuvm_export_dmabuf-API-to-get-Dma.patch (drm-backport-placeholder)
- commit de3fe4f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0279-drm-amd-adjust-whitespace-for-amdgpu_psp.h.patch (drm-backport-placeholder)
- commit 24792cf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0278-drm-amd-Detect-IFWI-or-PD-upgrade-support-in-psp_ear.patch (drm-backport-placeholder)
- commit ec1b31e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0277-drm-amd-Add-documentation-for-how-to-flash-a-dGPU.patch (drm-backport-placeholder)
- commit 042d3c1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0276-drm-amd-Convert-USB-C-PD-F-W-attributes-into-groups.patch (drm-backport-placeholder)
- commit 78209fc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0275-drm-amd-Make-flashing-messages-quieter.patch (drm-backport-placeholder)
- commit 58f7c9c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0274-drm-amd-Use-attribute-groups-for-PSP-flashing-attrib.patch (drm-backport-placeholder)
- commit 25cdd95
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0273-drm-amd-display-fix-comment-typo.patch (drm-backport-placeholder)
- commit 6767240
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0272-drm-amd-display-Use-seq_puts-in-amdgpu_current_color.patch (drm-backport-placeholder)
- commit dbf3d96
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0271-drm-amd-display-Remove-redundant-braces-in-amdgpu_dm.patch (drm-backport-placeholder)
- commit c068a21
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0270-drm-amd-display-Clean-up-style-problems-in-amdgpu_dm.patch (drm-backport-placeholder)
- commit bf783d4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0269-drm-amd-display-Remove-else-after-return-in-dm_crtc_.patch (drm-backport-placeholder)
- commit 34dade0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0268-drm-amd-display-Remove-else-after-return-statement-i.patch (drm-backport-placeholder)
- commit 488d2c8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0267-drm-amdgpu-Rename-aqua_vanjaram_reg_init.c.patch (drm-backport-placeholder)
- commit ab7d830
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0266-dma-buf-Fix-the-typo-in-DMA-BUF-statistics-doc.patch (drm-backport-placeholder)
- commit cf271eb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0265-drm-ssd130x-Allocate-buffer-in-the-plane-s-.atomic_c.patch (drm-backport-placeholder)
- commit f40d8af
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0264-drm-ssd130x-Inline-the-ssd130x_buf_-alloc-free-funct.patch (drm-backport-placeholder)
- commit 56440b2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0263-drm-ast-Do-not-enable-PCI-resources-multiple-times.patch (drm-backport-placeholder)
- commit 800d0e2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0262-drm-panel-ld9040-add-backlight-Kconfig-dependency.patch (drm-backport-placeholder)
- commit e9975e6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0261-fbdev-Harmonize-some-comments-in-linux-fb.h.patch (drm-backport-placeholder)
- commit d3b0b07
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0260-fbdev-Remove-FB_DEFAULT_SYS_OPS.patch (drm-backport-placeholder)
- commit e32734f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0259-drm-omapdrm-Set-fbdev-FBINFO_VIRTFB-flag.patch (drm-backport-placeholder)
- commit 374c629
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0258-drm-omapdrm-Use-GEM-mmap-for-fbdev-emulation.patch (drm-backport-placeholder)
- commit 9a7648b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0257-drm-omapdrm-Set-VM-flags-in-GEM-object-mmap-function.patch (drm-backport-placeholder)
- commit b01aabc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0256-drm-exynos-Set-fbdev-FBINFO_VIRTFB-flag.patch (drm-backport-placeholder)
- commit 944a159
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0255-drm-exynos-Use-fbdev-DMA-helpers.patch (drm-backport-placeholder)
- commit 485611d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0254-drm-tegra-Store-pointer-to-vmap-ed-framebuffer-in-sc.patch (drm-backport-placeholder)
- commit c852046
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0253-drm-tegra-Set-fbdev-FBINFO_VIRTFB-flag.patch (drm-backport-placeholder)
- commit 25ace41
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0252-drm-tegra-Use-fbdev-DMA-helpers.patch (drm-backport-placeholder)
- commit f9397de
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0251-drm-fbdev-dma-Use-fbdev-DMA-helpers.patch (drm-backport-placeholder)
- commit b228559
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0250-fbdev-Add-fb_ops-init-macros-for-framebuffers-in-DMA.patch (drm-backport-placeholder)
- commit c130a94
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0249-drm-panel-db7430-remove-unused-variables.patch (drm-backport-placeholder)
- commit 9b5f4bf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0248-fbdev-Document-that-framebuffer_alloc-returns-zero-e.patch (drm-backport-placeholder)
- commit 88cadb6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0247-fbdev-Remove-FBINFO_DEFAULT-and-FBINFO_FLAG_DEFAULT.patch (drm-backport-placeholder)
- commit f4d77fb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0245-fbdev-pxafb-Remove-flag-FBINFO_FLAG_DEFAULT.patch (drm-backport-placeholder)
- commit bac786e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0244-fbdev-atafb-Remove-flag-FBINFO_FLAG_DEFAULT.patch (drm-backport-placeholder)
- commit fd1d8af
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0243-fbdev-Remove-FBINFO_FLAG_DEFAULT-from-framebuffer_al.patch (drm-backport-placeholder)
- commit 4101cf4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0242-fbdev-Remove-FBINFO_FLAG_DEFAULT-from-kzalloc-ed-str.patch (drm-backport-placeholder)
- commit c325574
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0241-fbdev-fsl-diu-fb-Remove-flag-FBINFO_DEFAULT.patch (drm-backport-placeholder)
- commit f83f335
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0236-fbdev-Remove-FBINFO_DEFAULT-from-framebuffer_alloc-e.patch (drm-backport-placeholder)
- commit 1f0b2ce
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0235-fbdev-Remove-FBINFO_DEFAULT-from-devm_kzalloc-ed-str.patch (drm-backport-placeholder)
- commit 7d60251
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0234-fbdev-Remove-FBINFO_DEFAULT-from-kzalloc-ed-structs.patch (drm-backport-placeholder)
- commit 6786678
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0233-fbdev-Remove-FBINFO_DEFAULT-from-static-structs.patch (drm-backport-placeholder)
- commit 6dce7d2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0232-drm-Remove-flag-FBINFO_DEFAULT-from-fbdev-emulation.patch (drm-backport-placeholder)
- commit d71cc68
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0231-drm-managed-Clean-up-GFP_-flag-usage-in-drmm_kmalloc.patch (drm-backport-placeholder)
- commit 8ba6e47
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0230-drm-bridge-Remove-redundant-i2c_client-in-anx7625-it.patch (drm-backport-placeholder)
- commit 3b4e76d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0229-drm-bridge-it6505-Fix-Kconfig-indentation.patch (drm-backport-placeholder)
- commit 9da84c2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-anx7625-Drop-device-lock-before-drm_helpe.patch (drm-backport-placeholder)
- commit a9e1624
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0227-drm-Make-FB_CORE-to-be-selected-if-DRM-fbdev-emulati.patch (drm-backport-placeholder)
- commit dad3ebd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0226-fbdev-Split-frame-buffer-support-in-FB-and-FB_CORE-s.patch (drm-backport-placeholder)
- commit a46cb71
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0225-fbdev-Move-core-fbdev-symbols-to-a-separate-Kconfig-.patch (drm-backport-placeholder)
- commit 7aa5ad0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0224-video-Add-auxiliary-display-drivers-to-Graphics-supp.patch (drm-backport-placeholder)
- commit bb9969d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0223-drm-ssd130x-Fix-pitch-calculation-in-ssd130x_fb_blit.patch (drm-backport-placeholder)
- commit 9ac2239
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0222-drm-bridge-tc358767-give-VSDELAY-some-positive-value.patch (drm-backport-placeholder)
- commit 682c0bd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0221-drm-bridge-tc358767-increase-PLL-lock-time-delay.patch (drm-backport-placeholder)
- commit 3359a17
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0220-drm-arm-komeda-Remove-component-framework-and-add-a-.patch (drm-backport-placeholder)
- commit e25e2eb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-adv7511-Fix-low-refresh-rate-register-for-ADV753.patch (drm-backport-placeholder)
- commit b13d74e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0218-drm-Explicitly-include-correct-DT-includes.patch (drm-backport-placeholder)
- commit 07a314b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0217-gpu-host1x-Explicitly-include-correct-DT-includes.patch (drm-backport-placeholder)
- commit cd1bb4c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0216-drm-debugfs-Silence-warning-from-cast.patch (drm-backport-placeholder)
- commit ff70e62
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0215-drm-manager-Fix-printk-format-for-size_t.patch (drm-backport-placeholder)
- commit 88cf1ef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0214-drm-panel-simple-Drop-prepared_time.patch (drm-backport-placeholder)
- commit bb165f1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0213-drm-syncobj-add-IOCTL-to-register-an-eventfd.patch (drm-backport-placeholder)
- commit 3608874
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0212-drm-debugfs-provide-infrastructure-to-dump-a-DRM-GPU.patch (drm-backport-placeholder)
- commit d85c731
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0211-drm-manager-to-keep-track-of-GPUs-VA-mappings.patch (drm-backport-placeholder)
- commit fb72881
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-anx7625-Use-common-macros-for-HDCP-capabi.patch (drm-backport-placeholder)
- commit 6f1a4e3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-anx7625-Use-common-macros-for-DP-power-se.patch (drm-backport-placeholder)
- commit d54526d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0208-drm-file-use-explicit-values-for-enum-drm_minor_type.patch (drm-backport-placeholder)
- commit 5c6482e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0207-drm-drv-use-enum-drm_minor_type-when-appropriate.patch (drm-backport-placeholder)
- commit 193f88c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0206-drm-panel-ld9040-Register-a-backlight-device.patch (drm-backport-placeholder)
- commit 2b3ee57
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0205-drm-panel-ld9040-Use-better-magic-values.patch (drm-backport-placeholder)
- commit e1d721b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0204-drm-ssd130x-Change-pixel-format-used-to-compute-the-.patch (drm-backport-placeholder)
- commit 611ab1c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0203-drm-loongson-Remove-a-useless-check-in-cursor_plane_.patch (drm-backport-placeholder)
- commit c3b39aa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0202-drm-amdgpu-use-the-new-drm_exec-object-for-CS-v3.patch (drm-backport-placeholder)
- commit 2399158
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0201-drm-amdgpu-use-drm_exec-for-MES-testing.patch (drm-backport-placeholder)
- commit af38bf7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0200-drm-amdgpu-use-drm_exec-for-GEM-and-CSA-handling-v2.patch (drm-backport-placeholder)
- commit b1c8a09
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0199-drm-amdkfd-switch-over-to-using-drm_exec-v3.patch (drm-backport-placeholder)
- commit 6a02ccf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0198-drm-add-drm_exec-selftests-v4.patch (drm-backport-placeholder)
- commit 790b323
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0197-drm-execution-context-for-GEM-buffers-v7.patch (drm-backport-placeholder)
- commit 05f64cb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0196-fbdev-hyperv_fb-Include-linux-screen_info.h.patch (drm-backport-placeholder)
- commit 4694c96
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0195-drm-arm-Make-ARM-devices-menu-depend-on-DRM.patch (drm-backport-placeholder)
- commit 25e0c10
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0194-drm-ttm-Use-init_on_free-to-delay-release-TTM-BOs.patch (drm-backport-placeholder)
- commit ad686ea
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0193-drm-bridge-cdns-mhdp8546-Fix-the-interrupt-enable-di.patch (drm-backport-placeholder)
- commit 09a9ff9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0192-drm-tidss-Update-encoder-bridge-chain-connect-model.patch (drm-backport-placeholder)
- commit 26329cb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0191-drm-bridge-sii902x-Set-input_bus_flags-in-atomic_che.patch (drm-backport-placeholder)
- commit 53f5b39
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0190-drm-bridge-sii902x-Support-format-negotiation-hooks.patch (drm-backport-placeholder)
- commit 074b8ea
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0189-drm-bridge-mhdp8546-Set-input_bus_flags-from-atomic_.patch (drm-backport-placeholder)
- commit b86f6df
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0188-drm-bridge-mhdp8546-Add-minimal-format-negotiation.patch (drm-backport-placeholder)
- commit 490b1be
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0187-drm-bridge-tfp410-Set-input_bus_flags-in-atomic_chec.patch (drm-backport-placeholder)
- commit 4764118
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0186-drm-bridge-tfp410-Support-format-negotiation-hooks.patch (drm-backport-placeholder)
- commit f4140e7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0185-drm-bridge-tc358767-Use-devm_clk_get_enabled-helper.patch (drm-backport-placeholder)
- commit 14afcef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0184-drm-nouveau-disp-use-drm_kms_helper_connector_hotplu.patch (drm-backport-placeholder)
- commit 2b5d7c1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0183-nouveau-dispnv50-add-cursor-pitch-check.patch (drm-backport-placeholder)
- commit aae0c5d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0182-drm-virtio-Conditionally-allocate-virtio_gpu_fence.patch (drm-backport-placeholder)
- commit 9fe7fc2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-hyperv-Fix-a-compilation-issue-because-of-not-in.patch (drm-backport-placeholder)
- commit c2b7f4d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0180-fbdev-xen-fbfront-Generate-deferred-I-O-ops.patch (drm-backport-placeholder)
- commit 2cdfac2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0179-fbdev-xen-fbfront-Select-FB_SYS_HELPERS_DEFERRED.patch (drm-backport-placeholder)
- commit 3f5403a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0178-fbdev-ssd1307fb-Generate-deferred-I-O-ops.patch (drm-backport-placeholder)
- commit 866ef1b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0177-fbdev-ssd1307fb-Select-FB_SYS_HELPERS_DEFERRED.patch (drm-backport-placeholder)
- commit 8e5e7ee
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0176-fbdev-metronomefb-Generate-deferred-I-O-ops.patch (drm-backport-placeholder)
- commit ae466e6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0175-fbdev-metronomefb-Select-FB_SYS_HELPERS_DEFERRED.patch (drm-backport-placeholder)
- commit e0d4636
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0174-fbdev-hecubafb-Generate-deferred-I-O-ops.patch (drm-backport-placeholder)
- commit 8a2d947
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0173-fbdev-hecubafb-Select-FB_SYS_HELPERS_DEFERRED.patch (drm-backport-placeholder)
- commit 01727cd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0172-fbdev-broadsheetfb-Generate-deferred-I-O-ops.patch (drm-backport-placeholder)
- commit c1a48f2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0171-fbdev-broadsheetfb-Select-FB_SYS_HELPERS_DEFERRED.patch (drm-backport-placeholder)
- commit 5cc08d7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0170-sysfb-Do-not-include-linux-screen_info.h-from-sysfb-.patch (drm-backport-placeholder)
- commit 0a4b61a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0169-fbdev-sm712fb-Do-not-include-linux-screen_info.h.patch (drm-backport-placeholder)
- commit 51bf224
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0168-drm-nouveau-disp-drop-unused-argument-in-nv50_dp_mod.patch (drm-backport-placeholder)
- commit ad705b5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0167-drm-nouveau-kms-don-t-call-drm_dp_cec_set_edid-on-TM.patch (drm-backport-placeholder)
- commit 2d0a9a1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0166-drm-nouveau-nvif-fix-potential-double-free.patch (drm-backport-placeholder)
- commit 02dd332
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0165-drm-nouveau-fifo-ga100-add-per-runlist-nonstall-intr.patch (drm-backport-placeholder)
- commit 95bd30f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0164-drm-nouveau-fifo-ga100-remove-individual-runlists-ra.patch (drm-backport-placeholder)
- commit ba29845
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0163-drm-nouveau-fifo-return-ERR_PTR-from-nvkm_runl_new.patch (drm-backport-placeholder)
- commit 34139e4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0162-drm-nouveau-fifo-remove-left-over-references-to-nvkm.patch (drm-backport-placeholder)
- commit f983830
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0161-drm-nouveau-fb-ga102-construct-vidmem-heap-via-new-g.patch (drm-backport-placeholder)
- commit 74839f4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0160-drm-nouveau-fb-gp102-ga100-switch-to-simpler-vram-si.patch (drm-backport-placeholder)
- commit 2b2dbef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0159-drm-nouveau-nvkm-punt-spurious-irq-messages-to-debug.patch (drm-backport-placeholder)
- commit 02f59b0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0158-drm-nouveau-nvkm-fini-object-children-in-reverse-ord.patch (drm-backport-placeholder)
- commit a4602aa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0157-drm-Add-kms-driver-for-loongson-display-controller.patch (drm-backport-placeholder)
- commit 430964f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0156-drm-drm_gem.c-Remove-surplus-else-after-return.patch (drm-backport-placeholder)
- commit 665af8d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0155-drm-gud-use-vmalloc_array-and-vcalloc.patch (drm-backport-placeholder)
- commit 0201e3a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0154-drm-bridge-samsung-dsim-Drain-command-transfer-FIFO-.patch (drm-backport-placeholder)
- commit b36ca0c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0153-drm-edid-Add-quirk-for-OSVR-HDK-2.0.patch (drm-backport-placeholder)
- commit 41272eb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0152-drm-tests-Fix-swapped-drm_framebuffer-tests-paramete.patch (drm-backport-placeholder)
- commit ceed865
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0151-drm-edid-make-read-only-const-array-static.patch (drm-backport-placeholder)
- commit ddbe9f9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0150-drm-ast-Merge-config-and-chip-detection.patch (drm-backport-placeholder)
- commit fa08467
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0149-drm-ast-Move-widescreen-and-tx-chip-detection-into-s.patch (drm-backport-placeholder)
- commit aecca96
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0148-drm-ast-Detect-AST-2510-model.patch (drm-backport-placeholder)
- commit d8b7398
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0147-drm-ast-Detect-AST-1400-model.patch (drm-backport-placeholder)
- commit 8090b89
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0146-drm-ast-Detect-AST-1300-model.patch (drm-backport-placeholder)
- commit e94d064
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0145-drm-ast-Distinguish-among-chip-generations.patch (drm-backport-placeholder)
- commit 037d052
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0144-drm-ast-Set-up-release-action-right-after-enabling-M.patch (drm-backport-placeholder)
- commit b3103fa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0143-drm-ast-Enable-and-unlock-device-access-early-during.patch (drm-backport-placeholder)
- commit 16a6a34
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0142-drm-ast-Set-PCI-config-before-accessing-I-O-register.patch (drm-backport-placeholder)
- commit b5d1160
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0141-drm-ast-Remove-device-POSTing-and-config-from-chip-d.patch (drm-backport-placeholder)
- commit 2874bf1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0140-drm-ast-Remove-dead-else-branch-in-POST-code.patch (drm-backport-placeholder)
- commit a9a15b5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0139-drm-ast-Implement-register-helpers-in-ast_drv.h.patch (drm-backport-placeholder)
- commit 3131ae9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0138-drm-ast-Remove-vga2_clone-field.patch (drm-backport-placeholder)
- commit 5e3ec78
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-ast-Fix-DRAM-init-on-AST2200.patch (drm-backport-placeholder)
- commit a653eaa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0136-drm-ttm-Don-t-shadow-the-operation-context.patch (drm-backport-placeholder)
- commit 6ac9ad5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0135-fbdev-Make-support-for-userspace-interfaces-configur.patch (drm-backport-placeholder)
- commit 50451a8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0134-fbdev-core-Rework-fb-init-code.patch (drm-backport-placeholder)
- commit 66aaa6a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0133-fbdev-core-Move-file-I-O-code-into-separate-file.patch (drm-backport-placeholder)
- commit 7e42ef7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0132-fbdev-core-Move-procfs-code-to-separate-file.patch (drm-backport-placeholder)
- commit d53d14b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0131-fbdev-core-Add-fb_device_-create-destroy.patch (drm-backport-placeholder)
- commit 126877d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0130-fbdev-core-Move-framebuffer-and-backlight-helpers-in.patch (drm-backport-placeholder)
- commit 0e8f067
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0129-fbdev-core-Pass-Linux-device-to-pm_vt_switch_-functi.patch (drm-backport-placeholder)
- commit 58001ec
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0128-fbdev-tdfxfb-Set-i2c-adapter-parent-to-hardware-devi.patch (drm-backport-placeholder)
- commit 96b7eac
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0127-fbdev-smscufx-Detect-registered-fb_info-from-refcoun.patch (drm-backport-placeholder)
- commit 29e5565
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0126-fbdev-sm501fb-Output-message-with-fb_err.patch (drm-backport-placeholder)
- commit 6202dc2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0125-fbdev-sh7760fb-Use-hardware-device-with-dev_-output-.patch (drm-backport-placeholder)
- commit 60781b6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0124-fbdev-sh7760fb-Alloc-DMA-memory-from-hardware-device.patch (drm-backport-placeholder)
- commit 2e01f62
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0123-fbdev-sh7760fb-Output-messages-with-fb_dbg.patch (drm-backport-placeholder)
- commit 81900d0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0122-fbdev-sh7760fb-Use-fb_dbg-in-sh7760fb_get_color_info.patch (drm-backport-placeholder)
- commit 12f55bd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0121-fbdev-rivafb-Use-hardware-device-as-backlight-parent.patch (drm-backport-placeholder)
- commit e9c3810
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0120-fbdev-rivafb-Reorder-backlight-and-framebuffer-init-.patch (drm-backport-placeholder)
- commit 485609f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0119-fbdev-radeonfb-Use-hardware-device-as-backlight-pare.patch (drm-backport-placeholder)
- commit 4442550
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0118-fbdev-radeonfb-Reorder-backlight-and-framebuffer-cle.patch (drm-backport-placeholder)
- commit fb5162d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0117-fbdev-pxa168fb-Do-not-assign-to-struct-fb_info.dev.patch (drm-backport-placeholder)
- commit 245c0b2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0116-fbdev-nvidiafb-Use-hardware-device-as-backlight-pare.patch (drm-backport-placeholder)
- commit 5d9aa59
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0115-fbdev-nvidiafb-Reorder-backlight-and-framebuffer-ini.patch (drm-backport-placeholder)
- commit 04a803c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0114-fbdev-metronomefb-Use-hardware-device-for-dev_err.patch (drm-backport-placeholder)
- commit 134cbfc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0113-fbdev-mb862xxfb-Output-messages-with-fb_dbg.patch (drm-backport-placeholder)
- commit c2a2e7c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0112-fbdev-fsl-diu-fb-Output-messages-with-fb_-helpers.patch (drm-backport-placeholder)
- commit 65a3483
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-ep93xx-fb-Do-not-assign-to-struct-fb_info.dev.patch (drm-backport-placeholder)
- commit e698fac
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0110-fbdev-ep93xx-fb-Output-messages-with-fb_info-and-fb_.patch (drm-backport-placeholder)
- commit 19cd3a7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0109-fbdev-ep93xx-fb-Alloc-DMA-memory-from-hardware-devic.patch (drm-backport-placeholder)
- commit e7a1f82
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0108-fbdev-broadsheetfb-Call-device_remove_file-with-hard.patch (drm-backport-placeholder)
- commit 6ccdde4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0107-fbdev-aty128fb-Use-hardware-device-as-backlight-pare.patch (drm-backport-placeholder)
- commit 49146e2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0106-fbdev-aty128fb-Reorder-backlight-and-framebuffer-ini.patch (drm-backport-placeholder)
- commit 2722da1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0105-fbdev-atyfb-Use-hardware-device-as-backlight-parent.patch (drm-backport-placeholder)
- commit 9f644a0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0104-fbdev-atyfb-Reorder-backlight-and-framebuffer-init-c.patch (drm-backport-placeholder)
- commit 6c51cbe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0103-backlight-lv5207lp-Rename-struct-lv5207lp_platform_d.patch (drm-backport-placeholder)
- commit eb6c63d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/backlight-lv5207lp-Compare-against-struct-fb_info.de.patch (drm-backport-placeholder)
- commit 51a58cb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0101-backlight-gpio_backlight-Rename-field-fbdev-to-dev.patch (drm-backport-placeholder)
- commit 7ac4e61
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/backlight-gpio_backlight-Compare-against-struct-fb_i.patch (drm-backport-placeholder)
- commit 14a6119
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0099-backlight-bd6107-Rename-struct-bd6107_platform_data..patch (drm-backport-placeholder)
- commit 157a894
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/backlight-bd6107-Compare-against-struct-fb_info.devi.patch (drm-backport-placeholder)
- commit 83b9b82
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0097-drm-bridge-dw-hdmi-remove-dead-code-and-fix-indentat.patch (drm-backport-placeholder)
- commit 35490b1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0096-drm-bridge-dw-hdmi-truly-enforce-420-only-formats-wh.patch (drm-backport-placeholder)
- commit fc1662d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0095-drm-bridge-dw-hdmi-change-YUV420-selection-logic-at-.patch (drm-backport-placeholder)
- commit 0c58a43
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0001-drm-prime-Unexport-helpers-for-fd-handle-conversion.patch (drm-backport-placeholder)
- commit 21c0d42
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0093-drm-Clear-fd-handle-callbacks-in-struct-drm_driver.patch (drm-backport-placeholder)
- commit dbf4fa1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mxsfb-Disable-overlay-plane-in-mxsfb_plane_overl.patch (drm-backport-placeholder)
- commit 83813f3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0090-drm-vkms-Isolate-writeback-pixel-conversion-function.patch (drm-backport-placeholder)
- commit df3a098
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0089-drm-vkms-Enable-ARGB8888-support-for-writeback.patch (drm-backport-placeholder)
- commit dd575cd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0088-drm-vkms-Reduce-critical-section.patch (drm-backport-placeholder)
- commit 8dcb421
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0087-drm-bridge-ps8640-Drop-the-ability-of-ps8640-to-fetc.patch (drm-backport-placeholder)
- commit 369f2df
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0086-drm-kms-log-when-querying-an-object-not-included-in-.patch (drm-backport-placeholder)
- commit e88c510
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0085-drm-atomic-log-errors-in-drm_mode_atomic_ioctl.patch (drm-backport-placeholder)
- commit 251161a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0084-drm-atomic-log-when-page-flip-is-requested-without-C.patch (drm-backport-placeholder)
- commit c806cf6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0083-drm-atomic-log-on-attempt-to-set-legacy-DPMS-propert.patch (drm-backport-placeholder)
- commit 5a4957d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0082-drm-atomic-log-when-CRTC_ID-prop-value-is-invalid.patch (drm-backport-placeholder)
- commit 74e8421
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0081-drm-atomic-log-when-getting-setting-unknown-properti.patch (drm-backport-placeholder)
- commit 99bcd6b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0080-drm-atomic-drop-extra-bracket-from-log-messages.patch (drm-backport-placeholder)
- commit b78e91b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0079-drm-atomic-log-drm_atomic_replace_property_blob_from.patch (drm-backport-placeholder)
- commit cb78dbb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0078-drm-bridge_connector-use-drm_kms_helper_connector_ho.patch (drm-backport-placeholder)
- commit 6688f51
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0077-drm-sysfs-rename-drm_sysfs_connector_status_event.patch (drm-backport-placeholder)
- commit 19a3a2b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0076-drm-fix-code-style-for-embedded-structs-in-hdr_metad.patch (drm-backport-placeholder)
- commit cf957c8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0075-drm-mgag200-set-variable-mgag200_modeset-storage-cla.patch (drm-backport-placeholder)
- commit f741fa5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-dw-mipi-dsi-Fix-enable-disable-of-DSI-con.patch (drm-backport-placeholder)
- commit 7d2dcfd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0073-drm-i2c-Switch-i2c-drivers-back-to-use-.probe.patch (drm-backport-placeholder)
- commit 5e07347
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0072-drm-bridge-tc358762-Handle-HS-VS-polarity.patch (drm-backport-placeholder)
- commit 94f5171
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0071-drm-bridge-tc358762-Guess-the-meaning-of-LCDCTRL-bit.patch (drm-backport-placeholder)
- commit dfb1bcc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0070-drm-bridge-tc358762-Instruct-DSI-host-to-generate-HS.patch (drm-backport-placeholder)
- commit f9954d8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0069-drm-bridge-tc358762-Switch-to-atomic-ops.patch (drm-backport-placeholder)
- commit 9e95b14
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0068-drm-bridge-tc358762-Split-register-programming-from-.patch (drm-backport-placeholder)
- commit dce540d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0067-drm-bridge-tc358764-Use-BIT-macro-for-actual-bits.patch (drm-backport-placeholder)
- commit 71b2d71
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0066-drm-shmem-helper-Switch-to-reservation-lock.patch (drm-backport-placeholder)
- commit 9b34672
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0065-dma-buf-Change-locking-policy-for-mmap.patch (drm-backport-placeholder)
- commit 3f899e1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0064-drm-Don-t-assert-held-reservation-lock-for-dma-buf-m.patch (drm-backport-placeholder)
- commit b593d29
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0063-udmabuf-Don-t-assert-held-reservation-lock-for-dma-b.patch (drm-backport-placeholder)
- commit 2e466be
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0062-dma-buf-heaps-Don-t-assert-held-reservation-lock-for.patch (drm-backport-placeholder)
- commit 0b10995
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0061-drm-bridge-lt9611uxc-Add-MODULE_FIRMWARE-macro.patch (drm-backport-placeholder)
- commit f149c01
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0060-drm-vkms-Fix-all-kernel-doc-warnings-of-the-vkms_com.patch (drm-backport-placeholder)
- commit 9426ae5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0059-drm-vkms-Add-kernel-doc-to-the-function-vkms_compose.patch (drm-backport-placeholder)
- commit 218b617
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0058-drm-amdgpu-Remove-struct-drm_driver.gem_prime_mmap.patch (drm-backport-placeholder)
- commit ac71c00
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0057-drm-Remove-struct-drm_driver.gem_prime_mmap.patch (drm-backport-placeholder)
- commit 2d89ba7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0056-drm-msm-Initialize-mmap-offset-after-constructing-th.patch (drm-backport-placeholder)
- commit 374fe98
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0055-drm-tidss-Add-support-for-AM625-DSS.patch (drm-backport-placeholder)
- commit d56e869
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0054-drm-ingenic-Kconfig-select-REGMAP-and-REGMAP_MMIO.patch (drm-backport-placeholder)
- commit c0f9a9c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0052-drm-ssd130x-Remove-hardcoded-bits-per-pixel-in-ssd13.patch (drm-backport-placeholder)
- commit 1fa6f66
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0051-drm-ssd130x-Don-t-allocate-buffers-on-each-plane-upd.patch (drm-backport-placeholder)
- commit 918ad16
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0050-drm-ssd130x-Set-the-page-height-value-in-the-device-.patch (drm-backport-placeholder)
- commit 7982e29
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0049-drm-ssd130x-Make-default-width-and-height-to-be-cont.patch (drm-backport-placeholder)
- commit c3f4779
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0048-drm-omap-Convert-to-platform-remove-callback-returni.patch (drm-backport-placeholder)
- commit c04c8d8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0047-drm-tilcdc-Convert-to-platform-remove-callback-retur.patch (drm-backport-placeholder)
- commit 924ed35
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0046-drm-rcar-du-Convert-to-platform-remove-callback-retu.patch (drm-backport-placeholder)
- commit f5b4256
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0045-drm-xlnx-zynqmp_dpsub-Convert-to-platform-remove-cal.patch (drm-backport-placeholder)
- commit 2b8db51
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0044-drm-vc4-Convert-to-platform-remove-callback-returnin.patch (drm-backport-placeholder)
- commit 7ce99c7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0043-drm-v3d-Convert-to-platform-remove-callback-returnin.patch (drm-backport-placeholder)
- commit 09e0a12
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0042-drm-tve200-Convert-to-platform-remove-callback-retur.patch (drm-backport-placeholder)
- commit 5ce5d90
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0041-drm-tiny-Convert-to-platform-remove-callback-returni.patch (drm-backport-placeholder)
- commit b319fc9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0040-drm-tidss-Convert-to-platform-remove-callback-return.patch (drm-backport-placeholder)
- commit ad91ba9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0039-drm-sun4i-Convert-to-platform-remove-callback-return.patch (drm-backport-placeholder)
- commit 4b7baeb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0038-drm-stm-Convert-to-platform-remove-callback-returnin.patch (drm-backport-placeholder)
- commit 85e6458
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0037-drm-sti-Convert-to-platform-remove-callback-returnin.patch (drm-backport-placeholder)
- commit 9592720
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0036-drm-rockchip-Convert-to-platform-remove-callback-ret.patch (drm-backport-placeholder)
- commit 22c0677
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0035-drm-panfrost-Convert-to-platform-remove-callback-ret.patch (drm-backport-placeholder)
- commit b4d307d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0034-drm-panel-Convert-to-platform-remove-callback-return.patch (drm-backport-placeholder)
- commit 0ecb60f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0033-drm-mxsfb-Convert-to-platform-remove-callback-return.patch (drm-backport-placeholder)
- commit 0ea3476
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0032-drm-meson-Convert-to-platform-remove-callback-return.patch (drm-backport-placeholder)
- commit 242d4df
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0031-drm-mcde-Convert-to-platform-remove-callback-returni.patch (drm-backport-placeholder)
- commit 7b4222e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0030-drm-logicvc-Convert-to-platform-remove-callback-retu.patch (drm-backport-placeholder)
- commit 71b4d6e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0029-drm-lima-Convert-to-platform-remove-callback-returni.patch (drm-backport-placeholder)
- commit 0e84b75
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0028-drm-hisilicon-Convert-to-platform-remove-callback-re.patch (drm-backport-placeholder)
- commit d747a28
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0027-drm-fsl-dcu-Convert-to-platform-remove-callback-retu.patch (drm-backport-placeholder)
- commit 717c012
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0026-drm-atmel-hlcdc-Convert-to-platform-remove-callback-.patch (drm-backport-placeholder)
- commit 7380653
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0025-drm-aspeed-Convert-to-platform-remove-callback-retur.patch (drm-backport-placeholder)
- commit 8329430
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0024-drm-arm-malidp-Convert-to-platform-remove-callback-r.patch (drm-backport-placeholder)
- commit b38280d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0023-drm-arm-hdlcd-Convert-to-platform-remove-callback-re.patch (drm-backport-placeholder)
- commit c7821e9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0022-drm-komeda-Convert-to-platform-remove-callback-retur.patch (drm-backport-placeholder)
- commit 06f2842
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0021-drm-panel-Add-driver-for-Visionox-r66451-panel.patch (drm-backport-placeholder)
- commit 133e39a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0020-drm-panel-s6d7aa0-remove-the-unneeded-variable-in-s6.patch (drm-backport-placeholder)
- commit 0f2034c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0019-drm-panel-edp-Add-AUO-B116XAB01.4-edp-panel-entry.patch (drm-backport-placeholder)
- commit d996a75
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0018-drm-i915-Move-abs_diff-to-math.h.patch (drm-backport-placeholder)
- commit 72e2a63
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0017-minmax-add-in_range-macro.patch (drm-backport-placeholder)
- commit 8ed3506
* Mon Sep  9 2024 tiwai@suse.de
- sysfs: Fix crash on empty group attributes array (git-fixes).
- Refresh
  patches.suse/sysfs-Introduce-a-mechanism-to-hide-static-attribute.patch.
- commit 8c7ed55
* Mon Sep  9 2024 nmorey@suse.com
- RDMA/efa: Properly handle unexpected AQ completions (git-fixes)
- commit 8c8b9e5
* Sun Sep  8 2024 tiwai@suse.de
- clk: qcom: gcc-sc8280xp: don't use parking clk_ops for QUPs
  (git-fixes).
- clk: qcom: gcc-sm8550: Don't park the USB RCG at registration
  time (git-fixes).
- clk: qcom: gcc-sm8550: Don't use parking clk_ops for QUPs
  (git-fixes).
- clk: qcom: ipq9574: Update the alpha PLL type for GPLLs
  (git-fixes).
- clk: qcom: clk-alpha-pll: Fix zonda set_rate failure when PLL
  is disabled (git-fixes).
- clk: qcom: clk-alpha-pll: Fix the trion pll postdiv set rate
  API (git-fixes).
- clk: qcom: clk-alpha-pll: Fix the pll post div mask (git-fixes).
- commit 060a67a
* Sat Sep  7 2024 tiwai@suse.de
- ALSA: hda/realtek - Fix inactive headset mic jack for ASUS
  Vivobook 15 X1504VAP (stable-fixes).
- ALSA: hda/realtek: Support mute LED on HP Laptop 14-dq2xxx
  (stable-fixes).
- ALSA: hda/realtek: Enable Mute Led for HP Victus 15-fb1xxx
  (stable-fixes).
- ALSA: hda/realtek: extend quirks for Clevo V5[46]0
  (stable-fixes).
- ALSA: hda/realtek: add patch for internal mic in Lenovo V145
  (stable-fixes).
- ALSA: hda/conexant: Add pincfg quirk to enable top speakers
  on Sirius devices (stable-fixes).
- commit 5538dd8
* Sat Sep  7 2024 tiwai@suse.de
- ASoC: sunxi: sun4i-i2s: fix LRCLK polarity in i2s mode
  (git-fixes).
- ASoc: SOF: topology: Clear SOF link platform name upon unload
  (git-fixes).
- ASoC: tegra: Fix CBB error during probe() (git-fixes).
- ASoC: dapm: Fix UAF for snd_soc_pcm_runtime object (git-fixes).
- mmc: cqhci: Fix checking of CQHCI_HALT state (git-fixes).
- mmc: dw_mmc: Fix IDMAC operation with pages bigger than 4K
  (git-fixes).
- mmc: sdhci-of-aspeed: fix module autoloading (git-fixes).
- mmc: core: apply SD quirks earlier during probe (git-fixes).
- gpio: modepin: Enable module autoloading (git-fixes).
- gpio: rockchip: fix OF node leak in probe() (git-fixes).
- Revert "drm/amdgpu: align pp_power_profile_mode with kernel
  docs" (stable-fixes).
- nouveau: fix the fwsec sb verification register (git-fixes).
- drm/i915/fence: Mark debug_fence_free() with __maybe_unused
  (git-fixes).
- drm/i915/fence: Mark debug_fence_init_onstack() with
  __maybe_unused (git-fixes).
- drm/i915: Do not attempt to load the GSC multiple times
  (git-fixes).
- commit 7a89765
* Sat Sep  7 2024 tiwai@suse.de
- ASoC: codecs: lpass-va-macro: set the default codec version
  for sm8250 (jsc#PED-9993 jsc#PED-10202).
- commit 36fdd5c
* Sat Sep  7 2024 tiwai@suse.de
- PCI: Add INTEL_HDA_PTL to pci_ids.h (jsc#PED-9993
  jsc#PED-10202).
- commit e45011e
* Fri Sep  6 2024 tiwai@suse.de
- Revert "ALSA: emu10k1 - delay the PCM interrupts (add
  pcm_irq_delay parameter)" (jsc#PED-9993 jsc#PED-10202).
- commit 10de224
* Fri Sep  6 2024 tiwai@suse.de
- Refresh patches.suse/ASoC-SOF-Intel-mtl-Correct-rom_status_reg.patch (jsc#PED-9993 jsc#PED-10202)
  Fix the missing hunk at SLE15-SP6 backport
- commit 503352d
* Fri Sep  6 2024 tiwai@suse.de
- Refresh patches.suse/ASoC-Intel-avs-Switch-to-ACPI-NHLT.patch
  Fix the minor merge errors
- commit 192aba7
* Fri Sep  6 2024 tiwai@suse.de
- Refresh patches.suse/ASoC-lower-no-backend-DAIs-enabled-for-.-Port-log-se.patch
  Fix the missing hunk at the previous backport
- commit ab7b67f
* Fri Sep  6 2024 dsterba@suse.com
- blacklist.conf: CVE-2024-43886 bsc#1229748: not applicable, functionality not present
  The fix adds a NULL check but it is already there in this codebase. The
  upstream fix is for patch 5db346c256bbac ("drm/amd/display: update pipe
  topology log to support subvp") that adds a secondary display and
  refactors code so the NULL check gets lost in
  resource_log_pipe_topology_update().
- commit b9c5bf2
* Fri Sep  6 2024 tiwai@suse.de
- ALSA: hda: hda_component: Fix mutex crash if nothing ever binds
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-va-macro: warn on unknown version
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-macro: fix version strings returned for
  1.x codecs (jsc#PED-9993 jsc#PED-10202).
- treewide: remove unnecessary <linux/version.h> inclusion
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l41: Remove redundant call to
  hda_cs_dsp_control_remove() (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l56: Remove redundant call to
  hda_cs_dsp_control_remove() (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: button detect issue (jsc#PED-9993
  jsc#PED-10202).
- commit eda9d9f
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: cs35l56: Stop creating ALSA controls for firmware
  coefficients (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm_adsp: Add control_add callback and export
  wm_adsp_control_add() (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-macro: fix missing codec version
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Cache shutter IRQ control pointers (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l45: Use new snd_soc_component_get_kcontrol_locked()
  helper (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-component: Add new snd_soc_component_get_kcontrol()
  helpers (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Remove redundant semi-colon at end of function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_micfil: Differentiate register access permission
  for platforms (jsc#PED-9993 jsc#PED-10202).
- commit 1f4c50a
* Fri Sep  6 2024 tiwai@suse.de
- ALSA: hda: cs35l41: Stop creating ALSA Controls for firmware
  coefficients (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l56: Stop creating ALSA controls for firmware
  coefficients (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl-asoc-card: Dynamically allocate memory for
  snd_soc_dai_link_components (jsc#PED-9993 jsc#PED-10202).
- ASoC: tegra: select CONFIG_SND_SIMPLE_CARD_UTILS (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: tas2781: mark const variables as __maybe_unused
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: debugfs: simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- commit d1e3ff6
* Fri Sep  6 2024 tiwai@suse.de
- soundwire: cadence: simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_ace2x: simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_ace2x: simplify return path in hw_params
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel: simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel: simplify return path in hw_params
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: amd_init: simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- soundwire: amd: simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- soundwire: amd: simplify return path in hw_params (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_auxdevice: start the bus at default frequency
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_auxdevice: add cs42l43 codec to
  wake_capable_list (jsc#PED-9993 jsc#PED-10202).
- commit 69d256e
* Fri Sep  6 2024 tiwai@suse.de
- soundwire: intel_ace2.x: add AC timing extensions for
  PantherLake (jsc#PED-9993 jsc#PED-10202).
- commit db94782
* Fri Sep  6 2024 tiwai@suse.de
- soundwire: bus: add stream refcount (jsc#PED-9993
  jsc#PED-10202).
- Refresh patches.suse/soundwire-suse-kabi-padding.patch.
- commit 5f0f7f6
* Fri Sep  6 2024 tiwai@suse.de
- drivers:soundwire: qcom: cleanup port maask calculations
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: bus: simplify by using local slave->prop
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: generic_bandwidth_allocation: change port_bo
  parameter to pointer (jsc#PED-9993 jsc#PED-10202).
- soundwire: Intel: clarify Copyright information (jsc#PED-9993
  jsc#PED-10202).
- soundwire: debugfs: add interface to read/write commands
  (jsc#PED-9993 jsc#PED-10202).
- commit c0f9cd8
* Fri Sep  6 2024 tiwai@suse.de
- firmware: cs_dsp: Rename fw_ver to wmfw_ver (jsc#PED-9993
  jsc#PED-10202).
- firmware: cs_dsp: Clarify wmfw format version log message
  (jsc#PED-9993 jsc#PED-10202).
- firmware: cs_dsp: Make wmfw and bin filename arguments const
  char * (jsc#PED-9993 jsc#PED-10202).
- firmware: cs_dsp: Don't allocate temporary buffer for info text
  (jsc#PED-9993 jsc#PED-10202).
- firmware: cs_dsp: Log that a bin file was loaded (jsc#PED-9993
  jsc#PED-10202).
- commit 7215555
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: tas2781: Add new Kontrol to set tas2563 digital Volume
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: topology: Simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: aw88395: Simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: Convert comma to semicolon (jsc#PED-9993
  jsc#PED-10202).
- ASoc: TAS2781: rename the tas2781_reset as tasdevice_reset
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl-asoc-card: merge spdif support from imx-spdif.c
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl-asoc-card: add compatibility to use 2 codecs in
  dai-links (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl-asoc-card: add second dai link component for codecs
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl-asoc-card: add support for dai links with multiple
  codecs (jsc#PED-9993 jsc#PED-10202).
- ASoC: dapm: Simplify snd_soc_dai_link_event_pre_pmu() with
  cleanup.h (jsc#PED-9993 jsc#PED-10202).
- ASoC: dapm: Simplify dapm_cnew_widget() with cleanup.h
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ops: Simplify with cleanup.h (jsc#PED-9993 jsc#PED-10202).
- ASoC: simple-card: Use cleanup.h instead of devm_kfree()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: Use cleanup.h instead of devm_kfree()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card: Use cleanup.h instead of devm_kfree()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: simple-card-utils: Simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wcd934x: Simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- commit cf399f9
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: codecs: wcd9335: Simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- ASoc: TAS2781: replace beXX_to_cpup with get_unaligned_beXX
  for potentially broken alignment (jsc#PED-9993 jsc#PED-10202).
- ASoc: pcm6240: Remove unnecessary name-prefix for all the
  controls (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: fsl_qmc_audio: Add support for non-interleaved mode
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: fsl_qmc_audio: Introduce
  qmc_dai_constraints_interleaved() (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: fsl_qmc_audio: Introduce
  qmc_audio_pcm_{read,write}_submit() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: fsl_qmc_audio: Identify the QMC channel involved
  in completion routines (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: fsl_qmc_audio: Split channel buffer and PCM pointer
  handling (jsc#PED-9993 jsc#PED-10202).
- commit 79caa13
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: fsl: fsl_qmc_audio: Fix issues detected by checkpatch
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-wsa-macro: Simplify with cleanup.h
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-rx-macro: Use unsigned for number of widgets
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: dapm: Use unsigned for number of widgets in
  snd_soc_dapm_new_controls() (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-rx-macro: Keep static regmap_config as const
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-rx-macro: Simplify with cleanup.h
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-rx-macro: Simplify PDS cleanup with devm
  (jsc#PED-9993 jsc#PED-10202).
- ASoc: tas2781: Set "Speaker Force Firmware Load" as the
  common kcontrol for both tas27871 and tas2563 (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ak4458: remove "reset-gpios" property handler
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-port: add link-trigger-order (jsc#PED-9993
  jsc#PED-10202).
- ASoC: dt-bindings: audio-graph-port: Drop type from "clocks"
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: dt-bindings: audio-graph-port: Document new DAI link
  flags playback-only/capture-only (jsc#PED-9993 jsc#PED-10202).
- ASoC: dt-bindings: Simplify referencing dai-params.yaml
  (jsc#PED-9993 jsc#PED-10202).
- commit fc8307f
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: SOF: ipc4-topology: Use single token list for the copiers
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tas5086: Convert to GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wsa884x: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wsa883x: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wsa881x: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- ASoC: jz4770: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- ASoC: jz4760: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs53l30: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l36: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l35: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- commit 8eeb04d
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: cs35l34: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl_xcvr: Improve suspend/resume flow in
  fsl_xcvr_trigger() (jsc#PED-9993 jsc#PED-10202).
- ASoC: tas2781: Use of_property_read_reg() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: PCM6240: Use of_property_read_reg() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: topology: Unify code for creating standalone and widget
  enum control (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Unify code for creating standalone and widget
  mixer control (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Unify code for creating standalone and widget
  bytes control (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Reshuffle function placement (jsc#PED-9993
  jsc#PED-10202).
- ASoC: topology: Rename function creating widget kcontrol
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Align dynamic object initialization for controls
  (jsc#PED-9993 jsc#PED-10202).
- commit 7080cfb
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: topology: Correctly set shift_r in soc_tplg_denum_create()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Cleanup soc_tplg_dapm_widget_denum_create
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Cleanup soc_tplg_dapm_widget_dmixer_create
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Cleanup soc_tplg_dapm_widget_dbytes_create
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Properly initialize soc_enum values
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Do not do unnecessary dobj management
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Simplify code (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: nau8824: Add master clock handling (jsc#PED-9993
  jsc#PED-10202).
- ASoC: simple-audio-mux: enable to select MUX names (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l56: Remove redundant clearing of clk_stop_mode1
  (jsc#PED-9993 jsc#PED-10202).
- commit 77a11fd
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: cs35l56: Remove support for A1 silicon (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: lpass-wsa-macro: Fix using NULL pointer in probe()
  dev_err (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-rx-macro: Fix using NULL pointer in probe()
  dev_err (jsc#PED-9993 jsc#PED-10202).
- ASoc: tas2781: Add name_prefix as the prefix name of
  DSP firmwares and calibrated data files (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl_rpmsg: Add support for i.MX95 platform (jsc#PED-9993
  jsc#PED-10202).
- commit 7132fda
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: meson: tdm: add sample rate support up to 768kHz
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-utils: allow sample rate up to 768kHz for the dummy
  dai (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-wsa-macro: add missing select of common code
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: imx-audmix: Split capture device for audmix (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl_audmix: Split playback and capture stream to different
  DAI (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_sai: Add separate DAI for transmitter and receiver
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: add link-trigger-order support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card: add link-trigger-order support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: simple-audio-card: add link-trigger-order support
  (jsc#PED-9993 jsc#PED-10202).
- commit 5712a5b
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: simple-card-utils: add link-trigger-order support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt712-sdca: add the function for version B (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt712-sdca: change the definition name of SDCA channel
  number (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-macro: Use enum for handling codec version
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-macro: Gracefully handle unknown version
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-wsa-macro: Correct support for newer v2.5
  version (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-wsa-macro: Prepare to accommodate new
  codec versions (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-wsa-macro: Drop unused define (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt711-sdca: add GE selected mode control (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: lpass-rx-macro: add missing handling of v2.1 codec
  (jsc#PED-9993 jsc#PED-10202).
- commit ecfebfa
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: Intel: sof_sdw: select PINCTRL_CS42L43 and SPI_CS42L43
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: add quirk for Dell SKU 0B8C (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: maxim-common: add max_98373_get_tx_mask function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: fix jack detection on ADL-N variant RVP
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: regcache_sync error issue (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: Minimize the pop noise (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: Slove headphone detection issue
  (jsc#PED-9993 jsc#PED-10202).
- ASoc: tas2781: Add name_prefix as the prefix name of firmwares
  and kcontrol to support corresponding TAS2563/TAS2781s
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt6358: Add "Dmic Mode Switch" kcontrol for
  switch DMIC mode (jsc#PED-9993 jsc#PED-10202).
- commit 45b8a03
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: nau8822: add MCLK support (jsc#PED-9993 jsc#PED-10202).
- ASoC: nau8822: set NAU8822_REFIMP_80K only once (jsc#PED-9993
  jsc#PED-10202).
- ASoC: nau8822: move nau8822_set_dai_sysclk() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: sc8280xp: add Display port Jack (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: common: add Display port Jack function (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: q6dsp: parse Display port tokens (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Constify return of snd_soc_dai_get_pcm_stream()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Constify DAI passed to get_channel_map (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Constify passed data to core function (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Constify of_phandle_args in snd_soc_dai_link_component
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Constify of_phandle_args in snd_soc_dai_driver
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Add support for ti,pcm5242 to the pcm512x driver
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd938x: Drop unused num_ports field (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wcd938x: Drop unused RX/TX direction enum
  (jsc#PED-9993 jsc#PED-10202).
- commit 5d925de
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: codecs: wcd938x: Constify wcd938x_sdw_ch_info
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd938x: Constify static data (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wcd934x: Handle nicer probe deferral and simplify
  with dev_err_probe() (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd934x: Drop unused mic bias voltage fields
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd934x: Constify static data (jsc#PED-9993
  jsc#PED-10202).
- commit 6914ec9
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: codecs: wcd934x: Drop unused interp path enum
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd9335: Drop unused dmic rate handling
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd9335: Drop unneeded error message (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wcd9335: Handle nicer probe deferral and simplify
  with dev_err_probe() (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd9335: Constify static data (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wcd9335: Drop unused state container fields
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd-mbhc: Constify passed MBHC reg fields
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tlv320adc3xxx: Add support for using MICBIAS pins as GPO
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add pcm constraints for buffer size and period
  size (jsc#PED-9993 jsc#PED-10202).
- commit 733c499
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: amd: acp: move i2s clock generation sequence (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: acp: modify conditional check for programming i2s
  mclk (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: remove unused variables from acp_resource
  structure (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: remove acp_i2s_probe function (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Constify DAI ops auto_selectable_formats (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-dai.h: Constify DAI ops auto_selectable_formats
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: add support for aux devices
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: mediatek: Constify struct mtk_adsp_ipc_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: imx-pcm-fiq: add missing MODULE_DESCRIPTION() macro
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codec: lpass-rx-macro: add support for 2.5 codec version
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codec: lpass-rx-macro: prepare driver to accomdate new
  codec versions (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-macro: add helpers to get codec version
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: add missing MODULE_DESCRIPTION() macros (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: midas_wm1811: Fix error code in probe()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Attempt to read from cirrus,speaker-id device
  property first (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: Replace of_gpio.h by proper one (jsc#PED-9993
  jsc#PED-10202).
- ASoC: generic: Replace of_gpio.h by proper one (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rockchip: Remove unused of_gpio.h (jsc#PED-9993
  jsc#PED-10202).
- commit 780a00e
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: fsl: Remove unused of_gpio.h (jsc#PED-9993 jsc#PED-10202).
- commit 0c14591
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: simple-audio-card: merge simple_parse_mclk_fs() into
  simple_link_init() (jsc#PED-9993 jsc#PED-10202).
- ASoC: simple-audio-card: enable playback/capture_only property
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card: merge graph_parse_mclk_fs() into
  graph_link_init() (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card: enable playback/capture_only property
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card: remove ports node name check
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card: add ep_to_port() / port_to_ports()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: merge graph_parse_mclk_fs() into
  graph_link_init() (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: expand dai_link property part
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: remove ports node name check
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: add ep_to_port() / port_to_ports()
  (jsc#PED-9993 jsc#PED-10202).
- commit 4939fa4
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: simple-card-utils: remove both playback/capture_only check
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_xcvr: Add support for i.MX95 platform (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: cx2072x: remove unused struct 'cx2072x_eq_ctrl'
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wm0010: remove unused struct 'wm0010_spi_msg'
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-rx-macro: remove unused struct
  'rx_macro_reg_mask_val' (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: pci-tgl: Align ADL-N sof_dev_desc struct
  name to convention (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd938x: Drop no-op ADC2_BCS Disable Switch
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: midas_wm1811: Use dev_err_probe where appropriate
  (jsc#PED-9993 jsc#PED-10202).
- commit 2e76136
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: samsung: midas_wm1811: Add GPIO-based headset jack
  detection (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: midas_wm1811: Add headset mic bias supply support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: midas_wm1811: Use SND_SOC_DAPM_REGULATOR_SUPPLY
  for bias regulators (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_mqs: Add i.MX95 platform support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: qdsp6: Set channel mapping instead of fixed defaults
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: q6apm-lpass-dais: Implement proper channel mapping
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Constify channel mapping array arguments in
  set_channel_map() (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: disable max98373 speaker pins in
  late_probe (jsc#PED-9993 jsc#PED-10202).
- commit edb5423
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: Intel: sof_da7219: remove local max98373 ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: maxim-common: rewrite max_98373_hw_params function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: support tdm slot number query
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc3-topology: support tdm slot number query
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-audio: add sof_dai_get_tdm_slots function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-audio: rename dai clock setting query function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Add quirks for some new Dell laptops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi: Add match entries for some cs42l43
  laptops (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Add missing controls for cs42l43/cs35l56
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: remove get_codec_dai_by_name (jsc#PED-9993
  jsc#PED-10202).
- commit f241188
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: use dai parameter
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt_dmic: use from dai parameter
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt700: use dai parameter (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt5682: use dai parameter (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt711: use dai parameter (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw_cs42l42: use dai parameter (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tegra: I2S client convert formats handling (jsc#PED-9993
  jsc#PED-10202).
- ASoC: simple-card-utils: Split simple_fixup_sample_fmt func
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: print PCI class info only once
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: Constify struct snd_soc_ops (jsc#PED-9993
  jsc#PED-10202).
- commit 398b8a2
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: fsl: fsl_xcvr: Switch to RUNTIME_PM_OPS() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: fsl_easrc: Switch to RUNTIME_PM_OPS() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: fsl_aud2htx: Switch to RUNTIME_PM_OPS() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: topology: Constify struct snd_soc_tplg_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: Skylake: Constify struct snd_soc_tplg_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qdsp6: audioreach: Constify struct snd_soc_tplg_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Constify struct snd_soc_tplg_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: topology: Constify an argument of
  snd_soc_tplg_component_load() (jsc#PED-9993 jsc#PED-10202).
- commit 87e970b
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: codecs: wcd938x: Unify define used for MIC2 bias register
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd938x: Drop unused duplicated MIC2 bias register
  defines (jsc#PED-9993 jsc#PED-10202).
- ALSA: usb: Use BIT() for bit values (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: Add tempo base unit for MIDI2 Set Tempo messages
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Fix id copying in snd_pcm_set_sync_per_card()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Fix missing export of snd_pcm_set_sync_per-card()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l41: Fix missing Speaker ID GPIO description
  in _DSD (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: optimize and clarify stream synchronization ID API
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: reinvent the stream synchronization ID API
  (jsc#PED-9993 jsc#PED-10202).
- commit 7f545a5
* Fri Sep  6 2024 tiwai@suse.de
- ALSA: pcm_dmaengine: Unify two close functions (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: cs35l56: Perform firmware download in the background
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Drop NULL check for snd_ctl_remove() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: control: Allow NULL passed to snd_ctl_remove()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Add input value sanity checks to HDMI channel map
  controls (jsc#PED-9993 jsc#PED-10202).
- ALSA: chmap: Mark Channel Map controls as volatile (jsc#PED-9993
  jsc#PED-10202).
- ALSA: control: Apply sanity check of input values for user
  elements (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Return -EINVAL for invalid volume/switch inputs
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: vmaster: Return error for invalid input values
  (jsc#PED-9993 jsc#PED-10202).
- commit 9bba7a4
* Fri Sep  6 2024 tiwai@suse.de
- ALSA: hda: hda_component: Protect shared data with a mutex
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: hda_component: Move codec field into the parent
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: hda_component: Change codecs to use component parent
  structure (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: hda_component: Introduce component parent structure
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: intel-dsp-config: Add PTL support (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: hda-intel: add PantherLake support (jsc#PED-9993
  jsc#PED-10202).
- commit dcd4c04
* Fri Sep  6 2024 dsterba@suse.com
- ipv6: fix possible UAF in ip6_finish_output2() (bsc#1230206)
- commit 64f6ea9
* Fri Sep  6 2024 dsterba@suse.com
- ipv6: prevent possible UAF in ip6_xmit() (CVE-2024-44985 bsc#1230206)
- commit 209198a
* Fri Sep  6 2024 ddiss@suse.de
- vfs: Don't evict inode under the inode lru traversing context
  (CVE-2024-45003 bsc#1230245).
- commit 630b67a
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: cs35l56: Revert support for dual-ownership of ASP
  registers (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-cs35l56-Handle-OTP-read-latency-over-SoundWire.patch.
- commit 051d80f
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: cs35l56: Limit Speaker Volume to +12dB maximum
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Use header defines for Speaker Volume control
  definition (jsc#PED-9993 jsc#PED-10202).
- commit 94695cd
* Fri Sep  6 2024 msuchanek@suse.de
- powerpc/pseries/iommu: Split Dynamic DMA Window to be used in
  Hybrid mode (jsc#ED-9897).
- commit 7356456
* Fri Sep  6 2024 tiwai@suse.de
- ALSA: scarlett2: Increase mixer range to +12dB (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add S/PDIF source selection controls
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: usb-audio: Add name for HP Engage Go dock (jsc#PED-9993
  jsc#PED-10202).
- ALSA: usb: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Zero initialize ret in
  scarlett2_ag_target_ctl_get() (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add Bluetooth volume control for Vocaster Two
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add autogain target controls (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add support for Focusrite Vocaster One and Two
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add DSP controls (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add input mute controls (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Define autogain status texts per-config-set
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Define the maximum preamp input gain
  per-config-set (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add additional input configuration parameters
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add support for config items with size = 32
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add pbuf field to struct scarlett2_config
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Rename gen4_write_addr to param_buf_addr
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add support for reading from flash
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Implement handling of the ACK notification
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Move initialisation code lower in the source
  (jsc#PED-9993 jsc#PED-10202).
- commit aec6fe7
* Fri Sep  6 2024 tiwai@suse.de
- Restore dropped fields for bluetooth MGMT/SMP structs
  (git-fixes).
- commit 5313ecb
* Fri Sep  6 2024 tiwai@suse.de
- usbnet: modern method to get random MAC (git-fixes).
- net: phy: Fix missing of_node_put() for leds (git-fixes).
- Bluetooth: MGMT: Ignore keys being loaded with invalid type
  (git-fixes).
- Revert "Bluetooth: MGMT/SMP: Fix address type when using SMP
  over BREDR/LE" (git-fixes).
- can: mcp251x: fix deadlock if an interrupt occurs during
  mcp251x_open (git-fixes).
- can: mcp251xfd: fix ring configuration when switching from
  CAN-CC to CAN-FD mode (git-fixes).
- can: m_can: Release irq on error in m_can_open (git-fixes).
- can: bcm: Remove proc entry when dev is unregistered
  (git-fixes).
- spi: rockchip: Resolve unbalanced runtime PM / system PM
  handling (git-fixes).
- regulator: core: Stub devm_regulator_bulk_get_const() if
  !CONFIG_REGULATOR (git-fixes).
- platform/x86: dell-smbios: Fix error path in dell_smbios_init()
  (git-fixes).
- commit b6769e6
* Fri Sep  6 2024 jslaby@suse.cz
- serial: sc16is7xx: fix invalid FIFO access with special register
  set (CVE-2024-44950 bsc#1230180).
- serial: sc16is7xx: fix TX fifo corruption (CVE-2024-44951
  bsc#1230181).
- serial: sc16is7xx: refactor FIFO access functions to increase
  commonality (CVE-2024-44951 bsc#1230181).
- commit 4ab54b2
* Fri Sep  6 2024 neilb@suse.de
- NFS: never reuse a NFSv4.0 lock-owner (bsc#1227726).
- commit ed692a4
* Thu Sep  5 2024 tiwai@suse.de
- supported.conf: add snd-sof-intel-hda-generic (jsc#PED-9993 jsc#PED-10202)
- commit dc40ce1
* Thu Sep  5 2024 tiwai@suse.de
- Update config files (jsc#PED-9993 jsc#PED-10202)
- commit c138b3b
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: cs-amp-lib: Ignore empty UEFI calibration entries
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Fix for incorrect acp error register offsets
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: move iram-dram fence register programming
  sequence (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l56: Don't use the device index as a calibration
  index (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs-amp-lib: Fix NULL pointer crash if efi.get_variable
  is NULL (jsc#PED-9993 jsc#PED-10202).
- ASoC: sti: add missing probe entry for player and reader
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Only handle dai_config with HW_PARAMS
  for ChainDMA (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: Fix RT5650 SSP lookup (jsc#PED-9993 jsc#PED-10202).
- ASOC: SOF: Intel: hda-loader: only wait for HDaudio IOC for
  IPC4 devices (jsc#PED-9993 jsc#PED-10202).
- ASoc: PCM6240: Return directly after a failed devm_kzalloc()
  in pcmdevice_i2c_probe() (jsc#PED-9993 jsc#PED-10202).
- soundwire: stream: add missing const to Documentation
  (jsc#PED-9993 jsc#PED-10202).
- mfd: cs42l43: Fix wrong GPIO_FN_SEL and SPI_CLK_CONFIG1 defaults
  (jsc#PED-9993 jsc#PED-10202).
- mfd: cs42l43: Fix wrong register defaults (jsc#PED-9993
  jsc#PED-10202).
- mfd: cs42l43: Correct SoundWire port list (jsc#PED-9993
  jsc#PED-10202).
- sh: boards: Fix Sound Simple-Card struct name (jsc#PED-9993
  jsc#PED-10202).
- mfd: cs42l43: Fix MFD_CS42L43 dependency on REGMAP_IRQ
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: aoa: Fix typos in PCM fix patch (jsc#PED-9993
  jsc#PED-10202).
- commit a4891ef
* Thu Sep  5 2024 tiwai@suse.de
- Refresh patches.suse/ASoC-SOF-ipc4-topology-Add-support-for-NHLT-with-16-.patch
  Add alt-commit
- commit 44b5ce3
* Thu Sep  5 2024 tiwai@suse.de
- soundwire: fix usages of device_get_named_child_node()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: fix typo in comment (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_ace2.x: add support for DOAISE property
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_ace2.x: add support for DODSE property
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_ace2x: use DOAIS and DODS settings from
  firmware (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_ace2x: cleanup DOAIS/DODS settings
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_ace2x: simplify check_wake() (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_ace2x: fix wakeup handling (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_init: resume all devices on exit (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel: export intel_resume_child_device (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_auxdevice: use pm_runtime_resume() instead
  of pm_request_resume() (jsc#PED-9993 jsc#PED-10202).
- soundwire: qcom: allow multi-link on newer devices (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_ace2x: use legacy formula for intel_alh_id
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: reconcile dp0_prop and dpn_prop (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_ace2x: set the clock source (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_ace2.x: power-up first before setting SYNCPRD
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_ace2x: move and extend clock selection
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel: add support for MeteorLake additional clocks
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel: add more values for SYNCPRD (jsc#PED-9993
  jsc#PED-10202).
- soundwire: bus: extend base clock checks to 96 MHz (jsc#PED-9993
  jsc#PED-10202).
- soundwire: cadence: show the bus frequency and frame shape
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: clarify maximum allowed address (jsc#PED-9993
  jsc#PED-10202).
- soundwire: remove unused sdw_bus_conf structure (jsc#PED-9993
  jsc#PED-10202).
- soundwire: cadence: remove PDI offset completely (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel: add intel_free_stream() back (jsc#PED-9993
  jsc#PED-10202).
- soundwire: qcom: Convert to platform remove callback returning
  void (jsc#PED-9993 jsc#PED-10202).
- soundwire: bus: don't clear SDCA_CASCADE bit (jsc#PED-9993
  jsc#PED-10202).
- soundwire: amd: use inline function for register update
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: sysfs: remove unneeded ATTRIBUTE_GROUPS() comments
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: sysfs: remove sdw_slave_sysfs_init() (jsc#PED-9993
  jsc#PED-10202).
- soundwire: sysfs: have the driver core handle the creation of
  the device groups (jsc#PED-9993 jsc#PED-10202).
- soundwire: sysfs: cleanup the logic for creating the dp0 sysfs
  attributes (jsc#PED-9993 jsc#PED-10202).
- soundwire: sysfs: move sdw_slave_dev_attr_group into the
  existing list of groups (jsc#PED-9993 jsc#PED-10202).
- ASoC: Use inline function for type safety in
  snd_soc_substream_to_rtd() (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Remove obsolete ABI v4 structs (jsc#PED-9993
  jsc#PED-10202).
- ALSA/ASoC: include: clarify Copyright information (jsc#PED-9993
  jsc#PED-10202).
- sysfs: Introduce a mechanism to hide static attribute_groups
  (jsc#PED-9993 jsc#PED-10202).
- commit 92cec54
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: rt5645: fix issue of random interrupt from push-button
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5645: mic-in detection threshold modification
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5645: improve the depop sequences of CBJ detection
  (jsc#PED-9993 jsc#PED-10202).
- commit ac7f28d
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: mediatek: mt8195: Add platform entry for ETDM1_OUT_BE
  dai link (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: move chip->flag variable assignment
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi: mtl: fix speaker no sound on Dell SKU
  0C64 (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Disconnect ASP1 TX sources when ASP1 DAI is
  hooked up (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Fix route override (jsc#PED-9993
  jsc#PED-10202).
- ASoC: atmel: atmel-classd: Re-add dai_link->platform to fix
  card init (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8183-da7219-max98357: Fix kcontrol name
  collision (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai: remove skip_tlv label (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai: skip tlv for dspless mode
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Solve headphone detection issue
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Increase default type detect time and button
  delay (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: add missing MODULE_DESCRIPTION() macro (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: add missing MODULE_DESCRIPTION() macro (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mxs: add missing MODULE_DESCRIPTION() macro (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: Use imply for suggesting
  CONFIG_SERIAL_MULTI_INSTANTIATE (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l56: Select SERIAL_MULTI_INSTANTIATE
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Adjust the params based on DAI formats
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Improve readability of
  sof_ipc4_prepare_dai_copier() (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology/pcm: Rename
  sof_ipc4_copier_is_single_format() (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Print out the channel count in
  sof_ipc4_dbg_audio_format (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Add support for NHLT with 16-bit
  only DMIC blob (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: add missing MODULE_DESCRIPTION() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: reorder MODULE_ definitions (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: AMD: group all module related information
  (jsc#PED-9993 jsc#PED-10202).
- commit edab822
* Thu Sep  5 2024 tiwai@suse.de
- leds: trigger: Store brightness set by led_trigger_event()
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/leds-triggers-Flush-pending-brightness-before-activa.patch.
- commit cda5ffe
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: SOF: stream-ipc: remove unnecessary MODULE_LICENSE
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-sdw: fix missing SPI_MASTER dependency
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Only restrict 44.1kHz for the ASP (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: solve hp and button detect issue
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: Use name_prefix for
  `-sdca` detection (jsc#PED-9993 jsc#PED-10202).
- ALSA: core: Enable proc module when CONFIG_MODULES=y
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: control-led: Integrate mute led trigger (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: hda: disable SoundWire interrupt later
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Fix build error with built-in config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt_amp: use dai parameter (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: add dai parameter to rtd_init callback
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: use .controls/.widgets to add
  controls/widgets (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: add controls and dapm widgets in
  codec_info (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: use generic name for controls/widgets
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_cs_amp: rename Speakers to Speaker
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: maxim-common: change max98373 data to static
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: add max98373 dapm routes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use max_98373_dai_link function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use max_98373_dai_link function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: use max_98373_dai_link function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: maxim-common: add max_98373_dai_link function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-lnl-match: add cs42l43 only support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-mtl-match: add cs42l43 only support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: realtek-common: remove 2-spk rt1015p config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: board id cleanup for mtl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-rt5682: remove DMI quirk for hatch
  (jsc#PED-9993 jsc#PED-10202).
- commit fc6340a
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: SOF: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- commit 9c86001
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: remove -sdca for
  new codecs (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt715-sdca-sdw: Fix wrong complete waiting in
  rt715_dev_resume() (jsc#PED-9993 jsc#PED-10202).
- ASoC: xilinx: Add missing module descriptions (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ux500: Add missing module description (jsc#PED-9993
  jsc#PED-10202).
- ASoC: topology-test: Add missing module description
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: dmaengine: Add missing module description (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: Add missing module descriptions (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sigmadsp: Add missing module description (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ab8500: Add missing module description (jsc#PED-9993
  jsc#PED-10202).
- ASoC: audio-graph-card2: remove unneeded of_node_get()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: xtensa: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: xilinx: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ux500: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: uniphier: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tegra: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: stm: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sti: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sprd: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: spear: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sh: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rockchip: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mxs: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: meson: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: kirkwood: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: jz4740: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: generic: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cirrus: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: bcm: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: au1x: Use *-y instead of *-objs Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: atmel: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: apple: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: adi: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: core: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: atmel: tse850-pcm5142: Remove unused of_gpio.h
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: uniphier: Constify static snd_pcm_hardware (jsc#PED-9993
  jsc#PED-10202).
- ASoC: meson: Constify static snd_pcm_hardware (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: Constify static snd_pcm_hardware (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: Constify static snd_pcm_hardware (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wm8996: use 'time_left' variable with
  wait_for_completion_timeout() (jsc#PED-9993 jsc#PED-10202).
- commit fd9364f
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: codecs: wm8994: use 'time_left' variable with
  wait_for_completion_timeout() (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wm8993: use 'time_left' variable with
  wait_for_completion_timeout() (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wm8962: use 'time_left' variable with
  wait_for_completion_timeout() (jsc#PED-9993 jsc#PED-10202).
- ASoC: sunxi: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: meson: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: kirkwood: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: img: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: tegra: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-topology-test: clarify Copyright information
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: clarify Copyright information (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: catpt: clarify Copyright information (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: Intel: clarify Copyright information (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: common: clarify Copyright information (jsc#PED-9993
  jsc#PED-10202).
- commit 3f82779
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: boards: clarify Copyright information (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: clarify Copyright information (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: q6apm-dai: drop unused 'q6apm_dai_rtd' fields
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: move hda.c to different module (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: remove circular dependency on
  hda_sdw_process_wakeen() (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: move tracepoint creation (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: move common code from hda.c (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: start splitting top-level from common parts
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: regroup all SoundWire/Intel functions in hda.c
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-stream: export stream_get_position()
  helper (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Correct DAI copier config and NHLT
  blob request (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Allow selective update in
  sof_ipc4_update_hw_params (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: discard SoundWire configuration if HDaudio
  codec is reported (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: Drop explicit initialization of struct
  i2c_device_id::driver_data to 0 (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-rt5682: support bclk as PLL source on rt5682s
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-rt5682: get bclk frequency from topology
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-rt5682: setup pll_id only when needed
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-rt5682: add driver_data to sof_rt5682 board
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: add icl_rt5682_def for icl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-rt5682: remove SOF_RT5682_MCLK_BYTCHT_EN
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-rt5682: add mclk_en to sof_rt5682_private
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: glk_rt5682_max98357a: delete driver (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_rt5682: support MAX98357A on glk boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: add glk_rt5682_def for glk boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bxt_da7219_max98357a: remove glk support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: support MAX98357A on glk boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: add glk_da7219_def for glk boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bxt_da7219_max98357a: remove cml support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: support MAX98357A on cml boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: support MAX98357A (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_rt5682: add missing MAX98357A config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bxt_da7219_max98357a: remove MAX98390 support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: support MAX98390 on cml boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: add cml_da7219_def for cml boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: support MAX98390 (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_maxim_common: support MAX98390 on cml boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: nau8825/rt5682: move speaker widget to common
  modules (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Clean up hw constraints initialization
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Store pointer to link_stream in dma_data
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Remove redundancy around DAI prepare
  (jsc#PED-9993 jsc#PED-10202).
- commit b8d3231
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: pcm: Reverse iterate DAIs when shutting them down
  (jsc#PED-9993 jsc#PED-10202).
- commit a99d8b2
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: avs: Remove redundancy around DAI startup
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Store pointer to adev in DAI dma_data
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Remove redundancy around DAI shutdown
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Relocate HDA BE DAI specific operations
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: mediatek: mt8195: Constify snd_sof_dsp_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: mediatek: mt8186: Constify snd_sof_dsp_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: intel: byt: Constify snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: intel: bdw: Constify snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: imx8ulp: Constify snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: core: add SOC_DOUBLE_RANGE_TLV() helper macro
  (jsc#PED-9993 jsc#PED-10202).
- commit 00c506f
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: SOF: imx8m: Constify snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: imx8: Constify snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: amd: acp: Constify snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: intel: hda: Constify snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: intel: pci-tng: Constify snd_sof_dsp_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Constify stored pointer to snd_sof_dsp_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: pcm: Constify local snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: ipc3: Constify local snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: debug: Constify local snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Advertise passthrough capable PCMs
  (using ChainDMA) (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: list SoundWire peripherals on mismatch
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: simplify and reduce indentation for
  hda_sdw_machine_select() (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: topology: remove incorrect widget id in error message
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: debug: Handle cases when fw_lib_prefix is not set,
  NULL (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Add support for cs42l43-cs35l56 sidecar
  amps (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Add callbacks to register sidecar devices
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Delay update of the codec_conf array
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: add a space before cfg-amp in components
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-sdw: don't set card long_name (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: Allocate snd_soc_card dynamically
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-lnl-match: adds RT714 and RT1318
  support (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi: mtl: add support for Acer Swift Go 14
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi: mtl: add Dell SKU 0C64 and 0CC6
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: skl_hda_dsp_generic: Use devm_kasprintf for the
  components string (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: skl_hda_dsp_generic: Allocate snd_soc_card
  dynamically (jsc#PED-9993 jsc#PED-10202).
- ASoC: sunxi: DMIC: Add controls for adjusting the mic gains
  (jsc#PED-9993 jsc#PED-10202).
- ASoc: PCM6240: Fix spelling mistake: "deley" -> "delay"
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l41: Delete unnecessary condition in
  cs35l41_pcm_hw_params() (jsc#PED-9993 jsc#PED-10202).
- ASoc: PCM6240: Create header file for PCM6240 Family driver code
  (jsc#PED-9993 jsc#PED-10202).
- ASoc: PCM6240: Create PCM6240 Family driver code (jsc#PED-9993
  jsc#PED-10202).
- commit 1dfdc67
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: avs: Switch to ACPI NHLT (jsc#PED-9993
  jsc#PED-10202).
- commit c21f9a2
* Thu Sep  5 2024 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_MT8186_MT6366=m
- supported.conf: update for the unified modules
- commit f79ea43
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: dapm: debugfs: show the widget type (jsc#PED-9993
  jsc#PED-10202).
- ASoC: dapm: debugfs: add component to route lines (jsc#PED-9993
  jsc#PED-10202).
- ASoC: nau8821: Remove redundant ADC controls (jsc#PED-9993
  jsc#PED-10202).
- ASoC: nau8821: Add delay control for ADC (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Remove unused IRQ-related code (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: New IRQ handling implementation (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sunxi: sun4i-i2s: Fix pcm_formats type specification
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8186: Unify mt8186-mt6366 machine drivers
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: Use common mtk_afe_pcm_platform with common
  probe cb (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: Add common mtk_afe_component_probe callback
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8186-rt1019: Migrate to the common
  mtk_soundcard_startup (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8192: Migrate to the common
  mtk_soundcard_startup (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8195: Migrate to the common
  mtk_soundcard_startup (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: Add common snd_soc_ops .startup() callback
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8186: Migrate to mtk_soundcard_common_probe
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8192: Migrate to mtk_soundcard_common_probe
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8195: Migrate to mtk_soundcard_common_probe
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8188: Migrate to mtk_soundcard_common_probe
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: common: Constify struct mtk_sof_priv
  (jsc#PED-9993 jsc#PED-10202).
- commit 512c34a
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: mediatek: Add common machine soundcard driver probe
  mechanism (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl-asoc-card: add wm8904 codec support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sunxi: sun4i-i2s: Support 32-bit audio formats
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp-da7219-max98357a: Constify regulator_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: i2s: Drop unneeded MODULE_ALIAS (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wcd934x: Drop unneeded MODULE_ALIAS (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: Support microphone from Acer Aspire A315-24P
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use RT5682S_PLL1 if needed
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: cml_rt1011_rt5682: delete driver (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_rt5682: support ALC1011 on cml boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_realtek_common: support 4xALC1011 amplifier
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: add mtl_da7219_def for mtl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: mach cleanup for rpl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: mach cleanup for adl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: remove FOUR_SPEAKER quirks (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: soc-acpi: add support for HP Omen14 SoundWire
  configuration (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: add missing sof_sdw_rt_amp_init for
  Realtek multi-function codecs (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: tas2780: remove redundant assignments to variable
  ret (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: davinci-i2s: Add T1 framing support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ti: davinci-i2s: Add S24_LE to supported formats
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: davinci-i2s: Link free-run mode to
  SND_SOC_DAIFMT_[GATED/CONT] (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: davinci-i2s: Enable unexpected frame pulses detection
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: davinci-i2s: Add handling of BP_FC format
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: davinci-i2s: Add TDM support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ti: davinci-i2s: Delete unnecessary assignment
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: davinci-i2s: Use external clock to drive sample rate
  generator (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: davinci-i2s: Replace dev_err with dev_err_probe
  (jsc#PED-9993 jsc#PED-10202).
- commit 69db77f
* Thu Sep  5 2024 tiwai@suse.de
- Update config files.
- commit 8b68be2
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: ti: davinci-i2s: Remove the unused clk_input_pin attribute
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: lnl: Add fw_regs area to debugfs map
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: mtl: Add fw_regs area to debugfs map
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: tgl: Add fw_regs area to debugfs map for IPC4
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: pcm: perform power-down delay checks a bit faster
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: fix for soundwire build dependencies for legacy stack
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: Fix uninitialized variable in probe
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: sc8280xp: Add support for QCM6490 and QCS6490
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-ctrl: only clear WAKESTS for HDaudio
  codecs (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-codec: preserve WAKEEN values
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: lnl: add helper to detect SoundWire wakes
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-ctrl: add missing WAKE_STS clear
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Rule invalid buffer and period sizes out
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Add assert_static to guarantee ABI sizes
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Init debugfs before booting firmware
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Wake from D0ix when starting streaming
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Remove dead code (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Replace risky functions with safer variants
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Fix config_length for config-less copiers
  (jsc#PED-9993 jsc#PED-10202).
- commit 1498adb
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: avs: Fix debug-slot offset calculation
  (jsc#PED-9993 jsc#PED-10202).
- commit a9bda87
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: avs: Silence false-positive memcpy() warnings
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Restore stream decoupling on prepare
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-stream: clarify comment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: don't ignore IOC interrupts for non-audio
  transfers (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-loader: change signature of code loader
  helpers (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-loader: add flag to tag ICCMAX stream
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Cleanup after ABI v4 support removal
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Remove ABI v4 support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: Skylake: Remove soc-topology ABI v4 support
  (jsc#PED-9993 jsc#PED-10202).
- commit fc82fed
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: SOF: Clean up sof_ipc_flood_dfs_write() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Disable pointless writes to debugfs file
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: imx: remove imx8_*_clocks API (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: imx: drop usage of the imx8_*_clocks API
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: nau8822: Remove unused member from struct (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm_adsp: Remove notification of driver write (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: hda_cs_dsp_ctl: Use
  cs_dsp_coeff_lock_and_[read|write]_ctrl() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm_adsp: Use cs_dsp_coeff_lock_and_[read|write]_ctrl()
  (jsc#PED-9993 jsc#PED-10202).
- firmware: cs_dsp: Add locked wrappers for coeff read and write
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: mtl: Correct the mtl_dsp_dump output
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dsp/mtl: Add support for ACE ROM state
  codes (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: Create debugfs file to force a clean
  DSP boot (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt5682: Constify card_headset_pins
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt5663: Constify card_headset_pins
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt298: Constify card_headset_pins
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt286: Constify card_headset_pins
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt274: Constify card_headset_pins
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: nau8825: Constify card_headset_pins
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: es8336: Constify card_headset_pins
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: hdaudio: Constify probing_link (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Use devm_kstrdup_const (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: hdaudio: Use devm_kstrdup_const (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rsnd: no exception for SCU (jsc#PED-9993 jsc#PED-10202).
- ASoC: rsnd: R-Car Gen1/Gen2 exception (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rsnd: rename rsnd_is_e3() to rsnd_is_gen3_e3()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rsnd: don't get resource from ID (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rsnd: cleanup regmap table (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: remove shadowed variable (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: ipc4-priv: align prototype and function declaration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: acp-loader: abort firmware download on write
  error (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-loader: save FW version info to debugfs
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Save the ALH DAI index during
  hw_params (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: pcm: reset all PCM sources in case of xruns
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: pcm: add pending_stop state variable (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: pcm: simplify sof_pcm_hw_free() with helper
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-audio: revisit sof_pcm_stream_free() error
  handling and logs (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: Clear Soundwire node ID during BE DAI
  hw_free (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: move helper to static inline
  (jsc#PED-9993 jsc#PED-10202).
- commit 3dcbc33
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: SOF: IPC4: extend dai_data with node_id (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: hda: extend signature of
  sdw_hda_dai_hw_params() (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: set the DMA TLV device as dai_index
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai: add helpers to set dai config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai: set dma_stream_channel_map device
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai: set lowest N bits in ch_mask
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: make dma_config_tlv be an array (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai: fix channel map configuration for
  aggregated dailink (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-card: Use snd_ctl_find_id_mixer() instead of
  open-coding (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Introduce snd_ctl_find_id_mixer_locked()
  (jsc#PED-9993 jsc#PED-10202).
- commit 874d7c1
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: nau8325: Revise soc_enum structure definition
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: nau8325: new driver (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: add mtl_cs42l42_def for mtl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: add rpl_cs42l42_def for rpl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: mach cleanup for adl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: board id cleanup for adl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: mach cleanup for mtl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: mach cleanup for rpl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: mach cleanup for adl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: mach cleanup for tgl boards
  (jsc#PED-9993 jsc#PED-10202).
- commit 4e8ed2e
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: sof_nau8825: mach cleanup for rpl boards
  (jsc#PED-9993 jsc#PED-10202).
- commit fe8e542
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: sof_nau8825: add mtl_nau8825_def for mtl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: mach cleanup for adl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: support tplg suffix detection (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: ssp-common: get codec tplg suffix function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: ssp-common: delete module (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: ssp-common: module name change (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: ssp-common: naming convention change (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: ssp-common: relocate header file (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: ssp-common: relocate source file (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sdw-mockup: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt722-sdca-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt715-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt715-sdca-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt712-sdca-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt712-sdca-dmic: drop driver owner assignment
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt711-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt711-sdca-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt700-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5682-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1318-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1316-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1308-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1017-sdca-sdw: drop driver owner assignment
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: max98373-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tlv320aic3x-spi: drop driver owner assignment
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tlv320aic32x4-spi: drop driver owner assignment
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sun8i-codec: Fix build with CONFIG_SND_JACK_INPUT_DEV
  disabled (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Add support for cs42l43 optional speaker
  output (jsc#PED-9993 jsc#PED-10202).
- commit ebe58be
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: sof_sdw: Add quirk for optional codec speakers
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Remove redundant initialisations
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Don't pass acpi_link_adr to init functions
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: change cs35l56 name_prefix (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: change rt715-sdca dai name (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt715-sdca: rename dai name with rt715-sdca prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt722_sdca: use rt_dmic_rtd_init
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt722_sdca: set rtd_init in
  codec_info_list[] (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: remove unused rt dmic rtd_init
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: use generic rtd_init function for Realtek
  SDW DMICs (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Factor out SoundWire DAI creation
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Move generation of DAI links to new
  parsing (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Move append_dai_type to new parsing
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Move ignore_pch_dmic to new parsing
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Move counting and codec_conf to new
  parsing (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-sdw: Add new code for parsing the snd_soc_acpi
  structs (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: soc-acpi: Add missing cs42l43 endpoints
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Remove no longer supported quirk
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-arl-match: Add rt711 sdca codec
  support (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Factor out codec name generation
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Factor out BlueTooth DAI creation
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Factor out HDMI DAI creation (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: Factor out DMIC DAI creation (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: Factor out SSP DAI creation (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: Use for_each_set_bit (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: Only pass dai_link pointer around
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Move flags to private struct (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: Move get_codec_dai_by_name() into sof_sdw
  itself (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Set channel map directly from endpoints
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Only pass codec_conf pointer around
  (jsc#PED-9993 jsc#PED-10202).
- commit ec776c3
* Thu Sep  5 2024 tiwai@suse.de
- atm: idt77252: prevent use after free in dequeue_rx()
  (CVE-2024-44998 bsc#1230171).
- commit fd57936
* Thu Sep  5 2024 sjaeckel@suse.de
- tcp: add sanity checks to rx zerocopy (CVE-2024-26640
  bsc#1221650).
- commit 21286c2
* Thu Sep  5 2024 nik.borisov@suse.com
- EDAC/skx: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 1a1bbd0
* Thu Sep  5 2024 nik.borisov@suse.com
- EDAC/sb_edac: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 45532f1
* Thu Sep  5 2024 nik.borisov@suse.com
- EDAC, pnd2: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 0594193
* Thu Sep  5 2024 nik.borisov@suse.com
- EDAC/i10nm: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit a6f1745
* Thu Sep  5 2024 nik.borisov@suse.com
- perf/x86/rapl: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 2f9fc15
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/boot: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit cec675a
* Thu Sep  5 2024 nik.borisov@suse.com
- perf/x86/intel: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit fdcacce
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/virt/tdx: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 60ad2f1
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/PCI: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit a330e17
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/cpu/intel: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 03ec745
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/platform/intel-mid: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 038d379
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/cpu: Fix x86_match_cpu() to match just X86_VENDOR_INTEL (jsc#PED-10246,jsc#PED-10350).
- commit 4dbaa29
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/mm: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 2517203
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/tsc: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 6402adf
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/resctrl: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- Refresh
  patches.suse/x86-resctrl-Prepare-for-new-Sub-NUMA-Cluster-SNC-monitor-f.patch.
- commit ae4e002
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/microcode/intel: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 8a97502
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/mce: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit cdf96db
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/cpu: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 3377036
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/cpu/intel_epb: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 07e24f8
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/aperfmperf: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit c68ac51
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/apic: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit e1ea1ad
* Thu Sep  5 2024 nik.borisov@suse.com
- perf/x86/msr: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit d282aab
* Thu Sep  5 2024 nik.borisov@suse.com
- perf/x86/intel/uncore: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 28da6e3
* Thu Sep  5 2024 nik.borisov@suse.com
- perf/x86/intel/pt: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit a2edaca
* Thu Sep  5 2024 nik.borisov@suse.com
- perf/x86/lbr: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 92fe0bc
* Thu Sep  5 2024 nik.borisov@suse.com
- perf/x86/intel/cstate: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit c31a98b
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/bugs: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 54b534f
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/cpu/vfm: Update arch/x86/include/asm/intel-family.h (jsc#PED-10246,jsc#PED-10350).
- commit ed3ff00
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/cpu/vfm: Add new macros to work with (vendor/family/model) values (jsc#PED-10246,jsc#PED-10350).
- commit 67d1d8f
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/cpu/vfm: Add/initialize x86_vfm field to struct cpuinfo_x86 (jsc#PED-10246,jsc#PED-10350).
- commit 038477f
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: intel: sof_sdw: Make find_codec_info_dai() return a
  pointer (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Make find_codec_info_acpi() return a
  pointer (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Make find_codec_info_part() return a
  pointer (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-jack: Get rid of legacy GPIO support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sun8i-codec: Implement jack and accessory detection
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sun50i-codec-analog: Enable jack detection on startup
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sun8i-codec: Enable bus clock at STANDBY and higher bias
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sun50i-codec-analog: Move suspend/resume to set_bias_level
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Delete unused REG_SUPPLY (jsc#PED-9993
  jsc#PED-10202).
- commit afaf0e7
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: codecs: ES8326: Reducing power consumption (jsc#PED-9993
  jsc#PED-10202).
- commit a1f576d
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: dmaengine_pcm: Allow passing component name via config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: i2s_test: Remove redundant dapm routes
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: ssm4567: Board cleanup (jsc#PED-9993
  jsc#PED-10202).
- ASoC: topology: Do not ignore route checks when parsing graphs
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: imx-rpmsg: Update to correct DT node (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: fsl_rpmsg: Register CPU DAI with name of rpmsg
  channel (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: Let imx-audio-rpmsg register platform device for card
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: imx-audio-rpmsg: Register device with rpmsg channel
  name (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: imx-pcm-rpmsg: Register component with rpmsg channel
  name (jsc#PED-9993 jsc#PED-10202).
- commit 654707f
* Thu Sep  5 2024 tiwai@suse.de
- Update config files: CONFIG_ACPI_NHLT=y (jsc#PED-9993 jsc#PED-10202)
- commit 5ba1b88
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: sof_rt5682: board id cleanup for cml boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: remove sof_nau8825 board id
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: remove unnecessary idisp HDMI quirk
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: remove unnecessary idisp HDMI quirk
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: board id cleanup for rpl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: board id cleanup for adl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: board id cleanup for jsl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: add SOF_DA7219_MCLK_EN quirk
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: add codec exit function (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_da7219: use common module for DAI link
  generation (jsc#PED-9993 jsc#PED-10202).
- commit 7dae8eb
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: sof_ssp_amp: use common module for sof_card_private
  initialization (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use common module for sof_card_private
  initialization (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use common module for sof_card_private
  initialization (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: use common module for sof_card_private
  initialization (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support sof_card_private
  initialization (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: rename BT offload quirk (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_rt5682: support ALC5650 on RPL boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: add rpl_mx98360_da7219 board config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: change dai link helpers to static
  function (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: use common module for DAI link
  generation (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support DAI link ID customization
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: Commonize ADDA rate transform functions and
  enums (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8192-afe-pcm: Simplify with dev_err_probe()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8192-afe-pcm: Convert to
  devm_pm_runtime_enable() (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-dai: Note valid values of sysclock direction
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: hdac_hda: improve error logs (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: imx-es8328: Remove leftover gpio initialisation
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: imx-es8328: Switch to using gpiod API (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: fsl_ssi: Add dev_err_probe if PCM DMA init fails
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: simplify soundwire dependencies for legacy stack
  (jsc#PED-9993 jsc#PED-10202).
- commit c99ecb5
* Thu Sep  5 2024 tiwai@suse.de
- ACPI: NHLT: Streamline struct naming (jsc#PED-9993
  jsc#PED-10202).
- commit 8eb615f
* Thu Sep  5 2024 tiwai@suse.de
- ALSA: core: Remove superfluous CONFIG_PM (jsc#PED-9993
  jsc#PED-10202).
- ASoC: audio-graph-card2: call of_node_get() before
  of_get_next_child() (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Correct spaces in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: boards: Properly name input device
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: fix for acp platform device creation failure
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: intel-dsp-config: Switch to ACPI NHLT (jsc#PED-9993
  jsc#PED-10202).
- ALSA: pcm_dmaengine: Add missing module description
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: hda_component: Initialize shared data during bind
  callback (jsc#PED-9993 jsc#PED-10202).
- ACPI: NHLT: Drop redundant types (jsc#PED-9993 jsc#PED-10202).
- ACPI: NHLT: Introduce API for the table (jsc#PED-9993
  jsc#PED-10202).
- ACPI: NHLT: Reintroduce types the table consists of
  (jsc#PED-9993 jsc#PED-10202).
- commit 3757eaa
* Thu Sep  5 2024 tiwai@suse.de
- ALSA: pci: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- commit 6e1a80a
* Thu Sep  5 2024 tiwai@suse.de
- ALSA: hda: conexant: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ALSA-hda-conexant-Fix-headset-auto-detect-fail-in-th.patch.
- commit 867b79f
* Thu Sep  5 2024 tiwai@suse.de
- ALSA: hda: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ALSA: core: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: via: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: sigmantel: Reduce CONFIG_PM dependencies
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: realtek: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: hdmi: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: cs4809: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: cirrus: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- commit b9c22eb
* Thu Sep  5 2024 tiwai@suse.de
- ALSA: hda: ca0132: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: analog: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: generic: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: codec: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: intel: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ASoC: meson: axg-tdm: add continuous clock support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l56: fix usages of device_get_named_child_node()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Avoid static analysis warning of uninitialised
  variable (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Core: Handle error returned by
  sof_select_ipc_and_paths (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: Do not reset the ChainDMA if it has not
  been allocated (jsc#PED-9993 jsc#PED-10202).
- commit 97a76e9
* Thu Sep  5 2024 tiwai@suse.de
- ALSA: control: Use list_for_each_entry_safe() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: dummy: Allow UMP conversion (jsc#PED-9993
  jsc#PED-10202).
- ALSA: pcm: add support for 705.6kHz and 768kHz sample rates
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: Introduce generic sof_ipc4_pcm_stream_priv
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: Use consistent name for
  sof_ipc4_timestamp_info pointer (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: Use consistent name for snd_sof_pcm_stream
  pointer (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: debug: show firmware/topology prefix/names
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Fix debug window description (jsc#PED-9993
  jsc#PED-10202).
- commit 0e10462
* Thu Sep  5 2024 tiwai@suse.de
- ALSA: hda: Intel: Select AZX_DCAPS_PIO_COMMANDS for Lunar Lake
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ALSA-hda-Add-Intel-BMG-PCI-ID-and-HDMI-codec-vid.patch.
- commit c335ee1
* Thu Sep  5 2024 tiwai@suse.de
- ALSA: hda: cs35l41: Use shared cs-amp-lib to apply calibration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-bus: Use PIO mode for Lunar Lake
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pci: hda: hda_controller: Add support for
  use_pio_for_commands mode (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: hdac_controller: Implement support for
  use_pio_for_commands mode (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Introduce flags to force commands via PIO instead
  of CORB (jsc#PED-9993 jsc#PED-10202).
- commit b3990a8
* Thu Sep  5 2024 oneukum@suse.com
- USB: serial: option: add MeiG Smart SRM825L (git-fixes).
- commit 047a639
* Thu Sep  5 2024 ailiop@suse.com
- nilfs2: fix state management in error path of log writing
  function (git-fixes).
- commit 9b55988
* Thu Sep  5 2024 oneukum@suse.com
- cdc-acm: Add DISABLE_ECHO quirk for GE HealthCare UI Controller
  (git-fixes).
- commit a322b71
* Thu Sep  5 2024 oneukum@suse.com
- usb: dwc3: core: Prevent USB core invalid event buffer address
  access (git-fixes).
- commit de7b6b3
* Thu Sep  5 2024 ailiop@suse.com
- nilfs2: fix missing cleanup on rollforward recovery error
  (git-fixes).
- commit b4149d3
* Thu Sep  5 2024 ailiop@suse.com
- nilfs2: protect references to superblock parameters exposed
  in sysfs (git-fixes).
- commit e7215f6
* Thu Sep  5 2024 iivanov@suse.de
- arm64: tlb: Allow range operation for MAX_TLBI_RANGE_PAGES (bsc#1229585)
- commit a52467b
* Thu Sep  5 2024 iivanov@suse.de
- arm64: tlb: Improve __TLBI_VADDR_RANGE() (bsc#1229585)
- commit 26752eb
* Thu Sep  5 2024 iivanov@suse.de
- arm64: tlb: Fix TLBI RANGE operand (bsc#1229585)
- commit 24bd468
* Thu Sep  5 2024 iivanov@suse.de
- blacklist.conf: ("KVM: arm64: Use TLBI_TTL_UNKNOWN in __kvm_tlb_flush_vmid_range()") (bsc#1229585)
- commit 29fbf2b
* Thu Sep  5 2024 iivanov@suse.de
- arm64/mm: Update tlb invalidation routines for FEAT_LPA2 (bsc#1229585)
- commit b8ec0d4
* Thu Sep  5 2024 iivanov@suse.de
- arm64/mm: Modify range-based tlbi to decrement scale (bsc#1229585)
- commit e08c708
* Thu Sep  5 2024 tiwai@suse.de
- Refresh patches.suse/ASoC-qcom-sc8280xp-Limit-speaker-digital-volumes.patch
- commit 2841ede
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: add more debugfs stub helpers (drm-backport-placeholder)
- commit e599ffd
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: refactor error info reset (drm-backport-placeholder)
- commit 9e3c36a
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: add event queue extra validation (drm-backport-placeholder)
- commit a16d367
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: unsecure TSB_CFG_MTRR regs (drm-backport-placeholder)
- commit 0bfa42e
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: move ioctl error print to debug level (drm-backport-placeholder)
- commit dd1fe80
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: fix bug of not fetching addr_dec info (drm-backport-placeholder)
- commit 31d61be
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: remove sim code (drm-backport-placeholder)
- commit 21f0745
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: mask part of hmmu page fault captured address (drm-backport-placeholder)
- commit d69018e
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: update state when loading boot fit (drm-backport-placeholder)
- commit 863b714
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: print qman data on error only for lower qman (drm-backport-placeholder)
- commit 55021cc
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: use lower QM in QM errors handling (drm-backport-placeholder)
- commit 99db81d
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: use binning info when handling razwi (drm-backport-placeholder)
- commit 7280d33
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: remove support for mmu disable (drm-backport-placeholder)
- commit d4f957f
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: upon DMA errors, use FW-extracted error cause (drm-backport-placeholder)
- commit b9ac16e
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: print max timeout value on CS stuck (drm-backport-placeholder)
- commit 741aa37
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: align to latest firmware specs (drm-backport-placeholder)
- commit 406dc54
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: set unused bit as reserved (drm-backport-placeholder)
- commit 90304be
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: rename security functions related arguments (drm-backport-placeholder)
- commit e930ca4
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: Fix some kernel-doc comments (drm-backport-placeholder)
- commit b22aa41
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: always fetch pci addr_dec error info (drm-backport-placeholder)
- commit e035d51
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: fix a static warning - 'dubious: x & !y' (drm-backport-placeholder)
- commit 4dbbfff
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: poll for device status update following WFE cmd (drm-backport-placeholder)
- commit 4dca9dc
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: expose debugfs files later (drm-backport-placeholder)
- commit 94925df
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: add missing tpc interrupt info (drm-backport-placeholder)
- commit 69d2f49
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: refactor abort of completions and waits (drm-backport-placeholder)
- commit 6e30b02
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: minimize encapsulation signal mutex lock time (drm-backport-placeholder)
- commit 8c7a31f
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: call to HW/FW err returns 0 when no events exist (drm-backport-placeholder)
- commit 44d31b0
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: unsecure TPC bias registers (drm-backport-placeholder)
- commit 7e2be8c
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: do soft-reset using cpucp packet (drm-backport-placeholder)
- commit 296b973
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: check fw version using sw version (drm-backport-placeholder)
- commit f81ab67
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: extract and save the FW's SW major/minor/sub-minor (drm-backport-placeholder)
- commit 55f0e9e
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: rename fw_{major/minor}_version to (drm-backport-placeholder)
- commit fc725bb
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: add helper to extract the FW major/minor (drm-backport-placeholder)
- commit 5a7bac6
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: fix bug in free scratchpad memory (drm-backport-placeholder)
- commit ee8dfc4
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: remove commented code that won't be used (drm-backport-placeholder)
- commit 0992b7d
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: allow user to modify EDMA RL register (drm-backport-placeholder)
- commit 3bd1fc9
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: ignore false positive razwi (drm-backport-placeholder)
- commit 7fa1a0f
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: remove variable gaudi_irq_name (drm-backport-placeholder)
- commit b273bfe
* Thu Sep  5 2024 pjakobsson@suse.de
- drm/gma500: Clear fbdev framebuffer with fb_memset_io() (drm-backport-placeholder)
- commit aa5cd8d
* Thu Sep  5 2024 pjakobsson@suse.de
- x86/fbdev: Include asm/fb.h as needed (drm-backport-placeholder).
- Refresh patches.suse/0012-arch-x86-Include-asm-fb.h-in-fbdev-source-file.patch.
- commit 444a024
* Thu Sep  5 2024 tiwai@suse.de
- USB: serial: option: add MeiG Smart SRM825L (stable-fixes).
- cdc-acm: Add DISABLE_ECHO quirk for GE HealthCare UI Controller
  (stable-fixes).
- usb: dwc3: core: Prevent USB core invalid event buffer address
  access (stable-fixes).
- selinux,smack: don't bypass permissions check in inode_setsecctx
  hook (stable-fixes).
- drm/amdgpu/swsmu: always force a state reprogram on init
  (stable-fixes).
- drm/amdgpu: align pp_power_profile_mode with kernel docs
  (stable-fixes).
- commit 1d64229
* Thu Sep  5 2024 tiwai@suse.de
- supported.conf: mark soundwire-amd as supported (jsc#PED-9993 jsc#PED-10202)
- commit c51ed92
* Thu Sep  5 2024 tiwai@suse.de
- Refresh patches.suse/ASoC-mediatek-Assign-dummy-when-codec-not-specified-.patch
  Fix the build
- commit 5e84cf7
* Wed Sep  4 2024 krisman@suse.de
- Resort io_uring kABI patches
  These ended up in the wrong section.  Push them to the right place, next
  to the other io_uring kabi patches.
- commit f218522
* Wed Sep  4 2024 krisman@suse.de
- kABI: Split kABI out of 'io_uring: Re-add dummy_ubuf for kABI purposes'
  When introducing this patch, I merged the kABI patch with the actual
  backport, which is not recommended.  Split it up, such that the backport
  is similar to the upstream patch and handle the kABI issue exactly the
  same way, but through a separate kABI patch.
- commit 5b3aa8f
* Wed Sep  4 2024 krisman@suse.de
- kABI: Split kABI out of 'io_uring/kbuf: get rid of bl->is_ready'
  When introducing this patch, I merged the kABI patch with the actual
  backport, which is not recommended.  Split it up, such that the backport
  is similar to the upstream patch and handle the kABI issue exactly the
  same way, but through a separate kABI patch.
- commit d39d376
* Wed Sep  4 2024 jack@suse.cz
- ext4: sanity check for NULL pointer after ext4_force_shutdown
  (bsc#1229753 CVE-2024-43898).
- commit d9361cb
* Wed Sep  4 2024 jack@suse.cz
- udf: Fix bogus checksum computation in udf_rename() (bsc#1229389
  CVE-2024-43845).
- commit 985c73e
* Wed Sep  4 2024 jack@suse.cz
- ext4: fix infinite loop when replaying fast_commit (bsc#1229394
  CVE-2024-43828).
- commit c9c168b
* Wed Sep  4 2024 jack@suse.cz
- block: fix deadlock between sd_remove & sd_release (bsc#1229371
  CVE-2024-42294).
- commit a556834
* Wed Sep  4 2024 jack@suse.cz
- udf: Avoid using corrupted block bitmap buffer (bsc#1229362
  CVE-2024-42306).
- commit 26b3a5d
* Wed Sep  4 2024 jack@suse.cz
- ext4: check dot and dotdot of dx_root before making dir indexed
  (bsc#1229363 CVE-2024-42305).
- commit d42c7e5
* Wed Sep  4 2024 jack@suse.cz
- mm/filemap: make MAX_PAGECACHE_ORDER acceptable to xarray
  (bsc#1229001 CVE-2024-42243).
- commit 962c57e
* Wed Sep  4 2024 jack@suse.cz
- protect the fetch of ->fd[fd] in do_dup2() from mispredictions
  (bsc#1229334 CVE-2024-42265).
- commit 1088a58
* Wed Sep  4 2024 jack@suse.cz
- ext4: make sure the first directory block is not a hole
  (bsc#1229364 CVE-2024-42304).
- commit 0ee54f7
* Wed Sep  4 2024 davide.benini@suse.com
- netfilter: ctnetlink: use helper function to calculate expect ID
  (CVE-2024-44944 bsc#1229899).
- commit da9b5c6
* Wed Sep  4 2024 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_CS_AMP_LIB=m (jsc#PED-9993 jsc#PED-10202)
- commit e129bc9
* Wed Sep  4 2024 tiwai@suse.de
- Revert "ALSA: usb-audio: Skip setting clock selector for single
  connections" (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ALSA-usb-audio-Ignore-clock-selector-errors-for-sing.patch.
- commit 88f95f4
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: usb-audio: Support read-only clock selector control
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ALSA-usb-audio-Ignore-clock-selector-errors-for-sing.patch.
- commit d95b38c
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: usb-audio: Skip setting clock selector for single
  connections (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ALSA-usb-audio-Ignore-clock-selector-errors-for-sing.patch.
- commit 28075b6
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: scarlett2: Fix Scarlett 4th Gen input gain range again
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Fix Scarlett 4th Gen input gain range
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Fix Scarlett 4th Gen autogain status values
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Fix Scarlett 4th Gen 4i4 low-voltage detection
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Fix yet more -Wformat-truncation warnings
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add PCM Input Switch for Solo Gen 4
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add support for Solo, 2i2, and 4i4 Gen 4
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add R/O headphone volume control (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add minimum firmware version check
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Rename DSP mux channels (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add support for DSP mux channels (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add support for custom Gen 4 Direct Monitor
  mixes (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Handle Gen 4 Direct Monitor mix updates
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Store mix_ctls for Gen 4 Direct Monitor
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add power status control (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Disable autogain during phantom power state
  change (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Disable input controls while autogain is
  running (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Minor refactor MSD mode check (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add support for software-controllable input
  gain (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add support for Air Presence + Drive option
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Allow for controls with a "mute mode"
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add support for Gen 4 style parameters
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add support for air/phantom control on input 2
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Remove repeated elem->head.mixer references
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Split direct_monitor out from monitor_other
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Split input_other into level/pad/air/phantom
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Rename db_scale_scarlett2_gain to volume
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add #define for SCARLETT2_MIX_MAX (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add scarlett2_mixer_value_to_db() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Allow for interfaces without per-channel volume
  (jsc#PED-9993 jsc#PED-10202).
- commit 84eef3b
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: scarlett2: Remove line_out_hw_vol device info entry
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Split dim_mute_update from vol_updated
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Remove struct scarlett2_usb_volume_status
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Refactor common port_count lookups
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Change num_mux_* from int to u8 (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Parameterise notifications (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Formatting fixes (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Refactor scarlett2_config_save() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Refactor scarlett2_usb_set_config()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add check for config_item presence
  (jsc#PED-9993 jsc#PED-10202).
- commit d635a33
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: scarlett2: Remove scarlett2_config_sets array
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add config set struct (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Check presence of mixer using mux_assignment
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Check for phantom persistence config item
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Infer standalone switch from config items
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Infer has_msd_mode from config items
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Simplify enums by removing explicit values
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add support for uploading new firmware
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add ioctl commands to erase flash segments
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add skeleton hwdep/ioctl interface
  (jsc#PED-9993 jsc#PED-10202).
- commit 374a7bf
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: scarlett2: Allow passing any output to line_out_remap()
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ALSA-scarlett2-Add-missing-error-checks-to-_ctl_get.patch.
- commit 4c745d6
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: scarlett2: Retrieve useful flash segment numbers
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add #defines for firmware upgrade (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add missing mutex lock around get meter levels
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Update maintainer info (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Convert meter levels from little-endian
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add missing check with firmware version control
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Remap Level Meter values (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add support for reading firmware version
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Rename Gen 3 config sets (jsc#PED-9993
  jsc#PED-10202).
- commit d1c0361
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: scarlett2: Rename scarlett_gen2 to scarlett2 (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ALSA-scarlett2-Add-clamp-in-scarlett2_mixer_ctl_put.patch.
- Refresh
  patches.suse/ALSA-scarlett2-Add-missing-error-check-to-scarlett2_-5f6ff69.patch.
- Refresh
  patches.suse/ALSA-scarlett2-Add-missing-error-check-to-scarlett2_.patch.
- Refresh
  patches.suse/ALSA-scarlett2-Add-missing-error-checks-to-_ctl_get.patch.
- commit 4a34466
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: caiaq: Replace with __packed attribute (jsc#PED-9993
  jsc#PED-10202).
- ALSA: usx2y: Annotate struct snd_usx2y_urb_seq with __counted_by
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: usb-audio: scarlett_gen2: Fix another -Wformat-truncation
  warning (jsc#PED-9993 jsc#PED-10202).
- ALSA: caiaq: Fix -Wformat-truncation warning (jsc#PED-9993
  jsc#PED-10202).
- ALSA: usb-audio: scarlett_gen2: Fix -Wformat-truncation warning
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: usb-audio: mixer: Remove temporary string use in
  parse_clock_source_unit (jsc#PED-9993 jsc#PED-10202).
- ALSA: usb-audio: Remove unused function declaration
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: bcd2000: refactor deprecated strncpy (jsc#PED-9993
  jsc#PED-10202).
- commit 04e86fa
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: hda: Add pplcllpl/u members to hdac_ext_stream
  (jsc#PED-9993 jsc#PED-10202).
- commit 5ff47d9
* Wed Sep  4 2024 tiwai@suse.de
- ptrace: Convert ptrace_attach() to use lock guards (jsc#PED-9993
  jsc#PED-10202).
- cleanup: Add conditional guard support (jsc#PED-9993
  jsc#PED-10202).
- commit 86c77b1
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: SOF: Core: Add remove_late() to sof_init_environment
  failure path (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: fix for false dsp interrupts (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: lnl: Disable DMIC/SSP offload on remove
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Removing the control of ADC_SCALE
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Solve a headphone detection issue after
  suspend and resume (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: modify clock table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: Solve error interruption issue
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: boards: Add modules description (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt-sdw*: add __func__ to all error logs (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: acp: fix for acp pdm configuration check
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: Compensate LLP in case it is not reset
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: Correct the delay calculation (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: sof-pcm: Add pointer callback to sof_ipc_pcm_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: Invalidate the stream_start_offset in
  PAUSED state (jsc#PED-9993 jsc#PED-10202).
- commit 708daa0
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: SOF: ipc4-pcm: Combine the SOF_IPC4_PIPE_PAUSED cases
  in pcm_trigger (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: Move struct sof_ipc4_timestamp_info
  definition locally (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Remove the get_stream_position callback (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: hda-common-ops: Do not set the
  get_stream_position callback (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: Use the snd_sof_pcm_get_dai_frame_counter()
  for pcm_delay (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: Set the dai/host get frame/byte counter
  callbacks (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Introduce a new callback pair to be used for PCM
  delay reporting (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: mtl/lnl: Use the generic get_stream_position
  callback (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: Implement get_stream_position (Linear
  Link Position) (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-pcm: Use dsp_max_burst_size_in_ms to
  place constraint (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Save the DMA maximum burst size for
  PCMs (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Add dsp_max_burst_size_in_ms member to
  snd_sof_pcm_stream (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Correct extraction of data pointer in
  suspend/resume (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: mtrace: rework mtrace timestamp setting (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs-amp-lib: Check for no firmware controls when writing
  calibration (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda/tas2781: remove useless dev_dbg from playback_hook
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda/tas2781: add debug statements to kcontrols
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l56: Raise device name message log level
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: support NHLT device type (jsc#PED-9993
  jsc#PED-10202).
- commit 807355b
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: hda: intel-nhlt: add intel_nhlt_ssp_device_type() function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-compress: Fix and add DPCM locking (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: amd: Skip IRAM/DRAM size modification for Steam
  Deck OLED (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Move signed_fw_image to struct acp_quirk_entry
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: yc: Revert "add new YC platform variant (0x63)
  support" (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Fix unannotated kfree() cleanup (jsc#PED-9993
  jsc#PED-10202).
- ALSA: timer: Fix missing irq-disable at closing (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: catpt: Carefully use PCI bitwise constants
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Changing members of private structure
  (jsc#PED-9993 jsc#PED-10202).
- commit f052e70
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: trace: add event to snd_soc_dapm trace events
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: trace: add component to set_bias_level trace events
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: atom: sst_ipc: Remove unused intel-mid.h
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-core.c: Prefer to return dai->driver->name in
  snd_soc_dai_name_get() (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Prevent bad sign extension in
  cs35l56_read_silicon_uid() (jsc#PED-9993 jsc#PED-10202).
- ASoC: meson: axg-fifo: take continuous rates (jsc#PED-9993
  jsc#PED-10202).
- ASoC: meson: axg-spdifin: use max width for rate detection
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: meson: axg-tdm-interface: update error format error traces
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: rt5660: Simplify mclk initialization (jsc#PED-9993
  jsc#PED-10202).
- commit ef7403b
* Wed Sep  4 2024 tiwai@suse.de
- Refresh patches.suse/ASoC-generic-convert-not-to-use-asoc_xxx.patch
- commit fd7906d
* Wed Sep  4 2024 oneukum@suse.com
- media: v4l: async: Add some debug prints (jsc#PED-8643).
- Refresh
  patches.suse/media-v4l-async-Clean-up-testing-for-duplicate-async.patch.
- Refresh
  patches.suse/media-v4l-async-Make-V4L2-async-match-information-a-.patch.
- Refresh
  patches.suse/media-v4l-async-Rename-V4L2_ASYNC_MATCH_-macros-add-.patch.
- commit a83eedd
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: cs35l56: Apply amp calibration from EFI data (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-cs35l56-Fix-unintended-bus-access-while-resetti.patch.
- Refresh
  patches.suse/ASoC-cs35l56-Prevent-overwriting-firmware-ASP-config.patch.
- commit d6bb28b
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: cs35l56: Add helper functions for amp calibration
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-cs35l56-Prevent-overwriting-firmware-ASP-config.patch.
- commit b5d27dd
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: codecs: rt5640: Simplify mclk initialization (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: rt5616: Simplify mclk initialization (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: rt5514: Simplify mclk initialization (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: nau8825: Simplify mclk initialization
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: da7213: Simplify mclk initialization (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: tx-macro: correct TX SMIC MUXn widgets on SM8350+
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: tx-macro: split widgets per different LPASS
  versions (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l56: Apply amp calibration from EFI data
  (jsc#PED-9993 jsc#PED-10202).
- commit 7ddf902
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: avs: TGL-based platforms support (jsc#PED-9993
  jsc#PED-10202).
- commit 8f33595
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: avs: ICL-based platforms support (jsc#PED-9993
  jsc#PED-10202).
- commit b044b28
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: avs: CNL-based platforms support (jsc#PED-9993
  jsc#PED-10202).
- commit b624180
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: cs-amp-lib: Add helpers for factory calibration data
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm_adsp: Add wm_adsp_start() and wm_adsp_stop()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-core: tidyup strcmp() param on
  snd_soc_is_matching_dai() (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: ps: modify ACP register end address macro
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: ps: update license (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wsa884x: Allow sharing reset GPIO (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: ICCMAX recommendations for ICL+ platforms
  (jsc#PED-9993 jsc#PED-10202).
- commit b4c9a2d
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: avs: Abstract IRQ handling (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Abstract IPC handling (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Prefix SKL/APL-specific members (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Fix sound clipping in single capture scenario
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: L1SEN reference counted (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l42: Remove redundant delays in suspend()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tas2781: Remove redundant initialization of pointer 'data'
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: fix soundwire dependencies (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: ps: add machine select and register code
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: ps: fix for acp pme wake for soundwire configuration
  (jsc#PED-9993 jsc#PED-10202).
- commit 92bbc5e
* Wed Sep  4 2024 tiwai@suse.de
- Update config files. (jsc#PED-9993 jsc#PED-10202)
- commit a45c76f
* Wed Sep  4 2024 oneukum@suse.com
- media: v4l: async: Rename V4L2_ASYNC_MATCH_ macros, add TYPE_
  (jsc#PED-8643).
- commit e8464cd
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: amd: ps: remove acp_reset flag (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: ps: refactor acp child platform device creation code
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: ps: refactor acp device configuration read logic
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Constify pointer to of_phandle_args (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: remove redundant 'tristate' in
  sound/soc/codecs/Kconfig (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai: add support for dspless mode beyond
  HDAudio (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: lnl: Do not use LNL specific wrappers in
  DSPless mode (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai-ops: add SoundWire dspless mode
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai-ops: use dai_type (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: topology: Parse DAI type token for dspless mode
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: start SoundWire links earlier for LNL+
  devices (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: topology: dynamically allocate and store DAI
  widget->private (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai: remove dspless special case
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: allow chain_dma for all supported DAIs
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: fix dma_id for CHAIN_DMA capture
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4: store number of playback/capture streams
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai-ops: enable chain_dma for ALH
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: add 'is_chain_dma_supported' callback
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ops: add new 'is_chain_dma_supported' callback
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: change chain_dma handling in
  dai_config (jsc#PED-9993 jsc#PED-10202).
- commit ad61e3b
* Wed Sep  4 2024 tiwai@suse.de
- supported.conf: sync for 6.9 (jsc#PED-9993 jsc#PED-10202)
- commit 41dc584
* Wed Sep  4 2024 oneukum@suse.com
- media: v4l: async: Make V4L2 async match information a struct
  (jsc#PED-8643).
- commit 1024e9a
* Wed Sep  4 2024 tiwai@suse.de
- Update config files: sync with 6.9 (jsc#PED-9993 jsc#PED-10202)
- commit 6fa7644
* Wed Sep  4 2024 oneukum@suse.com
- media: v4l: async: Clean up testing for duplicate async subdevs
  (jsc#PED-8643).
- commit 20947e2
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: codecs: tx-macro: Simplify setting AMIC control
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: tx-macro: Mark AMIC control registers as volatile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: tx-macro: Drop unimplemented DMIC clock divider
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: va-macro: add npl clk (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: ipc4-topology: set config_length based on
  device_count (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Fix runtime pm usage counter balance after fw
  exception (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: fix TYPO 'reguest' to 'request' in error log
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: imx: Add devicetree support to select topologies
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Expose FW version with sysfs (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tas2781: remove unused acpi_subysystem_id (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: starts non sdw BE id with the highest
  sdw BE id (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-lnl-match: Add rt722 support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi: add RT712 support for LNL (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: Remove unused function prototypes
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: ssp-common: Add stub for sof_ssp_get_codec_name
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: remove .init callbacks (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: add common sdw dai link init (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt5682: use helper to get codec dai by name
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_cs42l42: use helper to get codec dai by
  name (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt700: use helper to get codec dai by name
  (jsc#PED-9993 jsc#PED-10202).
- commit c3d3f31
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: sof_sdw_rt712_sdca: use helper to get codec dai
  by name (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt711: use helper to get codec dai by name
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: use helper to get
  codec dai by name (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: add get_codec_dai_by_name helper function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: use single rtd_init for rt_amps
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: use common module for DAI link
  generation (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support DAI link order customization
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: dmi quirk cleanup for mtl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: board id cleanup for mtl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: board id cleanup for rpl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: board id cleanup for adl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: board id cleanup for tgl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: board id cleanup for jsl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Send initial config to module if present
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Add topology parsing support for initial
  config (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: UAPI: Add tokens for initial config feature
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: constify static sdw_slave_ops struct (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa: remove duplicated CONFIG_SND_PXA2XX_AC97 entry
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: fix SND_AMD_SOUNDWIRE_ACPI dependencies
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Shut down jack detection on component remove
  (jsc#PED-9993 jsc#PED-10202).
- commit 0371a2a
* Wed Sep  4 2024 tiwai@suse.de
- soundwire: Use snd_soc_substream_to_rtd() to obtain rtd
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: constify the struct device_type usage (jsc#PED-9993
  jsc#PED-10202).
- soundwire: bus_type: make sdw_bus_type const (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_auxdevice: remove redundant assignment to
  variable link_flags (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Sync the hp ilimit works when removing the
  component (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Add clear of stashed pointer on component remove
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: refactor acp driver pm ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: amd: select soundwire dependency flag for acp6.3
  based platform (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: update descriptor fields for acp6.3 based
  platform (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: add machine select logic for soundwire based
  platforms (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Add Soundwire DAI configuration support for
  AMD platforms (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: add interrupt handling for SoundWire manager
  devices (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: add code for invoking soundwire manager helper
  functions (jsc#PED-9993 jsc#PED-10202).
- soundwire: amd: refactor register mask structure (jsc#PED-9993
  jsc#PED-10202).
- soundwire: amd: refactor soundwire pads enable (jsc#PED-9993
  jsc#PED-10202).
- soundwire: amd: implement function to extract slave information
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: amd: refactor amd soundwire manager device node
  creation (jsc#PED-9993 jsc#PED-10202).
- soundwire: amd: update license (jsc#PED-9993 jsc#PED-10202).
- ASoC/soundwire: implement generic api for scanning amd soundwire
  controller (jsc#PED-9993 jsc#PED-10202).
- commit 8cab2b1
* Wed Sep  4 2024 oneukum@suse.com
- media: v4l: async: Drop v4l2_async_nf_parse_fwnode_endpoints()
  (jsc#PED-8643).
- commit 43bd60c
* Wed Sep  4 2024 davide.benini@suse.com
- sctp: Fix null-ptr-deref in reuseport_add_sock()
  (CVE-2024-44935 bsc#1229810).
- commit c34ddb2
* Wed Sep  4 2024 tiwai@suse.de
- soundwire: amd: drop bus freq calculation and set 'max_clk_freq'
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: generic_bandwidth_allocation use
  bus->params.max_dr_freq (jsc#PED-9993 jsc#PED-10202).
- soundwire: qcom: set controller id to hw master id (jsc#PED-9993
  jsc#PED-10202).
- soundwire: stream: constify sdw_port_config when adding devices
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: qcom: move sconfig in qcom_swrm_stream_alloc_ports()
  out of critical section (jsc#PED-9993 jsc#PED-10202).
- soundwire: qcom: drop unneeded qcom_swrm_stream_alloc_ports()
  cleanup (jsc#PED-9993 jsc#PED-10202).
- soundwire: bus: improve error handling for clock stop
  prepare/deprepare (jsc#PED-9993 jsc#PED-10202).
- soundwire: qcom: Log clk_get("iface") failures (jsc#PED-9993
  jsc#PED-10202).
- soundwire: qcom: handle command ignored interrupt (jsc#PED-9993
  jsc#PED-10202).
- soundwire: qcom: use newer link status tregister on v2.0.0
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soundwire: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- commit 72fcbc4
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Cleanup unused unit structure (bsc#1230119).
- commit 48a66a6
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: mtl-match: Add cs42l43_l0 cs35l56_l23 for MTL
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Use fls to calculate the pre-divider for the PLL
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Refactor to use for_each_set_bit() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l43: Use USEC_PER_MSEC rather than hard coding
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Add pm_ptr around the power ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l43: Check error from device_property_read_u32_array()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Minor code tidy ups (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Tidy up header includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: Adding new volume kcontrols (jsc#PED-9993
  jsc#PED-10202).
- commit 8353b66
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: codecs: Add support for the framer codec (jsc#PED-9993
  jsc#PED-10202).
- ASoC: atmel: use devm_snd_soc_register_card() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: use devm_snd_soc_register_card() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ti: use devm_snd_soc_register_card() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl_sai: Add support for i.MX95 platform (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codec: wcd-mbhc-v2: add support when connected behind
  an USB-C audio mux (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Compute file paths on firmware load
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: core: Skip firmware test for custom loaders
  (jsc#PED-9993 jsc#PED-10202).
- commit 7fc7702
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: amd: acp: Drop redundant initialization of machine driver
  data (jsc#PED-9993 jsc#PED-10202).
- commit d42dbcd
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Apply the unit control RB tree to PCI uncore
  units (bsc#1230119).
- commit e202e9f
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: cs35l56: Add support for CS35L54 and CS35L57 (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-cs35l56-Fix-unintended-bus-access-while-resetti.patch.
- commit 50fe8e5
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: amd: acp: Update MODULE_DESCRIPTION for sof-mach
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Make use of existing *_CODEC_DAI macros
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: j721e-evm: Use devm_kcalloc() instead of
  devm_kzalloc() (jsc#PED-9993 jsc#PED-10202).
- ASoC: nau8540: Add pre-charge actions for input (jsc#PED-9993
  jsc#PED-10202).
- ASoC: p1022_rdk: fix all kernel-doc warnings (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: Use devm_kcalloc() instead of devm_kzalloc()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l56: Add support for CS35L54 and CS35L57
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: hda_component: Include sound/hda_codec.h
  (jsc#PED-9993 jsc#PED-10202).
- commit 281aa92
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: hda: hda_component: Add missing #include guards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: hda: Cleanup error messages (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Ignore codecs with no suppoting driver
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: hda: Skip HDMI/DP registration if i915 is missing
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Skip i915 initialization on CNL/LKF-based platforms
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hwdep: Move put_user() call out of scoped_guard() in
  snd_hwdep_control_ioctl() (jsc#PED-9993 jsc#PED-10202).
- ALSA: control_led: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: pcm: oss: Use guard() for setup (jsc#PED-9993
  jsc#PED-10202).
- ALSA: pcm: Use guard() for PCM stream locks (jsc#PED-9993
  jsc#PED-10202).
- ALSA: pcm: Use guard() for locking (jsc#PED-9993 jsc#PED-10202).
- commit 7cd39e2
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: core: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ALSA-Fix-deadlocks-with-kctl-removals-at-disconnecti.patch.
- commit c1053ba
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: seq: prioq: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: virmidi: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: ump: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: midi: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: timer: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: queue: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: ports: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: memory: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: fifo: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- commit 6919b22
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: jack: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ALSA-core-Remove-debugfs-at-disconnection.patch.
- commit 5c94f68
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: timer: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ALSA-timer-Relax-start-tick-time-check-for-slave-tim.patch.
- Refresh
  patches.suse/ALSA-timer-Set-lower-bound-of-start-tick-time.patch.
- commit 0d7101b
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: rawmidi: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: control: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: mixer_oss: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: info: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hwdep: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hrtimer: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: compress_offload: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: ump: Use guard() for locking (jsc#PED-9993 jsc#PED-10202).
- commit 2603534
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: seq: ump: Use automatic cleanup of kfree() (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ALSA-seq-ump-Skip-useless-ports-for-static-blocks.patch.
- commit 5d93335
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: pcm_oss: ump: Use automatic cleanup of kfree()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: mixer_oss: ump: Use automatic cleanup of kfree()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Use CLASS() for fdget()/fdput() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: core: Use automatic cleanup of kfree() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: virmidi: Use automatic cleanup of kfree()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: seq: oss: Use automatic cleanup of kfree() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: vmaster: Use automatic cleanup of kfree() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: timer: Use automatic cleanup of kfree() (jsc#PED-9993
  jsc#PED-10202).
- commit 6e3e441
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: compress_offload: Use automatic cleanup of kfree()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Use automatic cleanup of kfree() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: pcm: Use automatic cleanup of kfree() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: prioq: Unify cell removal functions (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: Downgrade BDL table overflow message (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: Set up BDL table at hw_params (jsc#PED-9993
  jsc#PED-10202).
- ALSA: avoid 'bool' as variable name (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: remove redundant 'tristate' for SND_SEQ_UMP_CLIENT
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: seq: make snd_seq_bus_type const (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa2xx-ac97: Replace with DEFINE_SIMPLE_DEV_PM_OPS()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: HDA: intel-sdw-acpi: add kernel parameter to select
  alternate controller (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Fix snd_pcm_format_name function (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: realtek: Move hda_component implementation to module
  (jsc#PED-9993 jsc#PED-10202).
- commit 5e6f9cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1825-drm-i915-Fix-HPD-polling-reenabling-the-output-poll-.patch (drm-backport-placeholder)
- commit 7887f8a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-Add-an-HPD-poll-helper-to-reschedule-the-p.patch (drm-backport-placeholder)
- commit 6232a83
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1823-drm-i915-fix-Sphinx-indentation-warning.patch (drm-backport-placeholder)
- commit 755317d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dgfx-Enable-d3cold-at-s2idle.patch (drm-backport-placeholder)
- commit 01ba862
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Fix-possible-invalid-drm-gem-put-ca.patch (drm-backport-placeholder)
- commit aba92bc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Fix-shader-stage-validation.patch (drm-backport-placeholder)
- commit b5494ed
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/dma-buf-sw_sync-Avoid-recursive-lock-during-fe.patch (drm-backport-placeholder)
- commit 4a30c6f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-display-dp-Fix-the-DP-DSC-Receiver-cap-siz.patch (drm-backport-placeholder)
- commit 5e876c1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-panfrost-Skip-speed-binning-on-EOPNOTSUPP.patch (drm-backport-placeholder)
- commit a155307
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1816-drm-bridge-samsung-dsim-Fix-init-during-host-transfe.patch (drm-backport-placeholder)
- commit a443430
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-goldfishfb-Do-not-check-0-for-platform_get_irq.patch (drm-backport-placeholder)
- commit c23ddbb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1814-fbdev-atmel_lcdfb-Remove-redundant-of_match_ptr.patch (drm-backport-placeholder)
- commit 20ec421
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1813-fbdev-kyro-Remove-unused-declarations.patch (drm-backport-placeholder)
- commit 6eb60c4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1812-fbdev-ssd1307fb-Print-the-PWM-s-label-instead-of-its.patch (drm-backport-placeholder)
- commit fa5cfa4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-mmp-fix-value-check-in-mmphw_probe.patch (drm-backport-placeholder)
- commit 1f92093
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1810-fbdev-amifb-Replace-zero-length-arrays-with-DECLARE_.patch (drm-backport-placeholder)
- commit 3f0ed03
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-qxl-fix-UAF-on-handle-creation.patch (drm-backport-placeholder)
- commit 1876c71
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/Revert-Revert-drm-amdgpu-display-change-pipe-p.patch (drm-backport-placeholder)
- commit 899a235
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-flush-any-delayed-gfxoff-on-suspend-en.patch (drm-backport-placeholder)
- commit c28e8b9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-skip-fence-GFX-interrupts-disable-e.patch (drm-backport-placeholder)
- commit b9b5c77
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1805-drm-amdgpu-skip-xcp-drm-device-allocation-when-out-o.patch (drm-backport-placeholder)
- commit a6b88f3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1804-drm-amd-pm-Update-pci-link-width-for-smu-v13.0.6.patch (drm-backport-placeholder)
- commit 4c78f99
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-Fix-temperature-unit-of-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit eca13dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-fix-throttle_status-for-other-th.patch (drm-backport-placeholder)
- commit fb56ade
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1801-drm-amdgpu-disable-mcbp-if-parameter-zero-is-set.patch (drm-backport-placeholder)
- commit fea8df1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1800-drm-amd-pm-disallow-the-fan-setting-if-there-is-no-f.patch (drm-backport-placeholder)
- commit 414b938
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/accel-qaic-Clean-up-integer-overflow-checking-.patch (drm-backport-placeholder)
- commit 1bd460a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/accel-qaic-Fix-slicing-memory-leak.patch (drm-backport-placeholder)
- commit 9dbd417
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-simple-Fix-AUO-G121EAN01-panel-timin.patch (drm-backport-placeholder)
- commit 6872c62
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1796-drm-panel-JDI-LT070ME05000-simplify-with-dev_err_pro.patch (drm-backport-placeholder)
- commit 5ce0eb5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1795-drm-i915-fix-display-probe-for-IVB-Q-and-IVB-D-GT2-s.patch (drm-backport-placeholder)
- commit 90ef882
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-sdvo-fix-panel_type-initialization.patch (drm-backport-placeholder)
- commit ab62e30
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-guc-slpc-Restore-efficient-freq-earli.patch (drm-backport-placeholder)
- commit db4f05a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1792-drm-amdkfd-disable-IOMMUv2-support-for-Raven.patch (drm-backport-placeholder)
- commit 5192092
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1791-drm-amdkfd-disable-IOMMUv2-support-for-KV-CZ.patch (drm-backport-placeholder)
- commit 06bd849
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1790-drm-amdkfd-ignore-crat-by-default.patch (drm-backport-placeholder)
- commit cf0db77
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1789-drm-amdgpu-gfx11-only-enable-CP-GFX-shadowing-on-SR-.patch (drm-backport-placeholder)
- commit e16fa70
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-a-regression-on-Polaris-ca.patch (drm-backport-placeholder)
- commit ff67935
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-possible-UAF-in-amdgpu_cs_pass1.patch (drm-backport-placeholder)
- commit 95a5df0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1786-drm-amd-pm-Fix-SMU-v13.0.6-energy-reporting.patch (drm-backport-placeholder)
- commit 050bc01
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-check-attr-flag-before-set-cur.patch (drm-backport-placeholder)
- commit 63269c8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1784-drm-amd-pm-disable-the-SMU13-OD-feature-support-temp.patch (drm-backport-placeholder)
- commit 6a9be39
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-correct-the-pcie-width-for-smu-13.0.patch (drm-backport-placeholder)
- commit aaf71ef
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Don-t-show-stack-trace-for-mis.patch (drm-backport-placeholder)
- commit 27eb8b9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Match-against-exact-bootloader-status.patch (drm-backport-placeholder)
- commit d4a6340
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-skip-the-RLC-stop-when-S0i3-suspend.patch (drm-backport-placeholder)
- commit ba4d69f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Disable-S-G-for-APUs-when-64GB-or-more.patch (drm-backport-placeholder)
- commit de64756
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-shmem-helper-Reset-vma-vm_ops-before-calli.patch (drm-backport-placeholder)
- commit 8f7e21a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-Don-t-spam-logs-in-atomic-check.patch (drm-backport-placeholder)
- commit ff0d479
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/accel-ivpu-Add-set_pages_array_wc-uc-for-inter.patch (drm-backport-placeholder)
- commit e81a07f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-disp-Revert-a-NULL-check-inside-no.patch (drm-backport-placeholder)
- commit 97cd65b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1775-Revert-drm-bridge-lt9611-Do-not-generate-HFP-HBP-HSA.patch (drm-backport-placeholder)
- commit f00180d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-remove-unused-tu102_gr_load-functi.patch (drm-backport-placeholder)
- commit 1b53272
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-nvkm-dp-Add-workaround-to-fix-DP-1.patch (drm-backport-placeholder)
- commit 4bd2826
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-gr-enable-memory-loads-on-helper-i.patch (drm-backport-placeholder)
- commit 15245ca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-it6505-Check-power-state-with-it650.patch (drm-backport-placeholder)
- commit f26ce6e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1770-drm-i915-gvt-Fix-bug-in-getting-msg-length-in-AUX-CH.patch (drm-backport-placeholder)
- commit 2233974
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-premature-release-of-request-s-re.patch (drm-backport-placeholder)
- commit ad2308f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Support-aux-invalidation-on-all-en.patch (drm-backport-placeholder)
- commit 7a052b2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Poll-aux-invalidation-register-bit.patch (drm-backport-placeholder)
- commit 5aa7968
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Enable-the-CCS_FLUSH-bit-in-the-pi.patch (drm-backport-placeholder)
- commit 988cd35
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Rename-flags-with-bit_group_X-acco.patch (drm-backport-placeholder)
- commit bab983c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Ensure-memory-quiesced-before-inva.patch (drm-backport-placeholder)
- commit d4576cf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Add-the-gen12_needs_ccs_aux_inv-helpe.patch (drm-backport-placeholder)
- commit 86a482a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Cleanup-aux-invalidation-registers.patch (drm-backport-placeholder)
- commit 412d79a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1761-drm-panel-samsung-s6d7aa0-Add-MODULE_DEVICE_TABLE.patch (drm-backport-placeholder)
- commit 0647bd8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-imx-ipuv3-Fix-front-porch-adjustment-upon-.patch (drm-backport-placeholder)
- commit 4eab1d6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-ttm-check-null-pointer-before-accessing-wh.patch (drm-backport-placeholder)
- commit b0e9d34
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/locking-rtmutex-Fix-task-pi_waiters-integrity.patch (drm-backport-placeholder)
- commit e014727
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-Disallow-submit-with-fence-id-0.patch (drm-backport-placeholder)
- commit 90000fb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-Fix-hw_fence-error-path-cleanup.patch (drm-backport-placeholder)
- commit dd1f683
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-Fix-IS_ERR_OR_NULL-vs-NULL-check-in-a5x.patch (drm-backport-placeholder)
- commit 0244dc5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-adreno-Fix-snapshot-BINDLESS_DATA-size.patch (drm-backport-placeholder)
- commit 55e0fcf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1753-drm-msm-a690-Remove-revn-and-name.patch (drm-backport-placeholder)
- commit 4b1ebee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1752-drm-msm-adreno-Fix-warn-splat-for-devices-without-re.patch (drm-backport-placeholder)
- commit 30e0b1b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-Drop-unused-regulators-from-QCM2290.patch (drm-backport-placeholder)
- commit 5d50c87
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-drop-enum-dpu_core_perf_data_bus_id.patch (drm-backport-placeholder)
- commit 977a4e3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-add-missing-flush-and-fetch-bits-fo.patch (drm-backport-placeholder)
- commit dcc2b94
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-mdss-correct-UBWC-programming-for-SM855.patch (drm-backport-placeholder)
- commit ad7c0f4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1747-drm-amdgpu-Restore-HQD-persistent-state-register.patch (drm-backport-placeholder)
- commit 5c86626
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Unlock-on-error-path-in-dm_hand.patch (drm-backport-placeholder)
- commit cee0fc2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Exit-idle-optimizations-before-attem.patch (drm-backport-placeholder)
- commit eb3925a
* Wed Sep  4 2024 tiwai@suse.de
- Update config files. (jsc#PED-9993 jsc#PED-10202)
- commit e905069
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1744-drm-amd-display-Don-t-apply-FIFO-resync-W-A-if-rdivi.patch (drm-backport-placeholder)
- commit b6d2e00
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Guard-DCN31-PHYD32CLK-logic-against-.patch (drm-backport-placeholder)
- commit 87b7659
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-smu-use-AverageGfxclkFrequency-to-replace-pr.patch (drm-backport-placeholder)
- commit 972f074
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Fix-an-error-handling-mistake-in-psp_sw.patch (drm-backport-placeholder)
- commit e35802d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1740-drm-amdgpu-Fix-infinite-loop-in-gfxhub_v1_2_xcc_gart.patch (drm-backport-placeholder)
- commit cc40a8c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1739-drm-amdkfd-fix-trap-handling-work-around-for-debuggi.patch (drm-backport-placeholder)
- commit 3d17abc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-an-error-handling-path-in-igt_writ.patch (drm-backport-placeholder)
- commit d44e0b0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dpt-Use-shmem-for-dpt-objects.patch (drm-backport-placeholder)
- commit d16041b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1736-drm-fb-helper-Remove-unused-inline-function-drm_fb_h.patch (drm-backport-placeholder)
- commit d2ba4e1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1735-fbdev-Explicitly-include-correct-DT-includes.patch (drm-backport-placeholder)
- commit 5935328
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1734-fbdev-ep93xx-fb-fix-return-value-check-in-ep93xxfb_p.patch (drm-backport-placeholder)
- commit 50d380c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-au1200fb-Fix-missing-IRQ-check-in-au1200f.patch (drm-backport-placeholder)
- commit 1d39a48
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1732-fbdev-kyro-make-some-const-read-only-arrays-static-a.patch (drm-backport-placeholder)
- commit 79c6353
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1731-fbcon-remove-unused-display-p-from-fbcon_redraw.patch (drm-backport-placeholder)
- commit e3631b3
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: seq: Replace with __packed attribute (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-acpi: Add missing kernel doc (jsc#PED-9993
  jsc#PED-10202).
- ALSA: info: Remove unused function declarations (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-dapm.h: Convert macros to return a compound literal
  (jsc#PED-9993 jsc#PED-10202).
- commit 307d9c8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1730-sticon-make-sticon_set_def_font-void-and-remove-op-p.patch (drm-backport-placeholder)
- commit f686277
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1729-vgacon-cache-vc_cell_height-in-vgacon_cursor.patch (drm-backport-placeholder)
- commit 5d7afe5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1728-vgacon-let-vgacon_doresize-return-void.patch (drm-backport-placeholder)
- commit 9f69f30
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1727-vgacon-remove-unused-xpos-from-vgacon_set_cursor_siz.patch (drm-backport-placeholder)
- commit db2aadc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1726-vgacon-remove-unneeded-forward-declarations.patch (drm-backport-placeholder)
- commit 6b4a743
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1725-vgacon-switch-vgacon_scrolldelta-and-vgacon_restore_.patch (drm-backport-placeholder)
- commit 6fb8649
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1724-fbdev-imxfb-remove-unneeded-labels.patch (drm-backport-placeholder)
- commit 9aa525d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1723-fbdev-imxfb-Convert-to-devm_platform_ioremap_resourc.patch (drm-backport-placeholder)
- commit d446c6a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1722-fbdev-imxfb-Convert-to-devm_kmalloc_array.patch (drm-backport-placeholder)
- commit 445fbab
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-imxfb-Removed-unneeded-release_mem_region.patch (drm-backport-placeholder)
- commit 38a5312
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1720-fbdev-imxfb-switch-to-DEFINE_SIMPLE_DEV_PM_OPS.patch (drm-backport-placeholder)
- commit 2d4a59f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-imxfb-warn-about-invalid-left-right-margi.patch (drm-backport-placeholder)
- commit 499a21b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-atomic-Fix-potential-use-after-free-in-nonb.patch (drm-backport-placeholder)
- commit 760fe4c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1717-drm-amdgpu-use-a-macro-to-define-no-xcp-partition-ca.patch (drm-backport-placeholder)
- commit 4d83650
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1716-drm-amdgpu-vm-use-the-same-xcp_id-from-root-PD.patch (drm-backport-placeholder)
- commit bcf895d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1715-drm-amdgpu-fix-slab-out-of-bounds-issue-in-amdgpu_vm.patch (drm-backport-placeholder)
- commit 08651f1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1714-drm-amdgpu-Allocate-root-PD-on-correct-partition.patch (drm-backport-placeholder)
- commit 0736029
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Keep-PHY-active-for-DP-displays.patch (drm-backport-placeholder)
- commit 0dc5adb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Prevent-vtotal-from-being-set-t.patch (drm-backport-placeholder)
- commit 4cb56c8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Disable-MPC-split-by-default-on.patch (drm-backport-placeholder)
- commit 56a947c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-check-TG-is-non-null-before-che.patch (drm-backport-placeholder)
- commit f54e0da
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-polling-method-to-handle-MS.patch (drm-backport-placeholder)
- commit b452b7c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Clean-up-errors-warnings-in-amd.patch (drm-backport-placeholder)
- commit 0bd9ea6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1707-drm-amdgpu-Allow-the-initramfs-generator-to-include-.patch (drm-backport-placeholder)
- commit 51ee7a4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-make-mclk-consistent-for-smu-13.0.patch (drm-backport-placeholder)
- commit 94a3189
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-make-gfxclock-consistent-for-sien.patch (drm-backport-placeholder)
- commit 5087082
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-only-accept-async-flips-for-fas.patch (drm-backport-placeholder)
- commit 78cc454
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-vkms-relax-timer-deactivation-by-hrt.patch (drm-backport-placeholder)
- commit 8fae3c6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1702-drm-amd-display-add-DCN301-specific-logic-for-OTG-pr.patch (drm-backport-placeholder)
- commit ca0ccea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1701-drm-amd-display-export-some-optc-function-for-reuse.patch (drm-backport-placeholder)
- commit 6547d7e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1700-drm-amd-Use-amdgpu_device_pcie_dynamic_switching_sup.patch (drm-backport-placeholder)
- commit f85415e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1699-Revert-drm-i915-use-localized-__diag_ignore_all-inst.patch (drm-backport-placeholder)
- commit 436ed3f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-perf-add-sentinel-to-xehp_oa_b_counter.patch (drm-backport-placeholder)
- commit 135e172
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-kms-nv50-init-hpd_irq_lock-for-PIOR.patch (drm-backport-placeholder)
- commit 6aa3ad4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-disp-PIOR-DP-uses-GPIO-for-HPD-not-.patch (drm-backport-placeholder)
- commit 54efcbe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-i2c-fix-number-of-aux-event-slots.patch (drm-backport-placeholder)
- commit 0e498f3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/dma-buf-dma-resv-Stop-leaking-on-krealloc-failu.patch (drm-backport-placeholder)
- commit d0865d2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/accel-qaic-Fix-a-leak-in-map_user_pages.patch (drm-backport-placeholder)
- commit ba922dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/accel-qaic-Add-consistent-integer-overflow-chec.patch (drm-backport-placeholder)
- commit eb67713
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/accel-qaic-tighten-bounds-checking-in-decode_me.patch (drm-backport-placeholder)
- commit 926a2be
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/accel-qaic-tighten-bounds-checking-in-encode_me.patch (drm-backport-placeholder)
- commit fac35b5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-client-Fix-memory-leak-in-drm_client_modese.patch (drm-backport-placeholder)
- commit 8ff9238
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-client-Fix-memory-leak-in-drm_client_target.patch (drm-backport-placeholder)
- commit 85f716f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Align-SMU11-SMU_MSG_OverridePcieParamet.patch (drm-backport-placeholder)
- commit 5a28c38
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: SOF: Intel: pci-lnl: Change the topology path to
  intel/sof-ipc4-tplg (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-SOF-Intel-add-default-firmware-library-path-for.patch.
- commit 24725dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Move-helper-for-dynamic-speed-switch-ch.patch (drm-backport-placeholder)
- commit b4df8a7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-conditionally-disable-pcie-lane-spee.patch (drm-backport-placeholder)
- commit e4139fc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-share-the-code-around-SMU13-pcie-par.patch (drm-backport-placeholder)
- commit e4b2ad2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-avoid-restore-process-run-into-dead-.patch (drm-backport-placeholder)
- commit 205f530
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-fix-smu-i2c-data-read-risk.patch (drm-backport-placeholder)
- commit 5879f21
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-one-wrong-caching-mode-enum-usage.patch (drm-backport-placeholder)
- commit 3aa80d6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1684-drm-i915-Remove-dead-code-from-gen8_pte_encode.patch (drm-backport-placeholder)
- commit 6007387
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1683-drm-i915-perf-Consider-OA-buffer-boundary-when-zeroi.patch (drm-backport-placeholder)
- commit 5314a76
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Don-t-preserve-dpll_hw_state-for-slave.patch (drm-backport-placeholder)
- commit 9a8a1ba
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-bring-back-blit-subchannel-for-pre-.patch (drm-backport-placeholder)
- commit 85a2af1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-acr-Abort-loading-ACR-if-no-firmwar.patch (drm-backport-placeholder)
- commit dae83eb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-disp-g94-enable-HDMI.patch (drm-backport-placeholder)
- commit 5dd2a8f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-disp-fix-HDMI-on-gt215.patch (drm-backport-placeholder)
- commit 121adb0
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: amd: yc: add new YC platform variant (0x63) support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-card: Fix missing locking in
  snd_soc_card_get_kcontrol() (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: clarify and fix default msbits value for all formats
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Workaround for ACPI with broken spk-id-gpios
  property (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: pci-tgl: Change the default paths and firmware
  names (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5645: Add DMI quirk for inverted jack-detect on MeeGoPad
  T8 (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: cht_bsw_rt5645: Cleanup codec_name handling
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: Boards: Fix NULL pointer deref in BYT/CHT boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Fix locking in ACP IRQ handler (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l56: Remove default from IRQ1_CFG register
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Fix dynamic port assignment when TDM is set
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Add system suspend ops to disable IRQ
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Handle error from devm_pm_runtime_enable
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Fix pci_probe() error path (jsc#PED-9993
  jsc#PED-10202).
- commit 395575f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1677-drm-client-Send-hotplug-event-after-registering-a-cl.patch (drm-backport-placeholder)
- commit f3951d3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1676-drm-panel-Fine-tune-Starry-ili9882t-panel-HFP-and-HB.patch (drm-backport-placeholder)
- commit 68479ba
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1675-drm-i915-use-mock-device-info-for-creating-mock-devi.patch (drm-backport-placeholder)
- commit d4c2b70
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-psr-Fix-BDW-PSR-AUX-CH-data-register-o.patch (drm-backport-placeholder)
- commit e31c73f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1672-drm-amd-pm-avoid-unintentional-shutdown-due-to-tempe.patch (drm-backport-placeholder)
- commit 64ecee2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-expose-swctf-threshold-setting-for-.patch (drm-backport-placeholder)
- commit 2ed2a08
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1670-drm-amd-display-3.2.241.patch (drm-backport-placeholder)
- commit 5ffb3d2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1669-drm-amd-display-Take-full-update-path-if-number-of-p.patch (drm-backport-placeholder)
- commit 97ecda5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1668-drm-amd-display-Create-debugging-mechanism-for-Gamin.patch (drm-backport-placeholder)
- commit 9ff200e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-monitor-specific-edid-quirk.patch (drm-backport-placeholder)
- commit 21674c2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1666-drm-amd-display-For-new-fast-update-path-loop-throug.patch (drm-backport-placeholder)
- commit d73a998
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Remove-Phantom-Pipe-Check-When-.patch (drm-backport-placeholder)
- commit 5512fe6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1664-drm-amd-display-Limit-new-fast-update-path-to-addr-a.patch (drm-backport-placeholder)
- commit 020620c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1663-drm-amd-display-Fix-the-delta-clamping-for-shaper-LU.patch (drm-backport-placeholder)
- commit 53e87d3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1662-drm-amdgpu-Keep-non-psp-path-for-partition-switch.patch (drm-backport-placeholder)
- commit 7c54386
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1661-drm-amd-display-program-DPP-shaper-and-3D-LUT-if-upd.patch (drm-backport-placeholder)
- commit 5e1b5f2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amd-display-edp-do-not-add-non-edid-.patch (drm-backport-placeholder)
- commit e4dd72f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1659-drm-amdgpu-share-drm-device-for-pci-amdgpu-device-wi.patch (drm-backport-placeholder)
- commit b78e143
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1658-drm-amd-pm-Add-GFX-v9.4.3-unique-id-to-sysfs.patch (drm-backport-placeholder)
- commit 47ada19
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1657-drm-amd-pm-Enable-pp_feature-attribute.patch (drm-backport-placeholder)
- commit 11c88d0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1656-drm-amdgpu-vcn-Need-to-unpause-dpg-before-stop-dpg.patch (drm-backport-placeholder)
- commit 5fdf805
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1655-drm-amdgpu-remove-duplicated-doorbell-range-init-for.patch (drm-backport-placeholder)
- commit a8cb282
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1654-drm-amdgpu-gpu-recovers-from-fatal-error-in-poison-m.patch (drm-backport-placeholder)
- commit 7c0b3f7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1653-drm-amdgpu-enable-mcbp-by-default-on-gfx9.patch (drm-backport-placeholder)
- commit 700e1a0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1652-drm-amdgpu-make-mcbp-a-per-device-setting.patch (drm-backport-placeholder)
- commit f39159e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1651-drm-amd-Don-t-initialize-PSP-twice-for-Navi3x.patch (drm-backport-placeholder)
- commit 0a75056
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amd-Disable-PSR-SU-on-Parade-0803-TC.patch (drm-backport-placeholder)
- commit c1bd00f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Set-minimum-requirement-for-usi-cd2e31a.patch (drm-backport-placeholder)
- commit 458e451
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: amd: acp: Fix support for a Huawei Matebook laptop
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd9335: drop unused gain hack remnant
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: fix the capture noise issue (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: Minimize the pop noise on headphone
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Improving the THD+N performance
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: improving crosstalk performance
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Remove executable bit (jsc#PED-9993
  jsc#PED-10202).
- ASoC: allow up to eight CPU/codec DAIs (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wcd934x: drop unneeded regulator include
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd938x: skip printing deferred probe failuers
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Update platform name for different boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Enable rt5682s clocks in acp slave mode
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Add missing formats to formats list (jsc#PED-9993
  jsc#PED-10202).
- ASoC: audio-graph-card2: fix index check on
  graph_parse_node_multi_nm() (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: icp3-dtrace: Revert "Fix wrong kfree() usage"
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8195: Remove afe-dai component and rework
  codec link (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8192: Check existence of dai_name before
  dereferencing (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bxt_rt298: Fix kernel ops due to COMP_DUMMY change
  (jsc#PED-9993 jsc#PED-10202).
- commit 81b27d0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Set-minimum-requirement-for-usi.patch (drm-backport-placeholder)
- commit 57f0af8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Correct-DMUB_FW_VERSION-macro.patch (drm-backport-placeholder)
- commit c6cdc31
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1646-drm-amd-pm-fulfill-the-missing-enablement-for-vega12.patch (drm-backport-placeholder)
- commit aaed644
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1645-drm-amd-display-Remove-asserts.patch (drm-backport-placeholder)
- commit 24f8b11
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1644-drm-amd-display-Work-around-bad-DPCD-state-on-link-l.patch (drm-backport-placeholder)
- commit 4e05a84
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1643-drm-amdgpu-port-SRIOV-VF-missed-changes.patch (drm-backport-placeholder)
- commit 11f5047
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Don-t-try-to-enable-secure-display-TA-m.patch (drm-backport-placeholder)
- commit f1ce2b7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1641-drm-amdkfd-Update-interrupt-handling-for-GFX-9.4.3.patch (drm-backport-placeholder)
- commit 9e6792c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-number-of-fence-calculations.patch (drm-backport-placeholder)
- commit 226d125
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-perform-a-bounds-check-before-f.patch (drm-backport-placeholder)
- commit c1b2104
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1638-drm-amd-pm-Provide-energy-data-in-15.625mJ-units.patch (drm-backport-placeholder)
- commit 8f9c3ee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1637-drm-amdgpu-Modify-for_each_inst-macro.patch (drm-backport-placeholder)
- commit aaa54d6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1636-drm-amdgpu-Remove-sdma-halt-unhalt-during-frontdoor-.patch (drm-backport-placeholder)
- commit ea8c5a2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-check-RAS-irq-existence-for-VCN-JPEG.patch (drm-backport-placeholder)
- commit 38b305e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-add-abnormal-fan-detection-for-smu-1.patch (drm-backport-placeholder)
- commit cdfca36
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1633-drm-amdgpu-remove-vm-sanity-check-from-amdgpu_vm_mak.patch (drm-backport-placeholder)
- commit 32a69eb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Disable-PSR-SU-on-Parade-0803-TCON.patch (drm-backport-placeholder)
- commit 1c43411
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1631-drm-amdkfd-Enable-GWS-on-GFX9.4.3.patch (drm-backport-placeholder)
- commit b492842
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-update-the-LC_L1_INACTIVITY-setting-to-ad.patch (drm-backport-placeholder)
- commit 3b4720d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1629-drm-amd-display-3.2.240.patch (drm-backport-placeholder)
- commit 42f1125
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1628-drm-amd-display-Enable-dc-mode-clock-switching-for-D.patch (drm-backport-placeholder)
- commit 1a5e58d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-128b132b-link-loss-handling.patch (drm-backport-placeholder)
- commit 27a523e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1626-drm-amd-display-fix-odm-k2-div-calculation.patch (drm-backport-placeholder)
- commit ed21d02
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1625-drm-amd-display-Add-MST-Preferred-Link-Setting-Entry.patch (drm-backport-placeholder)
- commit 48925f0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-disable-seamless-boot-if-force_.patch (drm-backport-placeholder)
- commit 28b58d5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1623-drm-amd-display-Disable-DC-Mode-Capping-On-DCN321.patch (drm-backport-placeholder)
- commit 8d750df
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1622-drm-amd-display-enable-the-new-fast-update-path-for-.patch (drm-backport-placeholder)
- commit f5e362f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1621-drm-amd-display-Clear-update-flags-at-end-of-flip.patch (drm-backport-placeholder)
- commit 9862d7b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1620-drm-amd-display-Fix-pipe-check-condition-for-manual-.patch (drm-backport-placeholder)
- commit f0502d2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1619-drm-amd-display-add-missing-ABM-registers.patch (drm-backport-placeholder)
- commit cbaf4f4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1618-drm-amd-display-Add-Clock-Table-Entry-With-Max-DC-Va.patch (drm-backport-placeholder)
- commit f9f955c
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: tas2781: Add tas2563 into driver (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-tas2781-Fix-wrong-loading-calibrated-data-seque.patch.
- commit 4125fe4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-add-a-NULL-pointer-check.patch (drm-backport-placeholder)
- commit f5bbfa1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/Partially-revert-drm-amd-display-Fix-possible-underf.patch (drm-backport-placeholder)
- commit 392dcd9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1615-Revert-drm-amd-display-Move-DCN314-DOMAIN-power-cont.patch (drm-backport-placeholder)
- commit 7b6a312
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1614-drm-amd-display-disable-RCO-for-DCN314.patch (drm-backport-placeholder)
- commit 1ad39cf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1613-drm-amd-display-disable-power-gating-for-DCN314.patch (drm-backport-placeholder)
- commit 5f30e5d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1612-drm-amdgpu-Skip-TMR-for-MP0_HWIP-13.0.6.patch (drm-backport-placeholder)
- commit b2b308e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1611-drm-amdgpu-Move-clocks-closer-to-its-only-usage-in-a.patch (drm-backport-placeholder)
- commit f0af4e2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-revise-the-ASPM-settings-for-thunder.patch (drm-backport-placeholder)
- commit a36ef05
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-clearing-mappings-for-BOs-that-a.patch (drm-backport-placeholder)
- commit ee24431
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1608-drm-amdkfd-set-coherent-host-access-capability-flag.patch (drm-backport-placeholder)
- commit 922086f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1607-drm-amdgpu-Add-vbios-attribute-only-if-supported.patch (drm-backport-placeholder)
- commit c2129af
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1606-drm-amdgpu-atomfirmware-fix-LPDDR5-width-reporting.patch (drm-backport-placeholder)
- commit 537838b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1605-drm-amdgpu-Remove-CONFIG_DEBUG_FS-guard-around-body-.patch (drm-backport-placeholder)
- commit 2a5bd06
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1604-drm-amd-pm-remove-unneeded-variable.patch (drm-backport-placeholder)
- commit 927f567
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1603-drm-amdgpu-Move-calculation-of-xcp-per-memory-node.patch (drm-backport-placeholder)
- commit 3f5f9eb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Skip-mark-offset-for-high-priority-r.patch (drm-backport-placeholder)
- commit 0f35f64
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1601-amd-display-dc-remove-repeating-expression.patch (drm-backport-placeholder)
- commit 40d6c9f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1600-drm-i915-Add-missing-forward-declarations-includes-t.patch (drm-backport-placeholder)
- commit d91ffe8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1599-drm-i915-hdcp-Assign-correct-hdcp-content-type.patch (drm-backport-placeholder)
- commit be4edd7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-guc-slpc-Apply-min-softlimit-correctly.patch (drm-backport-placeholder)
- commit eee46f6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-psr-Use-hw.adjusted-mode-when-calculat.patch (drm-backport-placeholder)
- commit 691b19d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1596-drm-i915-mtl-Fix-SSC-selection-for-MPLLA.patch (drm-backport-placeholder)
- commit 9efbd2d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1595-drm-i915-adlp-Allow-DC-states-along-with-PW2-only-fo.patch (drm-backport-placeholder)
- commit 0f556fa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1594-mei-bus-fixup-fix-buffer-type.patch (drm-backport-placeholder)
- commit 334f017
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1593-mei-bus-drop-useless-cldev-null-check.patch (drm-backport-placeholder)
- commit cbc8705
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1592-backlight-led_bl-Take-led_access-lock-when-required.patch (drm-backport-placeholder)
- commit bfaab58
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1591-video-backlight-lp855x-Get-PWM-for-PWM-mode-during-p.patch (drm-backport-placeholder)
- commit f17b61d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1590-backlight-pwm_bl-Remove-unneeded-checks-for-valid-GP.patch (drm-backport-placeholder)
- commit 9a28ebf
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: bxt_da7219_max98357a: Fix kernel ops due to
  COMP_DUMMY change (jsc#PED-9993 jsc#PED-10202).
- ASoC: tas2781: Add tas2563 into header file for DSP mode
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tas2562: move tas2563 from tas2562 driver to tas2781
  driver (jsc#PED-9993 jsc#PED-10202).
- i2c: make i2c_bus_type const (jsc#PED-9993 jsc#PED-10202).
- ASoC: pxa: sspa: Don't select SND_ARM (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5663: cancel the work when system suspends (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: imx: Add SNDRV_PCM_INFO_BATCH flag (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: cht_bsw_rt5645: Set card.components string
  (jsc#PED-9993 jsc#PED-10202).
- commit cef462d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1589-backlight-Switch-i2c-drivers-back-to-use-.probe.patch (drm-backport-placeholder)
- commit 7031a23
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1588-backlight-lm3630a-Turn-off-both-led-strings-when-dis.patch (drm-backport-placeholder)
- commit e0ec1ee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1587-sticon-parisc-Fix-STI-console-on-64-bit-only-machine.patch (drm-backport-placeholder)
- commit 0e193dd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1586-sticon-parisc-Allow-64-bit-STI-calls-in-PDC-firmware.patch (drm-backport-placeholder)
- commit 44f06db
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1585-drm-nouveau-stop-using-is_swiotlb_active.patch (drm-backport-placeholder)
- commit f003e3a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1584-drm-i915-Fix-a-NULL-vs-IS_ERR-bug.patch (drm-backport-placeholder)
- commit 26ccf6d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1583-drm-i915-make-i915_drm_client_fdinfo-reference-condi.patch (drm-backport-placeholder)
- commit b18e9f2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1582-drm-i915-huc-Fix-missing-error-code-in-intel_huc_ini.patch (drm-backport-placeholder)
- commit 9bcd778
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1581-drm-i915-gsc-take-a-wakeref-for-the-proxy-init-compl.patch (drm-backport-placeholder)
- commit c34b541
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1580-drm-msm-a6xx-Add-A610-speedbin-support.patch (drm-backport-placeholder)
- commit 1327ea5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1579-drm-msm-a6xx-Add-A619_holi-speedbin-support.patch (drm-backport-placeholder)
- commit 4ff936f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1578-drm-msm-a6xx-Use-adreno_is_aXYZ-macros-in-speedbin-m.patch (drm-backport-placeholder)
- commit 41a5022
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1577-drm-msm-a6xx-Use-else-if-in-GPU-speedbin-rev-matchin.patch (drm-backport-placeholder)
- commit e18ad19
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1576-drm-msm-a6xx-Fix-some-A619-tunables.patch (drm-backport-placeholder)
- commit b1011ab
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1575-drm-msm-a6xx-Add-A610-support.patch (drm-backport-placeholder)
- commit ad21bde
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1574-drm-msm-a6xx-Add-support-for-A619_holi.patch (drm-backport-placeholder)
- commit 319868e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1573-drm-msm-adreno-Disable-has_cached_coherent-in-GMU-wr.patch (drm-backport-placeholder)
- commit 88e6a75
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1572-drm-msm-a6xx-Introduce-GMU-wrapper-support.patch (drm-backport-placeholder)
- commit 3a0b1ba
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1571-drm-msm-a6xx-Move-CX-GMU-power-counter-enablement-to.patch (drm-backport-placeholder)
- commit 180f027
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1570-drm-msm-a6xx-Extend-and-explain-UBWC-config.patch (drm-backport-placeholder)
- commit 1568c74
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1569-drm-msm-a6xx-Remove-both-GBIF-and-RBBM-GBIF-halt-on-.patch (drm-backport-placeholder)
- commit 206db9d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1568-drm-msm-a6xx-Add-a-helper-for-software-resetting-the.patch (drm-backport-placeholder)
- commit b1ef21b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1567-drm-msm-a6xx-Improve-a6xx_bus_clear_pending_transact.patch (drm-backport-placeholder)
- commit f1fa7cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1566-drm-msm-a6xx-Move-a6xx_bus_clear_pending_transaction.patch (drm-backport-placeholder)
- commit a7a7b07
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1565-drm-msm-a6xx-Move-force-keepalive-vote-removal-to-a6.patch (drm-backport-placeholder)
- commit 248c7d1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1564-drm-msm-a6xx-Remove-static-keyword-from-sptprac-en-d.patch (drm-backport-placeholder)
- commit ec22c3c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1563-drm-msm-adreno-Use-adreno_is_revn-for-A690.patch (drm-backport-placeholder)
- commit ae32e31
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1562-drm-msm-dsi-split-dsi_ctrl_config-function.patch (drm-backport-placeholder)
- commit 9cfcbb5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1561-drm-msm-dsi-dsi_host-drop-unused-clocks.patch (drm-backport-placeholder)
- commit 6e57a4a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1560-drm-msm-dpu-remove-unused-INTF_NONE-interfaces.patch (drm-backport-placeholder)
- commit 7256a6f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-correct-MERGE_3D-length.patch (drm-backport-placeholder)
- commit f804d0c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-fix-sc7280-and-sc7180-PINGPONG-done.patch (drm-backport-placeholder)
- commit 7fdf40b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dp-Free-resources-after-unregistering-t.patch (drm-backport-placeholder)
- commit 43586ff
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dp-Drop-aux-devices-together-with-DP-co.patch (drm-backport-placeholder)
- commit c9f5324
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-provide-fb_dirty-implemenation.patch (drm-backport-placeholder)
- commit 61b8a7d
* Wed Sep  4 2024 oneukum@suse.com
- lib/math: Move dvb_math.c into lib/math/int_log.c
  (jsc#PED-8643).
- Refresh
  patches.suse/media-Explicitly-include-correct-DT-includes.patch.
- commit 27a81aa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-Remove-incorrect-references-to-slic.patch (drm-backport-placeholder)
- commit a547d3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1553-drm-msm-dpu-Set-DATA_COMPRESS-on-command-mode-for-DC.patch (drm-backport-placeholder)
- commit ecbb8da
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1552-drm-msm-dpu-Add-DPU_INTF_DATA_COMPRESS-feature-flag-.patch (drm-backport-placeholder)
- commit 543ea78
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1551-drm-msm-dsi-Reduce-pclk-rate-for-compression.patch (drm-backport-placeholder)
- commit b6ecea6
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: rt5645: Add mono speaker information to the components
  string (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5645: Add a rt5645_components() helper (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5645: Add rt5645_get_pdata() helper (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5645: Refactor rt5645_parse_dt() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5645: Add platform-data for Acer Switch V 10
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: sc8280xp: Add support for SM8650 (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: mt8188-mt6359: Enable dual amp for
  mt8188-rt5682s (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8188-mt6359: add es8326 support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: mt8188-mt6359: commonize headset codec init/exit
  api (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: vangogh: Switch to {RUNTIME,SYSTEM_SLEEP}_PM_OPS
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: vangogh: Allow probing ACP PCI when SOF is disabled
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc.h: don't create dummy Component via COMP_DUMMY()
  (jsc#PED-9993 jsc#PED-10202).
- commit 417f5a4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1550-msm-drm-dsi-Round-up-DSC-hdisplay-calculation.patch (drm-backport-placeholder)
- commit 4b74fe0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1549-drm-msm-dpu-add-DSC-1.2-hw-blocks-for-relevant-chips.patch (drm-backport-placeholder)
- commit 06087fb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1548-drm-msm-dpu-add-support-for-DSC-encoder-v1.2-engine.patch (drm-backport-placeholder)
- commit b98639d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1547-drm-msm-dsi-update-hdisplay-calculation-for-dsi_timi.patch (drm-backport-placeholder)
- commit bcd6d0a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1546-drm-msm-dsi-Use-MSM-and-DRM-DSC-helper-methods.patch (drm-backport-placeholder)
- commit c2695f8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Fix-slice_last_group_size-calculati.patch (drm-backport-placeholder)
- commit c21733a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1544-drm-msm-dpu-Use-fixed-DRM-DSC-helper-for-det_thresh_.patch (drm-backport-placeholder)
- commit f7a611a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1543-drm-msm-Add-MSM-specific-DSC-helper-methods.patch (drm-backport-placeholder)
- commit c94883b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1542-drm-msm-dsi-use-DRM-DSC-helpers-for-DSC-setup.patch (drm-backport-placeholder)
- commit 9ab0e7d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1541-drm-display-dsc-Add-drm_dsc_get_bpp_int-helper.patch (drm-backport-placeholder)
- commit f9a8f53
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1540-drm-display-dsc-add-helper-to-set-semi-const-paramet.patch (drm-backport-placeholder)
- commit b6e3255
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1539-drm-display-dsc-Add-flatness-and-initial-scale-value.patch (drm-backport-placeholder)
- commit 9a503d3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1538-drm-msm-dpu-catalog-define-DSPP-blocks-found-on-sdm8.patch (drm-backport-placeholder)
- commit 8aa9cfb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-do-not-enable-color-management-if-D.patch (drm-backport-placeholder)
- commit 21d8f5f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1536-drm-msm-adreno-make-adreno_is_a690-s-argument-const.patch (drm-backport-placeholder)
- commit 652ce7f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1535-drm-msm-adreno-change-adreno_is_-functions-to-accept.patch (drm-backport-placeholder)
- commit a886af4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1534-drm-msm-adreno-warn-if-chip-revn-is-verified-before-.patch (drm-backport-placeholder)
- commit 79ec084
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a5xx-really-check-for-A510-in-a5xx_gpu_.patch (drm-backport-placeholder)
- commit 49fd23f
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: SOF: IPC4: synchronize fw_config_params with fw
  definitions (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: add alignment for topology header file struct
  definition (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: align topology header file with sof topology header
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Deprecate invalid enums in IPC3 (jsc#PED-9993
  jsc#PED-10202).
- commit bae8afb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1532-drm-msm-a6xx-Fix-a690-CP_PROTECT-settings.patch (drm-backport-placeholder)
- commit d62360e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1531-drm-msm-adreno-Add-Adreno-A690-support.patch (drm-backport-placeholder)
- commit 2f48004
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1530-drm-msm-Move-cmdstream-dumping-out-of-sched-kthread.patch (drm-backport-placeholder)
- commit 6fdcb59
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a6xx-don-t-set-IO_PGTABLE_QUIRK_ARM_OUT.patch (drm-backport-placeholder)
- commit c8b7dd0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1528-drm-msm-drop-unused-ring-variable-in-msm_ioctl_gem_s.patch (drm-backport-placeholder)
- commit cf23244
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-adreno-fix-sparse-warnings-in-a6xx-code.patch (drm-backport-placeholder)
- commit edde071
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1526-drm-msm-mdp5-Add-MDP5-configuration-for-MSM8226.patch (drm-backport-placeholder)
- commit f6eedcf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1525-drm-msm-dsi-Add-phy-configuration-for-MSM8226.patch (drm-backport-placeholder)
- commit eac0e91
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1524-drm-msm-dsi-Add-configuration-for-MSM8226.patch (drm-backport-placeholder)
- commit e194666
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1523-drm-msm-dpu-drop-mostly-unused-DPU_NAME_SIZE-define.patch (drm-backport-placeholder)
- commit bc5339a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1522-drm-msm-dpu-drop-dpu_encoder_phys_ops-late_register.patch (drm-backport-placeholder)
- commit ba8f43c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1521-drm-msm-dsi-use-mult_frac-for-pclk_bpp-calculation.patch (drm-backport-placeholder)
- commit 08f8930
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1520-drm-msm-dsi-remove-extra-call-to-dsi_get_pclk_rate.patch (drm-backport-placeholder)
- commit f8fa4d8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-don-t-allow-enabling-14nm-VCO-with-.patch (drm-backport-placeholder)
- commit e9545e6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1518-drm-msm-dsi-More-properly-handle-errors-in-regards-t.patch (drm-backport-placeholder)
- commit 71d9b0a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1517-drm-msm-dsi-Stop-unconditionally-powering-up-DSI-hos.patch (drm-backport-placeholder)
- commit 767fd8f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1516-drm-msm-dp-Clean-up-pdev-dev-duplication-in-dp_power.patch (drm-backport-placeholder)
- commit 0481a59
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1515-drm-msm-dp-Clean-up-logs-dp_power-module.patch (drm-backport-placeholder)
- commit c49ff1f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1514-drm-msm-dp-remove-most-of-usbpd-related-remains.patch (drm-backport-placeholder)
- commit 8300ee8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1513-drm-msm-dpu-tidy-up-some-error-checking.patch (drm-backport-placeholder)
- commit 1298ddb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1512-drm-msm-dpu-add-DSC-blocks-to-the-catalog-of-MSM8998.patch (drm-backport-placeholder)
- commit 475f463
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1511-drm-msm-dpu-Add-SM6375-support.patch (drm-backport-placeholder)
- commit 40ee317
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1510-drm-msm-dpu-Add-SM6350-support.patch (drm-backport-placeholder)
- commit 4617dff
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1509-drm-msm-dpu-use-PINGPONG_NONE-to-unbind-WB-from-PP.patch (drm-backport-placeholder)
- commit ffd1ed9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1508-drm-msm-dpu-use-PINGPONG_NONE-to-unbind-INTF-from-PP.patch (drm-backport-placeholder)
- commit 367762f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1507-drm-msm-dpu-simplify-dpu_encoder_phys_wb_init.patch (drm-backport-placeholder)
- commit 2400f1d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1506-drm-msm-dpu-drop-temp-variable-from-dpu_encoder_phys.patch (drm-backport-placeholder)
- commit ba14741
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1505-drm-msm-dpu-call-dpu_rm_get_intf-from-dpu_encoder_ge.patch (drm-backport-placeholder)
- commit aaaf179
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1504-drm-msm-dpu-inline-dpu_encoder_get_wb.patch (drm-backport-placeholder)
- commit 429e0db
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1503-drm-msm-dpu-drop-duplicated-intf-wb-indices-from-enc.patch (drm-backport-placeholder)
- commit 3c99ba2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1502-drm-msm-dpu-separate-common-function-to-init-physica.patch (drm-backport-placeholder)
- commit c2eec51
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1501-drm-msm-dpu-merge-dpu_encoder_init-and-dpu_encoder_s.patch (drm-backport-placeholder)
- commit 8d4bf06
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-clean-up-dpu_kms_get_clk_rate-returns.patch (drm-backport-placeholder)
- commit ccdf562
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1499-drm-msm-dpu-Tear-down-DSC-datapath-on-encoder-cleanu.patch (drm-backport-placeholder)
- commit 6134b7c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1498-drm-msm-dpu-separate-DSC-flush-update-out-of-interfa.patch (drm-backport-placeholder)
- commit b0bc9c1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-always-clear-every-individual-pendi.patch (drm-backport-placeholder)
- commit 9834c16
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1496-drm-msm-dpu-Introduce-PINGPONG_NONE-to-disconnect-DS.patch (drm-backport-placeholder)
- commit e840c9d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1495-drm-msm-dpu-Guard-PINGPONG-DSC-ops-behind-DPU_PINGPO.patch (drm-backport-placeholder)
- commit 2b708c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1494-drm-msm-dpu-add-DPU_PINGPONG_DSC-feature-bit-for-DPU.patch (drm-backport-placeholder)
- commit 6cc42e8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-set-DSC-flush-bit-correctly-at-MDP-.patch (drm-backport-placeholder)
- commit 3448f38
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1492-drm-msm-dpu-use-common-helper-for-WB-and-SSPP-QoS-se.patch (drm-backport-placeholder)
- commit 2ac40fb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1491-drm-msm-dpu-remove-struct-dpu_hw_pipe_qos_cfg.patch (drm-backport-placeholder)
- commit ac6d5cf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1490-drm-msm-dpu-drop-DPU_PLANE_QOS_PANIC_CTRL.patch (drm-backport-placeholder)
- commit 5902b75
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1489-drm-msm-dpu-simplify-qos_ctrl-handling.patch (drm-backport-placeholder)
- commit 020864b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1488-drm-msm-dpu-drop-DPU_PLANE_QOS_VBLANK_CTRL.patch (drm-backport-placeholder)
- commit 24e361f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1487-drm-msm-dpu-rearrange-QoS-setting-code.patch (drm-backport-placeholder)
- commit 4d51ef7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1486-drm-msm-dpu-fix-the-condition-for-not-applying-QoS-t.patch (drm-backport-placeholder)
- commit 6c2101f
* Wed Sep  4 2024 oneukum@suse.com
- media: videobuf2: Don't assert held reservation lock for
  dma-buf mmapping (jsc#PED-8643).
- commit d104fcf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1485-drm-msm-dpu-simplify-CDP-programming.patch (drm-backport-placeholder)
- commit de5f592
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1484-drm-msm-dpu-fix-SSPP-register-definitions.patch (drm-backport-placeholder)
- commit adf75c2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1483-drm-msm-dpu-move-PINGPONG_NONE-check-to-dpu_lm_init.patch (drm-backport-placeholder)
- commit 254ede5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1482-drm-msm-dpu-use-PINGPONG_NONE-for-LMs-with-no-PP-att.patch (drm-backport-placeholder)
- commit 26c0f91
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1481-drm-msm-dpu-remove-futile-checks-from-dpu_rm_init.patch (drm-backport-placeholder)
- commit f4b9aa7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1480-drm-msm-dpu-replace-IS_ERR_OR_NULL-with-IS_ERR-durin.patch (drm-backport-placeholder)
- commit b36c8b5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Set-DPU_DATA_HCTL_EN-for-in-INTF_SC.patch (drm-backport-placeholder)
- commit b07801c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1478-drm-msm-dpu-access-CSC-CSC10-registers-directly.patch (drm-backport-placeholder)
- commit 7c0ea15
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1477-drm-msm-dpu-access-QSEED-registers-directly.patch (drm-backport-placeholder)
- commit 8d8a837
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1476-drm-msm-dpu-drop-SSPP-s-SRC-subblock.patch (drm-backport-placeholder)
- commit 964ab3e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1475-drm-msm-dpu-Remove-intr_rdptr-from-DPU-5.0.0-pingpon.patch (drm-backport-placeholder)
- commit 09e81e8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1474-drm-msm-dpu-Implement-tearcheck-support-on-INTF-bloc.patch (drm-backport-placeholder)
- commit 772761e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1473-drm-msm-dpu-Merge-setup_-and-enable_tearcheck-pingpo.patch (drm-backport-placeholder)
- commit 2d1c657
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1472-drm-msm-dpu-Add-TEAR-READ-pointer-interrupt-to-INTF-.patch (drm-backport-placeholder)
- commit 099dc0c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1471-drm-msm-dpu-Describe-TEAR-interrupt-registers-for-DS.patch (drm-backport-placeholder)
- commit 6d588b7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1470-drm-msm-dpu-Factor-out-shared-interrupt-register-in-.patch (drm-backport-placeholder)
- commit b80c489
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1469-drm-msm-dpu-Move-dpu_hw_-tear_check-pp_vsync_info-to.patch (drm-backport-placeholder)
- commit be2fdf1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1468-drm-msm-dpu-Disable-MDP-vsync-source-selection-on-DP.patch (drm-backport-placeholder)
- commit 6479154
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Disable-pingpong-TE-on-DPU-5.0.0-an.patch (drm-backport-placeholder)
- commit b70d2e0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Move-autorefresh-disable-from-CMD-e.patch (drm-backport-placeholder)
- commit 1453b8f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Drop-unused-poll_timeout_wr_ptr-PIN.patch (drm-backport-placeholder)
- commit efedbc7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1464-drm-msm-dpu-Take-INTF-index-as-parameter-in-interrup.patch (drm-backport-placeholder)
- commit 1b2081d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1463-drm-msm-dpu-Sort-INTF-registers-numerically.patch (drm-backport-placeholder)
- commit 4d76263
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1462-drm-msm-dpu-Remove-extraneous-register-define-indent.patch (drm-backport-placeholder)
- commit f5706d9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Use-V4.0-PCC-DSPP-sub-block-in-SC7-.patch (drm-backport-placeholder)
- commit a097d8c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1460-drm-msm-dpu-add-writeback-support-for-sc7280.patch (drm-backport-placeholder)
- commit 4a3f784
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1459-drm-msm-dpu-drop-unused-SSPP-sub-block-information.patch (drm-backport-placeholder)
- commit 9fa9fb9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1458-drm-msm-dpu-drop-DSPP_MSM8998_MASK-from-hw-catalog.patch (drm-backport-placeholder)
- commit 88aabda
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1457-drm-msm-dpu-remove-GC-and-IGC-related-code-from-dpu-.patch (drm-backport-placeholder)
- commit 6da496a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1456-drm-msm-dpu-remove-DPU_DSPP_IGC-handling-in-dspp-flu.patch (drm-backport-placeholder)
- commit 3225bb8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1455-drm-msm-dpu-remove-DPU_DSPP_GC-handling-in-dspp-flus.patch (drm-backport-placeholder)
- commit e44469b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1454-drm-msm-dpu-Pass-catalog-pointers-in-RM-to-replace-f.patch (drm-backport-placeholder)
- commit 0c9f2eb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1453-drm-msm-dpu-Drop-unused-members-from-HW-structs.patch (drm-backport-placeholder)
- commit f679258
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1452-drm-msm-dpu-stop-mapping-the-regdma-region.patch (drm-backport-placeholder)
- commit 6b59ad3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-drop-the-regdma-configuration.patch (drm-backport-placeholder)
- commit 74906ea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1450-drm-msm-dpu-set-max-cursor-width-to-512x512.patch (drm-backport-placeholder)
- commit 19e77bc
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: remove asoc_xxx() compatible macro (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-makes-CPU-Codec-channel-connection-map-more-gen.patch.
- commit f49caee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-fix-cursor-block-register-bit-offse.patch (drm-backport-placeholder)
- commit d1e881a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1448-drm-msm-dpu-use-hsync-vsync-polarity-set-by-the-enco.patch (drm-backport-placeholder)
- commit d9cf6a6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1447-drm-msm-dpu-add-HDMI-output-support.patch (drm-backport-placeholder)
- commit 96383ac
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1446-drm-msm-dpu-simplify-intf-allocation-code.patch (drm-backport-placeholder)
- commit b5f1dd9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1445-drm-msm-dpu-use-CTL_SC7280_MASK-for-sm8450-s-ctl_0.patch (drm-backport-placeholder)
- commit 11b33a0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1444-drm-msm-dpu-enable-DSPP-and-DSC-on-sc8180x.patch (drm-backport-placeholder)
- commit 48be455
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-enable-DSPP_2-3-for-LM_2-3-on-sm845.patch (drm-backport-placeholder)
- commit aac5410
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1442-drm-msm-dpu-enable-DPU_CTL_SPLIT_DISPLAY-for-sc8280x.patch (drm-backport-placeholder)
- commit 07b8d34
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1441-drm-msm-mdss-Add-SM6375-support.patch (drm-backport-placeholder)
- commit 20d1a9b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1440-drm-msm-mdss-Add-SM6350-support.patch (drm-backport-placeholder)
- commit 238178f
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: sof: use snd_soc_dummy_dlc (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: hdaudio.c: use snd_soc_dummy_dlc (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: odroid: don't need DUMMY Platform (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: fsl-asoc-card: don't need DUMMY Platform
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: simple-card-utils: Drop GPIO include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: sc7180: Drop GPIO include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: hisilicon: Drop GPIO include (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc.h: replace custom COUNT_ARGS() & CONCATENATE()
  implementations (jsc#PED-9993 jsc#PED-10202).
- commit 0dcf8ab
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1439-drm-msm-Remove-unnecessary-void-conversions.patch (drm-backport-placeholder)
- commit 69c7549
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-dp_mst-Clear-MSG_RDY-flag-before-sending-ne.patch (drm-backport-placeholder)
- commit 440e11b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1437-drm-amdgpu-Increase-hmm-range-get-pages-timeout.patch (drm-backport-placeholder)
- commit 7da47b6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1436-drm-amdgpu-Enable-translate-further-for-GC-v9.4.3.patch (drm-backport-placeholder)
- commit 46a3146
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1435-drm-amdgpu-Remove-unused-NBIO-interface.patch (drm-backport-placeholder)
- commit b0d4863
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1434-drm-amdkfd-bump-kfd-ioctl-minor-version-for-event-ag.patch (drm-backport-placeholder)
- commit 3d284a8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1433-drm-amdkfd-update-user-space-last_event_age.patch (drm-backport-placeholder)
- commit c58ded2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1432-drm-amdkfd-set-activated-flag-true-when-event-age-un.patch (drm-backport-placeholder)
- commit d8b750c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1431-drm-amdkfd-add-event_age-tracking-when-receiving-int.patch (drm-backport-placeholder)
- commit 0412efc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1430-drm-amdkfd-add-event-age-tracking.patch (drm-backport-placeholder)
- commit c5614c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1429-drm-scheduler-avoid-infinite-loop-if-entity-s-depend.patch (drm-backport-placeholder)
- commit fdc748a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1428-drm-amdgpu-add-entity-error-check-in-amdgpu_ctx_get_.patch (drm-backport-placeholder)
- commit a8d2b20
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1427-drm-amdgpu-add-VM-generation-token.patch (drm-backport-placeholder)
- commit 4d06d51
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1426-drm-amdgpu-reset-VM-when-an-error-is-detected.patch (drm-backport-placeholder)
- commit 3b29964
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1425-drm-amdgpu-abort-submissions-during-prepare-on-error.patch (drm-backport-placeholder)
- commit 75c27a9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1424-drm-amdgpu-mark-soft-recovered-fences-with-ENODATA.patch (drm-backport-placeholder)
- commit 35892ca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1423-drm-amdgpu-mark-force-completed-fences-with-ECANCELE.patch (drm-backport-placeholder)
- commit 70e14af
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1422-drm-amdgpu-add-amdgpu_error_-debugfs-file.patch (drm-backport-placeholder)
- commit f51843a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1421-drm-amdgpu-mark-GC-9.4.3-experimental-for-now.patch (drm-backport-placeholder)
- commit d8390bf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1420-drm-amdgpu-Use-PSP-FW-API-for-partition-switch.patch (drm-backport-placeholder)
- commit baf06dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1419-drm-amdgpu-Change-nbio-v7.9-xcp-status-definition.patch (drm-backport-placeholder)
- commit d5d8add
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-make-sure-that-BOs-have-a-backing-st.patch (drm-backport-placeholder)
- commit 4d8ce96
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-make-sure-BOs-are-locked-in-amdgpu_v.patch (drm-backport-placeholder)
- commit ccf5954
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1416-drm-amdgpu-Add-checking-mc_vram_size.patch (drm-backport-placeholder)
- commit 29878b3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1415-drm-amdgpu-Optimize-checking-ras-supported.patch (drm-backport-placeholder)
- commit 7ac704e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1414-drm-amdgpu-Add-channel_dis_num-to-ras-init-flags.patch (drm-backport-placeholder)
- commit 45b85c6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1413-drm-amdgpu-Update-total-channel-number-for-umc-v8_10.patch (drm-backport-placeholder)
- commit 1779aba
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1412-drm-amd-pm-Align-eccinfo-table-structure-with-smu-v1.patch (drm-backport-placeholder)
- commit c7dc7c9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1411-drm-amd-display-Convert-to-kdoc-formats-in-dc-core-d.patch (drm-backport-placeholder)
- commit 6938f81
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1410-drm-amdkfd-decrement-queue-count-on-mes-queue-destro.patch (drm-backport-placeholder)
- commit b1e3fce
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1409-drm-amd-pm-enable-more-Pstates-profile-levels-for-SM.patch (drm-backport-placeholder)
- commit a02e597
* Wed Sep  4 2024 oneukum@suse.com
- media: Add NV15_4L4 pixel format (jsc#PED-8643).
- commit 2d3e640
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1408-drm-radeon-Fix-missing-prototypes-in-radeon_atpx_han.patch (drm-backport-placeholder)
- commit 7358ae6
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: sprd: Simplify memory allocation in
  sprd_platform_compr_dma_config() (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Add acp-psp mailbox interface for iram-dram
  fence register modification (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Rename amd_bt sof_dai_type (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Add i2s bt dai configuration support for AMD
  platforms (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Refactor sof_i2s_tokens reading to update acpbt dai
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Refactor spinlock_irq(&sdev->ipc_lock) sequence
  in irq_handler (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Remove redundant ret variable (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: Fix trivial code style issues (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-pcm.c: Complete the active count for components
  without DAIs (jsc#PED-9993 jsc#PED-10202).
- commit 017004c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-usage-of-UMC-fill-record-in-RAS.patch (drm-backport-placeholder)
- commit 192c4cc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1405-drm-amdgpu-Report-ras_num_recs-in-debugfs.patch (drm-backport-placeholder)
- commit 5fc64c7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1404-drm-amdkfd-Remove-DUMMY_VRAM_SIZE.patch (drm-backport-placeholder)
- commit a2d95f1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1403-drm-amdgpu-Release-SDMAv4.4.2-ecc-irq-properly.patch (drm-backport-placeholder)
- commit b74fd0f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1402-drm-amdgpu-add-wait_for-helper-for-spirom-update.patch (drm-backport-placeholder)
- commit 5329c5e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1401-drm-amd-display-Clean-up-dcn10_optc.c-kdoc.patch (drm-backport-placeholder)
- commit 4197e3c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1400-drm-amd-display-Correct-kdoc-formats-in-dcn32_resour.patch (drm-backport-placeholder)
- commit 028bc2a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1399-drm-amd-display-Provide-function-name-for-optc32_ena.patch (drm-backport-placeholder)
- commit f8fe331
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1398-drm-amd-display-Correct-and-remove-excess-function-p.patch (drm-backport-placeholder)
- commit 6d70389
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1397-drm-amd-display-Correct-kdoc-formats-in-dcn10_opp.c.patch (drm-backport-placeholder)
- commit b199251
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: amd: acp: add pm ops support for renoir platform
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: check fw_context_save for library reload
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: IPC4: query fw_context_save feature from fw
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_mqs: remove duplicated including (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: amd: remove duplicated including (jsc#PED-9993
  jsc#PED-10202).
- ASoC: audio-graph-card2: Introduce playback-only/capture-only
  DAI link flags (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Add missing statics for hp_ilimit functions
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Allow HP amp to cool off after current limit
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codec: wsa884x: make use of new mute_unmute_on_trigger
  flag (jsc#PED-9993 jsc#PED-10202).
- commit 63124e1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1396-drm-amdgpu-Add-missing-function-parameter-optc-enabl.patch (drm-backport-placeholder)
- commit 9550502
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1395-drm-amdgpu-Print-client-id-for-the-unregistered-inte.patch (drm-backport-placeholder)
- commit 75686ce
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1394-drm-amdkfd-To-enable-traps-for-GC_11_0_4-and-up.patch (drm-backport-placeholder)
- commit 3531d5b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1393-drm-amd-display-don-t-free-stolen-console-memory-dur.patch (drm-backport-placeholder)
- commit ea033f5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1392-Revert-drm-amd-display-fix-dpms_off-issue-when-disab.patch (drm-backport-placeholder)
- commit 468687c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1391-drm-amdkfd-fix-null-queue-check-on-debug-setting-exc.patch (drm-backport-placeholder)
- commit a764dac
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1390-drm-amd-pm-enable-vclk-and-dclk-Pstates-for-SMU-v13..patch (drm-backport-placeholder)
- commit 185a004
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-memcpy-in-sienna_cichlid_append_.patch (drm-backport-placeholder)
- commit e70b13c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1388-drm-amd-pm-fix-vclk-setting-failed-for-SMU-v13.0.5.patch (drm-backport-placeholder)
- commit d862aec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1387-drm-amd-display-3.2.239.patch (drm-backport-placeholder)
- commit 03aa12e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1386-drm-amd-display-fix-pixel-rate-update-sequence.patch (drm-backport-placeholder)
- commit 18b1793
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1385-Revert-drm-amd-display-reallocate-DET-for-dual-displ.patch (drm-backport-placeholder)
- commit 70c3d5f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1384-drm-amd-display-Include-CSC-updates-in-new-fast-upda.patch (drm-backport-placeholder)
- commit 637fd3a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1383-drm-amd-display-Limit-Minimum-FreeSync-Refresh-Rate.patch (drm-backport-placeholder)
- commit e5461f2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1382-drm-amd-display-Bug-fix-in-dcn315_populate_dml_pipes.patch (drm-backport-placeholder)
- commit 5a65d99
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1381-drm-amd-display-Block-SubVP-DRR-if-the-DRR-is-PSR-ca.patch (drm-backport-placeholder)
- commit 589cb10
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1380-drm-amd-display-Do-not-disable-phantom-pipes-in-driv.patch (drm-backport-placeholder)
- commit f0c7053
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1379-drm-amd-display-Re-enable-SubVP-high-refresh.patch (drm-backport-placeholder)
- commit f9db4b2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1378-drm-amd-display-Re-enable-DPP-HUBP-Power-Gating.patch (drm-backport-placeholder)
- commit e826946
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1377-drm-amd-display-SubVP-high-refresh-only-if-all-displ.patch (drm-backport-placeholder)
- commit 5c1fcff
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1376-drm-amd-display-Fix-disbling-PSR-slow-response-issue.patch (drm-backport-placeholder)
- commit 3cffaeb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1375-drm-amd-display-Promote-DAL-to-3.2.238.patch (drm-backport-placeholder)
- commit 60e7d77
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1374-drm-amd-display-Add-Error-Code-for-Dml-Validation-Fa.patch (drm-backport-placeholder)
- commit fa66191
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1373-drm-amd-display-Add-DP2-Metrics.patch (drm-backport-placeholder)
- commit 0a93dbf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1372-drm-amd-display-add-debugfs-for-allow_edp_hotplug_de.patch (drm-backport-placeholder)
- commit 04ba085
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1371-drm-amdgpu-expose-num_hops-and-num_links-xgmi-info-t.patch (drm-backport-placeholder)
- commit 997eab8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1370-drm-amd-amdgpu-enable-W-1-for-amdgpu.patch (drm-backport-placeholder)
- commit b7fa784
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1369-drm-amdgpu-Fix-kdoc-warning.patch (drm-backport-placeholder)
- commit e98b04e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Enable-dcn314-DPP-RCO.patch (drm-backport-placeholder)
- commit 8711b36
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1367-drm-amdgpu-Rename-DRM-schedulers-in-amdgpu-TTM.patch (drm-backport-placeholder)
- commit b78866a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1366-drm-amd-display-amdgpu_dm-amdgpu_dm_helpers-Move-SYN.patch (drm-backport-placeholder)
- commit 10e1cae
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Skip-DPP-DTO-update-if-root-cl.patch (drm-backport-placeholder)
- commit 5c13ea0
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: qcom: audioreach: Add 4 channel support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: audioreach: drop duplicate channel defines
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: audioreach: Commonize setting channel mappings
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm1250-ev1: Fix uninitialized ret (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm8996: Convert to GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm5100: Convert to GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm2200: Convert to GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm1250-ev1: Convert to GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm0010: Convert to GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: audio-graph-card2: fix off by one in
  graph_parse_node_multi_nm() (jsc#PED-9993 jsc#PED-10202).
- commit bc95cd6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1364-fbdev-Use-comment-in-initializer-macro.patch (drm-backport-placeholder)
- commit 856fda6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1363-drm-i915-selftests-add-local-workqueue-for-SW-fence-.patch (drm-backport-placeholder)
- commit 62e0e39
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1362-drm-i915-add-a-dedicated-workqueue-inside-drm_i915_p.patch (drm-backport-placeholder)
- commit 0b9381a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1361-drm-i915-use-pointer-to-i915-instead-of-rpm-in-waker.patch (drm-backport-placeholder)
- commit 11fe92c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1360-drm-i915-re-enable-Wunused-but-set-variable.patch (drm-backport-placeholder)
- commit eabee4d
* Wed Sep  4 2024 oneukum@suse.com
- media: v4l2-common: Add support for fractional bpp
  (jsc#PED-8643).
- commit 447cf61
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1358-drm-i915-display-Include-of-display-limits-doesn-t-n.patch (drm-backport-placeholder)
- commit 407be53
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1357-drm-i915-mtl-Add-support-for-PM-DEMAND.patch (drm-backport-placeholder)
- commit 535b199
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1356-drm-i915-mtl-find-the-best-QGV-point-for-the-SAGV-co.patch (drm-backport-placeholder)
- commit 9b73826
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1355-drm-i915-modify-max_bw-to-return-index-to-intel_bw_i.patch (drm-backport-placeholder)
- commit 69585f8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1354-drm-i915-extract-intel_bw_check_qgv_points.patch (drm-backport-placeholder)
- commit 21b9072
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1353-drm-i915-store-the-peak-bw-per-QGV-point.patch (drm-backport-placeholder)
- commit ac7b479
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1352-drm-i915-update-the-QGV-point-frequency-calculations.patch (drm-backport-placeholder)
- commit befb978
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1351-drm-i915-fix-the-derating-percentage-for-MTL.patch (drm-backport-placeholder)
- commit a79b4ed
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1350-drm-i915-dp-Fix-log-level-for-CDS-interlane-align-do.patch (drm-backport-placeholder)
- commit 5e6ba24
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1349-drm-i915-annotate-maybe-unused-but-set-intel_crtc_st.patch (drm-backport-placeholder)
- commit 2d71817
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1348-drm-i915-annotate-maybe-unused-but-set-intel_plane_s.patch (drm-backport-placeholder)
- commit 09d9dd6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1347-drm-i915-selftest-annotate-maybe-unused-but-set-vari.patch (drm-backport-placeholder)
- commit 9af8c6b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1346-drm-i915-gem-annotate-maybe-unused-but-set-variable-.patch (drm-backport-placeholder)
- commit 555b4c8
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: amd: acp: modify config flag read logic (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: acp: Set bclk as source to set pll for rt5682s codec
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Enable dpcm_capture for MAX98388 codec
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Add i2s bt support for nau8821-max card
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Add new cpu dai and dailink creation for I2S
  BT instance (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: Remove extra dmi parameter (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: vangogh: Add condition check for acp config flag
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: Add new dmi entries for acp5x platform (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Wire up buffer flags (jsc#PED-9993 jsc#PED-10202).
- commit 2b01d20
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1345-drm-i915-gem-drop-unused-but-set-variable-unpinned.patch (drm-backport-placeholder)
- commit 84bd987
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1344-drm-i915-gt-uc-drop-unused-but-set-variable-sseu.patch (drm-backport-placeholder)
- commit 226a252
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1343-drm-i915-irq-drop-unused-but-set-variable-tmp.patch (drm-backport-placeholder)
- commit b2d74a9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1342-drm-i915-fb-drop-unused-but-set-variable-cpp.patch (drm-backport-placeholder)
- commit 63e3a42
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1341-drm-i915-dpll-drop-unused-but-set-variables-bestn-an.patch (drm-backport-placeholder)
- commit 0f8e3fc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1340-drm-i915-dsi-drop-unused-but-set-variable-vbp.patch (drm-backport-placeholder)
- commit c56ff14
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1339-drm-i915-dsi-drop-unused-but-set-variable-data.patch (drm-backport-placeholder)
- commit 3a9cd61
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1338-drm-i915-ddi-drop-unused-but-set-variable-intel_dp.patch (drm-backport-placeholder)
- commit 3a27013
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1337-drm-i915-plane-warn-on-non-zero-plane-offset.patch (drm-backport-placeholder)
- commit cd92a4d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1336-drm-i915-debugfs-stop-using-edid_blob_ptr.patch (drm-backport-placeholder)
- commit cf2f631
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1335-drm-i915-Fix-error-handling-if-driver-creation-fails.patch (drm-backport-placeholder)
- commit 91b3598
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1334-drm-i915-display-Extract-display-init-from-intel_dev.patch (drm-backport-placeholder)
- commit 432c49f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1333-drm-i915-No-10bit-gamma-on-desktop-gen3-parts.patch (drm-backport-placeholder)
- commit 6fd9a74
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1332-drm-i915-display-Print-useful-information-on-error.patch (drm-backport-placeholder)
- commit c82d0fa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1331-drm-amd-display-Filter-out-AC-mode-frequencies-on-DC.patch (drm-backport-placeholder)
- commit 3daee07
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1330-drm-amd-display-DSC-Programming-Deltas.patch (drm-backport-placeholder)
- commit 028252d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1329-Revert-drm-amd-display-cache-trace-buffer-size.patch (drm-backport-placeholder)
- commit b6bcb5c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1328-drm-amd-display-add-NULL-pointer-check.patch (drm-backport-placeholder)
- commit b646ed6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1327-drm-amd-pm-enable-more-Pstates-profile-levels-for-ye.patch (drm-backport-placeholder)
- commit 74960cd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1326-drm-amdgpu-add-option-params-to-enforce-process-isol.patch (drm-backport-placeholder)
- commit 712c23d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1325-drm-amdgpu-Wrap-Wunused-but-set-variable-in-cc-optio.patch (drm-backport-placeholder)
- commit 3d4a458
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1324-drm-amdgpu-add-the-accelerator-PCIe-class.patch (drm-backport-placeholder)
- commit a596397
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1323-Revert-Revert-drm-amd-display-Enable-Freesync-Video-.patch (drm-backport-placeholder)
- commit c87652a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1322-drm-amdkfd-fix-and-enable-debugging-for-gfx11.patch (drm-backport-placeholder)
- commit 5a4cbbf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1321-drm-amd-pm-enable-more-Pstates-profile-levels-for-SM.patch (drm-backport-placeholder)
- commit e0547d7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1320-drm-amd-pm-enable-vclk-and-dclk-Pstates-for-SMU-v13..patch (drm-backport-placeholder)
- commit d2ada94
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1319-drm-amd-pm-fix-vclk-setting-failed-for-SMU-v13.0.4.patch (drm-backport-placeholder)
- commit 0c975fa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1318-drm-amdgpu-skip-to-resume-rlcg-for-gc-9.4.3-in-vf-si.patch (drm-backport-placeholder)
- commit fbe8a88
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1317-drm-amdgpu-disable-virtual-display-support-on-APP-de.patch (drm-backport-placeholder)
- commit 03b20b7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-unmap-and-remove-csa_va-properly.patch (drm-backport-placeholder)
- commit 47d4307
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1315-drm-amd-display-Refactor-avi_info_frame-colorimetry-.patch (drm-backport-placeholder)
- commit 99feab2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1314-drm-amd-display-Add-debugfs-for-testing-output-color.patch (drm-backport-placeholder)
- commit 36eea5c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1313-drm-amd-display-Always-set-crtcinfo-from-create_stre.patch (drm-backport-placeholder)
- commit 952f907
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1312-drm-amd-display-Send-correct-DP-colorspace-infopacke.patch (drm-backport-placeholder)
- commit a49ebef
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1311-drm-amd-display-Signal-mode_changed-if-colorspace-ch.patch (drm-backport-placeholder)
- commit 226ceb6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1310-drm-amd-display-Register-Colorspace-property-for-DP-.patch (drm-backport-placeholder)
- commit 3d72fb3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1309-drm-amd-display-Always-pass-connector_state-to-strea.patch (drm-backport-placeholder)
- commit e654f32
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1308-drm-connector-Allow-drivers-to-pass-list-of-supporte.patch (drm-backport-placeholder)
- commit e074a13
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1307-drm-connector-Print-connector-colorspace-in-state-de.patch (drm-backport-placeholder)
- commit 12c6132
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1306-drm-connector-Use-common-colorspace_names-array.patch (drm-backport-placeholder)
- commit f635b8b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1305-drm-connector-Pull-out-common-create_colorspace_prop.patch (drm-backport-placeholder)
- commit 125d5b8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1304-drm-connector-Add-enum-documentation-to-drm_colorspa.patch (drm-backport-placeholder)
- commit 1378217
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1303-drm-connector-Convert-DRM_MODE_COLORIMETRY-to-enum.patch (drm-backport-placeholder)
- commit ef484f5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1302-drm-amdkfd-Fix-reserved-SDMA-queues-handling.patch (drm-backport-placeholder)
- commit b04695a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1301-drm-amd-Check-that-a-system-is-a-NUMA-system-before-.patch (drm-backport-placeholder)
- commit fc3bf76
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1300-drm-amdkfd-fix-vmfault-signalling-with-additional-da.patch (drm-backport-placeholder)
- commit 581cc1c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1299-drm-amdgpu-Set-EEPROM-ras-info.patch (drm-backport-placeholder)
- commit 638af93
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1298-drm-amdgpu-Calculate-EEPROM-table-ras-info-bytes-sum.patch (drm-backport-placeholder)
- commit f002e54
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1297-drm-amdgpu-Add-support-EEPROM-table-v2.1.patch (drm-backport-placeholder)
- commit 1c383b4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1296-drm-amdgpu-Support-setting-EEPROM-table-version.patch (drm-backport-placeholder)
- commit f8c3bb0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1295-drm-amdgpu-Add-RAS-table-v2.1-macro-definition.patch (drm-backport-placeholder)
- commit 63f26aa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1294-drm-amdgpu-Rename-ras-table-version.patch (drm-backport-placeholder)
- commit b68f81c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1293-drm-amdgpu-mmsch-Correct-the-definition-for-mmsch-in.patch (drm-backport-placeholder)
- commit 6ae6134
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1292-drm-amdkfd-potential-error-pointer-dereference-in-io.patch (drm-backport-placeholder)
- commit ea98d9c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1291-drm-amd-display-Only-use-ODM2-1-policy-for-high-pixe.patch (drm-backport-placeholder)
- commit 84c533e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1290-drm-amd-pm-Fix-memory-some-memory-corruption.patch (drm-backport-placeholder)
- commit bdcb8ff
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1289-drm-amdgpu-display-Kconfig-replace-leading-spaces-wi.patch (drm-backport-placeholder)
- commit d4dafb9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1288-drm-amd-display-mark-dml314-s-UseMinimumDCFCLK-as-no.patch (drm-backport-placeholder)
- commit 00599cd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1287-drm-amd-display-mark-dml31-s-UseMinimumDCFCLK-as-noi.patch (drm-backport-placeholder)
- commit e28da82
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1286-drm-amd-display-Fix-unused-variable-should_lock_all_.patch (drm-backport-placeholder)
- commit 57e3db7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1285-drm-amd-display-Add-control-flag-to-dc_stream_state-.patch (drm-backport-placeholder)
- commit 4d9d85f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1284-drm-amd-display-Wrong-index-type-for-pipe-iterator.patch (drm-backport-placeholder)
- commit 9311c19
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1283-drm-amd-display-Refactor-fast-update-to-use-new-HWSS.patch (drm-backport-placeholder)
- commit 9d94574
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-dcn315-single-stream-crb-al.patch (drm-backport-placeholder)
- commit bb04659
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1281-drm-amdgpu-convert-vcn-jpeg-logical-mask-to-physical.patch (drm-backport-placeholder)
- commit 2fe936d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1280-drm-amdgpu-support-check-vcn-jpeg-block-mask.patch (drm-backport-placeholder)
- commit 75b2989
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1279-drm-amdgpu-pass-xcc-mask-to-ras-ta.patch (drm-backport-placeholder)
- commit cc48cf9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1278-drm-amd-pm-update-smu-driver-if-header-for-smu-13.0..patch (drm-backport-placeholder)
- commit 0e395a5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1277-drm-amdgpu-pm-notify-driver-unloading-to-PMFW-for-SM.patch (drm-backport-placeholder)
- commit 6073db1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1276-drm-amdgpu-Mark-kgd_gfx_aldebaran_clear_address_watc.patch (drm-backport-placeholder)
- commit 8efb01d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1275-drm-amd-display-Program-OTG-vtotal-min-max-selectors.patch (drm-backport-placeholder)
- commit 7797e1f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1274-Revert-drm-amd-display-Only-use-ODM2-1-policy-for-hi.patch (drm-backport-placeholder)
- commit a4dda2c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1273-drm-amd-display-Add-gnu_printf-format-attribute-for-.patch (drm-backport-placeholder)
- commit 8bfb7a5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1272-drm-amd-display-Address-kdoc-warnings-in-dcn30_fpu.c.patch (drm-backport-placeholder)
- commit 9691a75
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1271-drm-amd-display-fix-compilation-error-due-to-shiftin.patch (drm-backport-placeholder)
- commit 773cb12
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1270-drm-amdgpu-discovery-Replace-fake-flex-arrays-with-f.patch (drm-backport-placeholder)
- commit c4b6656
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/amdgpu-validate-offset_in_bo-of-drm_amdgpu_gem_.patch (drm-backport-placeholder)
- commit 3f8f408
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1268-drm-amdgpu-fix-debug-wait-on-idle-for-gfx9.4.1.patch (drm-backport-placeholder)
- commit bdb76ee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-seamless-odm-transitions.patch (drm-backport-placeholder)
- commit 9044471
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1266-drm-amd-display-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 4f20f41
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1265-drm-amd-display-Fix-dc-dcn20-dcn20_optc.c-kdoc.patch (drm-backport-placeholder)
- commit cd56a48
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: check
  ctx->headset_codec_dev instead of playback (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_nau8825: board id cleanup for rpl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: board id cleanup for adl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_cs_amp: Connect outputs to a speaker widget
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: lnl: add core get and set support for dsp core
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs4271: Fix spelling mistake "retrieveing" -> "retrieving"
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt722-sdca: Set lane_control_support for multilane
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-tgl-match: add cs42l43 and cs35l56
  support (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bytcht_es8316: Determine quirks/routing with
  codec-dev ACPI DSM (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bytcht_es8316: Add is_bytcr helper variable
  (jsc#PED-9993 jsc#PED-10202).
- commit e3b693c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1264-drm-amd-pm-fulfill-the-OD-support-for-SMU13.0.7.patch (drm-backport-placeholder)
- commit 34ae1fa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1263-drm-amd-pm-Fill-metrics-data-for-SMUv13.0.6.patch (drm-backport-placeholder)
- commit e0aa8d4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1262-drm-amd-pm-fulfill-the-OD-support-for-SMU13.0.0.patch (drm-backport-placeholder)
- commit dd6a481
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1261-drm-amd-pm-fulfill-SMU13-OD-settings-init-and-restor.patch (drm-backport-placeholder)
- commit 1e3b44d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1260-drm-amdkfd-bump-kfd-ioctl-minor-version-for-debug-ap.patch (drm-backport-placeholder)
- commit 7bf3c16
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1259-drm-amdkfd-add-debug-device-snapshot-operation.patch (drm-backport-placeholder)
- commit 9ff4b73
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1258-drm-amdkfd-add-debug-queue-snapshot-operation.patch (drm-backport-placeholder)
- commit c56c05c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1257-drm-amdkfd-add-debug-query-exception-info-operation.patch (drm-backport-placeholder)
- commit 13cb005
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1256-drm-amdkfd-add-debug-query-event-operation.patch (drm-backport-placeholder)
- commit be86289
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1255-drm-amdkfd-add-debug-set-flags-operation.patch (drm-backport-placeholder)
- commit 4e566de
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1254-drm-amdkfd-add-debug-set-and-clear-address-watch-poi.patch (drm-backport-placeholder)
- commit 8471ea0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1253-drm-amdkfd-add-debug-suspend-and-resume-process-queu.patch (drm-backport-placeholder)
- commit 33dc8a8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1252-drm-amdkfd-add-debug-wave-launch-mode-operation.patch (drm-backport-placeholder)
- commit 0987ec3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1251-drm-amdkfd-add-debug-wave-launch-override-operation.patch (drm-backport-placeholder)
- commit 9ff30bf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1250-drm-amdkfd-add-debug-set-exceptions-enabled-operatio.patch (drm-backport-placeholder)
- commit d3abfd6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1249-drm-amdkfd-update-process-interrupt-handling-for-deb.patch (drm-backport-placeholder)
- commit c89ef5d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1248-drm-amd-pm-update-SMU13-header-files-for-coming-OD-s.patch (drm-backport-placeholder)
- commit 03cf76e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1247-drm-amdkfd-add-debug-trap-enabled-flag-to-tma.patch (drm-backport-placeholder)
- commit e7960f1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1246-drm-amdkfd-add-runtime-enable-operation.patch (drm-backport-placeholder)
- commit 97fa35a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1245-drm-amdkfd-add-send-exception-operation.patch (drm-backport-placeholder)
- commit 882fa8e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1244-drm-amdkfd-add-raise-exception-event-function.patch (drm-backport-placeholder)
- commit 76e4651
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1243-drm-amdkfd-apply-trap-workaround-for-gfx11.patch (drm-backport-placeholder)
- commit 459f277
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1242-drm-amdkfd-add-per-process-hw-trap-enable-and-disabl.patch (drm-backport-placeholder)
- commit 3d716e8
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: bytcht_es8316: Dump basic _DSM information
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: es83xx: add ACPI DSM helper module (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Move sof_of_machine_select() to core.c from
  sof-of-dev.c (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs4349: Drop legacy include (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs43130: Drop legacy includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l42: Drop legacy include (jsc#PED-9993 jsc#PED-10202).
- ASoC: cirrus: edb93xx: Drop legacy include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs4271: Convert to GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l36: Drop legacy includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l35: Drop legacy includes (jsc#PED-9993
  jsc#PED-10202).
- commit 784fd31
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1241-drm-amdgpu-expose-debug-api-for-mes.patch (drm-backport-placeholder)
- commit 19523dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1240-drm-amdgpu-prepare-map-process-for-multi-process-deb.patch (drm-backport-placeholder)
- commit 1aa2dd6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1239-drm-amdkfd-prepare-map-process-for-single-process-de.patch (drm-backport-placeholder)
- commit a02162a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1238-drm-amdgpu-add-configurable-grace-period-for-unmap-q.patch (drm-backport-placeholder)
- commit d017c40
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1237-drm-amdgpu-add-gfx11-hw-debug-mode-enable-and-disabl.patch (drm-backport-placeholder)
- commit 3836bca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1236-drm-amdgpu-add-gfx9.4.2-hw-debug-mode-enable-and-dis.patch (drm-backport-placeholder)
- commit b3bceea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1235-drm-amdgpu-add-gfx10-hw-debug-mode-enable-and-disabl.patch (drm-backport-placeholder)
- commit b834208
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1234-drm-amdkfd-fix-kfd_suspend_all_processes.patch (drm-backport-placeholder)
- commit 2d91e42
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1233-drm-amdgpu-add-gfx9.4.1-hw-debug-mode-enable-and-dis.patch (drm-backport-placeholder)
- commit ef80eb5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1232-drm-amdgpu-add-gfx9-hw-debug-mode-enable-and-disable.patch (drm-backport-placeholder)
- commit f64f059
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1231-drm-amdkfd-clean-up-one-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 58126ce
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1230-drm-amd-display-Drop-unused-DCN_BASE-variable-in-dcn.patch (drm-backport-placeholder)
- commit c3645c6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1229-drm-amdgpu-setup-hw-debug-registers-on-driver-initia.patch (drm-backport-placeholder)
- commit c92e4c3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1228-drm-amdgpu-add-kgd-hw-debug-mode-setting-interface.patch (drm-backport-placeholder)
- commit 29d43b1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1227-drm-amdkfd-prepare-per-process-debug-enable-and-disa.patch (drm-backport-placeholder)
- commit e4126ec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1226-drm-amdkfd-display-debug-capabilities.patch (drm-backport-placeholder)
- commit 5f8dabb
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: cs35l34: Fix GPIO name and drop legacy include
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l32: Drop legacy include (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: sc8280xp: Add support for SM8450 and SM8550
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: sc8280xp: set card driver name from match data
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: core: Implement IPC version fallback if firmware
  files are missing (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: Do not use resource managed allocation for
  ipc4_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: core: Add helper for initialization of paths, ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-pci-dev: Rely on core to create the file paths
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-of-dev: Rely on core to create the file paths
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-acpi-dev: Rely on core to create the file paths
  (jsc#PED-9993 jsc#PED-10202).
- commit e616ec9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1225-drm-amdkfd-add-debug-and-runtime-enable-interface.patch (drm-backport-placeholder)
- commit c46f9fd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1224-amd-amdkfd-drop-unused-KFD_IOCTL_SVM_FLAG_UNCACHED-f.patch (drm-backport-placeholder)
- commit ebd59c3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1223-drm-amd-pm-add-unique-serial-number-support-for-smu_.patch (drm-backport-placeholder)
- commit b90df6e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1222-drm-amd-pm-Fix-SMUv13.0.6-throttle-status-report.patch (drm-backport-placeholder)
- commit b1066b3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1221-drm-amd-pm-Update-SMUv13.0.6-PMFW-headers.patch (drm-backport-placeholder)
- commit c11ccac
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1220-drm-amdgpu-Add-function-parameter-event-to-kdoc-in-s.patch (drm-backport-placeholder)
- commit 2e20993
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1219-drm-amdgpu-Fix-up-kdoc-in-amdgpu_device.c.patch (drm-backport-placeholder)
- commit 5457ea5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1218-drm-amdgpu-Fix-up-kdoc-ring-parameter-in-sdma_v6_0_r.patch (drm-backport-placeholder)
- commit 8db7a12
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1217-drm-amd-display-Fix-up-kdoc-formatting-in-display_mo.patch (drm-backport-placeholder)
- commit 09f0ce1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1216-drm-amd-amdgpu-introduce-DRM_AMDGPU_WERROR.patch (drm-backport-placeholder)
- commit b5269b6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1215-drm-amdkfd-remove-unused-sq_int_priv-variable.patch (drm-backport-placeholder)
- commit e0636c7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1214-drm-amd-display-Correct-kdoc-formatting-for-DCN32_CR.patch (drm-backport-placeholder)
- commit 46d528e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1213-drm-amd-display-Fix-up-missing-dc-pipe_ctx-kdoc-para.patch (drm-backport-placeholder)
- commit 3f911d2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1212-drm-amd-display-Fix-up-kdoc-formatting-in-dcn32_reso.patch (drm-backport-placeholder)
- commit 06a8d34
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1211-drm-amdxcp-fix-Makefile-to-build-amdxcp-module.patch (drm-backport-placeholder)
- commit c45edcb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1210-drm-amdgpu-Fix-up-missing-parameters-kdoc-in-svm_mig.patch (drm-backport-placeholder)
- commit cd7f045
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1209-drm-amdgpu-set-finished-fence-error-if-job-timedout.patch (drm-backport-placeholder)
- commit d19fc40
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1208-drm-amdgpu-Fix-missing-parameter-desc-for-xcp_id-in-.patch (drm-backport-placeholder)
- commit 2fcfa12
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1207-drm-amdgpu-Fix-up-missing-parameter-in-kdoc-for-inst.patch (drm-backport-placeholder)
- commit c16032c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1206-drm-amdgpu-Fix-up-missing-kdoc-parameter-inst-in-get.patch (drm-backport-placeholder)
- commit be2ee89
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1205-drm-amdgpu-Fix-missing-parameter-desc-for-xcc_id-in-.patch (drm-backport-placeholder)
- commit a7f649f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1204-drm-amdkfd-flag-added-to-handle-errors-from-svm-vali.patch (drm-backport-placeholder)
- commit 6fa2ecc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1203-drm-amdgpu-Initialize-xcc-mask.patch (drm-backport-placeholder)
- commit f35450f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1202-drm-amd-display-Fix-up-kdoc-formats-in-dcn32_fpu.c.patch (drm-backport-placeholder)
- commit 173651b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1201-drm-amd-display-Add-missing-kdoc-entries-in-update_p.patch (drm-backport-placeholder)
- commit cb8ba4d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1200-drm-amdgpu-Fix-create_dmamap_sg_bo-kdoc-warnings.patch (drm-backport-placeholder)
- commit 32baaa9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1199-drm-amdkfd-Fix-MEC-pipe-interrupt-enablement.patch (drm-backport-placeholder)
- commit 7eb48c3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1198-drm-amdkfd-Add-new-gfx_target_versions-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit 1d7f236
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1197-drm-amdgpu-Fix-up-missing-kdoc-in-sdma_v6_0.c.patch (drm-backport-placeholder)
- commit 1d7f114
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1196-drm-amdgpu-Fix-up-kdoc-in-amdgpu_acpi.c.patch (drm-backport-placeholder)
- commit a8be13b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1195-drm-amdgpu-Fix-up-kdoc-in-sdma_v4_4_2.c.patch (drm-backport-placeholder)
- commit f535047
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1194-drm-amdkfd-fix-gfx_target_version-for-certain-11.0.3.patch (drm-backport-placeholder)
- commit fc37683
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-keep-irq-count-in-amdgpu_irq_disabl.patch (drm-backport-placeholder)
- commit e6a6b43
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1192-drm-amd-amdgpu-Fix-up-locking-etc-in-amdgpu_debugfs_.patch (drm-backport-placeholder)
- commit ac4e894
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1191-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 95e9597
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1190-drm-amdgpu-use-amdxcp-platform-device-as-spatial-par.patch (drm-backport-placeholder)
- commit ee3c739
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1189-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 31f983d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1188-drm-amdxcp-add-platform-device-driver-for-amdxcp.patch (drm-backport-placeholder)
- commit e254561
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1187-drm-amdgpu-Mark-mmhub_v1_8_mmea_err_status_reg-as-__.patch (drm-backport-placeholder)
- commit 2ea1f28
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1186-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit e655679
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1185-drm-amd-display-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit fd96dae
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1184-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit d27866a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1183-drm-amd-display-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 20bc21a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1182-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 2a04720
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1181-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit adf8271
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1180-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 3c7aea1
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Apply the unit control RB tree to MSR uncore
  units (bsc#1230119).
- commit 8a1e34d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1179-drm-amdgpu-add-the-accelerator-pcie-class.patch (drm-backport-placeholder)
- commit 87a8a3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1178-drm-amdgpu-save-restore-part-of-xcp-drm_device-field.patch (drm-backport-placeholder)
- commit 64ff2ed
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1177-drm-amdgpu-set-the-APU-flag-based-on-package-type.patch (drm-backport-placeholder)
- commit 1e54e2e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1176-drm-jpeg-add-init-value-for-num_jpeg_rings.patch (drm-backport-placeholder)
- commit 93f637f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1175-drm-amdgpu-complement-the-4-6-and-8-XCC-cases.patch (drm-backport-placeholder)
- commit 7da1e78
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1174-drm-amdgpu-golden-settings-for-ASIC-rev_id-0.patch (drm-backport-placeholder)
- commit a06f26f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1173-drm-amdgpu-bypass-bios-dependent-operations.patch (drm-backport-placeholder)
- commit 58a6813
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1172-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 9f7768b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1171-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 9a8301a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1170-drm-amdgpu-Fix-unused-variable-in-amdgpu_gfx.c.patch (drm-backport-placeholder)
- commit 305d015
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1169-drm-amdgpu-Fix-defined-but-not-used-gfx9_cs_data-in-.patch (drm-backport-placeholder)
- commit 894be85
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1168-drm-amdgpu-Fix-return-types-of-certain-NBIOv7.9-call.patch (drm-backport-placeholder)
- commit 34db345
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1167-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 41df5ca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1166-drm-amd-Drop-debugfs-access-to-the-DPCD.patch (drm-backport-placeholder)
- commit 4dfaeff
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1165-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 1522d00
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1164-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 82634a7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1163-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 39e7507
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1162-drm-amdgpu-Use-single-copy-per-SDMA-instance-type-v2.patch (drm-backport-placeholder)
- commit 9a87b25
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1161-drm-amdgpu-switch-to-unified-amdgpu_ring_test_helper.patch (drm-backport-placeholder)
- commit 4db3945
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1160-drm-amdgpu-gfx-set-sched.ready-status-after-ring-IB-.patch (drm-backport-placeholder)
- commit 272341e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1159-drm-amdgpu-sdma-set-sched.ready-status-after-ring-IB.patch (drm-backport-placeholder)
- commit 34b7cd8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1158-drm-amdgpu-Fix-warnings.patch (drm-backport-placeholder)
- commit 4fb0a67
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1157-drm-amdkfd-Set-event-interrupt-class-for-GFX-9.4.3.patch (drm-backport-placeholder)
- commit ba37dd8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1156-Revert-drm-amd-display-Do-not-set-drr-on-pipe-commit.patch (drm-backport-placeholder)
- commit 4e4a775
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1155-drm-amd-amdgpu-Fix-warnings-in-amdgpu_irq.c.patch (drm-backport-placeholder)
- commit d454477
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1154-Revert-drm-amd-display-Block-optimize-on-consecutive.patch (drm-backport-placeholder)
- commit 7a2e1bf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1153-drm-amdgpu-Add-a-low-priority-scheduler-for-VRAM-cle.patch (drm-backport-placeholder)
- commit a75da3c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1152-drm-amdgpu-vcn-Modify-mismatched-function-name.patch (drm-backport-placeholder)
- commit f523f50
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1151-drm-amdgpu-Modify-mismatched-function-name.patch (drm-backport-placeholder)
- commit eaefbf6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1150-drm-amdgpu-Remove-duplicate-include.patch (drm-backport-placeholder)
- commit ad07c24
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1149-drm-amd-display-remove-unused-variables-res_create_m.patch (drm-backport-placeholder)
- commit cffa9aa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1148-drm-amd-display-avoid-calling-missing-.resync_fifo_d.patch (drm-backport-placeholder)
- commit 2d8b9e6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1147-drm-amdkfd-Align-partition-memory-size-to-page-size.patch (drm-backport-placeholder)
- commit 0dc0cfb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1146-drm-amdgpu-remove-unused-variable-num_xcc.patch (drm-backport-placeholder)
- commit ddf486d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1145-drm-amdgpu-fix-acpi-build-warnings.patch (drm-backport-placeholder)
- commit 74df7f5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1144-drm-amdgpu-use-pad-format-string-for-dma_addr_t.patch (drm-backport-placeholder)
- commit f953935
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1143-drm-amdgpu-mark-aqua_vanjaram_reg_init.c-function-as.patch (drm-backport-placeholder)
- commit 4334631
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1142-drm-amdkfd-mark-local-functions-as-static.patch (drm-backport-placeholder)
- commit f3fe7ff
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1141-drm-amd-pm-mark-irq-functions-as-static.patch (drm-backport-placeholder)
- commit 9bc45f1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1140-drm-amdgpu-Fix-unsigned-comparison-with-zero-in-gmc_.patch (drm-backport-placeholder)
- commit 75199e1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1139-drm-amdgpu-Fix-a-couple-of-spelling-mistakes-in-info.patch (drm-backport-placeholder)
- commit 112de13
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1138-drm-amdgpu-Disable-interrupt-tracker-on-NBIOv7.9.patch (drm-backport-placeholder)
- commit 6e912bb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-fix-possible-division-by-zero-errors.patch (drm-backport-placeholder)
- commit cc6dbe1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1136-drm-radeon-stop-including-swiotlb.h.patch (drm-backport-placeholder)
- commit d89eeea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1135-drm-amdgpu-init-the-XCC_DOORBELL_FENCE-regs.patch (drm-backport-placeholder)
- commit 678ffc5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1134-drm-amdgpu-remove-unused-definition.patch (drm-backport-placeholder)
- commit 0b63abf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1133-drm-amdgpu-Fix-uninitialized-variable-in-gfxhub_v1_2.patch (drm-backport-placeholder)
- commit 97068fd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1132-drm-amdgpu-Fix-unused-amdgpu_acpi_get_numa_info-func.patch (drm-backport-placeholder)
- commit 8515b3f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1131-drm-amd-display-3.2.237.patch (drm-backport-placeholder)
- commit c7a34dd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1130-drm-amd-display-cache-trace-buffer-size.patch (drm-backport-placeholder)
- commit a5f1ec8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1129-drm-amd-display-Reorganize-DCN30-Makefile.patch (drm-backport-placeholder)
- commit a2578b7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1128-drm-amd-display-Trigger-DIO-FIFO-resync-on-commit-st.patch (drm-backport-placeholder)
- commit aa9f571
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Update-correct-DCN314-register-.patch (drm-backport-placeholder)
- commit e451a6b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1126-drm-amd-display-Clean-FPGA-code-in-dc.patch (drm-backport-placeholder)
- commit 55bf2c9
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Apply the unit control RB tree to MMIO uncore
  units (bsc#1230119).
- commit 956825c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Apply-60us-prefetch-for-DCFCLK.patch (drm-backport-placeholder)
- commit 34e37cc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1124-drm-amd-display-Fix-possible-underflow-for-displays-.patch (drm-backport-placeholder)
- commit d6c4c7b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1123-drm-amd-display-Revert-vblank-change-that-causes-nul.patch (drm-backport-placeholder)
- commit 4e71048
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1122-drm-amd-display-Trigger-DIO-FIFO-resync-on-commit-st.patch (drm-backport-placeholder)
- commit 6680e4a
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: SOF: core: Implement firmware, topology path setup in core
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-pci-dev: Save the default IPC type and path
  overrides (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-of-dev: Save the default IPC type and path
  overrides (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-acpi-dev: Save the default IPC type and path
  overrides (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Add placeholder for platform IPC type and path
  overrides (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Move sof_machine_* functions from sof-audio.c to
  core.c (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Move sof_of_machine_select() to sof-of-dev.c from
  sof-audio.c (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: Move Soundwire runtime stream alloc to soundcards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: Add helper for allocating Soundwire stream runtime
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_rpmsg: update Kconfig dependencies (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Add module ID print during module
  set up (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Drop unused IPC type defines (jsc#PED-9993
  jsc#PED-10202).
- commit 7d5e848
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1121-drm-amd-display-fix-dcn315-pixel-rate-crb-scaling-ch.patch (drm-backport-placeholder)
- commit c9254ce
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1120-drm-amd-display-lower-dp-link-training-message-level.patch (drm-backport-placeholder)
- commit 228f81a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1119-drm-amd-display-Update-SR-watermarks-for-DCN314.patch (drm-backport-placeholder)
- commit d1bdd26
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1118-drm-amd-display-disable-dcn315-pixel-rate-crb-when-s.patch (drm-backport-placeholder)
- commit 2b85c6f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1117-drm-amd-display-Fix-DMUB-debugging-print-issue.patch (drm-backport-placeholder)
- commit 72246eb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1116-drm-amdgpu-stop-including-swiotlb.h.patch (drm-backport-placeholder)
- commit e131f2a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1115-drm-amdgpu-Fix-uninitalized-variable-in-kgd2kfd_devi.patch (drm-backport-placeholder)
- commit 2b8aac3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1114-drm-amdgpu-Fix-uninitalized-variable-in-jpeg_v4_0_3_.patch (drm-backport-placeholder)
- commit bf19ffc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1113-drm-amd-amdgpu-Fix-errors-warnings-in-mmhub_v1_8.c.patch (drm-backport-placeholder)
- commit 3dc472f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1112-drm-amdgpu-retire-set_vga_state-for-some-ASIC.patch (drm-backport-placeholder)
- commit fad785b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1111-drm-amd-display-improve-the-message-printed-when-loa.patch (drm-backport-placeholder)
- commit 8bb7ab7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1110-drm-amdgpu-fix-vga_set_state-NULL-pointer-issue.patch (drm-backport-placeholder)
- commit bade892
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1109-drm-amdgpu-Fix-uninitialized-variable-in-gfx_v9_4_3_.patch (drm-backport-placeholder)
- commit ddc742d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1108-drm-amdgpu-Remove-IMU-ucode-in-vf2pf.patch (drm-backport-placeholder)
- commit 04b63c8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1107-drm-amdgpu-fix-the-memory-override-in-kiq-ring-struc.patch (drm-backport-placeholder)
- commit 4ead6e0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1106-drm-amdgpu-add-the-smu_v13_0_6-and-gfx_v9_4_3-ip-blo.patch (drm-backport-placeholder)
- commit 7824fc1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1105-drm-radeon-Remove-unnecessary-void-conversions.patch (drm-backport-placeholder)
- commit 53ccbf7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-artifacting-on-eDP-panels-w.patch (drm-backport-placeholder)
- commit 6e89803
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Validate-VM-ioctl-flags.patch (drm-backport-placeholder)
- commit 459a20e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1102-drm-amd-Update-driver-misc.html-for-Rembrandt-R.patch (drm-backport-placeholder)
- commit 51f050b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1101-drm-amdgpu-remove-unnecessary-void-conversions.patch (drm-backport-placeholder)
- commit 18f2bad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1100-drm-amd-Update-driver-misc.html-for-Dragon-Range.patch (drm-backport-placeholder)
- commit e28d2c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1099-drm-amd-Update-driver-misc.html-for-Phoenix.patch (drm-backport-placeholder)
- commit 6d54200
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1098-drm-amdgpu-fix-incorrect-pcie_gen_mask-in-passthroug.patch (drm-backport-placeholder)
- commit 2addf21
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1097-drm-amd-display-drop-unused-count-variable-in-create.patch (drm-backport-placeholder)
- commit bd5ea5d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1096-drm-amd-display-drop-unused-function-set_abm_event.patch (drm-backport-placeholder)
- commit 8b1c55e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1094-drm-amdgpu-fix-S3-issue-if-MQD-in-VRAM.patch (drm-backport-placeholder)
- commit e159f9e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1093-drm-amdgpu-Fix-warnings-in-amdgpu-_sdma-_ucode.c.patch (drm-backport-placeholder)
- commit 43b3eed
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1092-drm-amd-amdgpu-Fix-errors-warnings-in-amdgpu-_uvd-_v.patch (drm-backport-placeholder)
- commit fc725df
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1091-drm-amdgpu-perform-mode2-reset-for-sdma-fed-error-on.patch (drm-backport-placeholder)
- commit a6b9ad2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1090-drm-amd-amdgpu-Fix-errors-warnings-in-amdgpu_vcn.c.patch (drm-backport-placeholder)
- commit 8ee2c60
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1089-drm-amd-amdgpu-Fix-warnings-in-amdgpu_encoders.c.patch (drm-backport-placeholder)
- commit d64ef12
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1088-drm-amdkfd-fix-stack-size-in-svm_range_validate_and_.patch (drm-backport-placeholder)
- commit faf248e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1087-drm-amd-amdgpu-Fix-errors-warnings-in-amdgpu_ttm.c.patch (drm-backport-placeholder)
- commit ca5f6f8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1086-drm-amdgpu-vcn4-fix-endian-conversion.patch (drm-backport-placeholder)
- commit 96e7751
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1085-drm-amdgpu-gmc9-fix-64-bit-division-in-partition-cod.patch (drm-backport-placeholder)
- commit 5d04bf0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1084-drm-amdgpu-initialize-RAS-for-gfx_v9_4_3.patch (drm-backport-placeholder)
- commit 24a80fc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1083-drm-amdgpu-add-sq-timeout-status-functions-for-gfx_v.patch (drm-backport-placeholder)
- commit c02f77d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1082-drm-amdgpu-add-RAS-error-count-reset-for-gfx_v9_4_3.patch (drm-backport-placeholder)
- commit cc09ecc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1081-drm-amdgpu-add-RAS-error-count-query-for-gfx_v9_4_3.patch (drm-backport-placeholder)
- commit 80af200
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1080-drm-amdgpu-add-RAS-error-count-definitions-for-gfx_v.patch (drm-backport-placeholder)
- commit 1e93123
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1079-drm-amdgpu-add-RAS-definitions-for-GFX.patch (drm-backport-placeholder)
- commit 349ea68
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: core: Fix a handful of spelling mistakes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: ipc4: Move window offset configuration earlier
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: icp3-dtrace: Fix wrong kfree() usage (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-mtl-match: Add rt722 support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi: add Gen4.1 SDCA board support for LNL
  RVP (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi: rt713+rt1316, no sdw-dmic config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Add rt722 support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: remove unused function declaration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Make use of dev_err_probe() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use common module for DAI link
  generation (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4: Add data struct for module notification
  message from firmware (jsc#PED-9993 jsc#PED-10202).
- commit f53a245
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1078-drm-amdgpu-Add-gc-v9_4_3-ras-error-status-registers.patch (drm-backport-placeholder)
- commit 84c6afa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1077-drm-amdgpu-add-RAS-status-reset-for-gfx_v9_4_3.patch (drm-backport-placeholder)
- commit e9ae94e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1076-drm-amdgpu-add-RAS-status-query-for-gfx_v9_4_3.patch (drm-backport-placeholder)
- commit 3fa1285
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1075-drm-amdgpu-add-GFX-RAS-common-function.patch (drm-backport-placeholder)
- commit 2469f15
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1074-drm-amdgpu-Do-not-access-members-of-xcp-w-o-check-v2.patch (drm-backport-placeholder)
- commit 226d6ac
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1073-drm-amdkfd-Fix-null-ptr-access.patch (drm-backport-placeholder)
- commit 7757f68
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Retrieve the unit ID from the unit control
  RB tree (bsc#1230119).
- commit 81ab2f7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1072-drm-amdgpu-add-check-for-RAS-instance-mask.patch (drm-backport-placeholder)
- commit be0564d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1071-drm-amdgpu-remove-RAS-GFX-injection-for-gfx_v9_4-gfx.patch (drm-backport-placeholder)
- commit 47d1796
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1070-drm-amdgpu-reorganize-RAS-injection-flow.patch (drm-backport-placeholder)
- commit 2d95686
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1069-drm-amdgpu-add-instance-mask-for-RAS-inject.patch (drm-backport-placeholder)
- commit 6fbf223
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1068-drm-amdgpu-convert-logical-instance-mask-to-physical.patch (drm-backport-placeholder)
- commit e9ed41b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1067-drm-amdgpu-Enable-IH-CAM-on-GFX9.4.3.patch (drm-backport-placeholder)
- commit d627ae9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1066-drm-amdgpu-Correct-get_xcp_mem_id-calculation.patch (drm-backport-placeholder)
- commit a0e4351
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1065-drm-amdkfd-Refactor-migrate-init-to-support-partitio.patch (drm-backport-placeholder)
- commit 1a97e6b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1064-drm-amdgpu-route-ioctls-on-primary-node-of-XCPs-to-p.patch (drm-backport-placeholder)
- commit 749211c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1063-drm-amdkfd-APU-mode-set-max-svm-range-pages.patch (drm-backport-placeholder)
- commit 263b9b0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1062-drm-amdkfd-Fix-memory-reporting-on-GFX-9.4.3.patch (drm-backport-placeholder)
- commit e850104
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1061-drm-amdkfd-Move-local_mem_info-to-kfd_node.patch (drm-backport-placeholder)
- commit 4e8b763
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1060-drm-amdgpu-use-xcp-partition-ID-for-amdgpu_gem.patch (drm-backport-placeholder)
- commit ab9065a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1059-drm-amdgpu-KFD-graphics-interop-support-compute-part.patch (drm-backport-placeholder)
- commit 7d21212
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1058-drm-amdkfd-Store-xcp-partition-id-to-amdgpu-bo.patch (drm-backport-placeholder)
- commit 2f490c3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1057-drm-amdgpu-dGPU-mode-set-VRAM-range-lpfn-as-exclusiv.patch (drm-backport-placeholder)
- commit 5c9e37f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1056-drm-amdgpu-Alloc-page-table-on-correct-memory-partit.patch (drm-backport-placeholder)
- commit 4e32992
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1055-drm-amdkfd-Update-MTYPE-for-far-memory-partition.patch (drm-backport-placeholder)
- commit 3e50e96
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1054-drm-amdgpu-dGPU-mode-placement-support-memory-partit.patch (drm-backport-placeholder)
- commit 65a5a83
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1053-drm-amdkfd-SVM-range-allocation-support-memory-parti.patch (drm-backport-placeholder)
- commit 772073a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1052-drm-amdkfd-Alloc-memory-of-GPU-support-memory-partit.patch (drm-backport-placeholder)
- commit c149d38
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1051-drm-amdgpu-Add-memory-partition-mem_id-to-amdgpu_bo.patch (drm-backport-placeholder)
- commit 897c433
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1050-drm-amdkfd-Show-KFD-node-memory-partition-info.patch (drm-backport-placeholder)
- commit 00e2aee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1049-drm-amdgpu-Add-memory-partition-id-to-amdgpu_vm.patch (drm-backport-placeholder)
- commit 936c470
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1048-drm-amdkfd-Store-drm-node-minor-number-for-kfd-nodes.patch (drm-backport-placeholder)
- commit 1f83e6d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1047-drm-amdgpu-Add-xcp-manager-num_xcp_per_mem_partition.patch (drm-backport-placeholder)
- commit 4e74036
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1046-drm-amdgpu-update-ref_cnt-before-ctx-free.patch (drm-backport-placeholder)
- commit 1bf057e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1045-drm-amdgpu-run-partition-schedule-if-it-is-supported.patch (drm-backport-placeholder)
- commit d179673
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1044-drm-amdgpu-add-partition-schedule-for-GC-9-4-3.patch (drm-backport-placeholder)
- commit ac92014
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1043-drm-amdgpu-keep-amdgpu_ctx_mgr-in-ctx-structure.patch (drm-backport-placeholder)
- commit 7969322
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1042-drm-amdgpu-add-partition-scheduler-list-update.patch (drm-backport-placeholder)
- commit ef1e7dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1041-drm-amdgpu-update-header-to-support-partition-schedu.patch (drm-backport-placeholder)
- commit 3067897
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1040-drm-amdgpu-add-partition-ID-track-in-ring.patch (drm-backport-placeholder)
- commit 3230549
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: sof_nau8825: use common module for DAI link
  generation (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support DAI link array generation
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: use common module for HDMI-In link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use common module for HDMI-In link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support HDMI-In link initialization
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: simplify HDMI-In quirks (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: use common module for BT offload link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use common module for BT offload link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use common module for BT offload link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: use common module for BT offload link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support BT offload link
  initialization (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: rename function parameter
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: use common module for amp link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use common module for amp link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use common module for amp link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: use common module for amp link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support amp link initialization
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use common module for codec link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use common module for codec link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: use common module for codec link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support codec link initialization
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: ssp-common: get codec name function (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: cht_bsw_rt5672: check return value (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_maxim_common: check return value (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_maxim_common: add else between 2 if test
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: remove dead code (jsc#PED-9993
  jsc#PED-10202).
- ASoC: audio-graph-card2-custom-sample: add CPU/Codec = N:M
  sample (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2-custom-sample: Add connection image
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: add CPU:Codec = N:M support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: use better image for Multi connection
  (jsc#PED-9993 jsc#PED-10202).
- commit 29eb7bb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1039-drm-amdgpu-find-partition-ID-when-open-device.patch (drm-backport-placeholder)
- commit c0a6f36
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Support per PMU cpumask (bsc#1230119).
- commit e0b1be5
* Wed Sep  4 2024 pjakobsson@suse.de
- Refresh patches.suse/0058-drm-amdgpu-Remove-struct-drm_driver.gem_prime_mmap.patch.
- Update patches.suse/1038-drm-amdgpu-support-partition-drm-devices.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit af07cca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1037-drm-amdgpu-bu-update-mtype_local-parameter-settings.patch (drm-backport-placeholder)
- commit 7556fa7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1036-drm-amdgpu-bu-add-mtype_local-as-a-module-parameter.patch (drm-backport-placeholder)
- commit 7abc9d9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1035-drm-amdgpu-Override-MTYPE-per-page-on-GFXv9.4.3-APUs.patch (drm-backport-placeholder)
- commit 5367be8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1034-drm-amdgpu-Fix-per-BO-MTYPE-selection-for-GFXv9.4.3.patch (drm-backport-placeholder)
- commit 59daea0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1033-drm-amdgpu-bu-Add-use_mtype_cc_wa-module-param.patch (drm-backport-placeholder)
- commit 9bebfc3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1032-drm-amdgpu-Use-legacy-TLB-flush-for-gfx943.patch (drm-backport-placeholder)
- commit f3d0593
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1031-drm-amdgpu-For-GFX-9.4.3-APU-fix-vram_usage-value.patch (drm-backport-placeholder)
- commit 9369b33
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1030-drm-amdgpu-Enable-NPS4-CPX-mode.patch (drm-backport-placeholder)
- commit 9fa13ee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1029-drm-amdkfd-Move-pgmap-to-amdgpu_kfd_dev-structure.patch (drm-backport-placeholder)
- commit 1793b5f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1028-drm-amdgpu-Skip-halting-RLC-on-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit 9fe729d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1027-drm-amdgpu-Fix-register-accesses-in-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit eeb6e09
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1026-drm-amdkfd-Increase-queue-number-per-process-to-255-.patch (drm-backport-placeholder)
- commit 121517a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1025-drm-amdgpu-Adjust-the-sequence-to-query-ras-error-in.patch (drm-backport-placeholder)
- commit 67fbd2b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1024-drm-amdgpu-Initialize-jpeg-v4_0_3-ras-function.patch (drm-backport-placeholder)
- commit 1aff66d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1023-drm-amdgpu-Add-reset_ras_error_count-for-jpeg-v4_0_3.patch (drm-backport-placeholder)
- commit 51cb40e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1022-drm-amdgpu-Add-query_ras_error_count-for-jpeg-v4_0_3.patch (drm-backport-placeholder)
- commit 9f2b9ee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1021-drm-amdgpu-Re-enable-VCN-RAS-if-DPG-is-enabled.patch (drm-backport-placeholder)
- commit 0072475
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1020-drm-amdgpu-Initialize-vcn-v4_0_3-ras-function.patch (drm-backport-placeholder)
- commit f613710
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1019-drm-amdgpu-Add-reset_ras_error_count-for-vcn-v4_0_3.patch (drm-backport-placeholder)
- commit c0e262d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1018-drm-amdgpu-Add-query_ras_error_count-for-vcn-v4_0_3.patch (drm-backport-placeholder)
- commit 06edb12
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1017-drm-amdgpu-Add-vcn-jpeg-ras-err-status-registers.patch (drm-backport-placeholder)
- commit 71d640d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1016-drm-amdgpu-Checked-if-the-pointer-NULL-before-use-it.patch (drm-backport-placeholder)
- commit 33c640e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1015-drm-amdgpu-Set-memory-partitions-to-1-for-SRIOV.patch (drm-backport-placeholder)
- commit 1937774
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1014-drm-amdgpu-Skip-using-MC-FB-Offset-when-APU-flag-is-.patch (drm-backport-placeholder)
- commit 3db1a38
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1013-drm-amdgpu-Add-PSP-supporting-PSP-13.0.6-SRIOV-ucode.patch (drm-backport-placeholder)
- commit b9000f4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1012-drm-amdgpu-Add-PSP-spatial-parition-interface.patch (drm-backport-placeholder)
- commit 8460fa0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1011-drm-amdgpu-Return-error-on-invalid-compute-mode.patch (drm-backport-placeholder)
- commit c050ce2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1010-drm-amdgpu-Add-compute-mode-descriptor-function.patch (drm-backport-placeholder)
- commit a339350
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1009-drm-amdgpu-Fix-unmapping-of-aperture.patch (drm-backport-placeholder)
- commit 46f2047
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1008-drm-amdgpu-Fix-xGMI-access-P2P-mapping-failure-on-GF.patch (drm-backport-placeholder)
- commit f67f328
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1007-drm-amdkfd-Native-mode-memory-partition-support.patch (drm-backport-placeholder)
- commit 852d44a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1006-drm-amdgpu-Set-TTM-pools-for-memory-partitions.patch (drm-backport-placeholder)
- commit 2871b8a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1005-drm-ttm-export-ttm_pool_fini-for-cleanup.patch (drm-backport-placeholder)
- commit d2a9e70
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1004-drm-amdgpu-Add-auto-mode-for-compute-partition.patch (drm-backport-placeholder)
- commit b47a91d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1003-drm-amdgpu-Check-memory-ranges-for-valid-xcp-mode.patch (drm-backport-placeholder)
- commit 45683cd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1002-drm-amdkfd-Use-xcc-mask-for-identifying-xcc.patch (drm-backport-placeholder)
- commit fbafd6c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1001-drm-amdkfd-Add-xcp-reference-to-kfd-node.patch (drm-backport-placeholder)
- commit 4a1ce9a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1000-drm-amdgpu-Move-initialization-of-xcp-before-kfd.patch (drm-backport-placeholder)
- commit 325cd85
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0999-drm-amdgpu-Fill-xcp-mem-node-in-aquavanjaram.patch (drm-backport-placeholder)
- commit 35621f6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0998-drm-amdgpu-Add-callback-to-fill-xcp-memory-id.patch (drm-backport-placeholder)
- commit 38df784
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0997-drm-amdgpu-Initialize-memory-ranges-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit 695cabc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0996-drm-amdgpu-Add-memory-partitions-to-gmc.patch (drm-backport-placeholder)
- commit a0900c5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0995-drm-amdgpu-Add-API-to-get-numa-information-of-XCC.patch (drm-backport-placeholder)
- commit 9d2e0b0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0994-drm-amdgpu-Store-additional-numa-node-information.patch (drm-backport-placeholder)
- commit aa83223
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0993-drm-amdgpu-Get-supported-memory-partition-modes.patch (drm-backport-placeholder)
- commit b212db5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0992-drm-amdgpu-Move-memory-partition-query-to-gmc.patch (drm-backport-placeholder)
- commit fbe44c3
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Save the unit control address of all units
  (bsc#1230119).
- commit 3062251
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0991-drm-amdgpu-Add-utility-functions-for-xcp.patch (drm-backport-placeholder)
- commit 47c04d3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0990-drm-amdgpu-Use-apt-name-for-FW-reserved-region.patch (drm-backport-placeholder)
- commit 96952b8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0989-drm-amdgpu-Use-GPU-VA-space-for-IH-v4.4.2-in-APU.patch (drm-backport-placeholder)
- commit 9673191
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0988-drm-amdgpu-Simplify-aquavanjram-instance-mapping.patch (drm-backport-placeholder)
- commit 0721406
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0987-drm-amdgpu-vcn-Use-buffer-object-s-deletion-logic.patch (drm-backport-placeholder)
- commit 6830d74
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0986-drm-amdgpu-Use-a-different-value-than-0xDEADBEEF-for.patch (drm-backport-placeholder)
- commit 335949c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0985-drm-amdgpu-Add-a-read-after-write-DB_CTRL-for-vcn_v4.patch (drm-backport-placeholder)
- commit c9c9107
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0984-drm-amdgpu-fixes-a-JPEG-get-write-read-pointer-bug.patch (drm-backport-placeholder)
- commit 5ccc9c5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0983-drm-amdgpu-A-workaround-for-JPEG_v4_0_3-ring-test-fa.patch (drm-backport-placeholder)
- commit d8e904f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0982-drm-amdgpu-use-physical-AID-index-for-ring-name.patch (drm-backport-placeholder)
- commit 8ec9741
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0981-drm-amdgpu-vcn-use-dummy-register-selects-AID-for-VC.patch (drm-backport-placeholder)
- commit d498507
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0980-drm-amdgpu-Fix-harvest-reporting-of-VCN.patch (drm-backport-placeholder)
- commit f72e17a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0979-drm-amdgpu-Use-logical-ids-for-VCN-JPEG-v4.0.3.patch (drm-backport-placeholder)
- commit f793730
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0978-drm-amdgpu-Add-VCN-logical-to-physical-id-mapping.patch (drm-backport-placeholder)
- commit ed727d4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0977-drm-amdgpu-Add-instance-mask-for-VCN-and-JPEG.patch (drm-backport-placeholder)
- commit fa0dbb5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0976-drm-amdgpu-Load-vcn_v4_0_3-ucode-during-early_init.patch (drm-backport-placeholder)
- commit f69684c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0975-drm-amdgpu-preserve-the-num_links-in-case-of-reflect.patch (drm-backport-placeholder)
- commit 5488128
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0974-drm-amdgpu-Fix-discovery-sys-node-harvest-info.patch (drm-backport-placeholder)
- commit 48f086e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0973-drm-amdkfd-Flush-TLB-after-unmapping-for-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit 53bd9a2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0972-drm-amdgpu-Add-fallback-path-for-discovery-info.patch (drm-backport-placeholder)
- commit fb40e3c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0971-drm-amdgpu-Read-discovery-info-from-system-memory.patch (drm-backport-placeholder)
- commit 0bca8b8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0970-drm-amdgpu-Add-API-to-get-tmr-info-from-acpi.patch (drm-backport-placeholder)
- commit 2363357
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0969-drm-amdgpu-Add-parsing-of-acpi-xcc-objects.patch (drm-backport-placeholder)
- commit 49bab77
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0968-drm-amdkfd-Enable-SVM-on-Native-mode.patch (drm-backport-placeholder)
- commit a3f770b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0967-drm-amdgpu-Add-FGCG-for-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit 3dcd16c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0966-drm-amdgpu-Use-transient-mode-during-xcp-switch.patch (drm-backport-placeholder)
- commit f711d18
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0965-drm-amdgpu-Add-flags-for-partition-mode-query.patch (drm-backport-placeholder)
- commit 35eea13
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0964-drm-amd-pm-fix-wrong-smu-socclk-value.patch (drm-backport-placeholder)
- commit 06d2fa9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0963-drm-amdgpu-Add-mode-2-reset-in-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit 323e893
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0962-drm-amd-pm-Notify-PMFW-about-driver-unload-cases.patch (drm-backport-placeholder)
- commit 48cfa28
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0961-drm-amd-pm-Update-PMFW-headers-for-version-85.54.patch (drm-backport-placeholder)
- commit 1a7cf32
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0960-drm-amd-pm-Expose-mem-temperature-for-GC-version-9.4.patch (drm-backport-placeholder)
- commit 53496f4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0959-drm-amd-pm-Update-hw-mon-attributes-for-GC-version-9.patch (drm-backport-placeholder)
- commit e1c55e2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0958-drm-amd-pm-Initialize-power-limit-for-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit b303a43
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0957-drm-amd-pm-Keep-interface-version-in-PMFW-header.patch (drm-backport-placeholder)
- commit 1db0e58
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0956-drm-amd-pm-Add-ih-for-SMU-v13.0.6-thermal-throttling.patch (drm-backport-placeholder)
- commit 8f2e870
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0955-drm-amd-pm-Update-pmfw-header-files-for-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit 6482fc3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0954-drm-amd-pm-Update-gfx-clock-frequency-for-SMU-v13.0..patch (drm-backport-placeholder)
- commit 4f6847d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0953-drm-amd-pm-Update-pmfw-header-files-for-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit 396c57c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0952-drm-amdgpu-fix-sdma-instance.patch (drm-backport-placeholder)
- commit 26e778f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0951-drm-amdgpu-change-the-print-level-to-warn-for-ip-blo.patch (drm-backport-placeholder)
- commit 1e8a93d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0950-drm-amdgpu-Increase-Max-GPU-instance-to-64.patch (drm-backport-placeholder)
- commit 5835789
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0949-drm-amdgpu-increase-AMDGPU_MAX_RINGS.patch (drm-backport-placeholder)
- commit adfc5b2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0948-drm-amdgpu-Create-VRAM-BOs-on-GTT-for-GFXIP9.4.3.patch (drm-backport-placeholder)
- commit b518124
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0947-drm-amdgpu-Implement-new-dummy-vram-manager.patch (drm-backport-placeholder)
- commit d260d1d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0946-drm-amdgpu-Handle-VRAM-dependencies-on-GFXIP9.4.3.patch (drm-backport-placeholder)
- commit be397f8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0945-drm-amdgpu-Enable-CG-for-IH-v4.4.2.patch (drm-backport-placeholder)
- commit b549d59
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0944-drm-amdgpu-Enable-persistent-edc-harvesting-in-APP-A.patch (drm-backport-placeholder)
- commit 779e218
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0943-drm-amdgpu-Initialize-mmhub-v1_8-ras-function.patch (drm-backport-placeholder)
- commit cb193b6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0942-drm-amdgpu-Add-reset_ras_error_status-for-mmhub-v1_8.patch (drm-backport-placeholder)
- commit a10a0b0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0941-drm-amdgpu-Add-query_ras_error_status-for-mmhub-v1_8.patch (drm-backport-placeholder)
- commit 6e21129
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0940-drm-amdgpu-Add-reset_ras_error_count-for-mmhub-v1_8.patch (drm-backport-placeholder)
- commit 37ce903
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0939-drm-amdgpu-Add-query_ras_error_count-for-mmhub-v1_8.patch (drm-backport-placeholder)
- commit ffa8c3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0938-drm-amdgpu-Add-mmhub-v1_8_0-ras-err-status-registers.patch (drm-backport-placeholder)
- commit bfbebe6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0937-drm-amdgpu-Initialize-sdma-v4_4_2-ras-function.patch (drm-backport-placeholder)
- commit 64c59dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0936-drm-amdgpu-Add-reset_ras_error_count-for-sdma-v4_4_2.patch (drm-backport-placeholder)
- commit 6e1c729
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0935-drm-amdgpu-Add-query_ras_error_count-for-sdma-v4_4_2.patch (drm-backport-placeholder)
- commit 70988da
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0934-drm-amdgpu-Add-sdma-v4_4_2-ras-registers.patch (drm-backport-placeholder)
- commit d468ee7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0933-drm-amdgpu-Add-common-helper-to-reset-ras-error.patch (drm-backport-placeholder)
- commit 9bc5919
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0932-drm-amdgpu-Add-common-helper-to-query-ras-error-v2.patch (drm-backport-placeholder)
- commit d15c671
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0931-drm-amdgpu-Enable-MGCG-on-SDMAv4.4.2.patch (drm-backport-placeholder)
- commit 6ff48f3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0930-drm-amdgpu-enable-context-empty-interrupt-on-sdma-v4.patch (drm-backport-placeholder)
- commit 3660bed
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0929-drm-amdgpu-add-vcn_4_0_3-codec-query.patch (drm-backport-placeholder)
- commit 8051aad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0928-drm-amdkfd-bind-cpu-and-hiveless-gpu-to-a-hive-if-xg.patch (drm-backport-placeholder)
- commit d7c106a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0927-drm-amdkfd-Cleanup-KFD-nodes-creation.patch (drm-backport-placeholder)
- commit dfd1a1d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0926-drm-ttm-add-NUMA-node-id-to-the-pool.patch (drm-backport-placeholder)
- commit 8331cab
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0925-drm-amdgpu-Fix-mqd-init-on-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit 2248864
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0924-drm-amd-fix-compiler-error-to-support-older-compiler.patch (drm-backport-placeholder)
- commit 737d8b2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0923-drm-amdgpu-Enable-CGCG-LS-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit bbd499b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0922-drm-amdgpu-Use-unique-doorbell-range-per-xcc.patch (drm-backport-placeholder)
- commit d5ea89d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0921-drm-amdgpu-Keep-SDMAv4.4.2-active-during-reset.patch (drm-backport-placeholder)
- commit 533f592
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0920-drm-amdkfd-Report-XGMI-IOLINKs-for-GFXIP9.4.3.patch (drm-backport-placeholder)
- commit fad8f0c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0919-drm-amdgpu-add-num_xcps-return.patch (drm-backport-placeholder)
- commit 55226a7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0918-drm-amdgpu-increase-AMDGPU_MAX_HWIP_RINGS.patch (drm-backport-placeholder)
- commit c8b3047
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0917-drm-amdgpu-vcn_v4_0_3-load-vcn-fw-once-for-all-AIDs.patch (drm-backport-placeholder)
- commit 7f0ac5d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0916-drm-amdgpu-Populate-VCN-JPEG-harvest-information.patch (drm-backport-placeholder)
- commit 8286b5a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0915-drm-amdgpu-Correct-dGPU-MTYPE-settings-for-gfx943.patch (drm-backport-placeholder)
- commit 6819c8c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0914-drm-amdgpu-Remove-SMU-powergate-message-call-for-SDM.patch (drm-backport-placeholder)
- commit 73250a7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0913-drm-amdgpu-enable-vcn-jpeg-on-vcn_v4_0_3.patch (drm-backport-placeholder)
- commit 56b4cee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0912-drm-amdgpu-enable-indirect_sram-mode-on-vcn_v4_0_3.patch (drm-backport-placeholder)
- commit 8948fa5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0911-drm-amdgpu-add-unified-queue-support-on-vcn_v4_0_3.patch (drm-backport-placeholder)
- commit 01a0ffe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0910-drm-amdgpu-add-fwlog-support-on-vcn_v4_0_3.patch (drm-backport-placeholder)
- commit aab0119
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0909-drm-amdgpu-increase-MAX-setting-to-hold-more-jpeg-in.patch (drm-backport-placeholder)
- commit e3c5711
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0908-drm-amdgpu-Use-discovery-to-get-XCC-SDMA-mask.patch (drm-backport-placeholder)
- commit 51fe30b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0907-drm-amdgpu-Make-VRAM-discovery-read-optional.patch (drm-backport-placeholder)
- commit fed2e32
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0906-drm-amdgpu-Allocate-GART-table-in-RAM-for-AMD-APU.patch (drm-backport-placeholder)
- commit 2ee71b8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0905-drm-amdgpu-Add-FGCG-logic-for-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit e8c012d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0904-drm-amdgpu-Make-UTCL2-snoop-CPU-caches.patch (drm-backport-placeholder)
- commit 6661304
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0903-amd-amdgpu-Set-MTYPE_UC-for-access-over-PCIe.patch (drm-backport-placeholder)
- commit 57467fb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0902-drm-amdgpu-Fix-GFX-v9.4.3-EOP-buffer-allocation.patch (drm-backport-placeholder)
- commit a872e83
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0901-drm-amdgpu-Fix-GFX-9.4.3-dma-address-capability.patch (drm-backport-placeholder)
- commit 4d12997
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0900-drm-amdgpu-Fix-semaphore-release.patch (drm-backport-placeholder)
- commit 68953b0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0899-drm-amdkfd-Setup-current_logical_xcc_id-in-MQD.patch (drm-backport-placeholder)
- commit 6795c0c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0898-drm-amdgpu-Remove-unnecessary-return-value-check.patch (drm-backport-placeholder)
- commit e3cd88c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0897-drm-amdgpu-correct-the-vmhub-index-when-page-fault-o.patch (drm-backport-placeholder)
- commit 77979c3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0896-drm-amdkfd-Update-packet-manager-for-GFX9.4.3.patch (drm-backport-placeholder)
- commit bf59406
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0895-drm-amdgpu-set-MTYPE-in-PTE-for-GFXIP-9.4.3.patch (drm-backport-placeholder)
- commit f73f925
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0894-drm-amdgpu-Use-mask-for-active-clusters.patch (drm-backport-placeholder)
- commit d020551
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0893-drm-amdgpu-Derive-active-clusters-from-SDMA.patch (drm-backport-placeholder)
- commit 1c2ad6f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0892-drm-amdgpu-Move-generic-logic-to-soc-config.patch (drm-backport-placeholder)
- commit d2adaa0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0891-drm-amdgpu-Fix-the-KCQ-hang-when-binding-back.patch (drm-backport-placeholder)
- commit f9f6000
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0890-drm-amdgpu-Skip-TMR-allocation-if-not-required.patch (drm-backport-placeholder)
- commit 8116474
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0889-drm-amdgpu-Add-XCP-IP-callback-funcs-for-each-IP.patch (drm-backport-placeholder)
- commit 1e3e174
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0888-drm-amdgpu-Add-XCP-functions-for-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit be0f6d5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0887-drm-amdgpu-Add-SDMA-v4.4.2-XCP-funcs.patch (drm-backport-placeholder)
- commit 32434b5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0886-drm-amdgpu-Add-GFXHUB-v1.2-XCP-funcs.patch (drm-backport-placeholder)
- commit e071a07
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0885-drm-amdgpu-Switch-to-SOC-partition-funcs.patch (drm-backport-placeholder)
- commit 8dbe031
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0884-drm-amdgpu-Add-soc-config-init-for-GC9.4.3-ASICs.patch (drm-backport-placeholder)
- commit b607a36
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0883-drm-amdgpu-Add-SOC-partition-funcs-for-GC-v9.4.3.patch (drm-backport-placeholder)
- commit 71228c5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0882-drm-amdgpu-Add-initial-version-of-XCP-routines.patch (drm-backport-placeholder)
- commit 4743cc9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0881-drm-amdgpu-Add-sdma-instance-specific-functions.patch (drm-backport-placeholder)
- commit 0757f57
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0880-drm-amdgpu-Add-xcc-specific-functions-for-gfxhub.patch (drm-backport-placeholder)
- commit 808237c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0879-drm-amdgpu-Add-xcc-specific-functions.patch (drm-backport-placeholder)
- commit 4e91e66
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0878-drm-amdgpu-Rename-xcc-specific-functions.patch (drm-backport-placeholder)
- commit bfa4424
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0877-drm-amdgpu-Check-APU-supports-true-APP-mode.patch (drm-backport-placeholder)
- commit a60cbd4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0876-drm-amdgpu-more-GPU-page-fault-info-for-GC-v9.4.3.patch (drm-backport-placeholder)
- commit 64b67d1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0875-drm-amdgpu-remove-partition-attributes-sys-file-for-.patch (drm-backport-placeholder)
- commit 97b4d66
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0874-drm-amdgpu-fix-kcq-mqd_backup-buffer-double-free-for.patch (drm-backport-placeholder)
- commit 9e334d6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0873-drm-amdgpu-Skip-runtime-db-read-for-PSP-13.0.6.patch (drm-backport-placeholder)
- commit b555f07
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0872-drm-amdgpu-fix-vm-context-register-assignment-in-mmh.patch (drm-backport-placeholder)
- commit ad85026
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0871-drm-amdgpu-Revert-programming-of-CP_PSP_XCP_CTL.patch (drm-backport-placeholder)
- commit 5a53583
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0870-drm-amdgpu-detect-current-GPU-memory-partition-mode.patch (drm-backport-placeholder)
- commit a2d7c4e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0869-drm-amdgpu-init-smuio-funcs-for-smuio-v13_0_3.patch (drm-backport-placeholder)
- commit 18e88f8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0868-drm-amdgpu-implement-smuio-v13_0_3-callbacks.patch (drm-backport-placeholder)
- commit 19cd05c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0867-drm-amdgpu-add-smuio-v13_0_3-ip-headers.patch (drm-backport-placeholder)
- commit 97f3bb4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0866-drm-amdgpu-retire-render-backend-setup-from-gfx_v9_4.patch (drm-backport-placeholder)
- commit a25ca65
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0865-drm-amd-amdgpu-Update-debugfs-for-XCC-support-v3.patch (drm-backport-placeholder)
- commit 876023b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0864-drm-amdgpu-Add-SDMA-v4.4.2-golden-settings.patch (drm-backport-placeholder)
- commit db3e3e3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0863-drm-amdgpu-init-gfx_v9_4_3-external_rev_id.patch (drm-backport-placeholder)
- commit 3539bc8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0862-drm-amdgpu-Fix-interrupt-handling-in-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit 20a65b3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0861-drm-amdgpu-consolidate-the-access-helpers-in-nbio-v7.patch (drm-backport-placeholder)
- commit 690b9f8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0860-drm-amdgpu-add-helpers-to-access-registers-on-differ.patch (drm-backport-placeholder)
- commit 59c7e43
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0859-drm-amdgpu-parse-base-address-from-new-ip-discovery-.patch (drm-backport-placeholder)
- commit bf12119
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0858-drm-amdgpu-upgrade-amdgpu_discovery-struct-ip-to-ip_.patch (drm-backport-placeholder)
- commit 8405476
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0857-drm-amdgpu-do-some-register-access-cleanup-in-nbio-v.patch (drm-backport-placeholder)
- commit dd0c5b9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0856-drm-amdgpu-extend-max-instances.patch (drm-backport-placeholder)
- commit 65b6391
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0855-drm-amdgpu-increase-DISCOVERY_TMR_SIZE.patch (drm-backport-placeholder)
- commit 4ed1a55
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0854-drm-amdgpu-update-ip-discovery-header-to-v4.patch (drm-backport-placeholder)
- commit b0f9718
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0853-drm-amdgpu-switch-to-aqua_vanjaram_doorbell_index_in.patch (drm-backport-placeholder)
- commit 568aab0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0852-drm-amdgpu-Use-SDMA-instance-table-for-aqua-vanjaram.patch (drm-backport-placeholder)
- commit 50ff0eb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0851-drm-amdgpu-Add-mask-for-SDMA-instances.patch (drm-backport-placeholder)
- commit b2e41a8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0850-drm-amdgpu-Add-IP-instance-map-for-aqua-vanjaram.patch (drm-backport-placeholder)
- commit 963b8dd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0849-drm-amdgpu-add-new-doorbell-assignment-table-for-aqu.patch (drm-backport-placeholder)
- commit e78bb04
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0848-drm-amdgpu-Fix-register-access-on-GC-v9.4.3.patch (drm-backport-placeholder)
- commit 495bd88
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0847-drm-amdgpu-Fix-programming-of-initial-XCP-mode.patch (drm-backport-placeholder)
- commit b030372
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0846-drm-amdkfd-Update-interrupt-handling-for-GFX9.4.3.patch (drm-backport-placeholder)
- commit 31835ec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0845-drm-amdgpu-Fix-failure-when-switching-to-DPX-mode.patch (drm-backport-placeholder)
- commit 210988a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0844-drm-amdkfd-Use-instance-table-for-GFX-9.4.3.patch (drm-backport-placeholder)
- commit 244fdca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0843-drm-amdgpu-Fix-SWS-on-multi-XCD-GPU.patch (drm-backport-placeholder)
- commit 2405399
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0842-drm-amdgpu-drop-redundant-csb-init-for-gfx943.patch (drm-backport-placeholder)
- commit c75bcdb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0841-drm-amdgpu-adjust-s2a-entry-register-for-sdma-doorbe.patch (drm-backport-placeholder)
- commit 114f10c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0840-drm-amdkfd-Update-SMI-events-for-GFX9.4.3.patch (drm-backport-placeholder)
- commit 5fb2160
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0839-drm-amdgpu-Use-status-register-for-partition-mode.patch (drm-backport-placeholder)
- commit e227cea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0838-drm-amdkfd-pass-kfd_node-ref-to-svm-migration-api.patch (drm-backport-placeholder)
- commit 882acdf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0837-drm-amdgpu-Conform-to-SET_UCONFIG_REG-spec.patch (drm-backport-placeholder)
- commit 2a914c6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0836-drm-amdgpu-vcn-add-vcn-multiple-AIDs-support.patch (drm-backport-placeholder)
- commit b128eb9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0835-drm-amdgpu-vcn-update-clock-gate-setting-for-VCN-4.0.patch (drm-backport-placeholder)
- commit 6e25344
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0834-drm-amdgpu-jpeg-add-JPEG-multiple-AIDs-support.patch (drm-backport-placeholder)
- commit 72727c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0833-drm-amdgpu-nbio-add-vcn-doorbell-multiple-AIDs-suppo.patch (drm-backport-placeholder)
- commit 08a3153
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0832-drm-amdgpu-Fix-GRBM-programming-sequence.patch (drm-backport-placeholder)
- commit a34d683
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0831-drm-amdgpu-Use-instance-table-for-sdma-4.4.2.patch (drm-backport-placeholder)
- commit 86c2aa2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0830-drm-amdgpu-Add-mask-for-SDMA-instances.patch (drm-backport-placeholder)
- commit b62b04a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0829-drm-amdgpu-Use-instance-lookup-table-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit 73652cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0828-drm-amdgpu-Add-map-of-logical-to-physical-inst.patch (drm-backport-placeholder)
- commit 3c06b5b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0827-drm-amdkfd-Add-device-repartition-support.patch (drm-backport-placeholder)
- commit d544a84
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0826-drm-amdkfd-Rework-kfd_locked-handling.patch (drm-backport-placeholder)
- commit aa4693b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0825-drm-amdgpu-configure-the-doorbell-settings-for-sdma-.patch (drm-backport-placeholder)
- commit 4efd305
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0824-drm-amdgpu-add-indirect-r-w-interface-for-smn-addres.patch (drm-backport-placeholder)
- commit e502645
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0823-drm-amdkfd-EOP-Removal-Handle-size-0-correctly.patch (drm-backport-placeholder)
- commit 406793c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0822-drm-amdgpu-reflect-psp-xgmi-topology-info-for-gfx9.4.patch (drm-backport-placeholder)
- commit 0ac5bde
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0821-drm-amdgpu-vcn-update-amdgpu_fw_shared-to-amdgpu_vcn.patch (drm-backport-placeholder)
- commit 81bfd19
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0820-drm-amdgpu-vcn-remove-unused-code.patch (drm-backport-placeholder)
- commit 1a507de
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0819-drm-amdgpu-vcn-update-ucode-setup.patch (drm-backport-placeholder)
- commit fbacef2
* Wed Sep  4 2024 oneukum@suse.com
- media: video-mux: update driver to active state (jsc#PED-8643).
- commit a5f332b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0818-drm-amdgpu-vcn-update-new-doorbell-map.patch (drm-backport-placeholder)
- commit 1736c10
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0817-drm-amdgpu-jpeg-update-jpeg-header-to-support-multip.patch (drm-backport-placeholder)
- commit b172974
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0816-drm-amdgpu-vcn-update-vcn-header-to-support-multiple.patch (drm-backport-placeholder)
- commit c6fab2e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0815-drm-amdgpu-vcn-use-vcn4-irqsrc-header-for-VCN-4.0.3.patch (drm-backport-placeholder)
- commit bf6c5be
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0814-drm-amdgpu-Change-num_xcd-to-xcc_mask.patch (drm-backport-placeholder)
- commit 453a743
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0813-drm-amdgpu-add-the-support-of-XGMI-link-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit 54caee2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0812-drm-amdgpu-add-new-vram-type-for-dgpu.patch (drm-backport-placeholder)
- commit f449841
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0811-drm-amdkfd-Populate-memory-info-before-adding-GPU-no.patch (drm-backport-placeholder)
- commit a0db9ab
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0810-drm-amdkfd-Add-SDMA-info-for-SDMA-4.4.2.patch (drm-backport-placeholder)
- commit 44b5fba
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0809-drm-amdkfd-Fix-SDMA-in-CPX-mode.patch (drm-backport-placeholder)
- commit 575d4b6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0808-drm-amdkfd-add-gpu-compute-cores-io-links-for-gfx9.4.patch (drm-backport-placeholder)
- commit 228e517
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0807-drm-amdgpu-introduce-new-doorbell-assignment-table-f.patch (drm-backport-placeholder)
- commit 86ef2f0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0806-drm-amdgpu-program-GRBM_MCM_ADDR-for-non-AID0-GRBM.patch (drm-backport-placeholder)
- commit 80d16ef
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0805-drm-amdgpu-convert-the-doorbell_index-to-2-dwords-of.patch (drm-backport-placeholder)
- commit 2682d4d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0804-drm-amdgpu-set-mmhub-bitmask-for-multiple-AIDs.patch (drm-backport-placeholder)
- commit 99438db
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0803-drm-amdgpu-complement-the-IH-node_id-table-for-multi.patch (drm-backport-placeholder)
- commit 5543227
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0802-drm-amdgpu-correct-the-vmhub-reference-for-each-XCD-.patch (drm-backport-placeholder)
- commit d0cbeb3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0801-drm-amdgpu-do-mmhub-init-for-multiple-AIDs.patch (drm-backport-placeholder)
- commit 4187608
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0800-drm-amdgpu-assign-the-doorbell-index-for-sdma-on-non.patch (drm-backport-placeholder)
- commit 40a0a6f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0799-drm-amdgpu-add-support-for-SDMA-on-multiple-AIDs.patch (drm-backport-placeholder)
- commit ee9bc93
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0798-drm-amdgpu-adjust-some-basic-elements-for-multiple-A.patch (drm-backport-placeholder)
- commit 4f26c98
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0797-drm-amdgpu-assign-the-doorbell-index-in-1st-page-to-.patch (drm-backport-placeholder)
- commit 609efa9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0796-drm-amdgpu-Set-XNACK-per-process-on-GC-9.4.3.patch (drm-backport-placeholder)
- commit 19b8489
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0795-drm-amdgpu-Use-new-atomfirmware-init-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit 4b30be6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0794-drm-amdkfd-Update-coherence-settings-for-svm-ranges.patch (drm-backport-placeholder)
- commit db4fd7d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0793-drm-amdgpu-Fix-CP_HYP_XCP_CTL-register-programming-i.patch (drm-backport-placeholder)
- commit 3eead8e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0792-drm-amdkfd-Update-SDMA-queue-management-for-GFX9.4.3.patch (drm-backport-placeholder)
- commit f0523ee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0791-drm-amdkfd-Update-sysfs-node-properties-for-multi-XC.patch (drm-backport-placeholder)
- commit 8149b22
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0790-drm-amdkfd-Call-DQM-stop-during-DQM-uninitialize.patch (drm-backport-placeholder)
- commit 1920d10
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0789-drm-amdgpu-Fix-VM-fault-reporting-on-XCC1.patch (drm-backport-placeholder)
- commit 491b264
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0788-drm-amdkfd-Update-context-save-handling-for-multi-XC.patch (drm-backport-placeholder)
- commit 807a099
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0787-drm-amdgpu-Add-XCC-inst-to-PASID-TLB-flushing.patch (drm-backport-placeholder)
- commit ecd87b2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0786-drm-amdkfd-Add-XCC-instance-to-kgd2kfd-interface-v3.patch (drm-backport-placeholder)
- commit 2212005
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0785-drm-amdkfd-Add-PM4-target-XCC.patch (drm-backport-placeholder)
- commit db14718
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0784-drm-amdkfd-Update-MQD-management-on-multi-XCC-setup.patch (drm-backport-placeholder)
- commit 98ab10d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0783-drm-amdkfd-Add-spatial-partitioning-support-in-KFD.patch (drm-backport-placeholder)
- commit adb9fbd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0782-drm-amdkfd-Introduce-kfd_node-struct-v5.patch (drm-backport-placeholder)
- commit 7bdb8e7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0781-drm-amdgpu-Add-mode2-reset-logic-for-v13.0.6.patch (drm-backport-placeholder)
- commit c061e2b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0780-drm-amdgpu-Add-some-XCC-programming.patch (drm-backport-placeholder)
- commit 153c952
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0779-drm-amdgpu-add-node_id-to-physical-id-conversion-in-.patch (drm-backport-placeholder)
- commit 4dc5eac
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0778-drm-amdgpu-enable-the-ring-and-IB-test-for-slave-kcq.patch (drm-backport-placeholder)
- commit d2a0da4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0777-drm-amdgpu-support-gc-v9_4_3-ring_test-running-on-al.patch (drm-backport-placeholder)
- commit 478f4ec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0776-drm-amdgpu-fix-vcn-doorbell-range-setting.patch (drm-backport-placeholder)
- commit 65287a7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0775-drm-amdgpu-jpeg-enable-jpeg-doorbell-for-jpeg4.0.3.patch (drm-backport-placeholder)
- commit c663c9d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0774-drm-amdgpu-vcn-enable-vcn-doorbell-for-vcn4.0.3.patch (drm-backport-placeholder)
- commit dfb603e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0773-drm-amdgpu-nbio-update-vcn-doorbell-range.patch (drm-backport-placeholder)
- commit 84f8c05
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0772-drm-amdkfd-Set-F8_MODE-for-gc_v9_4_3.patch (drm-backport-placeholder)
- commit dc36ab3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0771-drm-amdgpu-jpeg-add-multiple-jpeg-rings-support-for-.patch (drm-backport-placeholder)
- commit c60f4eb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0770-drm-amdgpu-jpeg-add-multiple-jpeg-rings-support.patch (drm-backport-placeholder)
- commit 23573e9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0769-drm-amdgpu-vcn-enable-vcn-DPG-mode-for-VCN4_0_3.patch (drm-backport-placeholder)
- commit c26977b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0768-drm-amdgpu-vcn-enable-vcn-pg-for-VCN4_0_3.patch (drm-backport-placeholder)
- commit 2c0fe0f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0767-drm-amdgpu-vcn-enable-vcn-cg-for-VCN4_0_3.patch (drm-backport-placeholder)
- commit 60cf231
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0766-drm-amdgpu-jpeg-enable-jpeg-pg-for-VCN4_0_3.patch (drm-backport-placeholder)
- commit fd73524
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0765-drm-amdgpu-jpeg-enable-jpeg-cg-for-VCN4_0_3.patch (drm-backport-placeholder)
- commit 33472e3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0764-drm-amdgpu-vcn-add-vcn-support-for-VCN4_0_3.patch (drm-backport-placeholder)
- commit da3e8d6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0763-drm-amdgpu-jpeg-add-jpeg-support-for-VCN4_0_3.patch (drm-backport-placeholder)
- commit 538edf2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0762-drm-amdgpu-add-VCN4_0_3-firmware.patch (drm-backport-placeholder)
- commit 350d57a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0761-drm-amdgpu-add-vcn-v4_0_3-ip-headers.patch (drm-backport-placeholder)
- commit 5e7e1c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0760-drm-amdgpu-add-more-macro-to-support-offset-variant.patch (drm-backport-placeholder)
- commit e09ce8e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0759-drm-amdgpu-Use-the-correct-API-to-read-register.patch (drm-backport-placeholder)
- commit a4d51d0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0758-drm-amdgpu-Add-kgd2kfd-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit 6ccaffc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0757-drm-amdgpu-alloc-vm-inv-engines-for-every-vmhub.patch (drm-backport-placeholder)
- commit e7b83d0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0756-drm-amdgpu-override-partition-mode-through-module-pa.patch (drm-backport-placeholder)
- commit 0b663d4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0755-drm-amdgpu-make-the-WREG32_SOC15_xx-macro-to-support.patch (drm-backport-placeholder)
- commit 9eb3140
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0754-drm-amdgpu-add-sysfs-node-for-compute-partition-mode.patch (drm-backport-placeholder)
- commit 4adb759
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0753-drm-amdgpu-assign-different-AMDGPU_GFXHUB-for-rings-.patch (drm-backport-placeholder)
- commit 5fdd485
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0752-drm-amdgpu-init-vmhubs-bitmask-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit a811ae2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0751-drm-amdgpu-add-bitmask-to-iterate-vmhubs.patch (drm-backport-placeholder)
- commit 71dca3c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0750-drm-amdgpu-assign-register-address-for-vmhub-object-.patch (drm-backport-placeholder)
- commit 86ae784
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0749-drm-amdgpu-introduce-vmhub-definition-for-multi-part.patch (drm-backport-placeholder)
- commit 9ca3cef
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0748-drm-amd-display-3.2.236.patch (drm-backport-placeholder)
- commit e26ddf1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Remove-v_startup-workaround-fo.patch (drm-backport-placeholder)
- commit 5db592c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0746-drm-amd-display-Remove-unnecessary-variable.patch (drm-backport-placeholder)
- commit 4726b7e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0745-drm-amd-display-Make-unbounded-req-update-separate-f.patch (drm-backport-placeholder)
- commit b577d48
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0744-drm-amd-display-Add-visual-confirm-color-support-for.patch (drm-backport-placeholder)
- commit b39d682
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-possible-underflow-for-disp.patch (drm-backport-placeholder)
- commit e0fb682
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0742-drm-amd-display-Convert-connector-signal-id-to-strin.patch (drm-backport-placeholder)
- commit 41fdc7f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0741-drm-amd-display-Update-vactive-margin-and-max-vblank.patch (drm-backport-placeholder)
- commit da86e9e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0740-drm-amd-display-Only-skip-update-for-DCFCLK-UCLK-FCL.patch (drm-backport-placeholder)
- commit 1814e8b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0739-drm-amdgpu-improve-wait-logic-at-fence-polling.patch (drm-backport-placeholder)
- commit 82167ad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0738-drm-amd-display-Simplify-the-calculation-of-variable.patch (drm-backport-placeholder)
- commit b6e6688
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Fix-potential-deallocation-of-previo.patch (drm-backport-placeholder)
- commit 1dbeb76
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0736-drm-amd-amdgpu-Fix-warnings-in-amdgpu-_object-_ring..patch (drm-backport-placeholder)
- commit 99b03bf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0735-drm-amdgpu-release-correct-lock-in-amdgpu_gfx_enable.patch (drm-backport-placeholder)
- commit 7cbed1b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0734-drm-amdgpu-display-Enable-DC_FP-for-LoongArch.patch (drm-backport-placeholder)
- commit 604a8ea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0733-drm-amd-display-Promote-DAL-to-3.2.235.patch (drm-backport-placeholder)
- commit c90a872
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0732-drm-amd-display-Block-SubVP-on-displays-that-have-pi.patch (drm-backport-placeholder)
- commit b8d47c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0731-drm-amd-display-Block-SubVP-high-refresh-when-VRR-ac.patch (drm-backport-placeholder)
- commit 453a956
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0730-drm-amd-display-Check-Vactive-for-VRR-active-for-FPO.patch (drm-backport-placeholder)
- commit 53de8d9
* Wed Sep  4 2024 oneukum@suse.com
- media: video-mux: fix error paths (jsc#PED-8643).
- commit ec35a19
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0729-drm-amdgpu-set-default-num_kcq-to-2-under-sriov.patch (drm-backport-placeholder)
- commit a8a24c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-install-stub-fence-into-potential-u.patch (drm-backport-placeholder)
- commit 22d6e05
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0727-drm-amd-display-Show-the-DCN-DCE-version-in-the-log.patch (drm-backport-placeholder)
- commit 3fb0d64
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0726-drm-amdgpu-Remove-the-unused-variable-golden_setting.patch (drm-backport-placeholder)
- commit 3664536
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0725-drm-amdkfd-Don-t-trigger-evictions-unmapping-dmabuf-.patch (drm-backport-placeholder)
- commit 40e7993
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0724-drm-amd-display-Add-additional-pstate-registers-to-H.patch (drm-backport-placeholder)
- commit aa9e8cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0723-drm-amdgpu-remove-unneeded-semicolon.patch (drm-backport-placeholder)
- commit d233171
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0722-drm-amdgpu-do-gfxhub-init-for-all-XCDs.patch (drm-backport-placeholder)
- commit d92925c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0721-drm-amdgpu-unlock-on-error-in-gfx_v9_4_3_kiq_resume.patch (drm-backport-placeholder)
- commit 36152b2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0720-drm-amdgpu-unlock-the-correct-lock-in-amdgpu_gfx_ena.patch (drm-backport-placeholder)
- commit a80db28
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0719-drm-amdgpu-drop-unused-function.patch (drm-backport-placeholder)
- commit 29a9028
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0718-drm-amdgpu-drop-invalid-IP-revision.patch (drm-backport-placeholder)
- commit ffa5ef0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0717-drm-amdgpu-put-MQDs-in-VRAM.patch (drm-backport-placeholder)
- commit a474eb6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0716-drm-amd-amdgpu-Fix-errors-warnings-in-amdgpu-_bios-_.patch (drm-backport-placeholder)
- commit a069103
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0715-drm-amdgpu-gfx11-always-restore-kcq-kgq-MQDs.patch (drm-backport-placeholder)
- commit fc3d99e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0714-drm-amd-display-mark-amdgpu_dm_connector_funcs_force.patch (drm-backport-placeholder)
- commit 86f9445
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0713-drm-amdgpu-gfx10-always-restore-kcq-kgq-MQDs.patch (drm-backport-placeholder)
- commit 04854a4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0712-drm-amdgpu-gfx9-always-restore-kcq-MQDs.patch (drm-backport-placeholder)
- commit 307ea01
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0711-drm-amdgpu-gfx8-always-restore-kcq-MQDs.patch (drm-backport-placeholder)
- commit d70c0cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0710-drm-amdgpu-gfx11-drop-unused-variable.patch (drm-backport-placeholder)
- commit 79eac63
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0709-drm-amdgpu-gfx10-drop-unused-variable.patch (drm-backport-placeholder)
- commit b07455e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0708-drm-amd-Downgrade-message-about-watermarks-table-aft.patch (drm-backport-placeholder)
- commit 2e50b8c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0707-drm-amdgpu-gfx11-use-generic-en-dis-able_kgq-helpers.patch (drm-backport-placeholder)
- commit 8a24c5c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0706-drm-amdgpu-gfx10-use-generic-en-dis-able_kgq-helpers.patch (drm-backport-placeholder)
- commit f687237
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0705-drm-amdgpu-add-en-dis-able_kgq-functions.patch (drm-backport-placeholder)
- commit 08ae580
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0704-drm-amd-display-3.2.234.patch (drm-backport-placeholder)
- commit 4fe3081
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0703-drm-amd-display-FW-Promotion-Release-0.0.165.0.patch (drm-backport-placeholder)
- commit 798802b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0702-drm-amd-display-Add-w-a-to-disable-DP-dual-mode-on-c.patch (drm-backport-placeholder)
- commit e3a52f6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0701-drm-amd-display-revert-Update-scaler-recout-data-for.patch (drm-backport-placeholder)
- commit 6978b3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0700-drm-amd-display-Adding-debug-option-to-override-Z8-w.patch (drm-backport-placeholder)
- commit 7f5a4f0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0699-drm-amd-display-Workaround-wrong-HDR-colorimetry-wit.patch (drm-backport-placeholder)
- commit 15e88df
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0698-drm-amd-display-Add-logging-when-DP-link-training-Ch.patch (drm-backport-placeholder)
- commit 559cb16
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0697-drm-amd-amdgpu-Fix-style-problems-in-amdgpu_psp.c.patch (drm-backport-placeholder)
- commit a3dc8ca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0696-drm-amdgpu-gfx10-drop-old-bring-up-code.patch (drm-backport-placeholder)
- commit 3dee2fe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0695-drm-amdgpu-gfx11-drop-old-bring-up-code.patch (drm-backport-placeholder)
- commit 3c81faf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0694-drm-amdkfd-Optimize-svm-range-map-to-GPU-with-XNACK-.patch (drm-backport-placeholder)
- commit 419718d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0693-drm-amd-display-Add-logging-for-eDP-v1.4-supported-s.patch (drm-backport-placeholder)
- commit 5ce3674
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0692-drm-amd-display-Fix-possible-NULL-dereference-in-dc_.patch (drm-backport-placeholder)
- commit 0152e30
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0691-drm-amd-amdgpu-Fix-style-problems-in-amdgpu_debugfs..patch (drm-backport-placeholder)
- commit 0fc8199
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0690-drm-amdgpu-Enable-mcbp-under-sriov-by-default.patch (drm-backport-placeholder)
- commit dd1fb33
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0689-drm-amdgpu-remove-pasid_src-field-from-IV-entry.patch (drm-backport-placeholder)
- commit 12f524a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0688-drm-amd-amdgpu-Simplify-switch-case-statements-in-am.patch (drm-backport-placeholder)
- commit 28efdad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0687-drm-amdgpu-Add-SDMA_UTCL1_WR_FIFO_SED-field-for-sdma.patch (drm-backport-placeholder)
- commit 5f412cf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0686-drm-amdkfd-Update-KFD-TTM-mem-limit.patch (drm-backport-placeholder)
- commit fbfe7c2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0685-drm-amdgpu-Set-GTT-size-equal-to-TTM-mem-limit.patch (drm-backport-placeholder)
- commit 10f95d5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0684-drm-ttm-Helper-function-to-get-TTM-mem-limit.patch (drm-backport-placeholder)
- commit b42e992
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0683-drm-amdgpu-mark-gfx_v9_4_3_disable_gpa_mode-static.patch (drm-backport-placeholder)
- commit a533fc4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0682-drm-amdgpu-check-correct-allocated-mqd_backup-object.patch (drm-backport-placeholder)
- commit c68f0a5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0681-drm-amdgpu-fix-a-build-warning-by-a-typo-in-amdgpu_g.patch (drm-backport-placeholder)
- commit 5e541a3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0680-drm-amd-display-return-status-of-dmub_srv_get_fw_boo.patch (drm-backport-placeholder)
- commit d0bd3ef
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0679-drm-amd-display-set-variable-custom_backlight_curve0.patch (drm-backport-placeholder)
- commit eb4081c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0678-drm-amd-amdgpu-Fix-style-errors-in-amdgpu_display.c.patch (drm-backport-placeholder)
- commit 1a3d48b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0677-drm-amd-display-DSC-passthrough-is-for-DP-HDMI-pcon-.patch (drm-backport-placeholder)
- commit e4d21f0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0676-drm-amdgpu-add-new-flag-to-AMDGPU_CTX_QUERY2.patch (drm-backport-placeholder)
- commit d74d002
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-a-test-dml32_rq_dlg_get_rq_.patch (drm-backport-placeholder)
- commit 29f8ded
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-a-test-CalculatePrefetchSch.patch (drm-backport-placeholder)
- commit 303b7fb
* Wed Sep  4 2024 oneukum@suse.com
- media: video-mux: Add missing media_entity_cleanup upon async
  register fail (jsc#PED-8643).
- commit 5e42fcf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0673-drm-amd-amdgpu-Fix-missing-bo-unlock-in-failure-path.patch (drm-backport-placeholder)
- commit ed82e81
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0672-drm-amd-display-remove-unused-variables-dispclk_dela.patch (drm-backport-placeholder)
- commit 251f341
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0671-drm-amdgpu-support-psp-vbflash-sysfs-for-MP0-13_0_10.patch (drm-backport-placeholder)
- commit 7f9b05f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amd-display-disable-SubVP-DRR-to-pr.patch (drm-backport-placeholder)
- commit 71d89ae
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0669-drm-amd-display-3.2.233.patch (drm-backport-placeholder)
- commit f4ff806
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Keep-disable-aux-i-delay-as-0.patch (drm-backport-placeholder)
- commit 9dd88b1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0667-drm-amd-display-Query-GECC-enable-for-SubVP-disable.patch (drm-backport-placeholder)
- commit b1d6acf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0666-drm-amd-display-Enable-SubVP-for-high-refresh-rate-d.patch (drm-backport-placeholder)
- commit df74883
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0665-drm-amd-display-For-no-plane-case-set-pstate-support.patch (drm-backport-placeholder)
- commit f24710a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0664-drm-amd-display-Add-p-state-debugging.patch (drm-backport-placeholder)
- commit ed26873
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-update-extended-blank-for-dcn31.patch (drm-backport-placeholder)
- commit cd70c1f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-in-secure-display-context-c.patch (drm-backport-placeholder)
- commit f2e4219
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0661-drm-amd-display-Update-scaler-recout-data-for-visual.patch (drm-backport-placeholder)
- commit ed689aa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0660-drm-amd-display-Program-OTG-vtotal-min-max-selectors.patch (drm-backport-placeholder)
- commit 9ef98ed
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0659-drm-amd-display-add-option-to-use-custom-backlight-c.patch (drm-backport-placeholder)
- commit 89bf91d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0658-drm-amd-display-Enable-SubVP-on-PSR-panels-if-single.patch (drm-backport-placeholder)
- commit 64317a6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-add-pixel-rate-based-CRB-alloca.patch (drm-backport-placeholder)
- commit f2d14f9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Limit-DCN32-8-channel-or-less-p.patch (drm-backport-placeholder)
- commit e3f1766
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0655-drm-amd-display-Restore-rptr-wptr-for-DMCUB-as-worka.patch (drm-backport-placeholder)
- commit eb61288
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0654-drm-amd-display-Update-FW-feature-caps-struct.patch (drm-backport-placeholder)
- commit 6b48753
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0653-drm-amd-display-implement-force-function-in-amdgpu_d.patch (drm-backport-placeholder)
- commit 3781f63
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0652-drm-amd-display-3.2.232.patch (drm-backport-placeholder)
- commit 9edbf50
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0651-drm-amd-display-FW-Promotion-Release-0.0.163.0.patch (drm-backport-placeholder)
- commit 635b45d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0650-drm-amdgpu-add-debugfs-interface-for-reading-MQDs.patch (drm-backport-placeholder)
- commit 6d6dc5c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0649-drm-amdgpu-track-MQD-size-for-gfx-and-compute.patch (drm-backport-placeholder)
- commit 42a3815
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0648-drm-amdgpu-bump-driver-version-number-for-CP-GFX-sha.patch (drm-backport-placeholder)
- commit 7932f91
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0647-drm-amdkfd-Fix-an-issue-at-userptr-buffer-validation.patch (drm-backport-placeholder)
- commit 79d2c20
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Convert-Delaying-Aux-I-Disable-.patch (drm-backport-placeholder)
- commit 40874bf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0645-drm-amd-display-assign-edid_blob_ptr-with-edid-from-.patch (drm-backport-placeholder)
- commit 636cbb2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0644-drm-amdgpu-add-support-for-new-GFX-shadow-size-query.patch (drm-backport-placeholder)
- commit ae7ab2a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0643-drm-amdgpu-add-get_gfx_shadow_info-callback-for-gfx1.patch (drm-backport-placeholder)
- commit 4d76e94
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0642-drm-amdgpu-add-gfx-shadow-callback.patch (drm-backport-placeholder)
- commit 02e31a9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0641-drm-amdgpu-add-UAPI-to-query-GFX-shadow-sizes.patch (drm-backport-placeholder)
- commit 23e0917
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0640-drm-amdgpu-don-t-require-a-job-for-cond_exec-and-sha.patch (drm-backport-placeholder)
- commit b865309
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0639-drm-amdgpu-add-gfx11-emit-shadow-callback.patch (drm-backport-placeholder)
- commit ee3a149
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0638-drm-amdgpu-add-gfx-shadow-CS-IOCTL-support.patch (drm-backport-placeholder)
- commit 42afd79
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0637-drm-amdgpu-UAPI-add-new-CS-chunk-for-GFX-shadow-buff.patch (drm-backport-placeholder)
- commit 88ff018
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0636-drm-amdgpu-gfx11-check-the-CP-FW-version-CP-GFX-shad.patch (drm-backport-placeholder)
- commit 4bc2a6e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-memory-leak-in-mes-self-test.patch (drm-backport-placeholder)
- commit 4302553
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0634-drm-amdgpu-gfx11-add-FW-version-check-for-new-CP-GFX.patch (drm-backport-placeholder)
- commit b229ec0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0633-drm-amd-display-dumb_abm_lcd-avoid-missing-prototype.patch (drm-backport-placeholder)
- commit 4d29082
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0632-drm-amd-display-3.2.231.patch (drm-backport-placeholder)
- commit ba85bbe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0631-drm-amd-display-Add-FAMS-related-definitions-and-doc.patch (drm-backport-placeholder)
- commit 9d4840d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-integer-overflow-in-amdgpu_cs_p.patch (drm-backport-placeholder)
- commit 701c543
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-Fix-integer-overflow-in-radeon_cs_pa.patch (drm-backport-placeholder)
- commit 696af77
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0628-drm-amd-display-Add-FAMS-capability-to-DCN31.patch (drm-backport-placeholder)
- commit dc2b84a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Explicitly-specify-update-type-.patch (drm-backport-placeholder)
- commit 569fd97
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0626-drm-amd-display-fix-dpms_off-issue-when-disabling-bi.patch (drm-backport-placeholder)
- commit 475c3fd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0625-drm-amd-display-update-GSP1-generic-info-packet-for-.patch (drm-backport-placeholder)
- commit 8081bca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0624-drm-amd-display-Adjust-dmub-outbox-notification-enab.patch (drm-backport-placeholder)
- commit 2ba7cd0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0623-drm-amd-display-3-plane-MPO-enablement-for-DCN321.patch (drm-backport-placeholder)
- commit fd2f464
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0622-drm-amd-display-Add-extra-check-for-444-16-format.patch (drm-backport-placeholder)
- commit 8dd5f37
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0621-drm-amd-display-correct-DML-calc-error.patch (drm-backport-placeholder)
- commit c34e16c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0620-drm-amd-display-Limit-nv21-dst_y.patch (drm-backport-placeholder)
- commit 6113c09
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0619-drm-amd-display-Add-check-for-PState-change-in-DCN32.patch (drm-backport-placeholder)
- commit 0a267ca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0618-drm-amd-display-Set-DRAM-clock-if-retraining-is-requ.patch (drm-backport-placeholder)
- commit 16d75e0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0617-drm-amd-display-add-support-for-low-bpc.patch (drm-backport-placeholder)
- commit 705a6d6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0616-drm-amd-amdgpu-Fix-style-issues-in-amdgpu_discovery..patch (drm-backport-placeholder)
- commit b79307f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0615-drm-amd-display-Remove-unused-variables-in-dcn21_hws.patch (drm-backport-placeholder)
- commit 44acec0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0614-drm-amdgpu-allocate-doorbell-index-for-multi-die-cas.patch (drm-backport-placeholder)
- commit 2f64311
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0613-drm-amd-amdgpu-Fix-style-errors-in-amdgpu_drv.c-amdg.patch (drm-backport-placeholder)
- commit e64e71a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0612-drm-amd-amdgpu-Fix-spaces-in-array-indexing-and-inde.patch (drm-backport-placeholder)
- commit 4fd2c3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0611-drm-amdgpu-Drop-pcie_bif-ras-check-from-fatal-error-.patch (drm-backport-placeholder)
- commit 16a9e7c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-calltrace-warning-in-amddrm_bud.patch (drm-backport-placeholder)
- commit b0c6249
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0609-drm-amdgpu-initialize-num_xcd-to-1-for-gfx-v9_0.patch (drm-backport-placeholder)
- commit 5539c8f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0608-drm-amdgpu-add-master-slave-check-in-init-phase.patch (drm-backport-placeholder)
- commit ce10c01
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0607-drm-amd-display-Clear-GPINT1-before-taking-DMCUB-out.patch (drm-backport-placeholder)
- commit 1e497c9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0606-drm-amdgpu-add-xcc-index-argument-to-rlc-safe_mode-f.patch (drm-backport-placeholder)
- commit 985d2b9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0605-drm-amdgpu-add-xcc-index-argument-to-select_sh_se-fu.patch (drm-backport-placeholder)
- commit d0202b9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0604-drm-amdgpu-add-xcc-index-argument-to-gfx-v9_4_3-func.patch (drm-backport-placeholder)
- commit b5e8e32
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0603-drm-amdgpu-add-multi-XCC-initial-support-in-gfx_v9_4.patch (drm-backport-placeholder)
- commit d0c8d91
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0602-drm-amdgpu-add-xcc-index-argument-to-soc15_grbm_sele.patch (drm-backport-placeholder)
- commit 412bc7d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0601-drm-amdgpu-split-gc-v9_4_3-functionality-from-gc-v9_.patch (drm-backport-placeholder)
- commit 11c8946
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0600-drm-amdgpu-add-multi-xcc-support-to-amdgpu_gfx-inter.patch (drm-backport-placeholder)
- commit c84c303
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0599-drm-amdgpu-separate-the-mqd_backup-for-kiq-from-kcq.patch (drm-backport-placeholder)
- commit 4d5326b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0598-drm-amdgpu-move-queue_bitmap-to-an-independent-struc.patch (drm-backport-placeholder)
- commit 7aa2705
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0597-drm-amdgpu-convert-gfx.kiq-to-array-type-v3.patch (drm-backport-placeholder)
- commit a93bbf3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/radeon-avoid-double-free-in-ci_dpm_init.patch (drm-backport-placeholder)
- commit f26dc4b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0595-drm-amd-display-remove-unused-variable-oldest_index.patch (drm-backport-placeholder)
- commit 32506f2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0594-drm-amd-pm-Fix-spelling-mistake-aquire-acquire.patch (drm-backport-placeholder)
- commit b208937
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0593-drm-amdgpu-Add-support-for-querying-the-max-ibs-in-a.patch (drm-backport-placeholder)
- commit 895cab8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0592-drm-amdgpu-Add-a-max-ibs-per-submission-limit.patch (drm-backport-placeholder)
- commit b29a884
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0591-drm-amdgpu-Increase-GFX6-graphics-ring-size.patch (drm-backport-placeholder)
- commit 9f24aef
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Update-DTBCLK-for-DCN32.patch (drm-backport-placeholder)
- commit 1618e6c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-is_timing_changed-prototype.patch (drm-backport-placeholder)
- commit 668dea5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-logging-for-display-MALL-re.patch (drm-backport-placeholder)
- commit 8aa3ed6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0587-drm-amd-display-Write-TEST_EDID_CHECKSUM_WRITE-for-E.patch (drm-backport-placeholder)
- commit 71060df
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0586-drm-amd-display-add-mechanism-to-skip-DCN-init.patch (drm-backport-placeholder)
- commit c1aa7bc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0585-drm-amd-display-add-extra-dc-odm-debug-options.patch (drm-backport-placeholder)
- commit 37849dd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0584-drm-amd-display-FW-Promotion-Release-0.0.162.0.patch (drm-backport-placeholder)
- commit 44c1128
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0583-drm-amd-display-Enable-FPO-Vactive.patch (drm-backport-placeholder)
- commit 4e89cf9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0582-drm-amd-display-Set-watermarks-set-D-equal-to-A.patch (drm-backport-placeholder)
- commit 670738b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0581-drm-amd-display-Correct-output-color-space-during-HW.patch (drm-backport-placeholder)
- commit 66aa6cf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0580-drm-amd-display-DSC-policy-override-when-ODM-combine.patch (drm-backport-placeholder)
- commit 1b15c1b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0579-drm-amd-display-Adding-support-for-VESA-SCR.patch (drm-backport-placeholder)
- commit 03e521a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-FAMS-validation-before-tryi.patch (drm-backport-placeholder)
- commit 3a23a30
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0577-drm-amd-display-drain-dmub-inbox-if-queue-is-full.patch (drm-backport-placeholder)
- commit 109f5c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0576-drm-amd-display-refactor-dmub-commands-into-single-f.patch (drm-backport-placeholder)
- commit f5edadd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0575-drm-amd-display-Only-consider-DISPCLK-when-using-opt.patch (drm-backport-placeholder)
- commit 2661d4e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0574-drm-amd-display-update-max-streams-per-surface.patch (drm-backport-placeholder)
- commit 0714541
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0573-drm-amd-display-Fix-in-disabling-secure-display.patch (drm-backport-placeholder)
- commit 04280d4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0572-drm-amd-display-Block-optimize-on-consecutive-FAMS-e.patch (drm-backport-placeholder)
- commit 4371975
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0571-drm-amd-display-Do-not-set-drr-on-pipe-commit.patch (drm-backport-placeholder)
- commit 5fc8572
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0570-drm-amd-display-Fix-ABM-pipe-backlight-issues-when-c.patch (drm-backport-placeholder)
- commit d73b9c3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0569-drm-amd-display-Check-log-if-receiver-supports-MST-D.patch (drm-backport-placeholder)
- commit 5841f25
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Unconditionally-print-when-DP-s.patch (drm-backport-placeholder)
- commit da1fc6e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0567-drm-amd-display-Refactor-ABM-feature.patch (drm-backport-placeholder)
- commit 6c7e397
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0566-drm-i915-gsc-Fix-error-code-in-intel_gsc_uc_heci_cmd.patch (drm-backport-placeholder)
- commit 8c80e12
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0565-i915-perf-Do-not-add-ggtt-offset-to-hw_tail.patch (drm-backport-placeholder)
- commit 89800fd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0564-i915-perf-Drop-the-aging_tail-logic-in-perf-OA.patch (drm-backport-placeholder)
- commit a1b1baa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0563-drm-i915-Allow-user-to-set-cache-at-BO-creation.patch (drm-backport-placeholder)
- commit 1db498c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0562-drm-i915-guc-Remove-some-obsolete-definitions.patch (drm-backport-placeholder)
- commit 99f9bfb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0561-drm-i915-rename-I915_PMU_MAX_GTS-to-I915_PMU_MAX_GT.patch (drm-backport-placeholder)
- commit a2d7564
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0560-drm-i915-Reduce-I915_MAX_GT-to-2.patch (drm-backport-placeholder)
- commit 1685a76
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0559-drm-i915-Use-the-fdinfo-helper.patch (drm-backport-placeholder)
- commit 71331b7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0558-drm-i915-huc-define-HuC-FW-version-for-MTL.patch (drm-backport-placeholder)
- commit 315292e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0557-drm-i915-mtl-huc-Use-the-media-gt-for-the-HuC-getpar.patch (drm-backport-placeholder)
- commit 7ed07ef
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0556-drm-i915-mtl-huc-auth-HuC-via-GSC.patch (drm-backport-placeholder)
- commit b87e52b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0555-drm-i915-huc-differentiate-the-2-steps-of-the-MTL-Hu.patch (drm-backport-placeholder)
- commit 26787c2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0554-drm-i915-huc-Load-GSC-enabled-HuC-via-DMA-xfer-if-th.patch (drm-backport-placeholder)
- commit f7b533e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0553-drm-i915-huc-Parse-the-GSC-enabled-HuC-binary.patch (drm-backport-placeholder)
- commit fed3759
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0552-drm-i915-uc-perma-pin-firmwares.patch (drm-backport-placeholder)
- commit 567f47f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Add-workaround-14016712196.patch (drm-backport-placeholder)
- commit f023fad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0550-drm-i915-pxp-Fix-size_t-format-specifier-in-gsccs_se.patch (drm-backport-placeholder)
- commit d23a26e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0549-drm-i915-gt-limit-lmem-allocation-size-to-succeed-on.patch (drm-backport-placeholder)
- commit be42e32
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0548-drm-i915-gt-Fix-parameter-in-gmch_ggtt_insert_-entri.patch (drm-backport-placeholder)
- commit f699256
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0547-drm-i915-gt-Fix-second-parameter-type-of-pre-gen8-pt.patch (drm-backport-placeholder)
- commit 602426c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0546-drm-i915-pmu-Make-PMU-sample-array-two-dimensional.patch (drm-backport-placeholder)
- commit 573d353
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0545-drm-i915-pmu-Turn-off-the-timer-to-sample-frequencie.patch (drm-backport-placeholder)
- commit edc8544
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0544-drm-i915-guc-Drop-legacy-CTB-definitions.patch (drm-backport-placeholder)
- commit 1884a34
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0543-drm-i915-guc-Track-all-sent-actions-to-GuC.patch (drm-backport-placeholder)
- commit 71d8506
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0542-drm-i915-guc-Update-log-for-unsolicited-CTB-response.patch (drm-backport-placeholder)
- commit 7e1c8c3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0541-drm-i915-guc-Use-FAST_REQUEST-for-non-blocking-H2G-c.patch (drm-backport-placeholder)
- commit 3e79dbe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0540-drm-i915-gem-Use-large-rings-for-compute-contexts.patch (drm-backport-placeholder)
- commit d6198d3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0539-drm-i915-gsc-use-system-include-style-for-drm-header.patch (drm-backport-placeholder)
- commit efa802a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0538-drm-i915-mtl-Reset-only-one-lane-in-case-of-MFD.patch (drm-backport-placeholder)
- commit a816ccc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0537-drm-i915-Flush-power-delayed-put-when-connector-init.patch (drm-backport-placeholder)
- commit 517633e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0536-drm-i915-Remove-i915_drm_suspend_mode.patch (drm-backport-placeholder)
- commit 6f1d627
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0535-drm-i915_drm.h-fix-a-typo.patch (drm-backport-placeholder)
- commit 63c30ec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0534-drm-i915-display-switch-the-rest-of-the-connectors-t.patch (drm-backport-placeholder)
- commit 4c4ef9d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0533-drm-display-dp_mst-convert-to-struct-drm_edid.patch (drm-backport-placeholder)
- commit d91bb66
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0532-drm-edid-make-drm_edid_duplicate-safe-to-call-with-N.patch (drm-backport-placeholder)
- commit 27d2d43
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0531-drm-i915-lvds-switch-to-drm_edid_read_switcheroo.patch (drm-backport-placeholder)
- commit 7f8dedd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0530-drm-edid-add-drm_edid_read_switcheroo.patch (drm-backport-placeholder)
- commit 85a7154
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0529-drm-i915-sdvo-stop-caching-has_hdmi_audio-in-struct-.patch (drm-backport-placeholder)
- commit 680d3f3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0528-drm-i915-sdvo-stop-caching-has_hdmi_monitor-in-struc.patch (drm-backport-placeholder)
- commit 11bc913
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0527-drm-i915-hdmi-stop-caching-has_hdmi_sink-in-struct-i.patch (drm-backport-placeholder)
- commit 73fc917
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0526-drm-i915-hdmi-stop-caching-has_audio-in-struct-intel.patch (drm-backport-placeholder)
- commit f566550
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0525-drm-i915-dp-stop-caching-has_hdmi_sink-in-struct-int.patch (drm-backport-placeholder)
- commit f04fda2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0524-drm-i915-dp-stop-caching-has_audio-in-struct-intel_d.patch (drm-backport-placeholder)
- commit 36e3068
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0523-drm-display-dp_mst-drop-has_audio-from-struct-drm_dp.patch (drm-backport-placeholder)
- commit 9950b4c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0522-drm-edid-parse-display-info-has_audio-similar-to-is_.patch (drm-backport-placeholder)
- commit 9008723
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0521-drm-i915-use-localized-__diag_ignore_all-instead-of-.patch (drm-backport-placeholder)
- commit da1c4a3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0520-drm-i915-hdcp-Rename-comp_mutex-to-hdcp_mutex.patch (drm-backport-placeholder)
- commit 8b4fd7d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0519-drm-i915-hdcp-Move-away-from-master-naming-to-arbite.patch (drm-backport-placeholder)
- commit 74e4e8a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0518-drm-i915-hdcp-Rename-dev_priv-to-i915.patch (drm-backport-placeholder)
- commit ccf0a3a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0517-drm-i915-Implement-CTM-property-support-for-VLV.patch (drm-backport-placeholder)
- commit 6292e78
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0516-drm-i915-Always-enable-CGM-CSC-on-CHV.patch (drm-backport-placeholder)
- commit db0f1ad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0515-drm-i915-Fix-CHV-CGM-CSC-coefficient-sign-handling.patch (drm-backport-placeholder)
- commit 09ae6a3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0514-drm-i915-Expose-crtc-CTM-property-on-ilk-snb.patch (drm-backport-placeholder)
- commit 52f7b60
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0513-drm-i915-Fix-clang-Wimplicit-fallthrough-in-intel_as.patch (drm-backport-placeholder)
- commit cec0f74
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0512-drm-i915-display-Move-feature-test-macros-to-intel_d.patch (drm-backport-placeholder)
- commit 4f6eba9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0511-drm-i915-display-Handle-GMD_ID-identification-in-dis.patch (drm-backport-placeholder)
- commit e82a572
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0510-drm-i915-display-Make-display-responsible-for-probin.patch (drm-backport-placeholder)
- commit 1e9f86f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0509-drm-i915-display-Move-display-runtime-info-to-displa.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh patches.suse/0510-drm-i915-display-Make-display-responsible-for-probin.patch.
- Refresh patches.suse/0512-drm-i915-display-Move-feature-test-macros-to-intel_d.patch.
- commit 3aed6cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0508-drm-i915-Convert-INTEL_INFO-display-to-a-pointer.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh patches.suse/0509-drm-i915-display-Move-display-runtime-info-to-displa.patch.
- Refresh patches.suse/0510-drm-i915-display-Make-display-responsible-for-probin.patch.
- commit 917a287
* Wed Sep  4 2024 oneukum@suse.com
- media: mc: Make media_entity_get_fwnode_pad() fwnode argument
  const (jsc#PED-8643).
- commit 3898743
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-display-Move-display-device-info-to-he.patch (drm-backport-placeholder)
- commit a7046dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0506-drm-i915-Replace-all-non-returning-strlcpy-with-strs.patch (drm-backport-placeholder)
- commit 0634c00
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0505-drm-i915-Wait-for-active-retire-before-i915_active_f.patch (drm-backport-placeholder)
- commit 2b16f3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0504-drm-i915-Support-Async-Flip-on-Linear-buffers.patch (drm-backport-placeholder)
- commit c84f6f9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0503-drm-i915-constify-pointers-to-hwmon_channel_info.patch (drm-backport-placeholder)
- commit 38a30ec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0502-drm-display-dsc-add-YCbCr-4-2-2-and-4-2-0-RC-paramet.patch (drm-backport-placeholder)
- commit f7e01d0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0501-drm-display-dsc-include-the-rest-of-pre-SCR-paramete.patch (drm-backport-placeholder)
- commit 4de417e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0500-drm-display-dsc-split-DSC-1.2-and-DSC-1.1-pre-SCR-pa.patch (drm-backport-placeholder)
- commit c2c50cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0499-drm-display-dsc-use-flat-array-for-rc_parameters-loo.patch (drm-backport-placeholder)
- commit d38bf5a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0498-drm-i915-dsc-stop-using-interim-structure-for-calcul.patch (drm-backport-placeholder)
- commit 4b4573f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0497-drm-i915-dsc-move-DSC-tables-to-DRM-DSC-helper.patch (drm-backport-placeholder)
- commit f0a816b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0496-drm-i915-dsc-move-rc_buf_thresh-values-to-common-hel.patch (drm-backport-placeholder)
- commit 2cd0696
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0495-drm-i915-dsc-change-DSC-param-tables-to-follow-the-D.patch (drm-backport-placeholder)
- commit 7362c80
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0494-drm-i915-hdmi-C20-computed-PLL-frequencies.patch (drm-backport-placeholder)
- commit c74a4fb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0493-drm-i915-Add-16bit-register-mask-operators.patch (drm-backport-placeholder)
- commit 912a697
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0492-drm-i915-mtl-Fix-expected-reg-value-for-Thunderbolt-.patch (drm-backport-placeholder)
- commit 6304f71
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0491-drm-i915-tweak-language-in-fastset-pipe-config-compa.patch (drm-backport-placeholder)
- commit 85e4df8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0490-drm-i915-fix-intel_display_irq.c-include-order.patch (drm-backport-placeholder)
- commit 49447fc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0489-drm-i915-tc-Reset-TypeC-PHYs-left-enabled-in-DP-alt-.patch (drm-backport-placeholder)
- commit f66f1a4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0488-drm-i915-tc-Call-TypeC-port-flush_work-cleanup-witho.patch (drm-backport-placeholder)
- commit 51959f8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0487-drm-i915-Factor-out-a-helper-for-handling-atomic-mod.patch (drm-backport-placeholder)
- commit b45571b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0486-drm-i915-dp-Factor-out-intel_dp_get_active_pipes.patch (drm-backport-placeholder)
- commit 2438daa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0485-drm-i915-dp-Prevent-link-training-fallback-on-discon.patch (drm-backport-placeholder)
- commit 4f0d9ec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0484-drm-i915-dp-Convert-link-training-error-to-debug-mes.patch (drm-backport-placeholder)
- commit dd0116e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0483-drm-i915-dp-Add-link-training-debug-and-error-printi.patch (drm-backport-placeholder)
- commit 0ef8a76
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0482-drm-i915-Add-support-for-disabling-any-CRTCs-during-.patch (drm-backport-placeholder)
- commit a29ca12
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0481-drm-i915-Factor-out-set_encoder_for_connector.patch (drm-backport-placeholder)
- commit 3b4a528
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0480-drm-i915-Separate-intel_crtc_disable_noatomic_begin-.patch (drm-backport-placeholder)
- commit 4688fa0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0479-drm-i915-Update-connector-atomic-state-before-crtc-s.patch (drm-backport-placeholder)
- commit 56c72b4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0478-drm-i915-Make-the-CRTC-state-consistent-during-sanit.patch (drm-backport-placeholder)
- commit 5e498ed
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0477-drm-i915-Add-helpers-to-reference-unreference-a-DPLL.patch (drm-backport-placeholder)
- commit 93784b4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0476-drm-i915-hdcp-Fill-hdcp2_streamid_type-and-k-in-appr.patch (drm-backport-placeholder)
- commit 489164e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0475-drm-i915-hdcp-Fix-modeset-locking-issue-in-hdcp-mst.patch (drm-backport-placeholder)
- commit 1abd46b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0474-drm-i915-hdcp-Remove-enforce_type0-check-outside-loo.patch (drm-backport-placeholder)
- commit 6abf0c4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0473-drm-i915-hdcp-add-intel_atomic_state-argument-to-hdc.patch (drm-backport-placeholder)
- commit 168232d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0472-drm-i915-irq-split-out-display-irq-handling.patch (drm-backport-placeholder)
- commit 9f7dd1e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0471-drm-i915-irq-split-out-hotplug-irq-handling.patch (drm-backport-placeholder)
- commit c62d73b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0470-drm-i915-irq-convert-gen8_de_irq_handler-to-void.patch (drm-backport-placeholder)
- commit b61c2c2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0469-drm-i915-display-add-i915-parameter-to-I915_STATE_WA.patch (drm-backport-placeholder)
- commit 64687bc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0468-drm-i915-display-remove-I915_STATE_WARN_ON.patch (drm-backport-placeholder)
- commit 2ac69ec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0467-drm-i915-crtc-replace-I915_STATE_WARN_ON-with-I915_S.patch (drm-backport-placeholder)
- commit 1548980
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0466-drm-i915-dpll-drop-a-useless-I915_STATE_WARN_ON.patch (drm-backport-placeholder)
- commit bd71df7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0465-drm-i915-mtl-Add-handling-for-MTL-ccs-modifiers.patch (drm-backport-placeholder)
- commit ee73e9b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0464-drm-fourcc-define-Intel-Meteorlake-related-ccs-modif.patch (drm-backport-placeholder)
- commit c7c5b91
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0463-drm-i915-bios-add-helper-for-reading-SPI.patch (drm-backport-placeholder)
- commit 3a9efa2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0462-drm-i915-gt-drop-dependency-on-VLV_DISPLAY_BASE.patch (drm-backport-placeholder)
- commit 383ad57
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0461-drm-i915-irq-relocate-gmbus-and-dp-aux-irq-handlers.patch (drm-backport-placeholder)
- commit 2bf1e9e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0460-drm-i915-Nuke-intel_bios_is_port_dp_dual_mode.patch (drm-backport-placeholder)
- commit cf88983
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0459-drm-i915-Flip-VBT-DDC-pin-maps-around.patch (drm-backport-placeholder)
- commit 32d8e1a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0458-drm-i915-Split-map_aux_ch-into-per-platform-arrays.patch (drm-backport-placeholder)
- commit e42fc01
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0457-drm-i915-Use-REG_BIT-co.-for-AUX-CH-registers.patch (drm-backport-placeholder)
- commit ef8a960
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0456-drm-i915-Define-more-PS_CTRL-bits.patch (drm-backport-placeholder)
- commit 6fd579a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0455-drm-i915-hdcp-drop-display-prefix-from-include.patch (drm-backport-placeholder)
- commit 347c9fe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0454-drm-i915-Fix-wrong-condition-in-bxt_set_cdclk-for-DG.patch (drm-backport-placeholder)
- commit 8d9f505
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0453-drm-i915-Pick-one-HDMI-port-for-infoframe-audio-tran.patch (drm-backport-placeholder)
- commit 6778452
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0452-drm-i915-Move-has_hdmi_sink-out-from-intel_hdmi_comp.patch (drm-backport-placeholder)
- commit 650a96b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0451-drm-i915-dp-Rearrange-check-for-illegal-mode-and-com.patch (drm-backport-placeholder)
- commit fc50ece
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0450-drm-i915-dp-Add-helper-to-get-sink_format.patch (drm-backport-placeholder)
- commit 16cd0fe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0449-drm-i915-display-Use-sink_format-instead-of-ycbcr420.patch (drm-backport-placeholder)
- commit 5d724e6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0448-drm-i915-dp-Configure-PCON-for-conversion-of-output_.patch (drm-backport-placeholder)
- commit 1787811
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0447-drm-i915-dp-Replace-intel_dp.dfp-members-with-the-ne.patch (drm-backport-placeholder)
- commit fdd795e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0446-drm-i915-display-Add-new-member-to-configure-PCON-co.patch (drm-backport-placeholder)
- commit 306b689
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0445-drm-i915-Communicate-display-power-demands-to-pcode.patch (drm-backport-placeholder)
- commit b956cb5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0444-drm-i915-Use-REG_BIT-co.-for-pipe-scaler-registers.patch (drm-backport-placeholder)
- commit 4b5cb25
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0443-drm-i915-Define-bitmasks-for-skl-scaler-window-pos-s.patch (drm-backport-placeholder)
- commit eacbc26
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0442-drm-i915-s-PS_COEE_INDEX_AUTO_INC-PS_COEF_INDEX_AUTO.patch (drm-backport-placeholder)
- commit ec1da7d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0441-drm-i915-Rename-skl-scaler-binding-bits.patch (drm-backport-placeholder)
- commit 0fd43d0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0440-drm-i915-Remove-dead-scaler-register-defines.patch (drm-backport-placeholder)
- commit 3f2b7f9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0439-drm-i915-Define-bitmasks-for-ilk-pfit-window-pos-siz.patch (drm-backport-placeholder)
- commit 24fe9df
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0438-drm-i915-display-dp-128-132b-LT-requirement.patch (drm-backport-placeholder)
- commit 8b09d5f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0437-drm-i915-mtl-Enable-TC-ports.patch (drm-backport-placeholder)
- commit ceb4661
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0436-drm-i915-mtl-Pin-assignment-for-TypeC.patch (drm-backport-placeholder)
- commit d5308ea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0435-drm-i915-mtl-TypeC-HPD-live-status-query.patch (drm-backport-placeholder)
- commit 1f1a058
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0434-drm-i915-mtl-Power-up-TCSS.patch (drm-backport-placeholder)
- commit c4e98a9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0433-drm-i915-mtl-Define-mask-for-DDI-AUX-interrupts.patch (drm-backport-placeholder)
- commit 4000340
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0432-drm-i915-mtl-Readout-Thunderbolt-HW-state.patch (drm-backport-placeholder)
- commit d86dbf5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0431-drm-i915-mtl-Enabling-disabling-sequence-Thunderbolt.patch (drm-backport-placeholder)
- commit 0f7ce27
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0430-drm-i915-mtl-For-DP2.0-10G-and-20G-rates-use-MPLLA.patch (drm-backport-placeholder)
- commit acd87d5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0429-drm-i915-mtl-Add-voltage-swing-sequence-for-C20.patch (drm-backport-placeholder)
- commit efcca6a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0428-drm-i915-mtl-C20-port-clock-calculation.patch (drm-backport-placeholder)
- commit fcc9e2a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0427-drm-i915-mtl-Dump-C20-pll-hw-state.patch (drm-backport-placeholder)
- commit 5571b32
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0426-drm-i915-mtl-C20-HW-readout.patch (drm-backport-placeholder)
- commit 54605f5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0425-drm-i915-mtl-C20-PLL-programming.patch (drm-backport-placeholder)
- commit 59d222c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0424-drm-i915-display-Increase-AUX-timeout-for-Type-C.patch (drm-backport-placeholder)
- commit fdf73e6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0423-drm-i915-adlp-Disable-DC5-6-states-for-TC-port-DDI-A.patch (drm-backport-placeholder)
- commit 543653e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0422-drm-i915-mtl-Skip-pcode-qgv-restrictions-for-MTL.patch (drm-backport-placeholder)
- commit 2d6433a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0421-drm-i915-Initialize-dkl_phy-spin-lock-from-display-c.patch (drm-backport-placeholder)
- commit ac0463f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0420-drm-i915-psr-Sprinkle-cpu_transcoder-variables-aroun.patch (drm-backport-placeholder)
- commit ae9c741
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0419-drm-i915-psr-Include-PSR_PERF_CNT-in-debugfs-output-.patch (drm-backport-placeholder)
- commit 2b7ed1b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0418-drm-i915-psr-Add-a-FIXME-for-the-PSR-vs.-AUX-usage-c.patch (drm-backport-placeholder)
- commit 2c0d70d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0417-drm-i915-psr-Define-more-PSR-mask-bits.patch (drm-backport-placeholder)
- commit 545db46
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0416-drm-i915-psr-Use-intel_de_rmw.patch (drm-backport-placeholder)
- commit 41459b7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0415-drm-i915-psr-Clean-up-PSR-register-defininitions.patch (drm-backport-placeholder)
- commit 8d1ff7a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0414-drm-i915-Clean-up-various-display-chicken-registers.patch (drm-backport-placeholder)
- commit 30ddf2f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0413-drm-i915-Fix-up-whitespace-in-some-display-chicken-r.patch (drm-backport-placeholder)
- commit 543e9c4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0412-drm-i915-Drop-a-useless-forward-declararion.patch (drm-backport-placeholder)
- commit b090003
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0411-drm-i915-Use-REG_BIT-co.-for-ilk-pfit-registers.patch (drm-backport-placeholder)
- commit 7ee1797
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0410-drm-i915-Namespace-pfit-registers-properly.patch (drm-backport-placeholder)
- commit 3fa5021
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0409-drm-i915-Use-REG_BIT-co-for-the-pre-ilk-pfit-registe.patch (drm-backport-placeholder)
- commit 9fd2f9e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0408-drm-i915-Relocate-skl_get_pfit_config.patch (drm-backport-placeholder)
- commit 8f8ac92
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0407-drm-i915-Relocate-intel_atomic_setup_scalers.patch (drm-backport-placeholder)
- commit e1c7b8d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0406-drm-i915-Relocate-VBLANK_EVASION_TIME_US.patch (drm-backport-placeholder)
- commit 542325a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0405-drm-i915-display-throw-out-struct-intel_load_detect_.patch (drm-backport-placeholder)
- commit 2e78fda
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0404-drm-i915-display-split-out-load-detect-to-a-separate.patch (drm-backport-placeholder)
- commit c2a578e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0403-drm-i915-wm-remove-stale-and-unused-ilk_wm_max_level.patch (drm-backport-placeholder)
- commit b12088a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0402-drm-i915-mtl-Re-use-ADL-P-s-DC-off-power-well.patch (drm-backport-placeholder)
- commit 97a1427
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0401-drm-i915-Use-separate-DC-off-power-well-for-ADL-P-an.patch (drm-backport-placeholder)
- commit 954900d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0400-drm-i915-use-explicit-includes-for-i915_reg.h-and-i9.patch (drm-backport-placeholder)
- commit 6dc8c82
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0399-drm-i915-Reuse-platform-_hotplug_mask-in-.hpd_detect.patch (drm-backport-placeholder)
- commit 7f89496
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0398-drm-i915-Check-HPD-live-state-during-eDP-probe.patch (drm-backport-placeholder)
- commit 4f51a5c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0397-drm-i915-Introduce-intel_hpd_enable_detection.patch (drm-backport-placeholder)
- commit d6411b5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0396-drm-i915-Introduce-platform-_hotplug_mask.patch (drm-backport-placeholder)
- commit 792581c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0395-drm-i915-pps-use-intel_de_rmw-for-panel-unlock.patch (drm-backport-placeholder)
- commit 33bf5bc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0394-drm-i915-display-add-intel_display_driver_early_prob.patch (drm-backport-placeholder)
- commit 7a83435
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0393-drm-i915-display-rename-intel_display_driver_suspend.patch (drm-backport-placeholder)
- commit 9286d19
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0392-drm-i915-display-move-display-suspend-resume-to-inte.patch (drm-backport-placeholder)
- commit 362aa2b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0391-drm-i915-display-add-intel_display_reset.-ch.patch (drm-backport-placeholder)
- commit e2d1e0f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0390-drm-i915-display-rename-intel_display_driver_-functi.patch (drm-backport-placeholder)
- commit fba5209
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0389-drm-i915-display-move-modeset-probe-remove-functions.patch (drm-backport-placeholder)
- commit 03f28b0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0388-drm-i915-display-rename-intel_modeset_probe_defer-in.patch (drm-backport-placeholder)
- commit 683a200
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0387-drm-i915-display-move-intel_modeset_probe_defer-to-i.patch (drm-backport-placeholder)
- commit a3f8551
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0386-drm-i915-display-start-high-level-display-driver-fil.patch (drm-backport-placeholder)
- commit ab5a58d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0385-drm-i915-display-remove-intel_display_commit_duplica.patch (drm-backport-placeholder)
- commit d61417a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0384-drm-i915-Make-intel_-mpllb-c10pll-_state_verify-safe.patch (drm-backport-placeholder)
- commit 525813a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0383-drm-i915-mtl-Initial-DDI-port-setup.patch (drm-backport-placeholder)
- commit c2e9deb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0382-drm-i915-display-mtl-Fill-port-width-in-DDI_BUF_-TRA.patch (drm-backport-placeholder)
- commit 82bb461
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0381-drm-i915-mtl-Add-C10-phy-programming-for-HDMI.patch (drm-backport-placeholder)
- commit 66dc482
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0380-drm-i915-mtl-display-Implement-DisplayPort-sequences.patch (drm-backport-placeholder)
- commit 28a56c5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0379-drm-i915-mtl-MTL-PICA-hotplug-detection.patch (drm-backport-placeholder)
- commit 26d6e2e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0378-drm-i915-mtl-Add-vswing-programming-for-C10-phys.patch (drm-backport-placeholder)
- commit ce21ce2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0377-drm-i915-mtl-Add-Support-for-C10-PHY-message-bus-and.patch (drm-backport-placeholder)
- commit 4e00cc5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0376-drm-i915-mtl-Create-separate-reg-file-for-PICA-regis.patch (drm-backport-placeholder)
- commit e9d594c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0375-drm-i915-mtl-Add-DP-rates.patch (drm-backport-placeholder)
- commit 86b9fb2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-hide-mkwrite_device_info-better.patch (drm-backport-placeholder)
- commit 9ba051d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0373-drm-i915-debugfs-New-debugfs-for-display-clock-frequ.patch (drm-backport-placeholder)
- commit df62e85
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0372-drm-i915-Use-min-instead-of-hand-rolling-it.patch (drm-backport-placeholder)
- commit 4683c62
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0371-drm-i915-Evade-transcoder-s-vblank-when-doing-seamle.patch (drm-backport-placeholder)
- commit 707dd60
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0370-drm-i915-Allow-arbitrary-refresh-rates-with-VRR-eDP-.patch (drm-backport-placeholder)
- commit 4b6446a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0369-drm-i915-Flag-purely-internal-commits-to-not-clear-c.patch (drm-backport-placeholder)
- commit 597ea77
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0368-drm-i915-vrr-Allow-VRR-to-be-toggled-during-fastsets.patch (drm-backport-placeholder)
- commit 0662cb3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0367-drm-i915-vrr-Relocate-VRR-enable-disable.patch (drm-backport-placeholder)
- commit 0e2109d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0366-drm-i915-vrr-Tell-intel_crtc_update_active_timings-a.patch (drm-backport-placeholder)
- commit 1a4dab3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0365-drm-i915-vrr-Make-delayed-vblank-operational-in-VRR-.patch (drm-backport-placeholder)
- commit b0e43cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0364-drm-i915-vrr-Eliminate-redundant-function-arguments.patch (drm-backport-placeholder)
- commit 56b4237
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0363-drm-i915-Generalize-planes_-enabling-disabling.patch (drm-backport-placeholder)
- commit 9ec16f4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0362-drm-i915-display-remove-unnecessary-i915_debugfs.h-i.patch (drm-backport-placeholder)
- commit f7d29a5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0361-drm-i915-Hook-up-csc-into-state-checker.patch (drm-backport-placeholder)
- commit 9a65dc9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0360-drm-i915-Include-the-csc-matrices-in-the-crtc-state-.patch (drm-backport-placeholder)
- commit 4bbce93
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0359-drm-i915-Implement-chv-cgm-csc-readout.patch (drm-backport-placeholder)
- commit dfac395
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0358-drm-i915-Add-hardware-csc-readout-for-ilk.patch (drm-backport-placeholder)
- commit 43302b3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0357-drm-i915-Sprinke-a-few-sanity-check-WARNS-during-csc.patch (drm-backport-placeholder)
- commit a584b5d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0356-drm-i915-Utilize-crtc_state-csc-on-chv.patch (drm-backport-placeholder)
- commit 6e226cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0355-drm-i915-Store-ilk-csc-matrices-in-the-crtc-state.patch (drm-backport-placeholder)
- commit 3867796
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0354-drm-i915-Start-using-struct-intel_csc_matrix-for-chv.patch (drm-backport-placeholder)
- commit 9a43dcc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0353-drm-i915-Split-chv_load_cgm_csc-into-pieces.patch (drm-backport-placeholder)
- commit c797016
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0352-drm-i915-Introduce-intel_csc_matrix-struct.patch (drm-backport-placeholder)
- commit aaa81f1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-limited-range-csc-matrix.patch (drm-backport-placeholder)
- commit 4b20613
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0350-drm-panel-simple-add-support-for-Rocktech-RK043FN48H.patch (drm-backport-placeholder)
- commit 48987cd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0349-drm-bridge-imx-turn-imx8-qm-qxp-ldb-into-single-obje.patch (drm-backport-placeholder)
- commit bd824b0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0348-drm-bridge-imx-fix-mixed-module-builtin-object.patch (drm-backport-placeholder)
- commit b7dfe9e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0347-drm-virtio-Wait-for-each-dma-fence-of-in-fence-array.patch (drm-backport-placeholder)
- commit eb05b01
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0346-drm-virtio-Refactor-and-optimize-job-submission-code.patch (drm-backport-placeholder)
- commit f65e2fb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0345-drm-meson-venc-include-linux-bitfield.h.patch (drm-backport-placeholder)
- commit 1eacba9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0344-drm-meson-Remove-unneeded-semicolon.patch (drm-backport-placeholder)
- commit 2e7fd5d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0343-drm-panel-Support-for-Starry-ili9882t-TDDI-MIPI-DSI-.patch (drm-backport-placeholder)
- commit af827a1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0342-drm-panel-Support-for-Starry-himax83102-j02-TDDI-MIP.patch (drm-backport-placeholder)
- commit e5ee736
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0341-drm-panel-khadas-ts050-update-timings-to-achieve-60H.patch (drm-backport-placeholder)
- commit 11acf3a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0340-drm-meson-add-support-for-MIPI-DSI-transceiver.patch (drm-backport-placeholder)
- commit 1286a3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0339-drm-meson-add-DSI-encoder.patch (drm-backport-placeholder)
- commit b7bf7c4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0338-drm-meson-venc-add-ENCL-encoder-setup-for-MIPI-DSI-o.patch (drm-backport-placeholder)
- commit f00380c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0337-drm-meson-only-use-components-with-dw-hdmi.patch (drm-backport-placeholder)
- commit 29e715f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0336-drm-meson-fix-unbind-path-if-HDMI-fails-to-bind.patch (drm-backport-placeholder)
- commit 3ee3967
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0335-drm-bridge-tc358762-Add-reset-GPIO-support.patch (drm-backport-placeholder)
- commit 294d28b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0334-accel-habanalabs-add-description-to-several-info-ioc.patch (drm-backport-placeholder)
- commit af67b06
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0333-drm-Place-Renesas-drivers-in-a-separate-dir.patch (drm-backport-placeholder)
- commit 3049d5d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-rcar-du-remove-R-Car-H3-ES1.-workarounds.patch (drm-backport-placeholder)
- commit 2242fad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0331-drm-i915-Implement-dedicated-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 539b360
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0330-drm-fbdev-generic-Implement-dedicated-fbdev-I-O-help.patch (drm-backport-placeholder)
- commit 8dde108
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0329-drm-msm-Use-regular-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 313e059
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0328-drm-fb-helper-Export-helpers-for-marking-damage-area.patch (drm-backport-placeholder)
- commit 9a00bd1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0327-drm-tegra-Use-regular-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit ed3901c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0326-drm-omapdrm-Use-regular-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 7e21c3f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0325-drm-fbdev-dma-Use-regular-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 1701450
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0324-drm-radeon-Use-regular-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 2056867
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0323-drm-gma500-Use-regular-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit d6c49da
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0322-drm-exynos-Use-regular-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 73d9657
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0321-drm-armada-Use-regular-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 4ce7aec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0320-fbdev-Add-initializer-macros-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit ff37955
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0319-fbdev-Add-Kconfig-options-to-select-different-fb_ops.patch (drm-backport-placeholder)
- commit 3e07f39
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0318-drm-i915-mtl-end-support-for-set-caching-ioctl.patch (drm-backport-placeholder)
- commit 1c01dd7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0317-drm-i915-pmu-Export-counters-from-all-tiles.patch (drm-backport-placeholder)
- commit b7f9e2c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0316-drm-i915-pmu-Prepare-for-multi-tile-non-engine-count.patch (drm-backport-placeholder)
- commit d22d638
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0315-drm-i915-pmu-Add-reference-counting-to-the-sampling-.patch (drm-backport-placeholder)
- commit 6035c61
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0314-drm-i915-pmu-Transform-PMU-parking-code-to-be-GT-bas.patch (drm-backport-placeholder)
- commit 5e7b8de
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0313-drm-i915-pmu-Skip-sampling-engines-with-no-enabled-c.patch (drm-backport-placeholder)
- commit fe2930d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0312-drm-i915-pmu-Support-PMU-for-all-engines.patch (drm-backport-placeholder)
- commit edd5b62
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0311-drm-i915-pmu-Change-bitmask-of-enabled-events-to-u32.patch (drm-backport-placeholder)
- commit 6892b94
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0310-drm-i915-Fix-memory-leaks-in-function-live_nop_switc.patch (drm-backport-placeholder)
- commit acaaa0d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0309-drm-i915-mtl-Extend-Wa_16014892111-to-MTL-A-step.patch (drm-backport-placeholder)
- commit 587ea1a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0308-drm-i915-mtl-Add-MTL-performance-tuning-changes.patch (drm-backport-placeholder)
- commit 5c42cf0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0307-drm-i915-mtl-do-not-enable-render-power-gating-on-MT.patch (drm-backport-placeholder)
- commit 4ba2a7c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0306-drm-i915-guc-slpc-Disable-rps_boost-debugfs.patch (drm-backport-placeholder)
- commit a44e71f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0305-drm-i915-guc-Dump-error-capture-to-dmesg-on-CTB-erro.patch (drm-backport-placeholder)
- commit 18e8685
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0304-drm-i915-Dump-error-capture-to-kernel-log.patch (drm-backport-placeholder)
- commit 2a43a71
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0303-drm-i915-hwmon-Silence-UBSAN-uninitialized-bool-vari.patch (drm-backport-placeholder)
- commit 3b2d2d6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0302-drm-i915-guc-Fix-confused-register-capture-list-crea.patch (drm-backport-placeholder)
- commit 3412bf2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0301-drm-i1915-guc-Fix-probe-injection-CI-failures-after-.patch (drm-backport-placeholder)
- commit 248ad31
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0300-drm-i915-pxp-Enable-PXP-with-MTL-GSC-CS.patch (drm-backport-placeholder)
- commit 71b3fdd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0299-drm-i915-pxp-On-MTL-KCR-enabling-doesn-t-wait-on-tee.patch (drm-backport-placeholder)
- commit d77a16d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0298-drm-i915-uapi-pxp-Add-a-GET_PARAM-for-PXP.patch (drm-backport-placeholder)
- commit 8b2ca1a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0297-drm-i915-pxp-Add-ARB-session-creation-and-cleanup.patch (drm-backport-placeholder)
- commit f51b83d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0296-drm-i915-pxp-Add-GSC-CS-backend-to-send-GSC-fw-messa.patch (drm-backport-placeholder)
- commit c057a5e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0295-drm-i915-pxp-Add-MTL-helpers-to-submit-Heci-Cmd-Pack.patch (drm-backport-placeholder)
- commit 4da4214
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0294-drm-i915-pxp-Add-MTL-hw-plumbing-enabling-for-KCR-op.patch (drm-backport-placeholder)
- commit 1cc6ca7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0293-drm-i915-pxp-Add-GSC-CS-back-end-resource-init-and-c.patch (drm-backport-placeholder)
- commit d5c361d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0292-drm-i915-use-pat_index-instead-of-cache_level.patch (drm-backport-placeholder)
- commit 8af4209
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0291-drm-i915-preparation-for-using-PAT-index.patch (drm-backport-placeholder)
- commit 2451dba
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0290-drm-i915-mtl-Fix-the-wa-number-for-Wa_22016670082.patch (drm-backport-placeholder)
- commit 5ea2134
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0289-drm-i915-mtl-Add-MTL-for-remapping-CCS-FBs.patch (drm-backport-placeholder)
- commit ecd7a45
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0288-drm-i915-mtl-Drop-FLAT-CCS-check.patch (drm-backport-placeholder)
- commit 58f3016
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0287-drm-i915-uc-Make-unexpected-firmware-versions-an-err.patch (drm-backport-placeholder)
- commit 3b9cc06
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0286-drm-i915-uc-Reject-duplicate-entries-in-firmware-tab.patch (drm-backport-placeholder)
- commit d6e062b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0285-drm-i915-uc-Enhancements-to-firmware-table-validatio.patch (drm-backport-placeholder)
- commit 9335913
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0284-drm-i915-guc-Print-status-register-when-waiting-for-.patch (drm-backport-placeholder)
- commit bc8eb03
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0283-drm-i915-guc-Decode-another-GuC-load-failure-case.patch (drm-backport-placeholder)
- commit 067abb1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0282-drm-i915-mtl-Define-GuC-firmware-version-for-MTL.patch (drm-backport-placeholder)
- commit 1358a57
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0281-drm-i915-uc-Track-patch-level-versions-on-reduced-ve.patch (drm-backport-placeholder)
- commit e117a23
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0280-drm-i915-use-kernel-doc-Werror-when-CONFIG_DRM_I915_.patch (drm-backport-placeholder)
- commit eeb2a63
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0279-drm-i915-ttm-fix-i915_ttm_to_gem-kernel-doc.patch (drm-backport-placeholder)
- commit b609496
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0278-drm-i915-scatterlist-fix-kernel-doc.patch (drm-backport-placeholder)
- commit 5ee48c5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0277-drm-i915-gem-fix-function-pointer-member-kernel-doc.patch (drm-backport-placeholder)
- commit 71a2695
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0276-drm-i915-vma-fix-struct-i915_vma_bindinfo-kernel-doc.patch (drm-backport-placeholder)
- commit 57ed420
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0275-drm-i915-gsc-add-support-for-GSC-proxy-interrupt.patch (drm-backport-placeholder)
- commit 2c98a55
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0274-drm-i915-gsc-add-initial-support-for-GSC-proxy.patch (drm-backport-placeholder)
- commit 34338b9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0273-mei-gsc_proxy-add-gsc-proxy-driver.patch (drm-backport-placeholder)
- commit f92182f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0272-drm-i915-mtl-Define-GSC-Proxy-component-interface.patch (drm-backport-placeholder)
- commit a9583a1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0271-drm-i915-scatterlist-fix-kernel-doc-parameter-docume.patch (drm-backport-placeholder)
- commit a29553c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0270-drm-i915-pxp-fix-kernel-doc-for-member-dev_link.patch (drm-backport-placeholder)
- commit 0d18177
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0269-drm-i915-pmu-drop-kernel-doc.patch (drm-backport-placeholder)
- commit 96044b5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0268-drm-i915-active-fix-kernel-doc-for-function-paramete.patch (drm-backport-placeholder)
- commit f1e2947
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0267-drm-i915-guc-add-intel_guc_state_capture-member-docs.patch (drm-backport-placeholder)
- commit 1639221
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0266-drm-i915-guc-drop-lots-of-kernel-doc-markers.patch (drm-backport-placeholder)
- commit 91ebbd9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0265-drm-i915-guc-add-dbgfs_node-member-kernel-doc.patch (drm-backport-placeholder)
- commit 368de47
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0264-drm-i915-engine-hide-preempt_hang-selftest-member-fr.patch (drm-backport-placeholder)
- commit 5090b5a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0263-drm-i915-gtt-fix-i915_vm_resv_put-kernel-doc-paramet.patch (drm-backport-placeholder)
- commit 6f7a359
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0262-drm-i915-context-fix-kernel-doc-parameter-descriptio.patch (drm-backport-placeholder)
- commit 98640c6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0261-drm-i915-engine-fix-kernel-doc-function-name-for-int.patch (drm-backport-placeholder)
- commit 8aad4b8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0260-drm-i915-gem-fix-i915_gem_object_lookup_rcu-kernel-d.patch (drm-backport-placeholder)
- commit aa96852
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0259-drm-i915-request-drop-kernel-doc.patch (drm-backport-placeholder)
- commit aeffcd5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0258-drm-i915-error-fix-i915_capture_error_state-kernel-d.patch (drm-backport-placeholder)
- commit 4303b65
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0257-drm-i915-perf-fix-i915_perf_ioctl_version-kernel-doc.patch (drm-backport-placeholder)
- commit c2ca975
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0256-drm-i915-vma-document-struct-i915_vma_resource-waker.patch (drm-backport-placeholder)
- commit c86d5ab
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0255-drm-i915-utils-drop-kernel-doc-from-__wait_for.patch (drm-backport-placeholder)
- commit 045d1ec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0254-drm-i915-vma-fix-kernel-doc-function-name-for-i915_v.patch (drm-backport-placeholder)
- commit 478ec1a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0253-drm-i915-gvt-fix-intel_vgpu_alloc_resource-kernel-do.patch (drm-backport-placeholder)
- commit 5061709
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0252-drm-i915-guc-Fix-error-capture-for-virtual-engines.patch (drm-backport-placeholder)
- commit b9430fd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0251-drm-i915-guc-Capture-list-naming-clean-up.patch (drm-backport-placeholder)
- commit f6fe97d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0250-drm-i915-guc-Consolidate-duplicated-capture-list-cod.patch (drm-backport-placeholder)
- commit d0eed3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0249-drm-i915-selftests-Use-gt_err-for-GT-info.patch (drm-backport-placeholder)
- commit bbd86b3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0248-drm-i915-gt-Use-gt_err-for-GT-info.patch (drm-backport-placeholder)
- commit 5822b14
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0247-drm-i915-fdinfo-Enable-fdinfo-for-GuC-backends.patch (drm-backport-placeholder)
- commit bf71ea6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0246-i915-pmu-Add-support-for-total-context-runtime-for-G.patch (drm-backport-placeholder)
- commit 0c9eed3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0245-drm-i915-rc6-throw-out-set-wrapper.patch (drm-backport-placeholder)
- commit 86d5331
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0244-drm-i915-selftest-Update-the-SLPC-selftest.patch (drm-backport-placeholder)
- commit bc50b0c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-guc-slpc-Provide-sysfs-for-efficient-f.patch (drm-backport-placeholder)
- commit db2634f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0242-drm-i915-Use-correct-huge-page-manager-for-MTL.patch (drm-backport-placeholder)
- commit 4ff9b15
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0241-drm-i915-Migrate-platform-dependent-mock-hugepage-se.patch (drm-backport-placeholder)
- commit 02fddd5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0240-drm-i915-mtl-Implement-Wa_14019141245.patch (drm-backport-placeholder)
- commit cebb650
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0239-drm-i915-hwmon-Block-waiting-for-GuC-reset-to-comple.patch (drm-backport-placeholder)
- commit 8232e10
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0238-drm-i915-guc-Disable-PL1-power-limit-when-loading-Gu.patch (drm-backport-placeholder)
- commit 730ad22
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0237-drm-i915-hwmon-Get-mutex-and-rpm-ref-just-once-in-hw.patch (drm-backport-placeholder)
- commit 27af82b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0236-drm-i915-mtl-Add-workaround-14018778641.patch (drm-backport-placeholder)
- commit 4d81199
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0235-drm-i915-selftest-Record-GT-error-for-gt-failure.patch (drm-backport-placeholder)
- commit ceeda84
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0234-drm-i915-mtl-workaround-coherency-issue-for-Media.patch (drm-backport-placeholder)
- commit d63c2a3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0233-drm-i915-mtl-Add-PTE-encode-function.patch (drm-backport-placeholder)
- commit a33f560
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0232-drm-i915-i915_drv-Use-i915-instead-of-dev_priv-insie.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh patches.suse/0508-drm-i915-Convert-INTEL_INFO-display-to-a-pointer.patch.
- Refresh patches.suse/0512-drm-i915-display-Move-feature-test-macros-to-intel_d.patch.
- commit 66a3300
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0231-drm-i915-i915_drv-Use-proper-parameter-naming-in-for.patch (drm-backport-placeholder)
- commit 8478a67
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0230-drm-i915-mtl-fix-mocs-selftest.patch (drm-backport-placeholder)
- commit 66b66d3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0229-drm-i915-mtl-Define-MOCS-and-PAT-tables-for-MTL.patch (drm-backport-placeholder)
- commit e6ca94f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0228-drm-i915-mtl-Set-has_llc-0.patch (drm-backport-placeholder)
- commit baace4a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0227-drm-i915-mtl-WA-to-clear-RDOP-clock-gating.patch (drm-backport-placeholder)
- commit cc24f84
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0226-drm-i915-mtl-Extend-Wa_22011802037-to-MTL-A-step.patch (drm-backport-placeholder)
- commit b387722
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0225-drm-i915-selftests-Consider-multi-gt-instead-of-to_g.patch (drm-backport-placeholder)
- commit cab2435
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0224-drm-i915-gem-Consider-multi-gt-instead-of-to_gt.patch (drm-backport-placeholder)
- commit d22d40d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0223-drm-i915-gt-Consider-multi-gt-instead-of-to_gt.patch (drm-backport-placeholder)
- commit 2b019d3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0222-drm-i915-Make-IRQ-reset-and-postinstall-multi-gt-awa.patch (drm-backport-placeholder)
- commit f862545
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0221-drm-i915-mtl-Disable-stolen-memory-backed-FB-for-A0.patch (drm-backport-placeholder)
- commit 1a9293d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0220-drm-i915-display-Implement-fb_mmap-callback-function.patch (drm-backport-placeholder)
- commit b661903
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0219-drm-i915-display-Add-helper-func-to-get-intel_fbdev-.patch (drm-backport-placeholder)
- commit 6237c25
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0218-drm-i915-Add-a-function-to-mmap-framebuffer-obj.patch (drm-backport-placeholder)
- commit 5390791
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0217-drm-i915-display-Set-I915_BO_ALLOC_USER-for-fb.patch (drm-backport-placeholder)
- commit ff47690
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0216-drm-i915-ttm-Add-I915_BO_PREALLOC.patch (drm-backport-placeholder)
- commit aab57a6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0215-drm-ttm-Remove-redundant-code-in-ttm_tt_init_fields.patch (drm-backport-placeholder)
- commit e6472a8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0214-drm-bridge-display-connector-handle-hdmi-pwr-supply.patch (drm-backport-placeholder)
- commit 8b17b37
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0213-drm-bridge-display-connector-rename-dp_pwr-to-connec.patch (drm-backport-placeholder)
- commit f46a02d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0212-drm-panel-edp-Convert-to-platform-remove-callback-re.patch (drm-backport-placeholder)
- commit 07de373
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0211-drm-Switch-i2c-drivers-back-to-use-.probe.patch (drm-backport-placeholder)
- commit 058e5d7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0210-drm-lcdif-Add-i.MX93-LCDIF-compatible-string.patch (drm-backport-placeholder)
- commit bd84418
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0209-drm-lcdif-Add-multiple-encoders-and-first-bridges-su.patch (drm-backport-placeholder)
- commit 64d7d76
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0208-drm-lcdif-Check-consistent-bus-format-and-flags-acro.patch (drm-backport-placeholder)
- commit 0a087e7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0207-drm-lcdif-Determine-bus-format-and-flags-in-atomic_c.patch (drm-backport-placeholder)
- commit 8048e4e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0206-drm-lcdif-Drop-unnecessary-NULL-pointer-check-on-lcd.patch (drm-backport-placeholder)
- commit dcf6c5c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-stm-ltdc-fix-late-dereference-check.patch (drm-backport-placeholder)
- commit 4e84e98
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0204-drm-stm-dsi-Use-devm_platform_ioremap_resource.patch (drm-backport-placeholder)
- commit 6bd227b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-simple-fix-active-size-for-Ampire-AM-.patch (drm-backport-placeholder)
- commit 9480cae
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0202-drm-panel-simple-Add-Ampire-AM-800480L1TMQW-T00H.patch (drm-backport-placeholder)
- commit 34e1f2f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0201-drm-bridge-samsung-dsim-Support-non-burst-mode.patch (drm-backport-placeholder)
- commit 47d2440
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0200-drm-bridge-samsung-dsim-Dynamically-configure-DPHY-t.patch (drm-backport-placeholder)
- commit ad5bfb2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0199-drm-bridge-samsung-dsim-Select-GENERIC_PHY_MIPI_DPHY.patch (drm-backport-placeholder)
- commit 80e469f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0198-drm-bridge-samsung-dsim-Fetch-pll-clock-frequency-au.patch (drm-backport-placeholder)
- commit 86e1287
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-samsung-dsim-Fix-PMS-Calculator-on-i.patch (drm-backport-placeholder)
- commit a71993d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0196-drm-bridge-samsung-dsim-fix-blanking-packet-size-cal.patch (drm-backport-placeholder)
- commit be1b2bc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0195-drm-amdgpu-Fix-no-procfs-build.patch (drm-backport-placeholder)
- commit 481845a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-ti-sn65dsi83-Fix-enable-disable-flow.patch (drm-backport-placeholder)
- commit d4fe0d1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0193-drm-bridge-samsung-dsim-Fix-i.MX8M-enable-flow-to-me.patch (drm-backport-placeholder)
- commit c069be4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0192-drm-bridge-tc358767-explicitly-set-readable-register.patch (drm-backport-placeholder)
- commit 2490089
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0191-drm-doc-Relax-fdinfo-string-constraints.patch (drm-backport-placeholder)
- commit ca00d3a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0190-drm-msm-Add-memory-stats-to-fdinfo.patch (drm-backport-placeholder)
- commit ca24510
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0189-drm-Add-fdinfo-memory-stats.patch (drm-backport-placeholder)
- commit 5e903d0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0188-drm-amdgpu-Switch-to-fdinfo-helper.patch (drm-backport-placeholder)
- commit 66cb9a5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0187-drm-msm-Switch-to-fdinfo-helper.patch (drm-backport-placeholder)
- commit d2139db
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0186-drm-Add-common-fdinfo-helper.patch (drm-backport-placeholder)
- commit 95d509f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0185-drm-docs-Fix-usage-stats-typos.patch (drm-backport-placeholder)
- commit 031ad80
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0184-drm-shmobile-Make-DRM_SHMOBILE-visible-on-Renesas-So.patch (drm-backport-placeholder)
- commit 7b49730
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0183-drm-shmobile-Add-missing-call-to-drm_fbdev_generic_s.patch (drm-backport-placeholder)
- commit 95e3663
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0182-drm-shmobile-Switch-to-drm_crtc_init_with_planes.patch (drm-backport-placeholder)
- commit 022e3e0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0181-drm-shmobile-Add-support-for-DRM_FORMAT_XRGB8888.patch (drm-backport-placeholder)
- commit 2ec9dc8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0180-drm-shmobile-Use-p4cc-to-print-fourcc-codes.patch (drm-backport-placeholder)
- commit 9702fe6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0179-dma-buf-sw_sync-Replace-all-non-returning-strlcpy-wi.patch (drm-backport-placeholder)
- commit 5421751
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0178-drm-panel-samsung-s6d7aa0-use-pointer-for-drm_mode-i.patch (drm-backport-placeholder)
- commit d17d5e2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0177-drm-bridge-dw-hdmi-Replace-all-non-returning-strlcpy.patch (drm-backport-placeholder)
- commit 1f7d1aa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-anx7625-Prevent-endless-probe-loop.patch (drm-backport-placeholder)
- commit ebd4ba4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0175-drm-msm-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit 22927b6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0174-drm-nouveau-acr-ga102-set-variable-ga102_gsps-storag.patch (drm-backport-placeholder)
- commit b4e5c73
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0173-drm-nouveau-constify-pointers-to-hwmon_channel_info.patch (drm-backport-placeholder)
- commit 58b4911
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-dispnv50-fix-missing-prototypes-war.patch (drm-backport-placeholder)
- commit b7185f8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0171-drm-bridge-samsung-dsim-Implement-support-for-clock-.patch (drm-backport-placeholder)
- commit b3a3126
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0170-drm-panel-Add-Samsung-S6D7AA0-panel-controller-drive.patch (drm-backport-placeholder)
- commit 2946fa4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0169-drm-sched-Rename-to-drm_sched_wakeup_if_can_queue.patch (drm-backport-placeholder)
- commit cea77bb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0168-drm-sched-Rename-to-drm_sched_can_queue.patch (drm-backport-placeholder)
- commit eed5a68
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0016-fbdev-Rename-fb_mem-helpers.patch (drm-backport-placeholder)
- commit 4952f6d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0015-fbdev-Move-framebuffer-I-O-helpers-into-asm-fb.h.patch (drm-backport-placeholder)
- commit 036d63b
* Wed Sep  4 2024 oneukum@suse.com
- media: dvbdev: fix most coding style issues (jsc#PED-8643).
- Refresh patches.suse/media-dvbdev-Initialize-sbuf.patch.
- Refresh
  patches.suse/media-edia-dvbdev-fix-a-use-after-free.patch.
- commit a085dbc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0014-fbdev-Include-linux-fb.h-instead-of-asm-fb.h.patch (drm-backport-placeholder)
- commit d250f20
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0013-fbdev-Include-linux-io.h-in-various-drivers.patch (drm-backport-placeholder)
- commit ea2340a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0167-ipu-v3-Include-linux-io.h.patch (drm-backport-placeholder)
- commit 0aefbea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0166-fbdev-matrox-Remove-trailing-whitespaces.patch (drm-backport-placeholder)
- commit 53d1c12
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0165-fbdev-hitfb-Cast-I-O-offset-to-address.patch (drm-backport-placeholder)
- commit a3ee3ac
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358767-Switch-to-devm-MIPI-DSI-hel.patch (drm-backport-placeholder)
- commit 32fea7b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0163-drm-ttm-let-struct-ttm_device_funcs-be-placed-in-rod.patch (drm-backport-placeholder)
- commit 147d98c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0162-drm-drm_atomic_helper.c-fix-a-typo.patch (drm-backport-placeholder)
- commit 1c221fc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0161-drm-panel-Modify-innolux-hj110iz-panel-initial-code.patch (drm-backport-placeholder)
- commit febaee6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0160-drm-bridge-tc358768-remove-unneeded-semicolon.patch (drm-backport-placeholder)
- commit dc7b4aa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0159-gpu-drm-bridge-No-need-to-set-device_driver-owner.patch (drm-backport-placeholder)
- commit c2d92b9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-vkms-Fix-RGB565-pixel-conversion.patch (drm-backport-placeholder)
- commit d08562b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-Add-fixed-point-helper-to-get-rounded-integ.patch (drm-backport-placeholder)
- commit 4080aac
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0156-drm-panel-boe-tv101wum-nl6-Fine-tune-the-panel-power.patch (drm-backport-placeholder)
- commit cd00f9d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0155-drm-panel-boe-tv101wum-nl6-Remove-extra-delay.patch (drm-backport-placeholder)
- commit 8121c5e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0154-drm-ssd130x-Fix-include-guard-name.patch (drm-backport-placeholder)
- commit 74ac6e0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0153-drivers-firmware-Move-sysfb_init-from-device_initcal.patch (drm-backport-placeholder)
- commit 01026e2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0152-drm-panel-panel-simple-Add-BOE-EV121WXM-N10-1850-pan.patch (drm-backport-placeholder)
- commit 32cb664
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0151-drm-panel-sharp-ls043t1le01-drop-dummy-functions-and.patch (drm-backport-placeholder)
- commit 2af7cb1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-sharp-ls043t1le01-adjust-mode-setting.patch (drm-backport-placeholder)
- commit 2b760d5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-sun4i_tcon-use-devm_clk_get_enabled-in-sun4.patch (drm-backport-placeholder)
- commit 83c3e23
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0148-drm-sun4i-calculate-proper-DCLK-rate-for-DSI.patch (drm-backport-placeholder)
- commit 5efa092
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0147-drm-sun4i-rename-sun4i_dotclock-to-sun4i_tcon_dclk.patch (drm-backport-placeholder)
- commit c52f8d8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0146-drm-connector-document-enum-drm_connector_tv_mode-DR.patch (drm-backport-placeholder)
- commit f6cd796
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0145-Documentation-vkms-clarify-devres-managed-reference-.patch (drm-backport-placeholder)
- commit 7bdc749
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0144-drm-fb-helper-Use-fb_-cfb-sys-_-read-write.patch (drm-backport-placeholder)
- commit 841dd22
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0143-fbdev-Move-I-O-read-and-write-code-into-helper-funct.patch (drm-backport-placeholder)
- commit 31210d7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0142-fbdev-Validate-info-screen_-base-buffer-in-fb_ops-im.patch (drm-backport-placeholder)
- commit f921535
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0141-fbdev-Don-t-re-validate-info-state-in-fb_ops-impleme.patch (drm-backport-placeholder)
- commit 7130d63
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0140-fbdev-Use-screen_buffer-in-fb_sys_-read-write.patch (drm-backport-placeholder)
- commit 8b19d72
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0139-fbdev-Return-number-of-bytes-read-or-written.patch (drm-backport-placeholder)
- commit a3ad4a0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0138-fbdev-xen-fbfront-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit 24562d8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0137-fbdev-vfb-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit 80da9e2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0136-fbdev-udlfb-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit 911e81d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0135-fbdev-smscufx-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit e94cfea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0134-fbdev-ps3fb-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit f3d58f2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0133-fbdev-metronomefb-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit ee18344
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0132-fbdev-hecubafb-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit ac74506
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0131-fbdev-broadsheetfb-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit 10de5ad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0130-fbdev-au1200fb-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit 2fb0651
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0129-fbdev-arcfb-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit df8dd49
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0128-drm-vkms-drop-Rotation-TODO.patch (drm-backport-placeholder)
- commit 885292b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0127-drm-vkms-add-rotate-270-property.patch (drm-backport-placeholder)
- commit 97a371a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0126-drm-vkms-add-rotate-90-property.patch (drm-backport-placeholder)
- commit be3d5fc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0125-drm-vkms-add-reflect-y-and-rotate-180-property.patch (drm-backport-placeholder)
- commit eb22094
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0124-drm-vkms-add-rotate-0-and-reflect-x-property.patch (drm-backport-placeholder)
- commit 9e082fe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-vram-helper-fix-function-names-in-vram-help.patch (drm-backport-placeholder)
- commit b8905d5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0122-drm-bridge-lt9611-Do-not-generate-HFP-HBP-HSA-and-EO.patch (drm-backport-placeholder)
- commit afe74f7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0121-drm-bridge-lt9211-Do-not-generate-HFP-HBP-HSA-and-EO.patch (drm-backport-placeholder)
- commit 25dc7bd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0120-drm-bridge-tc358768-remove-unused-variable.patch (drm-backport-placeholder)
- commit 510cbc5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-fix-THS_TRAILCNT-computatio.patch (drm-backport-placeholder)
- commit c46978c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-fix-TXTAGOCNT-computation.patch (drm-backport-placeholder)
- commit 450d4b6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-fix-THS_ZEROCNT-computation.patch (drm-backport-placeholder)
- commit 81cfdf4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-fix-TCLK_TRAILCNT-computati.patch (drm-backport-placeholder)
- commit 64ac142
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-fix-TCLK_ZEROCNT-computatio.patch (drm-backport-placeholder)
- commit 9cee2f9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-fix-PLL-target-frequency.patch (drm-backport-placeholder)
- commit 9088045
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-fix-PLL-parameters-computat.patch (drm-backport-placeholder)
- commit d225e78
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-always-enable-HS-video-mode.patch (drm-backport-placeholder)
- commit ecf4b28
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop-Leave-vblank-enabled-in-self-r.patch (drm-backport-placeholder)
- commit 83160ac
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-atomic-Allow-vblank-enabled-self-refresh-di.patch (drm-backport-placeholder)
- commit ce928ba
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-ti-sn65dsi83-Fix-enable-error-path.patch (drm-backport-placeholder)
- commit b7d2662
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0108-drm-udl-delete-dead-code.patch (drm-backport-placeholder)
- commit bf6483a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0107-drm-scheduler-mark-jobs-without-fence-as-canceled.patch (drm-backport-placeholder)
- commit 16c3d3c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0106-drm-rockchip-cdn-dp-call-drm_connector_update_edid_p.patch (drm-backport-placeholder)
- commit c888c03
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0105-drm-sti-sti_hdmi-convert-to-using-is_hdmi-from-displ.patch (drm-backport-placeholder)
- commit 2507be1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0104-drm-sysfs-Link-DRM-connectors-to-corresponding-Type-.patch (drm-backport-placeholder)
- commit ada320f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0103-drm-sysfs-Expose-DRM-connector-id-in-each-connector-.patch (drm-backport-placeholder)
- commit 295bc71
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-it6505-Move-a-variable-assignment-be.patch (drm-backport-placeholder)
- commit bdcb354
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0101-drm-uapi-Document-CTM-matrix-better.patch (drm-backport-placeholder)
- commit 8889d06
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0100-drm-meson-set-variables-meson_hdmi_-storage-class-sp.patch (drm-backport-placeholder)
- commit 39c6930
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0099-drm-panel-st7703-Add-Anbernic-RG353V-V2-Panel-Suppor.patch (drm-backport-placeholder)
- commit 0b781c5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0098-drm-panel-st7703-Rename-CMD_UNKNOWN_C6-to-CMD_SETECO.patch (drm-backport-placeholder)
- commit 56e034c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0097-drm-doc-rfc-Introduce-the-merge-plan-for-the-Xe-driv.patch (drm-backport-placeholder)
- commit 02c3ebe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0096-drm-vkms-drop-full-alpha-blending-TODO.patch (drm-backport-placeholder)
- commit 50f59b1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0095-drm-vkms-allow-full-alpha-blending-on-all-planes.patch (drm-backport-placeholder)
- commit 4c37876
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0012-arch-x86-Include-asm-fb.h-in-fbdev-source-file.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 226a17d
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/intel/uncore: Support HBM and CXL PMON counters
  (bsc#1230119).
- commit a4c2665
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Add-atomic_get_input_bus_fm.patch (drm-backport-placeholder)
- commit e012013
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0093-drm-vc4-hdmi-Add-BT.2020-Support.patch (drm-backport-placeholder)
- commit ade7f13
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0092-drm-vc4-hdmi-Add-BT.601-Support.patch (drm-backport-placeholder)
- commit 93e1ed1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0091-drm-vc4-hdmi-Add-a-function-to-retrieve-the-CSC-matr.patch (drm-backport-placeholder)
- commit 25e14dd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0090-drm-vc4-hdmi-Rework-the-CSC-matrices-organization.patch (drm-backport-placeholder)
- commit f47bcdd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0089-drm-vc4-hdmi-Swap-CSC-matrix-channels-for-YUV444.patch (drm-backport-placeholder)
- commit a3e4e5c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0088-drm-vc4-hdmi-Rename-full-range-helper.patch (drm-backport-placeholder)
- commit b29e589
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0087-drm-vc4-hdmi-Add-Broadcast-RGB-property-to-allow-ove.patch (drm-backport-placeholder)
- commit 5779383
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0086-drm-vc4-hdmi-Update-all-the-planes-if-the-TV-margins.patch (drm-backport-placeholder)
- commit 7e5e589
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0085-drm-vc4-Switch-to-container_of_const.patch (drm-backport-placeholder)
- commit 08f39ab
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-vkms-isolate-pixel-conversion-functionality.patch (drm-backport-placeholder)
- commit 7157159
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0083-drm-test-Add-test-cases-for-drm_rect_rotate_inv.patch (drm-backport-placeholder)
- commit 81df4cf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0082-drm-tests-Add-test-cases-for-drm_rect_rotate.patch (drm-backport-placeholder)
- commit d228d4e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0081-drm-tests-Add-test-cases-for-drm_rect_calc_vscale.patch (drm-backport-placeholder)
- commit 92cce65
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0080-drm-tests-Add-test-cases-for-drm_rect_calc_hscale.patch (drm-backport-placeholder)
- commit 12aa2de
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0079-drm-tests-Add-test-cases-for-drm_rect_intersect.patch (drm-backport-placeholder)
- commit 00f77b5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0078-drm-scheduler-add-drm_sched_entity_error-and-use-rcu.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 97bea26
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0077-drm-scheduler-properly-forward-fence-errors.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 0ad788e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0076-drm-tve200-Use-devm_platform_ioremap_resource.patch (drm-backport-placeholder)
- commit 350340e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0075-drm-sti-Drop-of_gpio-header.patch (drm-backport-placeholder)
- commit 86e9bbf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0074-drm-bridge-anx7625-Drop-of_gpio-header.patch (drm-backport-placeholder)
- commit 5029b58
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0073-drm-display-Add-missing-OLED-Vesa-brightnesses-defin.patch (drm-backport-placeholder)
- commit 721ed3a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0072-drm-panel-simple-Add-InnoLux-G070ACE-L01.patch (drm-backport-placeholder)
- commit 7e0d39c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0071-drm-armada-Implement-fbdev-emulation-as-in-kernel-cl.patch (drm-backport-placeholder)
- commit 322e9b1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0070-drm-armada-Initialize-fbdev-DRM-client.patch (drm-backport-placeholder)
- commit bb9ba1f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0069-drm-armada-Hide-fbdev-support-behind-config-option.patch (drm-backport-placeholder)
- commit d33a0dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0068-drm-armada-Include-linux-of.h.patch (drm-backport-placeholder)
- commit 8f13aed
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0067-drm-bridge-ti-sn65dsi86-Implement-wait_hpd_asserted.patch (drm-backport-placeholder)
- commit 44a191c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0004-arch-x86-Implement-asm-fb.h-with-generic-helpers.patch (drm-backport-placeholder)
- commit 6c9d63a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0011-arch-sparc-Implement-asm-fb.h-with-generic-helpers.patch (drm-backport-placeholder)
- commit 4612877
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0007-arch-sparc-Implement-fb_is_primary_device-in-source-.patch (drm-backport-placeholder)
- commit 334da3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0066-arch-parisc-Implement-fb_is_primary_device-under-arc.patch (drm-backport-placeholder)
- commit 3fcaf79
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0065-video-Move-HP-PARISC-STI-core-code-to-shared-locatio.patch (drm-backport-placeholder)
- commit 4a3449b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0064-video-Remove-trailing-whitespaces.patch (drm-backport-placeholder)
- commit c486bd8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0006-arch-arm64-Implement-asm-fb.h-with-generic-helpers.patch (drm-backport-placeholder)
- commit ca3b807
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0010-arch-mips-Implement-asm-fb.h-with-generic-helpers.patch (drm-backport-placeholder)
- commit 60d3aa2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0009-arch-loongarch-Implement-asm-fb.h-with-generic-helpe.patch (drm-backport-placeholder)
- commit 1411ad4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0008-arch-ia64-Implement-asm-fb.h-with-generic-helpers.patch (drm-backport-placeholder)
- commit 89abd41
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0003-fbdev-Prepare-generic-architecture-helpers.patch (drm-backport-placeholder)
- commit 9f9ad68
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0063-drm-gem-Check-for-valid-formats.patch (drm-backport-placeholder)
- commit 6ea4fa0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-scheduler-set-entity-to-NULL-in-drm_sched_.patch (drm-backport-placeholder)
- commit 3e1991c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0061-drm-nouveau-therm-Move-an-assignment-statement-behin.patch (drm-backport-placeholder)
- commit a83ca67
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0060-drm-nouveau-pci-Move-an-expression-into-a-function-c.patch (drm-backport-placeholder)
- commit d9d5d91
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0059-drm-nouveau-pci-Move-a-variable-assignment-behind-co.patch (drm-backport-placeholder)
- commit ffb2220
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0058-drm-nouveau-clk-Move-a-variable-assignment-behind-a-.patch (drm-backport-placeholder)
- commit dc1b979
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0057-drm-nouveau-bios-power_budget-Move-an-expression-int.patch (drm-backport-placeholder)
- commit 927c9a9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0056-drm-nouveau-debugfs-Replace-five-seq_printf-calls-by.patch (drm-backport-placeholder)
- commit 443b0c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0055-drm-nouveau-debugfs-Use-seq_putc-in-nouveau_debugfs_.patch (drm-backport-placeholder)
- commit 224c14c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0054-drm-nouveau-debugfs-Move-a-variable-assignment-behin.patch (drm-backport-placeholder)
- commit 34d1f14
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0053-drm-nouveau-debugfs-Move-an-expression-into-a-functi.patch (drm-backport-placeholder)
- commit 9c652dd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0052-drm-panel-nt36523-Add-Lenovo-J606F-panel.patch (drm-backport-placeholder)
- commit ba09eb7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0051-drm-panel-nt36523-Get-orientation-from-OF.patch (drm-backport-placeholder)
- commit b7dcda4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0050-drm-panel-nt36523-Add-DCS-backlight-support.patch (drm-backport-placeholder)
- commit 2473fa2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0049-dma-buf-dma-resv.c-fix-a-typo.patch (drm-backport-placeholder)
- commit a06f09c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0048-video-aperture-Provide-a-VGA-helper-for-gma500-and-i.patch (drm-backport-placeholder)
- commit ace61b1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0002-fbdev-Simplify-fb_is_primary_device-for-x86.patch (drm-backport-placeholder)
- commit 9dcea97
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0047-video-aperture-Only-remove-sysfb-on-the-default-vga-.patch (drm-backport-placeholder)
- commit 095dccb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0046-video-aperture-Drop-primary-argument.patch (drm-backport-placeholder)
- commit 2654a19
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0045-video-aperture-Move-vga-handling-to-pci-function.patch (drm-backport-placeholder)
- commit 27b4fd0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0044-video-aperture-Only-kick-vgacon-when-the-pdev-is-dec.patch (drm-backport-placeholder)
- commit b258f0b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0043-drm-aperture-Remove-primary-argument.patch (drm-backport-placeholder)
- commit e26f663
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0042-video-aperture-use-generic-code-to-figure-out-the-vg.patch (drm-backport-placeholder)
- commit 846fef3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0041-drm-gma500-Use-drm_aperture_remove_conflicting_pci_f.patch (drm-backport-placeholder)
- commit 1dd9b8a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-imx-lcdc-fix-a-NULL-vs-IS_ERR-bug-in-probe.patch (drm-backport-placeholder)
- commit 4e002cc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0039-drm-bridge-fsl-ldb-Add-i.MX6SX-support.patch (drm-backport-placeholder)
- commit 9ff8564
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0038-drm-vkms-Use-drmm_mode_config_init.patch (drm-backport-placeholder)
- commit 999f7f3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0037-drm-vkms-Use-drmm_crtc_init_with_planes.patch (drm-backport-placeholder)
- commit a04b476
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-fix-potential-OOB-read-in-fast_imageblit.patch (drm-backport-placeholder)
- commit 75de597
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0035-fbdev-sh7760fb-Fix-Wimplicit-fallthrough-warnings.patch (drm-backport-placeholder)
- commit 3275c66
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0034-fbdev-sh_mobile_lcdcfb-Fix-ARGB32-overlay-format-typ.patch (drm-backport-placeholder)
- commit 6707353
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0033-fbdev-hitfb-Use-NULL-for-pointers.patch (drm-backport-placeholder)
- commit 09eebf5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0032-fbdev-hitfb-Fix-integer-to-pointer-cast.patch (drm-backport-placeholder)
- commit 069cd79
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0031-fbdev-media-Use-GPIO-descriptors-for-VIA-GPIO.patch (drm-backport-placeholder)
- commit f555a28
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0030-video-hdmi-Reorder-fields-in-struct-hdmi_avi_infofra.patch (drm-backport-placeholder)
- commit e2e67dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0029-fbdev-broadsheetfb-Add-MODULE_FIRMWARE-macro.patch (drm-backport-placeholder)
- commit 8fc7e50
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0028-fbdev-metronomefb-Add-MODULE_FIRMWARE-macro.patch (drm-backport-placeholder)
- commit 31a0e7a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0027-fbdev-hitfb-Declare-hitfb_blank-as-static.patch (drm-backport-placeholder)
- commit 23e9dad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-omapfb-lcd_mipid-Fix-an-error-handling-pa.patch (drm-backport-placeholder)
- commit e09f25f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/Input-ads7846-Convert-to-use-software-nodes.patch (drm-backport-placeholder)
- commit d070ef0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0024-mm-gup-remove-unused-vmas-parameter-from-get_user_pa.patch (drm-backport-placeholder)
- commit 18a4db0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0023-drm-i2c-tda998x-Replace-all-non-returning-strlcpy-wi.patch (drm-backport-placeholder)
- commit 0c2502f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0022-drm-sun4i-hdmi-Replace-all-non-returning-strlcpy-wit.patch (drm-backport-placeholder)
- commit 59312c2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0021-drm-mediatek-Replace-all-non-returning-strlcpy-with-.patch (drm-backport-placeholder)
- commit 8e371c6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0020-drm-rockchip-Replace-all-non-returning-strlcpy-with-.patch (drm-backport-placeholder)
- commit c420455
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0019-drm-display-dp_mst-Replace-all-non-returning-strlcpy.patch (drm-backport-placeholder)
- commit 7a555f0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0018-drm-amd-pm-Replace-all-non-returning-strlcpy-with-st.patch (drm-backport-placeholder)
- commit 8f1aadc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0017-drm-radeon-Replace-all-non-returning-strlcpy-with-st.patch (drm-backport-placeholder)
- commit f0716d9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-ttm-never-consider-pinned-BOs-for-eviction-.patch (drm-backport-placeholder)
- commit 111a71b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-fbdev-dma-Fix-documented-default-preferred_.patch (drm-backport-placeholder)
- commit 4fb03a1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/dma-buf-fix-an-error-pointer-vs-NULL-bug.patch (drm-backport-placeholder)
- commit c96cd43
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/dma-buf-keep-the-signaling-time-of-merged-fence.patch (drm-backport-placeholder)
- commit 11083db
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-simple-Add-Powertip-PH800480T013-drm_.patch (drm-backport-placeholder)
- commit 583b3e0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-ttm-Don-t-leak-a-resource-on-swapout-move-e.patch (drm-backport-placeholder)
- commit 6366826
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-ttm-Don-t-leak-a-resource-on-eviction-error.patch (drm-backport-placeholder)
- commit 8c4dfda
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-ti-sn65dsi86-Fix-auxiliary-bus-lifet.patch (drm-backport-placeholder)
- commit 96d4152
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0007-drm-sched-Call-drm_sched_fence_set_parent-from-drm_s.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 0452183
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0006-drm-nouveau-kms-nv50-Fix-drm_dp_remove_payload-invoc.patch (drm-backport-placeholder)
- commit b247882
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0005-drm-ttm-fix-warning-that-we-shouldn-t-mix-and.patch (drm-backport-placeholder)
- commit dd076ee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-ttm-fix-bulk_move-corruption-when-adding-a-.patch (drm-backport-placeholder)
- commit 1d3ceff
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-dw_hdmi-fix-connector-access-for-scd.patch (drm-backport-placeholder)
- commit cee7120
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0002-drm-sched-Make-sure-we-wait-for-all-dependencies-in-.patch (drm-backport-placeholder)
- commit ab64432
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: makes CPU/Codec channel connection map more generic
  (jsc#PED-9993 jsc#PED-10202).
- commit f1175d7
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: SOF: ipc4: Handle ALSA kcontrol change notification from
  firmware (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-SOF-ipc4-check-return-value-of-snd_sof_ipc_msg_.patch.
- commit 350be84
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: SOF: Intel: Use existing helpers to change GPROCEN and
  PIE bits (jsc#PED-9993 jsc#PED-10202).
- ASoC: sh: convert not to use dma_request_slave_channel()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-control: Implement control update for
  switch/enum controls (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Helper to find an swidget by
  module/instance id (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs43130: Allow configuration of bit clock and frame
  inversion (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs43130: Allow driver to work without IRQ connection
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: mpc8610_hpcd: Remove unused driver (jsc#PED-9993
  jsc#PED-10202).
- ASoC: imx-rpmsg: Force codec power on in low power audio mode
  (jsc#PED-9993 jsc#PED-10202).
- commit f4da865
* Wed Sep  4 2024 tiwai@suse.de
- supported.conf: add snd-acp70 (jsc#PED-9993 jsc#PED-10202)
- commit 9b30e8e
* Wed Sep  4 2024 tiwai@suse.de
- Update config files: CONFIG_SND_AMD_ASOC_ACP70=m (jsc#PED-9993 jsc#PED-10202)
- commit ee03f99
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: nau8810: Fix incorrect type in assignment and cast to
  restricted __be16 (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_mqs: Remove duplicate linux/of.h header (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs43130: Add switch to control normal and alt hp inputs
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs43130: Add handling of ACPI (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs43130: Store device in private struct and use it more
  consistently (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add missing SND_SOC_AMD_ACP_LEGACY_COMMON flag
  for ACP70 (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5682s: Add LDO output selection for dacref (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: acp: add Kconfig options for acp7.0 based platform
  driver (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: add mtl_rt5650 support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l43: Add missing static from runtime PM ops
  (jsc#PED-9993 jsc#PED-10202).
- commit b5ee0ec
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: codecs: ES8326: Changing the headset detection time
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Changing initialisation and broadcasting
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Add chip version flag (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Add support for configuring PDM interface from
  topology (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: imx8m: Add DAI driver entry for MICFIL PDM
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: ssm4567: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: rt5682: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: rt5663: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: rt5514: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: rt298: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: rt286: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: rt274: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: probe: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: nau8825: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: max98927: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: max98373: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: max98357a: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: i2s_test: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: hdaudio: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: es8336: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: dmic: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: da7219: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: mediatek: remove unused variables (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: mediatek: mt8186: clean up unused code (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: mediatek: mt8195: clean up unused code (jsc#PED-9993
  jsc#PED-10202).
- ASoC: nau8821: Add slew rate controls (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: acp: remove unnecessary NULL check (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tegra: convert not to use dma_request_slave_channel()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: correct the format order (jsc#PED-9993
  jsc#PED-10202).
- commit 08aaee4
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: amd: acp: Fix for indentation issue (jsc#PED-9993
  jsc#PED-10202).
- ASoC: dapm: Simplify widget clone (jsc#PED-9993 jsc#PED-10202).
- ASoC: sti-uniperf: Use default pcm_config instead (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: fix kvmalloc_array() arguments order (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: pci-mtl: add HDA_ARL PCI support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: pci-mtl: fix ARL-S definitions (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Unhardcode HDAudio BE DAI drivers description
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Kill S24_LE format (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: Drop snd_hdac_calc_stream_format() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Switch to new stream-format interface
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: Switch to new stream-format interface
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel Skylake: Switch to new stream-format interface
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: hdac_hdmi: Switch to new stream-format interface
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: hdac_hda: Switch to new stream-format interface
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: hda: Switch to new stream-format interface
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda/ca0132: Switch to new stream-format interface
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda/hdmi: Switch to new stream-format interface
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Switch to new stream-format interface (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: Upgrade stream-format infrastructure (jsc#PED-9993
  jsc#PED-10202).
- commit 9a3a0fe
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: pcm: Honor subformat when configuring runtime
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Honor subformat when querying PCMs (jsc#PED-9993
  jsc#PED-10202).
- ALSA: pcm: Introduce MSBITS subformat interface (jsc#PED-9993
  jsc#PED-10202).
- soc: fsl: cpm1: qmc: Extend the API to provide Rx status
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Replace fake root_device with kunit_device in
  tests (jsc#PED-9993 jsc#PED-10202).
- commit 1f42fbc
* Wed Sep  4 2024 lhenriques@suse.de
- fuse: update stats for pages in dropped aux writeback list
  (bsc#1230125).
- fuse: fix memory leak in fuse_create_open (bsc#1230124).
- fuse: use unsigned type for getxattr/listxattr size truncation
  (bsc#1230123).
- commit c8902bc
* Wed Sep  4 2024 oneukum@suse.com
- thunderbolt: Add support for Intel Lunar Lake (jsc#PED-10232).
- commit 8f81652
* Wed Sep  4 2024 oneukum@suse.com
- usb: typec: tcpci: Fix error code in
  tcpci_check_std_output_cap() (jsc#PED-10361).
- commit 3866a89
* Wed Sep  4 2024 mwilck@suse.com
- Split kabi part of dm_blk_ioctl-implement-path-failover-for-SG_IO.patch
- kabi: dm_blk_ioctl: implement path failover for SG_IO
  (bsc#1183045, bsc#1216776).
- Refresh
  patches.suse/dm_blk_ioctl-implement-path-failover-for-SG_IO.patch.
- commit 9a2ecb0
* Wed Sep  4 2024 tiwai@suse.de
- supported.conf: add snd-soc-intel-sof-ssp-common (jsc#PED-9993 jsc#PED-10202)
- commit ba95831
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: drm/vc4: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- iov_iter: Export import_ubuf() (jsc#PED-9993 jsc#PED-10202).
- commit 773b247
* Wed Sep  4 2024 neilb@suse.de
- NFSD: Fix frame size warning in svc_export_parse() (git-fixes).
- NFSD: Rewrite synopsis of nfsd_percpu_counters_init()
  (git-fixes).
- commit 3ab58b8
* Wed Sep  4 2024 neilb@suse.de
- blacklist.conf: These aren't wanted for various reasons.
- commit 39478da
* Wed Sep  4 2024 neilb@suse.de
- SUNRPC: increase size of rpc_wait_queue.qlen from unsigned
  short to unsigned int (git-fixes).
- commit f718248
* Wed Sep  4 2024 neilb@suse.de
- blacklist.conf: remove a breaks-kabi commit
- commit 11603af
* Wed Sep  4 2024 krisman@suse.de
- kABI: Split kABI out of io_uring/kbuf: protect io_buffer_list teardown with a
  reference
  When introducing this patch, I merged the kABI patch with the actual
  backport, which is not recommended.  Split it up, such that the backport
  is similar to the upstream patch and handle the kABI issue exactly the
  same way, but through a separate kABI patch.
- commit 08e57d6
* Tue Sep  3 2024 lduncan@suse.com
- scsi: sd: Use READ(16) when reading block zero on large capacity
  disks (git-fixes).
- ata: libata-scsi: Fix ata_scsi_dev_rescan() error path
  (git-fixes).
- commit ab07c19
* Tue Sep  3 2024 tiwai@suse.de
- media: solo6x10: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- commit 3c3ece3
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: cs42l43: Don't enable bias sense during type detect
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-mtl-match: Change CS35L56 prefixes
  to AMPn (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: mediatek: mt8186: Revert Add Google Steelix topology
  compatible (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Add support for a new Huawei Matebook laptop
  (jsc#PED-9993 jsc#PED-10202).
- commit d311bc7
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: imx-rpmsg: SND_SOC_IMX_RPMSG should depend on OF and I2C
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Always register the HDMI dai links
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: mediatek: mt8186: Add Google Steelix topology
  compatible (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: i915: Alays handle -EPROBE_DEFER (jsc#PED-9993
  jsc#PED-10202).
- ASoC: nau8540: Add self recovery to improve capture quility
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: da7219: Improve system suspend and resume handling
  (jsc#PED-9993 jsc#PED-10202).
- commit 79422d7
* Tue Sep  3 2024 tiwai@suse.de
- supported.conf: add snd-soc-avs-rt5514 (jsc#PED-9993 jsc#PED-10202)
- commit a6c1561
* Tue Sep  3 2024 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_INTEL_AVS_MACH_RT5514=m (jsc#PED-9993 jsc#PED-10202)
- commit 08780dd
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: amd: acp: fix for i2s mode register field update
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt712-sdca: fix speaker route missing issue (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rockchip: Fix unused rockchip_i2s_tdm_match warning for
  !CONFIG_OF (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Add rt5514 machine board (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: acp: select SND_SOC_AMD_ACP_LEGACY_COMMON for ACP63
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add ACPI dependency (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: bytcr_wm5102: Add BYT_WM5102_IN_MAP quirk
  (jsc#PED-9993 jsc#PED-10202).
- commit 61ee659
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: Intel: bytcr_wm5102: Add BYT_WM5102_OUT_MAP quirk
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bytcr_wm5102: Add BYT_WM5102_MCLK_19_2MHZ quirk
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bytcr_wm5102: Add BYT_WM5102_SSP2 quirk
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: sc7180: Add support for qdsp6 baked sound
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tegra: machine: Handle component name prefix (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: speyside: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8192: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8188: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8186: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8183: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- commit c606f52
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: codecs: wm8995: Handle component name prefix (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wm8994: Handle component name prefix (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wm8962: Handle component name prefix (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wcd9335: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: rt5682s: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: max9867: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-rx-macro: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: adav80x: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: adau1373: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- commit a67be05
* Tue Sep  3 2024 tiwai@suse.de
- Fix compile warnings due to merge errors
- Refresh:
  patches.suse/ASoC-SOF-Make-return-of-remove_late-void-too.patch
  patches.suse/ASoC-SOF-make-.remove-callback-return-void.patch
- commit 8d4b3da
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: codecs: 88pm860x: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: Add code for bin parsing compatible with aw88399
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add machine driver support for acp7.0
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Add pci legacy driver support for acp7.0
  platform (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: change acp power on mask macro value
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: change acp-deinit function arguments
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add machine driver support for pdm use case
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add condition check for i2s clock generation
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add platform and flag data to acp data structure
  (jsc#PED-9993 jsc#PED-10202).
- commit f278ea0
* Tue Sep  3 2024 mkoutny@suse.com
- blacklist.conf: Add cf3f9a593dab mm: optimize the redundant loop of mm_update_owner_next()
- commit 3184f0b
* Tue Sep  3 2024 tiwai@suse.de
- supported.conf: add snd-acp63 (jsc#PED-9993 jsc#PED-10202)
- commit 2f19099
* Tue Sep  3 2024 tiwai@suse.de
- Update config files: CONFIG_SND_AMD_ASOC_ACP63=m (jsc#PED-9993 jsc#PED-10202)
- commit a51249d
* Tue Sep  3 2024 mkoutny@suse.com
- blacklist.conf: d24f05987ce8 cgroup: Avoid extra dereference in css_populate_dir()
- commit 922f944
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: amd: acp: add code for scanning acp pdm controller
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add Kconfig options for acp6.3 based platform
  driver (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add machine driver support for acp6.3 platform
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add i2s clock generation support for acp6.3
  based platforms (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: refactor acp i2s clock generation code
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Add acp6.3 pci legacy driver support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: Skylake: add an error code check in skl_pcm_trigger
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd938x: use defines for entries in
  snd_soc_dai_driver array (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: q6apm-lpass-dais: pass max number of channels to
  Audioreach (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bytcr_wm5102: Add support for Lenovo Yoga Tab 3
  Pro YT3-X90 (jsc#PED-9993 jsc#PED-10202).
- commit fb81d26
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: mediatek: mt8186: remove redundant assignments to variable
  tdm_con (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt7986: add sample rate checker (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: rt298: remove redundant assignment to d_len_code
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: ams-delta: Allow it to be test compiled (jsc#PED-9993
  jsc#PED-10202).
- ASoC: uniphier: Make uniphier_aio_remove() return void
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: lpass: Make asoc_qcom_lpass_cpu_platform_remove()
  return void (jsc#PED-9993 jsc#PED-10202).
- ASoC: meson: Make meson_card_remove() return void (jsc#PED-9993
  jsc#PED-10202).
- ASoC: simple-card-utils: Make simple_util_remove() return void
  (jsc#PED-9993 jsc#PED-10202).
- commit 5297af4
* Tue Sep  3 2024 tiwai@suse.de
- supported.conf: add snd-sof-amd-acp63 (jsc#PED-9993 jsc#PED-10202)
- commit ae4f709
* Tue Sep  3 2024 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_SOF_AMD_ACP63=m (jsc#PED-9993 jsc#PED-10202)
- commit b47eccf
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: cs42l43: Convert to platform remove callback returning
  void (jsc#PED-9993 jsc#PED-10202).
- ASoC: rockchip: i2s_tdm: Convert to platform remove callback
  returning void (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: add option to use sram for data bin loading
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: refactor acp dram usage for data bin loading
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: increase DSP cache window range (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: amd: add support for acp6.3 based platform
  (jsc#PED-9993 jsc#PED-10202).
- commit 71b62b5
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: amd: Add acpi machine id for acp6.3 version based platform
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-amd-acp-config-Add-missing-MODULE_DESCRIPTION.patch.
- commit fc71cee
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: es8328: Use rounded rate for es8328_set_sysclk()
  (jsc#PED-9993 jsc#PED-10202).
- commit b06fe21
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: SOF: Make return of remove_late void, too (jsc#PED-9993
  jsc#PED-10202).
- commit ede1beb
* Tue Sep  3 2024 tiwai@suse.de
- ALSA: rawmidi: Replace with __packed attribute (jsc#PED-9993
  jsc#PED-10202).
- ALSA: pcm: Replace with __packed attribute (jsc#PED-9993
  jsc#PED-10202).
- ALSA: control: Replace with __packed attribute (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: use common module for DMIC links
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use common module for DMIC links
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use common module for DMIC links
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: use common module for DMIC links
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support dmic link initialization
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: add RPL support for MAX98360A amp
  (jsc#PED-9993 jsc#PED-10202).
- commit 5668bb4
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: intel: sof_sdw: Move the builtin microphones to dataport 1
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw_cs42l43: Create separate jacks for hp
  and mic (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw_cs42l43: Some trivial formatting clean ups
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tlv320aic31xx: switch to gpiod_set_value_cansleep
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8186_mt6366_rt1019_rt5682s: add rt5650 support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: da7213: Add new kcontrol for tonegen (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tas2781: make const read-only array magic_number static
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: ps: enable wake capability for acp pci driver
  (jsc#PED-9993 jsc#PED-10202).
- commit 265fa70
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: SOF: make .remove callback return void (jsc#PED-9993
  jsc#PED-10202).
- commit 4053352
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: SOF: ipc4: Dump the notification payload (jsc#PED-9993
  jsc#PED-10202).
- commit aa58961
* Tue Sep  3 2024 tiwai@suse.de
- supported.conf: add snd-soc-intel-sof-board-helpers (jsc#PED-9993 jsc#PED-10202)
- commit 943e516
* Tue Sep  3 2024 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_INTEL_SOF_BOARD_HELPERS=m (jsc#PED-9993 jsc#PED-10202)
- commit c3a8033
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: SOF: Intel: pci-mtl: use ARL specific firmware definitions
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt715: reorder the argument in error log (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt715-sdca: reorder the argument in error log
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: use common module for HDMI link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use common module for HDMI link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use common module for HDMI link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: use common module for HDMI link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: new module for common functions
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: use sof_hdmi_private to init HDMI
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: use sof_hdmi_private to init HDMI
  (jsc#PED-9993 jsc#PED-10202).
- commit 1cc4108
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: Intel: sof_rt5682: use sof_hdmi_private to init HDMI
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use sof_hdmi_private to init HDMI
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: use sof_hdmi_private to init HDMI
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: use sof_hdmi_private to init HDMI
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_hdmi: add common header for HDMI (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: remove hdac-hdmi support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_rt5682: remove hdac-hdmi support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_nau8825: remove hdac-hdmi support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_da7219: remove hdac-hdmi support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: remove hdac-hdmi support (jsc#PED-9993
  jsc#PED-10202).
- commit 4cc6cb7
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: Intel: sof_sdw_rt712_sdca: construct cards->components
  by name_prefix (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: MTL: Add entry for HDMI-In capture support to
  non-I2S codec boards (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-mtl-match: add rt713 rt1316 config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-rpl-match: add rt711-l0-rt1316-l12
  support (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: update HP Omen match (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sigmadsp: Add __counted_by for struct sigmadsp_data and
  use struct_size() (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: ssm4567: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt5663: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt286: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: nau8825: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- commit b3e370a
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: Intel: avs: max98927: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: max98373: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: es8336: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: da7219: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt298: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: max98357a: Validate machine board
  configuration (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt5682: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt274: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: i2s_test: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Improve topology parsing of dynamic strings
  (jsc#PED-9993 jsc#PED-10202).
- commit 86c4d4e
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: Use device_get_match_data() (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-rockchip-i2s-tdm-Fix-inaccurate-sampling-rates.patch.
- commit b13dc1c
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: Intel: avs: Introduce helper functions for SSP and TDM
  handling (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Only create SSP%%d snd_soc_dai_driver when
  requested (jsc#PED-9993 jsc#PED-10202).
- ASoC: tegra: Fix -Wuninitialized in
  tegra210_amx_platform_probe() (jsc#PED-9993 jsc#PED-10202).
- ASoC: apple: mca: Annotate struct mca_data with __counted_by
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Convert to platform remove callback returning void
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8188-mt6359: add rt5682s support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom/lpass: Constify struct lpass_variant (jsc#PED-9993
  jsc#PED-10202).
- ASoC: da7218: Use i2c_get_match_data() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Drop unnecessary of_match_device() calls (jsc#PED-9993
  jsc#PED-10202).
- commit 94228f4
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: Explicitly include correct DT includes (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-cs35l33-Fix-GPIO-name-and-drop-legacy-include.patch.
- commit a2cc63c
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: mt8192-afe-gpio: Drop unused include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mt8186-mt6366-rt1019-rt5682s: Drop unused include
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mt8173-rt5650: Drop unused includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mt8173-rt5650-rt5676: Drop unused includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mt8173-rt5650-rt5514: Drop unused includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mt8173-max98090: Drop unused include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: mt2701-cs42448: Convert to GPIO descriptors
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rockchip: Drop includes from Rockchip RT5645 (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rockchip: Drop includes from Rockchip MAX98090
  (jsc#PED-9993 jsc#PED-10202).
- commit 34e6400
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: rockchip: Drop includes from RK3399 (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rockchip: Convert RK3288 HDMI to GPIO descriptors
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: reduce number of binding headers includes
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: explicitly include binding headers when used
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-client: fix build when only IPC4 is selected
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: IPC4: sort pipeline based on priority (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: IPC4: get pipeline priority from topology
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Enable low-power hibernation mode on SPI
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Enable low-power hibernation mode on i2c
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Change hibernate sequence to use allow auto
  hibernate (jsc#PED-9993 jsc#PED-10202).
- commit 4fd311f
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: cs35l56: Initialise a variable to silence possible static
  analysis error (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-dapm: Annotate struct snd_soc_dapm_widget_list with
  __counted_by (jsc#PED-9993 jsc#PED-10202).
- ASoC: Adds support for TAS575x to the pcm512x driver
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: osk5912: Drop unused include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ti: Convert TWL4030 to use GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ti: Convert N810 ASoC to GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ti: Convert RX51 to use exclusively GPIO descriptors
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tas2781: fixed compiling issue in m68k (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Remove unused variable (jsc#PED-9993
  jsc#PED-10202).
- commit e9e2283
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: intel: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-Intel-skl_hda_dsp_generic-Drop-HDMI-routes-when.patch.
- commit f7a12f5
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Update documentation with Sub-NUMA cluster changes (jsc#PED-10246).
- commit 2f6a8c1
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Detect Sub-NUMA Cluster (SNC) mode (jsc#PED-10246).
- commit a736a9f
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Enable shared RMID mode on Sub-NUMA Cluster (SNC) systems (jsc#PED-10246).
- commit 8470ab8
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Make __mon_event_count() handle sum domains (jsc#PED-10246).
- commit e12fa7f
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Fill out rmid_read structure for smp_call*() to read a  counter (jsc#PED-10246).
- commit 35c1e43
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Handle removing directories in Sub-NUMA Cluster (SNC)  mode (jsc#PED-10246).
- commit f516863
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: Intel: avs: Drop superfluous stream decoupling
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Disable DSP before loading basefw
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Keep module refcount up when gathering traces
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Preallocate memory for module configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Use generic size defines (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Move IPC error messages one level down
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: Add code for bin parsing compatible with aw87390
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: Modify i2c driver name (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: Modify the transmission method of parameters
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: Rename "sound-channel" to "awinic,audio-channel"
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: Remove the "fade-enable property" (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l43: Remove useless else (jsc#PED-9993 jsc#PED-10202).
- ASoC: sof: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-generic-dmaengine-pcm: convert not to use asoc_xxx()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-component: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-compress: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-topology: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-utils: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-link: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-dapm: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-core: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-pcm: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- commit 07347ce
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Create Sub-NUMA Cluster (SNC) monitor files (jsc#PED-10246).
- commit a08d01f
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Allocate a new field in union mon_data_bits (jsc#PED-10246).
- commit cc5e5f7
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Refactor mkdir_mondata_subdir() with a helper function (jsc#PED-10246).
- commit 0fb57c1
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Initialize on-stack struct rmid_read instances (jsc#PED-10246).
- commit c8eae6e
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Add a new field to struct rmid_read for summation of  domains (jsc#PED-10246).
- commit d4617d3
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Prepare for new Sub-NUMA Cluster (SNC) monitor files (jsc#PED-10246).
- commit 25a8f57
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Block use of mba_MBps mount option on Sub-NUMA Cluster  (SNC) systems (jsc#PED-10246).
- commit c78bcda
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: sof: intel: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/Revert-ASoC-SOF-Intel-hda-dai-ops-only-allocate-rele.patch.
- commit 2a3aaf9
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: soc-dai: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sof: mediatek: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sof: amd: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codec: cs47lxx: convert not to use asoc_xxx()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codec: rt5677: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codec: wm: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: intel: avs: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: uniphier: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- commit 2fe8f96
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Introduce snc_nodes_per_l3_cache (jsc#PED-10246).
- commit d2a023a
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Add node-scope to the options for feature scope (jsc#PED-10246).
- commit 7ee61bb
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: rockchip: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: kirkwood: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: extensa: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: generic: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cirrus: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ux500: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tegra: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- commit 68c0e0d
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: qcom: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-qcom-Fix-uninitialized-pointer-dmactl.patch.
- commit 9005a88
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Split the rdt_domain and rdt_hw_domain structures (jsc#PED-10246).
- commit 7d8730a
* Tue Sep  3 2024 oneukum@suse.com
- usb: typec: Update sysfs when setting ops (jsc#PED-10361).
- commit 1a222d3
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: sunxi: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: meson: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: atmel: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: apple: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sprd: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: au1x: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: stm: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mxs: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- commit 70687c7
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Prepare for different scope for control/monitor operations (jsc#PED-10246).
- commit 8396324
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: fsl: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- commit 514decd
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Prepare to split rdt_domain structure  (jsc#PED-10246).
- commit 209dab8
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: sh: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- commit af8fea3
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Simplify call convention for MSR update functions (jsc#PED-10246).
- commit 9309a0c
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Remove lockdep annotation that triggers false positive (git-fixes).
- Refresh patches.suse/x86-resctrl-Pass-domain-to-target-CPU.patch.
- commit 90d6a70
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Pass domain to target CPU (jsc#PED-10246).
- commit 6fa6f8f
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: img: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: dwc: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: bcm: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ti: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: simple_card_utils.h: convert not to use asoc_xxx()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc.h: convert asoc_xxx() to snd_soc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sh: dma-sh7760: Use %%pad and %%zu to format dma_addr_t
  and size_t (jsc#PED-9993 jsc#PED-10202).
- commit 937299e
* Tue Sep  3 2024 oneukum@suse.com
- usb: typec: ucsi: Wait 20ms before reading CCI after a reset
  (git-fixes).
- commit 26d16be
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: hdac_hda: fix HDA patch loader support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l43: Extend timeout on bias sense timeout
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Move headset bias sense enable earlier in process
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Enable bias sense by default (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l43: Lower default type detect time (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: hda: add ipc4 FW panic support on CAVS 2.5+
  platforms (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: mtl: dump dsp stack (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: add telemetry retrieval support on Intel
  platforms (jsc#PED-9993 jsc#PED-10202).
- commit 9a7e8b3
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Prepare for new domain scope (jsc#PED-10246).
- commit 841df76
* Tue Sep  3 2024 oneukum@suse.com
- usb: typec: tcpci: add support to set connector orientation
  (jsc#PED-10361).
- commit ce79fa0
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Separate arch and fs resctrl locks (jsc#PED-10246).
- commit 59dcdf2
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Move domain helper migration into resctrl_offline_cpu() (jsc#PED-10246).
- commit d9d6be2
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Add CPU offline callback for resctrl work (jsc#PED-10246).
- commit 0239fcf
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Allow overflow/limbo handlers to be scheduled on any-but  CPU (jsc#PED-10246).
- commit 2f1b99a
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Add CPU online callback for resctrl work (jsc#PED-10246).
- commit f61b83a
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Add helpers for system wide mon/alloc capable (jsc#PED-10246).
- commit 7a99070
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Make rdt_enable_key the arch's decision to switch (jsc#PED-10246).
- commit 0343158
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Move alloc/mon static keys into helpers (jsc#PED-10246).
- commit 40a257e
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Make resctrl_mounted checks explicit (jsc#PED-10246).
- commit 4130fd7
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Allow arch to allocate memory needed in resctrl_arch_rmid_read() (jsc#PED-10246).
- commit beffd86
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Allow resctrl_arch_rmid_read() to sleep (jsc#PED-10246).
- commit f673a82
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Queue mon_event_read() instead of sending an IPI (jsc#PED-10246).
- commit 4044104
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Add cpumask_any_housekeeping() for limbo/overflow (jsc#PED-10246).
- commit b70a155
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Move CLOSID/RMID matching and setting to use helpers (jsc#PED-10246).
- commit a397168
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Allocate the cleanest CLOSID by searching closid_num_dirty_rmid (jsc#PED-10246).
- commit 3147061
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Use __set_bit()/__clear_bit() instead of open coding (jsc#PED-10246).
- commit cfbc94d
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Track the number of dirty RMID a CLOSID has (jsc#PED-10246).
- commit 67aa65d
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Allow RMID allocation to be scoped by CLOSID (jsc#PED-10246).
- commit 0d248f5
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Access per-rmid structures by index (jsc#PED-10246).
- commit 5c53c09
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Track the closid with the rmid (jsc#PED-10246).
- commit e319879
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Move RMID allocation out of mkdir_rdt_prepare() (jsc#PED-10246).
- commit 7104a62
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Create helper for RMID allocation and mondata dir  creation (jsc#PED-10246).
- commit ff5a028
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Free rmid_ptrs from resctrl_exit() (jsc#PED-10246).
- commit 9df1f34
* Tue Sep  3 2024 nik.borisov@suse.com
- tick/nohz: Move tick_nohz_full_mask declaration outside the #ifdef (jsc#PED-10246).
- commit 4eae403
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Replace open coded cacheinfo searches (jsc#PED-10246).
- commit 7cb6f10
* Tue Sep  3 2024 nik.borisov@suse.com
- cacheinfo: Add function to get cacheinfo for a given CPU and cache  level (jsc#PED-10246).
- commit 7646391
* Tue Sep  3 2024 nik.borisov@suse.com
- cpu: Drop "extern" from function declarations in cpuhplock.h (jsc#PED-10246).
- commit 469d1ac
* Tue Sep  3 2024 nik.borisov@suse.com
- cpu: Move CPU hotplug function declarations into their own header (jsc#PED-10246).
- commit 3838f46
* Mon Sep  2 2024 msuchanek@suse.de
- Update config files (jsc#PED-10537).
  ppc64le: NR_CPUS=8192
  This alings with x86.
- commit e432f98
* Mon Sep  2 2024 lduncan@suse.com
- scsi: sd: Fix TCG OPAL unlock on system resume (git-fixes).
- commit d2a3c0c
* Mon Sep  2 2024 tiwai@suse.de
- supported.conf: add cs42l43 mfd stuff (jsc#PED-9993 jsc#PED-10202)
- commit cbf3c59
* Mon Sep  2 2024 tiwai@suse.de
- Update config files.
- commit 62b9c41
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: ipc4: add definition of telemetry slot for exception
  handling (jsc#PED-9993 jsc#PED-10202).
- commit a0f002f
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: ipc4-topology: Add definition for generic switch/enum
  control (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-SOF-ipc4-topology-Correct-data-structures-for-t-e238b68.patch.
- commit 2f55301
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: ipc4: add exception node in sof debugfs directory
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4: add a helper function to search debug slot
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-mtrace: move debug slot related definitions
  to header.h (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Xtensa: dump ar registers to restore call stack
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-control: Add support for ALSA enum control
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-control: Add support for ALSA switch control
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-mtl-match: add acpi match table
  for cdb35l56-eight-c (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Add CS42L43 CODEC support (jsc#PED-9993
  jsc#PED-10202).
- commit 2622d6f
* Mon Sep  2 2024 tiwai@suse.de
- mfd: cs42l43: Add support for cs42l43 core driver (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ALSA-hda-cs35l56-Add-support-for-speaker-id.patch.
- commit 7a6f06f
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: cs42l43: Update values for bias sense (jsc#PED-9993
  jsc#PED-10202).
- mfd: cs42l43: Use correct macro for new-style PM runtime ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Add shared IRQ flag for shutters (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l43: Fix missing error code in cs42l43_codec_probe()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Use new-style PM runtime macros (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l43: Initialize ret in default case in
  cs42l43_pll_ev() (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Add support for the cs42l43 (jsc#PED-9993
  jsc#PED-10202).
- commit a8e4694
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: Intel: Use generic names for IPC types (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-SOF-Intel-add-default-firmware-library-path-for.patch.
- commit 6f1113b
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: mediatek: Use generic names for IPC types
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: imx: Use generic names for IPC types (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: amd: Use generic names for IPC types (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Introduce generic names for IPC types (jsc#PED-9993
  jsc#PED-10202).
- commit 318d3b1
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: Use generic names for IPC types (jsc#PED-9993
  jsc#PED-10202).
- commit 709a77b
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: Kconfig: Rename SND_SOC_SOF_INTEL_IPC4 to
  SND_SOC_SOF_IPC4 (jsc#PED-9993 jsc#PED-10202).
- Update config files.
- commit c737115
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: sof-pci-dev: Update the ipc_type module parameter
  description (jsc#PED-9993 jsc#PED-10202).
- ASoC: hdac_hda: add HDA patch loader support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: da7213: add .auto_selectable_formats support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: da7213: tidyup SND_SOC_DAIFMT_xxx (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm8782: Use wlf,fsampen device tree property (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm8782: Constrain maximum audio rate at runtime
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: fixup dailink based on copier format
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: export
  sof_ipc4_copier_is_single_format (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Increment be_id in init_dai_link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Make create_sdw_dailink allocate link
  components (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Add simple DAI link creation helper
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Move sdw_pin_index into private struct
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-loader: Add support for split library
  loading (jsc#PED-9993 jsc#PED-10202).
- commit 198b013
* Mon Sep  2 2024 tiwai@suse.de
- supported.conf: rename to snd-soc-sof-da7219 (jsc#PED-9993 jsc#PED-10202)
- commit 9530d42
* Mon Sep  2 2024 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_INTEL_SOF_DA7219_MACH=m (jsc#PED-9993 jsc#PED-10202)
- commit 07ccb03
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: ipc4: Add new message type:
  SOF_IPC4_GLB_LOAD_LIBRARY_PREPARE (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: Add definition for SDxFIFOS.FIFOS mask
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4: Convert status code 2 and 15 to -EOPNOTSUPP
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Omit cs35l56_pm_ops_i2c_spi if I2C/SPI not
  enabled (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Use new export macro for dev_pm_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l56: Use pm_ptr() (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: use ssp-common module to detect codec
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: add adl_mx98360_da7219 board config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: use maxim-common module (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_da7219: rename driver file and kernel option
  (jsc#PED-9993 jsc#PED-10202).
- commit 69c3a63
* Mon Sep  2 2024 tiwai@suse.de
- supported.conf: add snd-soc-intel-sof-nuvoton-common (jsc#PED-9993 jsc#PED-10202)
- commit 4536dea
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: Intel: sof_nau8825: use realtek-common module
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use nuvoton-common module
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: nuvoton-common: support nau8318 amplifier
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: do not create amp link for nocodec
  board (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: add HDMI_In capture feature support
  for RPL (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: add adl_rt5650 board config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: Modify number of HDMI to 3 for MTL/Rex
  devices (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: Add support for Rex with discrete BT
  offload (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use ssp-common module to detect codec
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: use ssp-common module to detect codec
  (jsc#PED-9993 jsc#PED-10202).
- commit 16b6cac
* Mon Sep  2 2024 lduncan@suse.com
- scsi: sd: Remove the number of forward declarations (git-fixes).
- Refresh
  patches.suse/scsi-sd-Differentiate-system-and-runtime-start-stop-management.patch.
- commit 69a1f4f
* Mon Sep  2 2024 tiwai@suse.de
- supported.conf: add snd-soc-sof-ssp-common (jsc#PED-9993 jsc#PED-10202)
- commit c8b93b2
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: Intel: sof_cs42l42: use ssp-common module to detect codec
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use ssp-common module to detect codec
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: use ACPI HID definition in ssp-common (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: ssp-common: support codec detection (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_rt5682: cleanup unnecessary quirk flag
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: ps: Fix -Wformat-truncation warning (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1015: fix the first word being cut off (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Add deep buffer size to debug prints
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4: Dump the payload also when set_get_data fails
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ops.h: Change the error code for not supported to
  EOPNOTSUPP (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Fix -Wmissing-prototypes warning (jsc#PED-9993
  jsc#PED-10202).
- ASoC: nau8821: Revise MICBIAS control for power saving
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: hdac_hdmi: Remove temporary string use in
  create_fill_jack_kcontrols (jsc#PED-9993 jsc#PED-10202).
- ASoC: rsnd: remove unneeded of_node_put() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: lpass-tx-macro: Add SM6115 support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tlv320aic32x4-spi: Simplify probe() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tlv320aic32x4-i2c: Simplify probe() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codec: tlv320aic32x4: Add enum aic32x4_type to
  aic32x4_probe() (jsc#PED-9993 jsc#PED-10202).
- ASoC: max98927: Drop pointless includes (jsc#PED-9993
  jsc#PED-10202).
- commit d9e22c1
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: max98520: Drop pointless includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: max98396: Drop pointless include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: max98388: Correct the includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: max98373: Convert to use GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: max98357a: Drop pointless include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: max9768: Convert to use GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: mt8188-mt6359: add SOF support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: common: revise SOF common code (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ak4642: Simplify probe() (jsc#PED-9993 jsc#PED-10202).
- ASoC: ak4642: Minor cleanups in probe() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: acp: Add machine driver that enables sound for
  systems with a ES8336 codec (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Add support for splitting the codec specific
  code from the ACP driver (jsc#PED-9993 jsc#PED-10202).
- ASoC: es8316: Enable support for MCLK div by 2 (jsc#PED-9993
  jsc#PED-10202).
- ASoC: es8316: Replace NR_SUPPORTED_MCLK_LRCK_RATIOS with
  ARRAY_SIZE() (jsc#PED-9993 jsc#PED-10202).
- ASoC: es8316: Enable support for S32 LE format (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tas571x: Simplify probe() (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l45: Add AMP Enable Switch control (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l45: Connect DSP to the monitoring signals
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l45: Analog PCM Volume and Amplifier Mode controls
  (jsc#PED-9993 jsc#PED-10202).
- commit 2cb38d8
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: cs42xx8-i2c: Simplify probe() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm8580: Simplify probe() (jsc#PED-9993 jsc#PED-10202).
- ASoC: meson: axg: extend TDM maximum sample rate to 384kHz
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: i915: Remove extra argument from snd_hdac_i915_init
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: Move binding to display driver outside of
  deferred probe (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: Skylake: Move snd_hdac_i915_init to before
  probe_work (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Intel: Move snd_hdac_i915_init to before probe_work
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Move snd_hdac_i915_init to before probe_work
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: i915: Allow xe as match for
  i915_component_master_match (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: i915: Add an allow_modprobe argument to
  snd_hdac_i915_init (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: i915: Allow override of gpu binding (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: Fix error handling in hda_init() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: hda: start splitting the probe (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: core: Add probe_early and remove_late callbacks
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Add code_loading parameter to stream setup
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Fix stream fifo_size initialization (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: Skylake: Use helper to setup HOST stream
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Use helper to setup HOST stream (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: Introduce HOST stream setup mechanism (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: Poll SDxFIFOS after programming SDxFMT (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: Annotate struct hda_conn_list with __counted_by
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Use pci_get_base_class() to reduce duplicated code
  (jsc#PED-9993 jsc#PED-10202).
- sound: Fix snd_pcm_readv()/writev() to use iov access functions
  (jsc#PED-9993 jsc#PED-10202).
- commit 34c3bbb
* Mon Sep  2 2024 lhenriques@suse.de
- ceph: periodically flush the cap releases (bsc#1230057).
- commit e3f19db
* Mon Sep  2 2024 lhenriques@suse.de
- ceph: periodically flush the cap releases (bsc#1230056).
- commit e22b6e0
* Mon Sep  2 2024 denis.kirjanov@suse.com
- Bluetooth: Fix usage of __hci_cmd_sync_status (git-fixes).
- commit 1bec58d
* Mon Sep  2 2024 denis.kirjanov@suse.com
- Bluetooth: L2CAP: Fix deadlock (git-fixes).
- commit 13aba13
* Mon Sep  2 2024 sjaeckel@suse.de
- net/sched: act_ct: fix skb leak and crash on ooo frags
  (CVE-2023-52610 bsc#1221610).
- commit 7a32533
* Mon Sep  2 2024 denis.kirjanov@suse.com
- bluetooth/l2cap: sync sock recv cb and release (bsc#1228576
  CVE-2024-41062).
- commit 6553526
* Mon Sep  2 2024 osalvador@suse.de
- mm: prevent derefencing NULL ptr in pfn_section_valid()
  (git-fixes).
- commit 35f619d
* Mon Sep  2 2024 osalvador@suse.de
- mm, kmsan: fix infinite recursion due to RCU critical section
  (git-fixes).
- commit 16ad73a
* Mon Sep  2 2024 osalvador@suse.de
- mm/sparsemem: fix race in accessing memory_section->usage
  (bsc#1221326 CVE-2023-52489).
- commit 6aa8957
* Mon Sep  2 2024 ohering@suse.de
- net: mana: Fix race of mana_hwc_post_rx_wqe and new hwc response (git-fixes).
- commit 4dc1da1
* Sun Sep  1 2024 ailiop@suse.com
- xfs: Fix missing interval for missing_owner in xfs fsmap
  (git-fixes).
- commit 5448ab5
* Sun Sep  1 2024 ailiop@suse.com
- xfs: use XFS_BUF_DADDR_NULL for daddrs in getfsmap code
  (git-fixes).
- commit 288ad9b
* Sun Sep  1 2024 ailiop@suse.com
- xfs: Fix the owner setting issue for rmap query in xfs fsmap
  (git-fixes).
- commit 49b5eec
* Sun Sep  1 2024 tiwai@suse.de
- usb: cdnsp: fix for Link TRB with TC (git-fixes).
- usb: dwc3: st: add missing depopulate in probe error path
  (git-fixes).
- usb: dwc3: st: fix probed platform device ref count on probe
  error path (git-fixes).
- usb: core: sysfs: Unmerge @usb3_hardware_lpm_attr_group in
  remove_power_attributes() (git-fixes).
- usb: typec: fsa4480: Relax CHIP_ID check (git-fixes).
- usb: dwc3: omap: add missing depopulate in probe error path
  (git-fixes).
- usb: cdnsp: fix incorrect index in cdnsp_get_hw_deq function
  (git-fixes).
- soc: qcom: pmic_glink: Actually communicate when remote goes
  down (git-fixes).
- soc: qcom: cmd-db: Map shared memory as WC, not WB (git-fixes).
- commit 7121142
* Sat Aug 31 2024 lduncan@suse.com
- scsi: sd: usb_storage: uas: Access media prior to querying
  device properties (git-fixes).
- commit b52ca33
* Sat Aug 31 2024 lduncan@suse.com
- blacklist.conf: Remove 2 commits that broke kABI
  Removing two entries for SCSI upstream commits that
  broke the kABI in the previous release. The commits
  in question will be added in separate commits.
- commit d8b4368
* Sat Aug 31 2024 tiwai@suse.de
- dmaengine: dw: Add memory bus width verification (git-fixes).
- dmaengine: dw: Add peripheral bus width verification
  (git-fixes).
- soundwire: stream: fix programming slave ports for non-continous
  port maps (git-fixes).
- commit b7e9784
* Fri Aug 30 2024 mkoutny@suse.com
- Update patches.suse/Bluetooth-HCI-Remove-HCI_AMP-support.patch
  (git-fixes CVE-2024-38620 bsc#1226869).
- Update
  patches.suse/serial-core-Clearing-the-circular-buffer-before-NULLifying-it.patch
  (git-fixes CVE-2024-26998 bsc#1223736).
- Update patches.suse/wifi-mac80211-fix-TTLM-teardown-work.patch
  (jsc#PED-10412 CVE-2024-43848 bsc#1229302).
- commit 6b31cec
* Fri Aug 30 2024 mkoutny@suse.com
- Update
  patches.suse/0001-net-rds-fix-possible-cp-null-dereference.patch
  (git-fixes CVE-2024-35902 bsc#1224496).
- Update
  patches.suse/ASoC-TAS2781-Fix-tasdev_load_calibrated_data.patch
  (git-fixes CVE-2024-42278 bsc#1229403).
- Update
  patches.suse/ASoC-amd-Adjust-error-handling-in-case-of-absent-cod.patch
  (git-fixes CVE-2024-43818 bsc#1229296).
- Update
  patches.suse/ASoC-fsl-fsl_qmc_audio-Check-devm_kasprintf-returned.patch
  (git-fixes CVE-2024-42298 bsc#1229369).
- Update
  patches.suse/Bluetooth-MGMT-Add-error-handling-to-pair_device.patch
  (git-fixes CVE-2024-43884 bsc#1229739).
- Update
  patches.suse/KVM-Always-flush-async-PF-workqueue-when-vCPU-is-bei.patch
  (git-fixes CVE-2024-26976 bsc#1223635).
- Update
  patches.suse/PCI-DPC-Fix-use-after-free-on-concurrent-DPC-and-hot.patch
  (git-fixes CVE-2024-42302 bsc#1229366).
- Update
  patches.suse/PCI-endpoint-Clean-up-error-handling-in-vpci_scan_bu.patch
  (git-fixes CVE-2024-43875 bsc#1229486).
- Update
  patches.suse/PCI-endpoint-pci-epf-test-Make-use-of-cached-epc_fea.patch
  (git-fixes CVE-2024-43824 bsc#1229320).
- Update
  patches.suse/PCI-keystone-Fix-NULL-pointer-dereference-in-case-of.patch
  (git-fixes CVE-2024-43823 bsc#1229303).
- Update
  patches.suse/PCI-rcar-Demote-WARN-to-dev_warn_ratelimited-in-rcar.patch
  (git-fixes CVE-2024-43876 bsc#1229485).
- Update
  patches.suse/RDMA-hns-Fix-soft-lockup-under-heavy-CEQE-load.patch
  (git-fixes CVE-2024-43872 bsc#1229489).
- Update
  patches.suse/RDMA-iwcm-Fix-a-use-after-free-related-to-destroying.patch
  (git-fixes CVE-2024-42285 bsc#1229381).
- Update
  patches.suse/Revert-ALSA-firewire-lib-operate-for-period-elapse-e.patch
  (bsc#1208783 CVE-2024-42274 bsc#1229417).
- Update
  patches.suse/SUNRPC-add-a-missing-rpc_stat-for-TCP-TLS.patch
  (git-fixes CVE-2024-36907 bsc#1225751).
- Update
  patches.suse/bpf-arm64-Fix-trampoline-for-BPF_TRAMP_F_CALL_ORIG.patch
  (git-fixes CVE-2024-43840 bsc#1229344).
- Update
  patches.suse/btrfs-fix-double-inode-unlock-for-direct-IO-sync-wri.patch
  (git-fixes CVE-2024-43885 bsc#1229747).
- Update
  patches.suse/btrfs-fix-extent-map-use-after-free-when-adding-page.patch
  (git-fixes CVE-2024-42314 bsc#1229355).
- Update
  patches.suse/cgroup-cpuset-Prevent-UAF-in-proc_cpuset_show.patch
  (bsc#1228801 CVE-2024-43853 bsc#1229292).
- Update
  patches.suse/crypto-ccp-Fix-null-pointer-dereference-in-__sev_snp.patch
  (git-fixes CVE-2024-43874 bsc#1229487).
- Update
  patches.suse/devres-Fix-memory-leakage-caused-by-driver-API-devm_.patch
  (git-fixes CVE-2024-43871 bsc#1229490).
- Update
  patches.suse/dma-fix-call-order-in-dmam_free_coherent.patch
  (git-fixes CVE-2024-43856 bsc#1229346).
- Update
  patches.suse/drm-admgpu-fix-dereferencing-null-pointer-context.patch
  (stable-fixes CVE-2024-43906 bsc#1229785).
- Update
  patches.suse/drm-amd-display-Add-NULL-check-for-afb-before-derefe.patch
  (stable-fixes CVE-2024-43903 bsc#1229781).
- Update
  patches.suse/drm-amd-display-Add-null-checker-before-passing-vari.patch
  (stable-fixes CVE-2024-43902 bsc#1229767).
- Update
  patches.suse/drm-amd-display-Skip-Recompute-DSC-Params-if-no-Stre.patch
  (stable-fixes CVE-2024-43895 bsc#1229755).
- Update
  patches.suse/drm-amd-pm-Fix-the-null-pointer-dereference-for-vega.patch
  (stable-fixes CVE-2024-43905 bsc#1229784).
- Update
  patches.suse/drm-amdgpu-Fix-the-null-pointer-dereference-to-ras_m.patch
  (stable-fixes CVE-2024-43908 bsc#1229788).
- Update
  patches.suse/drm-amdgpu-pm-Fix-the-null-pointer-dereference-for-s.patch
  (stable-fixes CVE-2024-43909 bsc#1229789).
- Update
  patches.suse/drm-amdgpu-pm-Fix-the-null-pointer-dereference-in-ap.patch
  (stable-fixes CVE-2024-43907 bsc#1229787).
- Update
  patches.suse/drm-client-fix-null-pointer-dereference-in-drm_clien.patch
  (git-fixes CVE-2024-43894 bsc#1229746).
- Update
  patches.suse/drm-gma500-fix-null-pointer-dereference-in-cdv_intel.patch
  (git-fixes CVE-2024-42310 bsc#1229358).
- Update
  patches.suse/drm-gma500-fix-null-pointer-dereference-in-psb_intel.patch
  (git-fixes CVE-2024-42309 bsc#1229359).
- Update
  patches.suse/drm-nouveau-prime-fix-refcount-underflow.patch
  (git-fixes CVE-2024-43867 bsc#1229493).
- Update patches.suse/drm-qxl-Add-check-for-drm_cvt_mode.patch
  (git-fixes CVE-2024-43829 bsc#1229341).
- Update
  patches.suse/drm-vmwgfx-Fix-a-deadlock-in-dma-buf-fence-polling.patch
  (git-fixes CVE-2024-43863 bsc#1229497).
- Update
  patches.suse/exfat-fix-potential-deadlock-on-__exfat_get_dentry_set.patch
  (git-fixes CVE-2024-42315 bsc#1229354).
- Update
  patches.suse/gpio-prevent-potential-speculation-leaks-in-gpio_dev.patch
  (stable-fixes CVE-2024-44931 bsc#1229837).
- Update
  patches.suse/hfs-fix-to-initialize-fields-of-hfs_inode_info-after-hfs_alloc_inode.patch
  (git-fixes CVE-2024-42311 bsc#1229413).
- Update
  patches.suse/iio-Fix-the-sorting-functionality-in-iio_gts_build_a.patch
  (git-fixes CVE-2024-43825 bsc#1229298).
- Update
  patches.suse/jfs-Fix-array-index-out-of-bounds-in-diFree.patch
  (git-fixes CVE-2024-43858 bsc#1229414).
- Update
  patches.suse/jfs-Fix-shift-out-of-bounds-in-dbDiscardAG.patch
  (git-fixes CVE-2024-44938 bsc#1229792).
- Update
  patches.suse/jfs-fix-null-ptr-deref-in-dtInsertEntry.patch
  (git-fixes CVE-2024-44939 bsc#1229820).
- Update
  patches.suse/kobject_uevent-Fix-OOB-access-within-zap_modalias_en.patch
  (git-fixes CVE-2024-42292 bsc#1229373).
- Update
  patches.suse/kvm-s390-Reject-memory-region-operations-for-ucontrol-VMs.patch
  (git-fixes bsc#1229168 CVE-2024-43819 bsc#1229290).
- Update
  patches.suse/leds-trigger-Unregister-sysfs-attributes-before-call.patch
  (git-fixes CVE-2024-43830 bsc#1229305).
- Update
  patches.suse/lib-objagg-Fix-general-protection-fault.patch
  (git-fixes CVE-2024-43846 bsc#1229360).
- Update
  patches.suse/libbpf-Use-OPTS_SET-macro-in-bpf_xdp_query.patch
  (git-fixes CVE-2024-27050 bsc#1223767).
- Update
  patches.suse/mISDN-Fix-a-use-after-free-in-hfcmulti_tx.patch
  (git-fixes CVE-2024-42280 bsc#1229388).
- Update
  patches.suse/mailbox-mtk-cmdq-Move-devm_mbox_controller_register-.patch
  (git-fixes CVE-2024-42319 bsc#1229350).
- Update
  patches.suse/md-raid5-fix-deadlock-that-raid5d-wait-for-itself-to-clear-MD_SB_CHANGE_PENDING-151f.patch
  (git-fixes CVE-2024-39476 bsc#1227437).
- Update
  patches.suse/media-imx-pxp-Fix-ERR_PTR-dereference-in-pxp_probe.patch
  (git-fixes CVE-2024-42303 bsc#1229365).
- Update
  patches.suse/media-pci-ivtv-Add-check-for-DMA-map-result.patch
  (git-fixes CVE-2024-43877 bsc#1229484).
- Update
  patches.suse/media-v4l-async-Fix-NULL-pointer-dereference-in-addi.patch
  (git-fixes CVE-2024-43833 bsc#1229299).
- Update
  patches.suse/media-venus-fix-use-after-free-in-vdec_close.patch
  (git-fixes CVE-2024-42313 bsc#1229356).
- Update
  patches.suse/media-xc2028-avoid-use-after-free-in-load_firmware_c.patch
  (stable-fixes CVE-2024-43900 bsc#1229756).
- Update
  patches.suse/memcg-protect-concurrent-access-to-mem_cgroup_idr.patch
  (git-fixes CVE-2024-43892 bsc#1229761).
- Update
  patches.suse/net-drop-bad-gso-csum_start-and-offset-in-virtio_net.patch
  (git-fixes CVE-2024-43897 bsc#1229752).
- Update
  patches.suse/net-iucv-fix-use-after-free-in-iucv_sock_close.patch
  (bsc#1228973 CVE-2024-42271 bsc#1229400).
- Update patches.suse/net-missing-check-virtio.patch (git-fixes
  CVE-2024-43817 bsc#1229312).
- Update
  patches.suse/net-usb-qmi_wwan-fix-memory-leak-for-not-ip-packets.patch
  (git-fixes CVE-2024-43861 bsc#1229500).
- Update
  patches.suse/nfs-pass-explicit-offset-count-to-trace-events.patch
  (git-fixes CVE-2024-43826 bsc#1229294).
- Update
  patches.suse/nvme-pci-add-missing-condition-check-for-existence-o.patch
  (git-fixes CVE-2024-42276 bsc#1229410).
- Update
  patches.suse/padata-Fix-possible-divide-by-0-panic-in-padata_mt_h.patch
  (git-fixes CVE-2024-43889 bsc#1229743).
- Update
  patches.suse/remoteproc-imx_rproc-Skip-over-memory-region-when-no.patch
  (git-fixes CVE-2024-43860 bsc#1229319).
- Update
  patches.suse/s390-dasd-fix-error-checks-in-dasd_copy_pair_store.patch
  (git-fixes bsc#1229173 CVE-2024-42320 bsc#1229349).
- Update
  patches.suse/scsi-lpfc-Revise-lpfc_prep_embed_io-routine-with-pro.patch
  (bsc#1228857 CVE-2024-43816 bsc#1229318).
- Update
  patches.suse/scsi-qla2xxx-Complete-command-early-within-lock.patch
  (bsc#1228850 CVE-2024-42287 bsc#1229392).
- Update
  patches.suse/scsi-qla2xxx-During-vport-delete-send-async-logout-e.patch
  (bsc#1228850 CVE-2024-42289 bsc#1229399).
- Update
  patches.suse/scsi-qla2xxx-Fix-for-possible-memory-corruption.patch
  (bsc#1228850 CVE-2024-42288 bsc#1229398).
- Update
  patches.suse/scsi-qla2xxx-validate-nvme_local_port-correctly.patch
  (bsc#1228850 CVE-2024-42286 bsc#1229395).
- Update
  patches.suse/serial-core-check-uartclk-for-zero-to-avoid-divide-b.patch
  (stable-fixes CVE-2024-43893 bsc#1229759).
- Update
  patches.suse/soc-qcom-pdr-protect-locator_addr-with-the-main-mute.patch
  (git-fixes CVE-2024-43849 bsc#1229307).
- Update
  patches.suse/soc-xilinx-rename-cpu_number1-to-dummy_cpu_number.patch
  (git-fixes CVE-2024-43851 bsc#1229313).
- Update
  patches.suse/spi-microchip-core-ensure-TX-and-RX-FIFOs-are-empty-.patch
  (git-fixes CVE-2024-42279 bsc#1229390).
- Update
  patches.suse/usb-vhci-hcd-Do-not-drop-references-before-new-refer.patch
  (stable-fixes CVE-2024-43883 bsc#1229707).
- Update
  patches.suse/vhost-vsock-always-initialize-seqpacket_allow.patch
  (git-fixes CVE-2024-43873 bsc#1229488).
- Update
  patches.suse/wifi-ath12k-change-DMA-direction-while-mapping-reinj.patch
  (git-fixes CVE-2024-43881 bsc#1229480).
- Update
  patches.suse/wifi-ath12k-fix-invalid-memory-access-while-processi.patch
  (git-fixes CVE-2024-43847 bsc#1229291).
- Update
  patches.suse/wifi-cfg80211-handle-2x996-RU-allocation-in-cfg80211.patch
  (git-fixes CVE-2024-43879 bsc#1229482).
- Update
  patches.suse/wifi-nl80211-disallow-setting-special-AP-channel-wid.patch
  (stable-fixes CVE-2024-43912 bsc#1229830).
- Update
  patches.suse/wifi-rtw89-Fix-array-index-mistake-in-rtw89_sta_info.patch
  (git-fixes CVE-2024-43842 bsc#1229317).
- Update
  patches.suse/wifi-virt_wifi-avoid-reporting-connection-success-wi.patch
  (git-fixes CVE-2024-43841 bsc#1229304).
- commit 140ec33
* Fri Aug 30 2024 tiwai@suse.de
- soundwire: intel_auxdevice: add hybrid IDA-based device_number
  allocation (jsc#PED-9993 jsc#PED-10202).
- commit 6b2c29c
* Fri Aug 30 2024 tiwai@suse.de
- soundwire: bus: add callbacks for device_number allocation
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/soundwire-bus-introduce-controller_id.patch.
- Refresh patches.suse/soundwire-suse-kabi-padding.patch.
- commit 57520f2
* Fri Aug 30 2024 tiwai@suse.de
- soundwire: bus: Make IRQ handling conditionally built
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_ace2x: add DAI hw_params/prepare/hw_free
  callbacks (jsc#PED-9993 jsc#PED-10202).
- soundwire: extend parameters of new_peripheral_assigned()
  callback (jsc#PED-9993 jsc#PED-10202).
- soundWire: intel_auxdevice: resume 'sdw-master' on startup
  and system resume (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_auxdevice: enable pm_runtime earlier on startup
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: Explicitly include correct DT includes (jsc#PED-9993
  jsc#PED-10202).
- soundwire: bus: Allow SoundWire peripherals to register IRQ
  handlers (jsc#PED-9993 jsc#PED-10202).
- commit 1cef7db
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: dwc: Fix non-DT instantiation (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wsa-macro: handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5682: Fix regulator enable/disable sequence
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: core: Print component name when printing log (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-generic-dmaengine-pcm: Fix function name in comment
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: aw88395: Fix some error codes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-pcm: Shrink stack frame for __soc_pcm_hw_params
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8960: Fix error handling in probe (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rsnd: add missing of_node_put (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: midi: Fix -Wformat-truncation warning (jsc#PED-9993
  jsc#PED-10202).
- ALSA: core: Use dev_name of card_dev as debugfs directory name
  (jsc#PED-9993 jsc#PED-10202).
- commit 678dced
* Fri Aug 30 2024 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_WCD_CLASSH=m (jsc#PED-9993 jsc#PED-10202)
- commit bf5114f
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: rt5645: NULL pointer access when removing jack
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l45: Rename DACPCM1 Source control (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l45: Fix "Dead assigment" warning (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l45: Add support for Chip ID 0x35A460 (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wcd93xx: fix object added to multiple drivers
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Fix error checks of default read/write copy ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Name iov_iter argument as iterator instead of buffer
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: dmaengine: Drop unused iov_iter for process callback
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: dwc: i2s: Fix unused functions (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-core.c: Do not error if a DAI link component is not
  found (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card.c: move audio_graph_parse_of()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: dwc: i2s: Add StarFive JH7110 SoC support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: dwc: Use ops to get platform data (jsc#PED-9993
  jsc#PED-10202).
- commit 3c6994b
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: rsnd: setup BRGCKR/BRRA/BRRB on rsnd_adg_clk_control()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rsnd: remove default division of clock out (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rsnd: tidyup brga/brgb default value (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rsnd: setup clock-out only when all conditions are right
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rsnd: enable clk_i approximate rate usage (jsc#PED-9993
  jsc#PED-10202).
- ASoC: audio-graph-card2: add comment for format property
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: nau8821: Improve AMIC recording performance (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Delete UDA134x/L3 audio codec (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- commit 95a6f09
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: rt5640: fix typos (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-rt5640-Do-not-disable-enable-IRQ-twice-on-suspe.patch.
- Refresh
  patches.suse/ASoC-rt5640-Revert-Fix-sleep-in-atomic-context.patch.
- commit 938877f
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: rt5682s: Convert to use GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5682: Convert to use GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5668: Convert to use GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5665: Convert to use GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5640: Convert to just use GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- commit ffc61a3
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: mediatek: mt7986: support etdm in platform driver
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt7986: add common header (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: tm2_wm5110: parse audio-routing (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: odroid: parse audio-routing (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: midas_wm1811: parse audio-routing (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: aries_wm8994: parse audio-routing (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: odroid: use of_property_present to check for
  property (jsc#PED-9993 jsc#PED-10202).
- ASoC: rockchip: Fix Wvoid-pointer-to-enum-cast warning
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wm8904: Fix Wvoid-pointer-to-enum-cast warning
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: tlv320aic32x4: Fix Wvoid-pointer-to-enum-cast
  warning (jsc#PED-9993 jsc#PED-10202).
- ASoC: tas5805m: Use devm_kmemdup to replace devm_kmalloc +
  memcpy (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-jack: calling snd_soc_jack_report causes a null
  pointer access (jsc#PED-9993 jsc#PED-10202).
- ASoC: tlv320aic32x4: Fix the divide by zero (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ak4613: Simplify probe() (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-dai.h: remove unused call back functions (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs/hdmi-codec: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs/cx2072x: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs/cs47lxx: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-topology: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- commit 126b638
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: rockchip: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-rockchip-i2s-tdm-Fix-inaccurate-sampling-rates.patch.
- commit 269ee55
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: meson: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-meson-spdifin-start-hw-on-dai-probe.patch.
- commit 152318d
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: amd: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-amd-acp-remove-i2s-configuration-check-in-acp_i.patch.
- commit 0dec43f
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: codecs/wm*: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: hisilicon: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: uniphier: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cirrus: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: jz4740: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: atmel: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tegra: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sunxi: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ux500: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: au1x: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rsnd: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: stm: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sti: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sof: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: img: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: bcm: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: dwc: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: adi: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- commit 5a7ffea
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: adi: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ti: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-dai.h: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt715: Drop GPIO includes (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5682-sdw: Drop GPIO includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5660: Drop GPIO includes (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5659: Drop legacy GPIO include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5645: Drop legacy GPIO include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5514: Drop GPIO include (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5514-spi: Drop GPIO include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1308: Drop GPIO includes (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1305: Drop GPIO includes (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1019: Drop GPIO include (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1016: Drop GPIO include (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1015p: Drop legacy GPIO include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1015: Drop GPIO include (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1011: Drop GPIO includes (jsc#PED-9993 jsc#PED-10202).
- ASoC: ssm3515: Remove redundant of_match_ptr() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sunxi: sun4i-spdif: Remove redundant of_match_ptr()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: atmel: tse850-pcm5142: Remove redundant of_match_ptr()
  (jsc#PED-9993 jsc#PED-10202).
- commit bdb3b5a
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: atmel: Remove redundant of_match_ptr() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cygnus: Remove unused declarations (jsc#PED-9993
  jsc#PED-10202).
- ASoC: q6dsp: Remove unused declaration (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt715: Add software reset in io init (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: midas_wm1811: Fix 'Headphone Switch' control
  creation (jsc#PED-9993 jsc#PED-10202).
- ASoC: rsnd: call of_node_put() when break (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa: address unused variable warning (jsc#PED-9993
  jsc#PED-10202).
- ASoC: imx-audio-rpmsg: Remove redundant initialization owner
  in imx_audio_rpmsg_driver (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: midas_wm1811: Map missing jack kcontrols
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: lowland: Split Line Out jack kcontrol from
  Headphone (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: littlemill: Map missing jack kcontrols
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rockchip: rockchip_rt5645: Map missing jack kcontrols
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rk3399-gru-sound: Map missing Line Out jack kcontrol
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: sdm845: Map missing jack kcontrols (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: sc7280: Map missing jack kcontrols (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: sc7180: Map missing jack kcontrols (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: apq8016_sbc: Map missing jack kcontrols
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8186-mt6366-da7219-max98357: Map missing
  jack kcontrols (jsc#PED-9993 jsc#PED-10202).
- commit d22636a
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: mediatek: mt8183-mt6358-ts3a227-max98357: Map missing
  jack kcontrols (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8183-da7219-max98357: Map missing jack
  kcontrols (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8173-rt5650: Map missing jack kcontrols
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8173-rt5650-rt5676: Map missing jack kcontrols
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8173-rt5650-rt5514: Map missing jack kcontrols
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8173-max98090: Configure jack as a Headset
  jack (jsc#PED-9993 jsc#PED-10202).
- ASoC: imx-es8328: Map missing jack kcontrols (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: Add code for bin parsing compatible with aw88261
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: max98373-sdw: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- commit ac1ae66
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: rt1308-sdw: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- commit f43c4a3
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: max98363: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5682-sdw: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1318-sdw: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1316-sdw: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt715-sdca: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt715: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt712-sdca-dmic: enable pm_runtime in probe, keep status
  as 'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1712-sdca: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt700: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt711-sdca: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt711: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5682-sdw: make regmap cache-only in probe (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SoundWire codecs: make regmap cache-only in probe
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SoundWire codecs: return error status in probe
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: jz4740: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: max9892x: Reformat to coding style (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: max9892x: Unify interleave mode OF property
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: davinci-evm: simplify the code with
  module_platform_driver (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8960: Add support for the power supplies (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: mt8186: Remove unused mutex (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl_micfil: Use SET_SYSTEM_SLEEP_PM_OPS to simplify PM
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_micfil: Add fsl_micfil_use_verid function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_micfil: Add new registers and new bit definition
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-acpi: improve log messagesin link_slaves_found()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8960: Make automatic the default clocking mode
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8960: Read initial MCLK rate from clock API
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rsnd: enable multi Component support for Audio Graph
  Card/Card2 (jsc#PED-9993 jsc#PED-10202).
- ASoC: rsnd: cleanup rsnd_dai_of_node() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rsnd: use DAI driver ID instead of DAI ID (jsc#PED-9993
  jsc#PED-10202).
- commit 5fb5dde
* Fri Aug 30 2024 vkarasulli@suse.de
- iommu/amd: Convert comma to semicolon (git-fixes).
- commit 2714d8b
* Fri Aug 30 2024 lduncan@suse.com
- scsi: lpfc: Fix a possible null pointer dereference (bsc#1229315
  CVE-2024-43821).
- commit eb73e94
* Fri Aug 30 2024 vkarasulli@suse.de
- iommu/vt-d: Fix identity map bounds in si_domain_init()
  (git-fixes).
- commit b4d27e5
* Fri Aug 30 2024 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_RT1017_SDCA_SDW=m (jsc#PED-9993
  jsc#PED-10202)
- commit eb0aada
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: fsl_micfil: refactor deprecated strncpy (jsc#PED-9993
  jsc#PED-10202).
- ASoC: 88pm860x: refactor deprecated strncpy (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sti-sas: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: stac9766: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sta529: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sta350: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sta32x: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1017: Remove unused function (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1316: fix key tone missing (jsc#PED-9993 jsc#PED-10202).
- commit 75ad411
* Fri Aug 30 2024 vkarasulli@suse.de
- iommufd/device: Fix hwpt at err_unresv in
  iommufd_device_do_replace() (git-fixes).
- commit bbc9a65
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: dmaengine: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ALSA-dmaengine-Synchronize-dma-channel-after-drop.patch.
- commit 231e587
* Fri Aug 30 2024 tiwai@suse.de
- ALSA: xen: Fix -Wformat-truncation warning (jsc#PED-9993
  jsc#PED-10202).
- ALSA: sb: Fix wrong argument in commented code (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l51: change cs42l51_of_match to static (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1017: Add RT1017 SDCA amplifier driver (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: Update jact detection function
  (jsc#PED-9993 jsc#PED-10202).
- ASOC: codecs: ES8326: Add calibration support for version_b
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Fix power-up sequence (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: Change Volatile Reg function (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: Change Hp_detect register names
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-dai: don't call PCM audio ops if the stream is not
  supported (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Drop obsoleted PCM copy_user and copy_kernel ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: pcm: Drop obsoleted PCM copy_user ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: dmaengine: Use iov_iter for process callback, too
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: component: Add generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: xen: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: sh: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: rme9652: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hdsp: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: rme96: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: rme32: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: nm256: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: korg1212: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: es1938: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: emu8000: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: gus: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: dummy: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: core: Add memory copy helpers between iov_iter and iomem
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Add copy ops with iov_iter (jsc#PED-9993
  jsc#PED-10202).
- ALSA: core: Drop snd_device_initialize() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: Create device with snd_device_alloc() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: timer: Create device with snd_device_alloc() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: compress: Don't embed device (jsc#PED-9993 jsc#PED-10202).
- ALSA: rawmidi: Don't embed device (jsc#PED-9993 jsc#PED-10202).
- ALSA: hwdep: Don't embed device (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Don't embed device (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Don't embed ctl_dev (jsc#PED-9993 jsc#PED-10202).
- ALSA: core: Introduce snd_device_alloc() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: xen-front: refactor deprecated strncpy (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: lpass: Log clk_get() failures (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm8960: Add DAC filter characteristics selection
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: msm8916-wcd-analog: Properly handle probe errors
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: msm8916-wcd-analog: Drop invalid mclk
  (jsc#PED-9993 jsc#PED-10202).
- commit 490299c
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: ti: omap-mcbsp: Ignore errors for getting fck_src
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-ti-omap-mcbsp-Fix-runtime-PM-underflow-warnings.patch.
- commit 26b90d6
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: fsl_spdif: Add support for 22.05 kHz sample rate
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8188: DPCM used FE and BE merged parameters
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm9713: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm9712: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm9705: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8988: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8985: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8983: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- commit 133853a
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: wm8978: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8971: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8955: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8940: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8996: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8995: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8993: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8991: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8962: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8961: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8960: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8904: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8903: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8900: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8804: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8776: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8770: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8753: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8750: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8741: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8737: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8731: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8728: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8711: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8580: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8523: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8510: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm9090: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm9081: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm5100: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm2200: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs4349: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42xx8: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l56: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l52: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs4270: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs4265: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l51: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l45: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l36: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- commit af28055
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: simple-card.c: enable multi Component support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: simple-card-utils.c: enable multi Component support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-core.c: add snd_soc_copy_dai_args() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-core.c: add snd_soc_dlc_use_cpu_as_platform()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-core.c: add snd_soc_get_dai_via_args() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-core.c: enable multi Component (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-dai.c: add DAI get/match functions (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codec: wm8960: add additional probe check for codec
  identification (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_rpmsg: Add support for i.MX93 platform (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wsa883x: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wsa881x: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wcd938x: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wcd9335: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tegra: tegra20_ac97: Use
  devm_platform_get_and_ioremap_resource() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa: Use devm_platform_get_and_ioremap_resource()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8186: Convert to
  devm_platform_ioremap_resource() (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: Convert to devm_platform_ioremap_resource_byname()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: bcm: bcm63xx-i2s-whistler: Convert to
  devm_platform_ioremap_resource() (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Add es8326_mute function (jsc#PED-9993
  jsc#PED-10202).
- ASoC: adav80x: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: adau7118: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: adau1977: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: adau1781: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: adau1761: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: adau1701: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: adau1373: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: adau1372: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ad1980: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ad1836: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: q6dsp: q6apm: make g_apm static (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5677: Sort headers alphabetically (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5677: Use device_get_match_data() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5677: Use agnostic irq_domain_create_linear()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5677: Refactor GPIO support code (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: mt8188: add memory-region support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: es8316: Add support for S24_3LE format
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: es8316: Add support for 24 MHz MCLK (jsc#PED-9993
  jsc#PED-10202).
- commit 6e0117f
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: rt5645: add the system level suspend-resume callback
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-rt5645-Fix-the-electric-noise-due-to-the-CBJ-co.patch.
- commit 455a70c
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: dwc: Add TDM mode support (jsc#PED-9993 jsc#PED-10202).
- ASoC: tas2781: No need to set device_driver owner (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt722-sdca: Remove redundant sdca mask (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-core: protect dlc->of_node under mutex (jsc#PED-9993
  jsc#PED-10202).
- ASoC: imx-pcm-rpmsg: Set PCM hardware parameters separately
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5645: implement set_jack callback (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-core.c: cleanup soc_dai_link_sanity_check()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-core.c: initialize dlc on snd_soc_get_dai_id()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: vmaster: Add snd_ctl_add_followers() helper (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: mt8188: Simplify with snd_ctl_find_id_mixer()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Introduce snd_ctl_find_id_mixer() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: control: Take lock in snd_ctl_find_id() and
  snd_ctl_find_numid() (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Introduce unlocked version for snd_ctl_find_*()
  helpers (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Make snd_ctl_find_id() argument const
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sigmadsp: Simplify with snd_ctl_activate_id()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Add lockdep warning to internal functions
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Take controls_rwsem lock in snd_ctl_remove()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: atmel: mchp-pdmc: Use snd_ctl_remove_id() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: control: Take card->controls_rwsem in snd_ctl_rename()
  (jsc#PED-9993 jsc#PED-10202).
- commit f22a438
* Fri Aug 30 2024 tiwai@suse.de
- i2c: i801: Add support for Intel Arrow Lake-H (jsc#PED-10247).
- commit b1771c7
* Fri Aug 30 2024 tiwai@suse.de
- Update patch reference for Intel PMC patch (jsc#PED-10192)
- commit 8d1db2d
* Fri Aug 30 2024 lhenriques@suse.de
- blacklist.conf: add 053fc4f755ad fuse: fix UAF in rcu pathwalks
  This commit breaks kABI and the data structure has no free room for the
  extra field, i.e. memcpy would fail to copy the additional member added by
  this patch.
- commit 941b81c
* Fri Aug 30 2024 lhenriques@suse.de
- virtiofs: forbid newlines in tags (bsc#1229942).
- fuse: fix UAF in rcu pathwalks (bsc#1229941).
- commit 2ea5064
* Fri Aug 30 2024 lhenriques@suse.de
- virtiofs: forbid newlines in tags (bsc#1229940).
- commit 61514ce
* Fri Aug 30 2024 petr.pavlu@suse.com
- trace/pid_list: Change gfp flags in pid_list_fill_irq()
  (git-fixes).
- commit 88d1dac
* Fri Aug 30 2024 petr.pavlu@suse.com
- blacklist.conf: add a not-relevant tracing commit
- commit 9e3013e
* Fri Aug 30 2024 ailiop@suse.com
- evm: don't copy up 'security.evm' xattr (git-fixes).
- commit d3bb5af
* Fri Aug 30 2024 ailiop@suse.com
- afs: fix __afs_break_callback() / afs_drop_open_mmap() race
  (git-fixes).
- commit 150e615
* Fri Aug 30 2024 ailiop@suse.com
- jfs: define xtree root and page independently (git-fixes).
- commit fc62e49
* Fri Aug 30 2024 ailiop@suse.com
- kernfs: fix false-positive WARN(nr_mmapped) in
  kernfs_drain_open_files (git-fixes).
- commit 7fa46d1
* Fri Aug 30 2024 ailiop@suse.com
- gfs2: setattr_chown: Add missing initialization (git-fixes).
- commit 9b6ef3b
* Fri Aug 30 2024 tiwai@suse.de
- ACPI: EC: Evaluate _REG outside the EC scope more carefully
  (git-fixes).
- ACPICA: Add a depth argument to acpi_execute_reg_methods()
  (stable-fixes).
- Revert "ACPI: EC: Evaluate orphan _REG under EC device"
  (stable-fixes).
- commit 3e803e9
* Fri Aug 30 2024 tiwai@suse.de
- wifi: rtw89: pci: fix RX tag race condition resulting in wrong
  RX length (stable-fixes).
- wifi: ath12k: fix race due to setting
  ATH12K_FLAG_EXT_IRQ_ENABLED too early (stable-fixes).
- wifi: rtlwifi: handle return value of usb init TX/RX
  (stable-fixes).
- ALSA: hda: beep: Drop stale mutex (git-fixes).
- commit a5a55ef
* Fri Aug 30 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: allow 6 GHz channels in MLO scan
  (git-fixes).
- wifi: iwlwifi: mvm: take the mutex before running link selection
  (git-fixes).
- commit a430bfe
* Fri Aug 30 2024 tiwai@suse.de
- nfc: pn533: Add poll mod list filling check (git-fixes).
- wifi: wfx: repair open network AP mode (git-fixes).
- wifi: iwlwifi: fw: fix wgds rev 3 exact size (git-fixes).
- wifi: mwifiex: duplicate static structs used in driver instances
  (git-fixes).
- Input: i8042 - use new forcenorestore quirk to replace old
  buggy quirk combination (stable-fixes).
- Input: i8042 - add forcenorestore quirk to leave controller
  untouched even on s3 (stable-fixes).
- platform/surface: aggregator: Fix warning when controller is
  destroyed in probe (git-fixes).
- thunderbolt: Mark XDomain as unplugged when router is removed
  (stable-fixes).
- Input: MT - limit max slots (stable-fixes).
- usb: dwc3: core: Skip setting event buffers for host only
  controllers (stable-fixes).
- platform/x86: lg-laptop: fix %%s null argument warning
  (stable-fixes).
- rtc: nct3018y: fix possible NULL dereference (stable-fixes).
- usb: gadget: fsl: Increase size of name buffer for endpoints
  (stable-fixes).
- media: drivers/media/dvb-core: copy user arrays safely
  (stable-fixes).
- media: pci: cx23885: check cx23885_vdev_init() return
  (stable-fixes).
- memory: stm32-fmc2-ebi: check regmap_read return value
  (stable-fixes).
- memory: tegra: Skip SID programming if SID registers aren't set
  (stable-fixes).
- Revert "usb: gadget: uvc: cleanup request when not in correct
  state" (stable-fixes).
- usb: gadget: uvc: cleanup request when not in correct state
  (stable-fixes).
- staging: ks7010: disable bh on tx_dev_lock (stable-fixes).
- staging: iio: resolver: ad2s1210: fix use before initialization
  (stable-fixes).
- ssb: Fix division by zero issue in ssb_calc_clock_rate
  (stable-fixes).
- commit b84d799
* Fri Aug 30 2024 tiwai@suse.de
- drm/vmwgfx: Fix prime with external buffers (git-fixes).
- drm/i915/dsi: Make Lenovo Yoga Tab 3 X90F DMI match less strict
  (git-fixes).
- drm/amd/display: avoid using null object of framebuffer
  (git-fixes).
- Bluetooth: hci_core: Fix not handling hibernation actions
  (git-fixes).
- drm/amdgpu: Validate TA binary size (stable-fixes).
- drm/msm/dpu: take plane rotation into account for wide planes
  (git-fixes).
- drm/msm/dpu: move dpu_encoder's connector assignment to
  atomic_enable() (git-fixes).
- char: xillybus: Refine workqueue handling (git-fixes).
- char: xillybus: Don't destroy workqueue from work item running
  on it (stable-fixes).
- drm/amdgpu: Actually check flags for all context ops
  (stable-fixes).
- drm/amdgpu/jpeg4: properly set atomics vmid field
  (stable-fixes).
- drm/amdgpu/jpeg2: properly set atomics vmid field
  (stable-fixes).
- drm/amd/display: fix s2idle entry for DCN3.5+ (stable-fixes).
- drm/amdgpu: fix dereference null return value for the function
  amdgpu_vm_pt_parent (stable-fixes).
- hwmon: (ltc2992) Fix memory leak in ltc2992_parse_dt()
  (git-fixes).
- firmware: cirrus: cs_dsp: Initialize debugfs_root to invalid
  (stable-fixes).
- drm/msm/dpu: capture snapshot on the first commit_done timeout
  (stable-fixes).
- drm/msm/dpu: split dpu_encoder_wait_for_event into two functions
  (stable-fixes).
- drm/lima: set gp bus_stop bit before hard reset (stable-fixes).
- drm/panel: nt36523: Set 120Hz fps for xiaomi,elish panels
  (stable-fixes).
- gpio: sysfs: extend the critical section for unregistering
  sysfs devices (stable-fixes).
- Bluetooth: bnep: Fix out-of-bound access (stable-fixes).
- hwmon: (pc87360) Bounds check data->innr usage (stable-fixes).
- ASoC: SOF: ipc4: check return value of snd_sof_ipc_msg_data
  (stable-fixes).
- drm/msm/dpu: drop MSM_ENC_VBLANK support (stable-fixes).
- drm/msm/dpu: use drmm-managed allocation for dpu_encoder_phys
  (stable-fixes).
- drm/msm/mdss: Rename path references to mdp_path (stable-fixes).
- drm/msm/mdss: switch mdss to use devm_of_icc_get()
  (stable-fixes).
- drm/msm/dpu: try multirect based on mdp clock limits
  (stable-fixes).
- drm/msm: Reduce fallout of fence signaling vs reclaim hangs
  (stable-fixes).
- drm/rockchip: vop2: clear afbc en and transform bit for cluster
  window at linear mode (stable-fixes).
- Bluetooth: hci_conn: Check non NULL function before calling
  for HFP offload (stable-fixes).
- i2c: stm32f7: Add atomic_xfer method to driver (stable-fixes).
- i2c: riic: avoid potential division by zero (stable-fixes).
- i3c: mipi-i3c-hci: Do not unmap region not mapped for transfer
  (stable-fixes).
- i3c: mipi-i3c-hci: Remove BUG() when Ring Abort request times
  out (stable-fixes).
- ASoC: SOF: Intel: hda-dsp: Make sure that no irq handler is
  pending before suspend (stable-fixes).
- ASoC: cs35l45: Checks index of cs35l45_irqs[] (stable-fixes).
- clk: visconti: Add bounds-checking coverage for struct
  visconti_pll_provider (stable-fixes).
- hwmon: (ltc2992) Avoid division by zero (stable-fixes).
- commit 1b92ddd
* Thu Aug 29 2024 petr.pavlu@suse.com
- jump_label: Fix the fix, brown paper bags galore (git-fixes).
- commit 89b2827
* Thu Aug 29 2024 petr.pavlu@suse.com
- jump_label: Simplify and clarify
  static_key_fast_inc_cpus_locked() (git-fixes).
- commit 954eaa3
* Thu Aug 29 2024 petr.pavlu@suse.com
- jump_label: Clarify condition in
  static_key_fast_inc_not_disabled() (git-fixes).
- commit eb457dc
* Thu Aug 29 2024 petr.pavlu@suse.com
- jump_label: Fix concurrency issues in static_key_slow_dec()
  (git-fixes).
- commit 6e92a06
* Thu Aug 29 2024 petr.pavlu@suse.com
- tracing: Return from tracing_buffers_read() if the file has
  been closed (bsc#1229136 git-fixes).
- commit 8dc8510
* Thu Aug 29 2024 petr.pavlu@suse.com
- kprobes: Fix to check symbol prefixes correctly (git-fixes).
- commit e8b168b
* Thu Aug 29 2024 petr.pavlu@suse.com
- kprobes: Prohibit probing on CFI preamble symbol (git-fixes).
- commit 2f9e2b1
* Thu Aug 29 2024 petr.pavlu@suse.com
- bpf: kprobe: remove unused declaring of bpf_kprobe_override
  (git-fixes).
- commit 4045c94
* Thu Aug 29 2024 tiwai@suse.de
- Update patch reference for wireless fix (CVE-2024-43911 bsc#1229827)
- commit c8f695c
* Thu Aug 29 2024 tiwai@suse.de
- wifi: mac80211: fix NULL dereference at band check in starting
  tx ba session (CVE-2024-43911 bsc#1229827).
- commit 0892b94
* Thu Aug 29 2024 tiwai@suse.de
- Correct patches.suse/wifi-mac80211-reset-negotiated-TTLM-on-disconnect.patch (jsc#PED-10412)
- commit 7377f47
* Thu Aug 29 2024 tiwai@suse.de
- blacklist.conf: add superfluous iwlwifi entry (jsc#PED-10412)
- commit 3939f4b
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: always unblock EMLSR on ROC end
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: separate non-BSS/ROC EMLSR blocking
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: fix re-enabling EMLSR (jsc#PED-10412).
- wifi: mac80211: cancel TTLM teardown work earlier
  (jsc#PED-10412).
- wifi: mac80211: fix TTLM teardown work (jsc#PED-10412).
- wifi: iwlwifi: mvm: don't skip link selection (jsc#PED-10412).
- commit da7fdb7
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: check vif for NULL/ERR_PTR before
  dereference (jsc#PED-10412).
- wifi: iwlwifi: mvm: avoid link lookup in statistics
  (jsc#PED-10412).
- wifi: iwlwifi: scan: correctly check if PSC listen period is
  needed (jsc#PED-10412).
- wifi: iwlwifi: mvm: unlock mvm mutex (jsc#PED-10412).
- wifi: iwlwifi: mvm: always set the TWT IE offset
  (jsc#PED-10412).
- wifi: iwlwifi: Ensure prph_mac dump includes all addresses
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: don't request statistics in restart
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: exit EMLSR if secondary link is not used
  (jsc#PED-10412).
- commit 1f0b706
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: align UATS naming with firmware
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-iwlwifi-mvm-don-t-limit-VLP-AFC-to-UATS-enabled.patch.
- commit 1753282
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: add beacon template version 14
  (jsc#PED-10412).
- wifi: iwlwifi: Force SCU_ACTIVE for specific platforms
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: record and return channel survey information
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: add the firmware API for channel survey
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: Fix race in scan completion (jsc#PED-10412).
- wifi: iwlwifi: mvm: Add a print for invalid link pair due to
  bandwidth (jsc#PED-10412).
- wifi: iwlwifi: mvm: add a debugfs for reading EMLSR blocking
  reasons (jsc#PED-10412).
- wifi: iwlwifi: mvm: Add active EMLSR blocking reasons prints
  (jsc#PED-10412).
- wifi: iwlwifi: bump FW API to 90 for BZ/SC devices
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: fix primary link setting (jsc#PED-10412).
- commit df80d8b
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: use already determined cmd_id
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: don't reset link selection during restart
  (jsc#PED-10412).
- wifi: iwlwifi: Print EMLSR states name (jsc#PED-10412).
- wifi: iwlwifi: mvm: Block EMLSR when a p2p/softAP vif is active
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: fix typo in debug print (jsc#PED-10412).
- wifi: iwlwifi: mvm: exit EMLSR when CSA happens (jsc#PED-10412).
- wifi: iwlwifi: mvm: Disable/enable EMLSR due to link's
  bandwidth/band (jsc#PED-10412).
- wifi: iwlwifi: mvm: avoid always prefering single-link
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: trigger link selection upon TTLM start/end
  (jsc#PED-10412).
- commit 2ffd281
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: consider FWs recommendation for EMLSR
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: Activate EMLSR based on traffic volume
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: don't always unblock EMLSR (jsc#PED-10412).
- wifi: iwlwifi: mvm: Always allow entering EMLSR from debugfs
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: add a debugfs for (un)blocking EMLSR
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: trigger link selection after exiting EMLSR
  (jsc#PED-10412).
- wifi: iwlwifi: cleanup EMLSR when BT is active handling
  (jsc#PED-10412).
- wifi: mac80211: handle color change per link (jsc#PED-10412).
- wifi: cfg80211: handle color change per link (jsc#PED-10412).
- wifi: cfg80211: Clear mlo_links info when STA disconnects
  (jsc#PED-10412).
- wifi: iwlwifi: pcie: allocate dummy net_device dynamically
  (jsc#PED-10412).
- wifi: mac80211: handle link ID during management Tx
  (jsc#PED-10412).
- wifi: mac80211: handle sdata->u.ap.active flag with MLO
  (jsc#PED-10412).
- wifi: cfg80211: add return docs for regulatory functions
  (jsc#PED-10412).
- wifi: cfg80211: make some regulatory functions void
  (jsc#PED-10412).
- wifi: mac80211: add return docs for sta_info_flush()
  (jsc#PED-10412).
- wifi: mac80211: keep mac80211 consistent on link activation
  failure (jsc#PED-10412).
- wifi: mac80211: simplify ieee80211_assign_link_chanctx()
  (jsc#PED-10412).
- wifi: mac80211: reserve chanctx during find (jsc#PED-10412).
- wifi: iwlwifi: mvm: Don't allow EMLSR when the RSSI is low
  (jsc#PED-10412).
- net: create a dummy net_device allocator (jsc#PED-10412).
- net: Do not return value from init_dummy_netdev()
  (jsc#PED-10412).
- commit 8be7f22
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: disable EMLSR when we suspend with wowlan
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: get periodic statistics in EMLSR
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: don't recompute EMLSR mode in
  can_activate_links (jsc#PED-10412).
- wifi: iwlwifi: mvm: implement EMLSR prevention mechanism
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: exit EMLSR upon missed beacon
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: Add helper functions to update EMLSR status
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: Implement new link selection algorithm
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: move EMLSR/links code (jsc#PED-10412).
- wifi: iwlwifi: mvm: check if EMLSR is allowed before selecting
  links (jsc#PED-10412).
- wifi: iwlwifi: mvm: implement link grading (jsc#PED-10412).
- commit 19d9522
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: send ap_tx_power_constraints cmd to FW in
  AP mode (jsc#PED-10412).
- wifi: iwlwifi: Add support for LARI_CONFIG_CHANGE_CMD v10
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: Add support for PPAG cmd v6 (jsc#PED-10412).
- wifi: iwlwifi: move lari_config handlig to regulatory
  (jsc#PED-10412).
- wifi: iwlwifi: add a device ID for BZ-W (jsc#PED-10412).
- wifi: iwlwifi: move WTAS macro to api file (jsc#PED-10412).
- wifi: iwlwifi: mvm: extend STEP URM workaround for new devices
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: move phy band to nl80211 band helper
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: Refactor tracking of scan UIDs
  (jsc#PED-10412).
- wifi: mac80211: defer link switch work in reconfig
  (jsc#PED-10412).
- commit b72dfce
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: set wider BW OFDMA ignore correctly
  (jsc#PED-10412).
- commit 95cf0f9
* Thu Aug 29 2024 tiwai@suse.de
- wifi: mac80211: extend IEEE80211_KEY_FLAG_GENERATE_MMIE to
  other ciphers (jsc#PED-10412).
- wifi: mac80211: correctly document struct mesh_table
  (jsc#PED-10412).
- wifi: mac80211: use kvcalloc() for codel vars (jsc#PED-10412).
- wifi: iwlwifi: mvm: don't change BA sessions during restart
  (jsc#PED-10412).
- wifi: iwlwifi: Add support for LARI_CONFIG_CHANGE_CMD cmd v9
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: Declare HE/EHT capabilities support for
  P2P interfaces (jsc#PED-10412).
- wifi: iwlwifi: mvm: Remove outdated comment (jsc#PED-10412).
- wifi: iwlwifi: add support for BZ_W (jsc#PED-10412).
- wifi: iwlwifi: Print a specific device name (jsc#PED-10412).
- commit 5b94c91
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: remove wrong CRF_IDs (jsc#PED-10412).
- wifi: iwlwifi: remove devices that never came out
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: mark EMLSR disabled in cleanup iterator
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: assign link STA ID lookups during restart
  (jsc#PED-10412).
- wifi: mac80211: reactivate multi-link later in restart
  (jsc#PED-10412).
- wifi: mac80211: improve drop for action frame return
  (jsc#PED-10412).
- wifi: mac80211: don't ask driver about no-op link changes
  (jsc#PED-10412).
- wifi: mac80211: clarify IEEE80211_STATUS_SUBDATA_MASK
  (jsc#PED-10412).
- wifi: mac80211: don't enter idle during link switch
  (jsc#PED-10412).
- wifi: iwlwifi: enable monitor on passive/inactive channels
  (jsc#PED-10412).
- commit e223e3a
* Thu Aug 29 2024 andrea.porta@suse.com
- syscalls: fix compat_sys_io_pgetevents_time64 usage (git-fixes).
- commit b90dd07
* Thu Aug 29 2024 tiwai@suse.de
- wifi: mac80211: add support for tearing down negotiated TTLM
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-mac80211-cancel-multi-link-reconf-work-on-disco.patch.
- commit c7ae2fe
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: remove 6 GHz NVM override (jsc#PED-10412).
- wifi: iwlwifi: mvm: don't support puncturing in 5 GHz
  (jsc#PED-10412).
- wifi: iwlwifi: fw: add clarifying comments about
  iwl_fwrt_dump_data (jsc#PED-10412).
- wifi: iwlwifi: mvm: always apply 6 GHz probe limitations
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: add debugfs for forcing unprotected ranging
  request (jsc#PED-10412).
- wifi: iwlwifi: mvm: Add debugfs entry for triggering internal
  MLO scan (jsc#PED-10412).
- wifi: iwlwifi: mvm: Introduce internal MLO passive scan
  (jsc#PED-10412).
- wifi: cfg80211: check BSSID Index against MaxBSSID
  (jsc#PED-10412).
- commit cee31f5
* Thu Aug 29 2024 tiwai@suse.de
- wifi: mac80211: handle indoor AFC/LPI AP on assoc success
  (jsc#PED-10412).
- commit ae296f4
* Thu Aug 29 2024 tiwai@suse.de
- wifi: mac80211: improve association error reporting slightly
  (jsc#PED-10412).
- wifi: mac80211: add flag to disallow puncturing in 5 GHz
  (jsc#PED-10412).
- wifi: cfg80211: handle indoor AFC/LPI AP in probe response
  and beacon (jsc#PED-10412).
- wifi: nl80211: cleanup nl80211.h kernel-doc (jsc#PED-10412).
- wifi: nl80211: fix nl80211 uapi comment style issues
  (jsc#PED-10412).
- wifi: nl80211: rename enum plink_actions (jsc#PED-10412).
- wifi: mac80211: spectmgmt: simplify 6 GHz HE/EHT handling
  (jsc#PED-10412).
- wifi: mac80211: supplement parsing of puncturing bitmap
  (jsc#PED-10412).
- wifi: iwlwifi: pcie: remove duplicate PCI IDs entry
  (jsc#PED-10412).
- commit ac19b77
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: Move beacon filtering to be per link
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-iwlwifi-mvm-introduce-esr_disable_reason.patch.
- commit 1805226
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: Refactor scan start (jsc#PED-10412).
- wifi: iwlwifi: mvm: advertise IEEE80211_HW_HANDLES_QUIET_CSA
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: fix flushing during quiet CSA
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: support wowlan notif version 4
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: skip keys of other links (jsc#PED-10412).
- wifi: iwlwifi: mvm: stop assuming sta id 0 in d3
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: fix the sta id in offload (jsc#PED-10412).
- wifi: iwlwifi: fix firmware API kernel doc (jsc#PED-10412).
- commit b395b4f
* Thu Aug 29 2024 vkarasulli@suse.de
- iommu: sprd: Avoid NULL deref in sprd_iommu_hw_en
  (CVE-2024-42277 bsc#1229409).
- commit ede2511
* Thu Aug 29 2024 iivanov@suse.de
- blacklist.conf: Silence git-fixes in dts files
  We do not provide device trees with SUSE products.
- commit 19456ba
* Thu Aug 29 2024 iivanov@suse.de
- blacklist.conf: Documentation/devicetree/bindings are ignored globally
  No need to blacklist individual patches. Drop them.
- commit 0192d23
* Thu Aug 29 2024 cfamullaconrad@suse.com
- tools/power turbostat: Add ARL-H support (jsc#PED-10187
  jsc#PED-10184).
- tools/power turbostat: Enhance ARL/LNL support (jsc#PED-10187
  jsc#PED-10184).
- x86/cpu: Add model number for another Intel Arrow Lake mobile
  processor (jsc#PED-10187 jsc#PED-10184).
- commit 8795977
* Thu Aug 29 2024 oneukum@suse.com
- usb: typec: altmodes: add svdm version info for typec cables
  (git-fixes).
- Refresh patches.suse/paddings-add-paddings-to-TypeC-stuff.patch.
- commit 8701cb3
* Thu Aug 29 2024 oneukum@suse.com
- usb: typec: altmodes: add typec_cable_ops to typec_altmode
  (jsc#PED-10361).
- Refresh patches.suse/0001-typeC-add-kABI-padding.patch.
- commit 3bb5e68
* Thu Aug 29 2024 tiwai@suse.de
- wifi: cfg80211: correct S1G beacon length calculation
  (git-fixes).
- wifi: mac80211: fix NULL dereference at band check in starting
  tx ba session (stable-fixes).
- commit 49b630f
* Wed Aug 28 2024 dsterba@suse.com
- Update references patches.suse/drm-amd-display-Add-null-checks-for-stream-and-plane.patch (CVE-2024-43904 bsc#1229768 stable-fixes)
- commit aaa26ef
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: enforce ready state when queueing alt mode
  vdm (jsc#PED-10361).
- blacklist.conf: kABI can be changed in SP7
- commit b770f6a
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: avoid sink goto SNK_UNATTACHED state if not
  received source capability message (jsc#PED-10361).
- commit 84a9aee
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: use 'time_left' variable with
  wait_for_completion_timeout() (jsc#PED-10361).
- commit 25ac51e
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: avoid resets for missing source capability
  messages (jsc#PED-10361).
- commit 5b06c56
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: queue correct sop type in
  tcpm_queue_vdm_unlocked (jsc#PED-10361).
- commit 5fe4ad1
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: add support to set tcpc connector
  orientatition (jsc#PED-10361).
- commit f3c3fa9
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: fix SOP' sequences in tcpm_pd_svdm
  (jsc#PED-10361).
- commit 7e73e2e
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: add alt mode enter/exit/vdm support for sop'
  (jsc#PED-10361).
- commit 9843cc4
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: add discover svids and discover modes support
  for sop' (jsc#PED-10361).
- commit b68da06
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: add state machine support for
  SRC_VDM_IDENTITY_REQUEST (jsc#PED-10361).
- commit e394650
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: add discover identity support for SOP'
  (jsc#PED-10361).
- Refresh
  patches.suse/usb-typec-tcpm-Check-for-port-partner-validity-befor.patch.
- commit b4cdeb1
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpci: add attempt_vconn_swap_discovery callback
  (git-fixes).
- commit ae3572f
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: add control message support to sop'
  (jsc#PED-10361).
- commit bf9c1bb
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: process receive and transmission of sop'
  messages (jsc-PED#10361).
- commit 7562c40
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpci: add tcpm_transmit_type to tcpm_pd_receive
  (jsc#PED-10361).
- commit dbb7c7e
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpci: add cable_comm_capable attribute (jsc#PED-10361).
- commit dcc9131
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: Query Source partner for FRS capability only
  if it is DRP (jsc#PED-10361).
- commit 97ffb7c
* Wed Aug 28 2024 tbogendoerfer@suse.de
- kabi: lib: objagg: Put back removed metod in struct objagg_ops
  (CVE-2024-43880 bsc#1229481).
- commit 9566f2d
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpci: add vconn over current fault handling to
  maxim_core (jsc#PED-10361).
- commit a172726
* Wed Aug 28 2024 tiwai@suse.de
- wifi: nl80211: expose can-monitor channel property
  (jsc#PED-10412).
- wifi: rtw89: fw: remove unnecessary rcu_read_unlock() for
  punctured (jsc#PED-10412).
- commit 66467ac
* Wed Aug 28 2024 tiwai@suse.de
- Refresh patches.suse/wifi-mac80211-Add-getter-functions-for-vif-MLD-state.patch (jsc#PED-10412)
- commit 179a2e0
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: fix Spatial Reuse element size check
  (jsc#PED-10412).
- wifi: mac80211: pass proper link id for channel switch started
  notification (jsc#PED-10412).
- wifi: mac80211: transmit deauth only if link is available
  (jsc#PED-10412).
- commit bedfacb
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: ignore non-TX BSSs in per-STA profile
  (jsc#PED-10412).
- commit f263864
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: mlme: re-parse if AP mode is less than client
  (jsc#PED-10412).
- wifi: mac80211: mlme: fix memory leak (jsc#PED-10412).
- wifi: mac80211: mlme: re-parse with correct mode
  (jsc#PED-10412).
- wifi: mac80211: fix idle calculation with multi-link
  (jsc#PED-10412).
- wifi: mac80211: split mesh fast tx cache into
  local/proxied/forwarded (jsc#PED-10412).
- wifi: mac80211: fix mlme_link_id_dbg() (jsc#PED-10412).
- wifi: mac80211: remove TDLS peers on link deactivation
  (jsc#PED-10412).
- wifi: mac80211: remove TDLS peers only on affected link
  (jsc#PED-10412).
- commit dc5a961
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: mlme: unify CSA handling (jsc#PED-10412).
- wifi: mac80211: introduce a feature flag for quiet in CSA
  (jsc#PED-10412).
- wifi: mac80211: pass link conf to abort_channel_switch
  (jsc#PED-10412).
- wifi: mac80211: pass link_id to channel switch ops
  (jsc#PED-10412).
- wifi: cfg80211: allow cfg80211_defragment_element() without
  output (jsc#PED-10412).
- wifi: cfg80211: expose cfg80211_iter_rnr() to drivers
  (jsc#PED-10412).
- wifi: mac80211: hide element parsing internals (jsc#PED-10412).
- wifi: mac80211: remove unneeded scratch_len subtraction
  (jsc#PED-10412).
- wifi: mac80211: defragment reconfiguration MLE when parsing
  (jsc#PED-10412).
- wifi: mac80211: simplify multi-link element parsing
  (jsc#PED-10412).
- commit 913685d
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: remove unnecessary ML element checks
  (jsc#PED-10412).
- wifi: mac80211: add ieee80211_vif_link_active() helper
  (jsc#PED-10412).
- wifi: mac80211: remove unnecessary ML element type check
  (jsc#PED-10412).
- wifi: mac80211: Adjust CQM handling for MLO (jsc#PED-10412).
- wifi: mac80211: Allow beacons to update BSS table regardless
  of scan (jsc#PED-10412).
- wifi: cfg80211: print flags in tracing in hex (jsc#PED-10412).
- wifi: mac80211: obtain AP HT/VHT data for assoc request
  (jsc#PED-10412).
- wifi: mac80211: don't add VHT capa on links without them
  (jsc#PED-10412).
- wifi: mac80211: handle netif carrier up/down with link AP
  during MLO (jsc#PED-10412).
- wifi: mac80211: remove only link keys during stopping link AP
  (jsc#PED-10412).
- commit f5583c0
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: fix supported rate masking in scan
  (jsc#PED-10412).
- wifi: mac80211: check link exists before use (jsc#PED-10412).
- wifi: mac80211: always initialize match_auth (jsc#PED-10412).
- wifi: nl80211: refactor parsing CSA offsets (jsc#PED-10412).
- wifi: nl80211: force WLAN_AKM_SUITE_SAE in big endian in
  NL80211_CMD_EXTERNAL_AUTH (jsc#PED-10412).
- wifi: cfg80211: use ML element parsing helpers (jsc#PED-10412).
- wifi: mac80211: align ieee80211_mle_get_bss_param_ch_cnt()
  (jsc#PED-10412).
- commit d200d4e
* Wed Aug 28 2024 denis.kirjanov@suse.com
- net/sched: initialize noop_qdisc owner (git-fixes).
- commit 66e8d18
* Wed Aug 28 2024 iivanov@suse.de
- blacklist.conf: Drop e2768b798a19 ("arm64/mm: Modify range-based tlbi to decrement scale")
- commit 6f8618a
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: refactor RNR parsing (jsc#PED-10412).
- commit c8b0e9e
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: clean up cfg80211_inform_bss_frame_data()
  (jsc#PED-10412).
- commit 47b22b0
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: remove cfg80211_inform_single_bss_frame_data()
  (jsc#PED-10412).
- commit f728fce
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: Add KHZ_PER_GHZ to units.h and reuse
  (jsc#PED-10412).
- wifi: mac80211: make associated BSS pointer visible to the
  driver (jsc#PED-10412).
- wifi: mac80211: check beacon countdown is complete on per link
  basis (jsc#PED-10412).
- wifi: cfg80211: use IEEE80211_MAX_MESH_ID_LEN appropriately
  (jsc#PED-10412).
- wifi: mac80211: drop injection on disabled-chan monitor
  (jsc#PED-10412).
- wifi: cfg80211: optionally support monitor on disabled channels
  (jsc#PED-10412).
- wifi: mac80211: remove only own link stations during stop_ap
  (jsc#PED-10412).
- wifi: mac80211: flush only stations using requests links
  (jsc#PED-10412).
- wifi: cfg80211: add support for link id attribute in
  NL80211_CMD_DEL_STATION (jsc#PED-10412).
- wifi: mac80211: remove gfp parameter from
  ieee80211_obss_color_collision_notify (jsc#PED-10412).
- commit af927ab
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: fix kernel-doc for cfg80211_chandef_primary
  (jsc#PED-10412).
- wifi: mac80211: add support to call csa_finish on a link
  (jsc#PED-10412).
- wifi: mac80211: start and finalize channel switch on link basis
  (jsc#PED-10412).
- wifi: mac80211: handle set csa/after_csa beacon on per link
  basis (jsc#PED-10412).
- wifi: cfg80211: send link id in channel_switch ops
  (jsc#PED-10412).
- wifi: mac80211: refactor STA CSA parsing flows (jsc#PED-10412).
- wifi: cfg80211: Add utility for converting op_class into chandef
  (jsc#PED-10412).
- wifi: mac80211: don't use sband->band early (jsc#PED-10412).
- wifi: mac80211: add missing kernel-doc for fast_tx_check
  (jsc#PED-10412).
- wifi: mac80211: clarify vif handling in TX dequeue
  (jsc#PED-10412).
- commit 2d6daca
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: move element parsing to a new file
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-mac80211-update-scratch_pos-after-defrag.patch.
- commit bf13760
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: allow CSA to same channel (jsc#PED-10412).
- wifi: mac80211: convert ieee80211_ie_build_eht_cap() to SKB use
  (jsc#PED-10412).
- wifi: mac80211: convert ieee80211_ie_build_he_cap() to SKB use
  (jsc#PED-10412).
- wifi: mac80211: start building elements in SKBs (jsc#PED-10412).
- wifi: mac80211: simplify adding supported rates (jsc#PED-10412).
- wifi: mac80211: tdls: use ieee80211_put_he_6ghz_cap()
  (jsc#PED-10412).
- wifi: mac80211: rename ieee80211_ie_build_he_6ghz_cap()
  (jsc#PED-10412).
- wifi: mac80211: limit HE RU capabilities when limiting bandwidth
  (jsc#PED-10412).
- wifi: mac80211: adjust EHT capa when lowering bandwidth
  (jsc#PED-10412).
- commit a166a82
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: implement MLO multicast deduplication
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-mac80211-cancel-multi-link-reconf-work-on-disco.patch.
- commit ed289f4
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: simplify HE/EHT element length functions
  (jsc#PED-10412).
- wifi: mac80211: disallow basic multi-link element in per-STA
  profile (jsc#PED-10412).
- wifi: mac80211: disambiguate element parsing errors
  (jsc#PED-10412).
- wifi: mac80211: add/use ieee80211_get_sn() (jsc#PED-10412).
- commit 892692a
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211/mac80211: move puncturing into chandef
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-ath12k-enable-802.11-power-save-mode-in-station.patch.
- Refresh
  patches.suse/wifi-mac80211-fix-BSS_CHANGED_UNSOL_BCAST_PROBE_RESP.patch.
- commit 148c5a2
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: use cfg80211_chandef_primary_freq()
  (jsc#PED-10412).
- wifi: cfg80211: simplify cfg80211_chandef_compatible()
  (jsc#PED-10412).
- wifi: wireless: declare different S1G chandefs incompatible
  (jsc#PED-10412).
- wifi: mac80211: refactor puncturing bitmap extraction
  (jsc#PED-10412).
- commit 4421602
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: move puncturing validation code (jsc#PED-10412).
- wifi: mac80211: validate assoc response channel config
  (jsc#PED-10412).
- commit 5a45b69
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: support wider bandwidth OFDMA config
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-mac80211-correcty-limit-wider-BW-TDLS-STAs.patch.
- commit 2bbf3ce
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: add and use a link iteration macro
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-mac80211-correcty-limit-wider-BW-TDLS-STAs.patch.
- commit d5712ca
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: introduce 'channel request' (jsc#PED-10412).
- Refresh
  patches.suse/wifi-iwlwifi-mvm-calculate-EMLSR-mode-after-connecti.patch.
- Refresh
  patches.suse/wifi-iwlwifi-mvm-don-t-always-disable-EMLSR-due-to-B.patch.
- Refresh
  patches.suse/wifi-mac80211-correcty-limit-wider-BW-TDLS-STAs.patch.
- commit af16a83
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: chan: chandef is non-NULL for reserved
  (jsc#PED-10412).
- wifi: mac80211: clean up HE 6 GHz and EHT chandef parsing
  (jsc#PED-10412).
- commit cb58526
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: clean up connection process (jsc#PED-10412).
- commit 732cff2
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: clean up band switch in duration
  (jsc#PED-10412).
- wifi: mac80211: remove extra shadowing variable (jsc#PED-10412).
- commit 4194ddc
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: remove unused MAX_MSG_LEN define
  (jsc#PED-10412).
- wifi: mac80211: don't allow deactivation of all links
  (jsc#PED-10412).
- wifi: nl80211: move WPA version validation to policy
  (jsc#PED-10412).
- wifi: mac80211: clean up FILS discovery change flags handling
  (jsc#PED-10412).
- wifi: mac80211: trace SMPS requests from driver (jsc#PED-10412).
- Revert "nl80211/cfg80211: Specify band specific min RSSI
  thresholds with sched scan" (jsc#PED-10412).
- wifi: mac80211: Drop WBRF debugging statements (jsc#PED-10412).
- commit c53e5bb
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: take EML/MLD capa from assoc response
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-mac80211-cancel-multi-link-reconf-work-on-disco.patch.
- commit de97fb2
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: apply duration for SW scan (jsc#PED-10412).
- wifi: mac80211: don't set bss_conf in parsing (jsc#PED-10412).
- wifi: mac80211: disallow drivers with HT wider than HE
  (jsc#PED-10412).
- wifi: mac80211: simplify HE capability access (jsc#PED-10412).
- wifi: mac80211: remove extra element parsing (jsc#PED-10412).
- wifi: mac80211: simplify ieee80211_config_bw() prototype
  (jsc#PED-10412).
- wifi: cfg80211: validate MLO connections better (jsc#PED-10412).
- commit c34e2bb
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: add support for negotiated TTLM request
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-mac80211-cancel-multi-link-reconf-work-on-disco.patch.
- Refresh
  patches.suse/wifi-mac80211-reset-negotiated-TTLM-on-disconnect.patch.
- commit ddf627d
* Wed Aug 28 2024 tiwai@suse.de
- wifi: wireless: avoid strlen() in cfg80211_michael_mic_failure()
  (jsc#PED-10412).
- commit d116332
* Wed Aug 28 2024 tiwai@suse.de
- wifi: nl80211: fix grammar & spellos (jsc#PED-10412).
- commit aee3bd5
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: Add support for WBRF features (jsc#PED-10412).
- Refresh
  patches.suse/wifi-mac80211-process-and-save-negotiated-TID-to-Lin.patch.
- Refresh
  patches.suse/wifi-mac80211-simplify-non-chanctx-drivers.patch.
- Refresh patches.suse/wireless-suse-kabi-padding.patch.
- commit b2b30d5
* Wed Aug 28 2024 oneukum@suse.com
- ubsan: fix unused variable warning in test module (git fix
  rejected for SP6).
- blacklist.conf: kABI can be changed in SP7
- commit dd9615e
* Wed Aug 28 2024 tiwai@suse.de
- Update config files: CONFIG_AMD_WBRF=y (jsc#PED-10412)
- commit 3705dfc
* Wed Aug 28 2024 tiwai@suse.de
- platform/x86/amd: Add support for AMD ACPI based Wifi band
  RFI mitigation feature (jsc#PED-10412).
- commit 1be0c01
* Wed Aug 28 2024 tiwai@suse.de
- Update config files: CONFIG_BT_HS is obsoleted
- commit 4b9af5d
* Wed Aug 28 2024 oneukum@suse.com
- xfrm: Correct spelling mistake in xfrm.h comment (git fix
  rejected for SP6).
- blacklist.conf: kABI can be changed in SP7
- commit 071ae18
* Wed Aug 28 2024 tiwai@suse.de
- wifi: nl80211: Documentation update for
  NL80211_CMD_PORT_AUTHORIZED event (jsc#PED-10412).
- wifi: nl80211: fix doc typos (jsc#PED-10412).
- commit a6bc697
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: add ieee80211_fragment_element to public API
  (jsc#PED-10412).
- commit 2f3d9f2
* Wed Aug 28 2024 oneukum@suse.com
- uapi: in6: replace temporary label with rfc9486 (git fix
  rejected for SP6).
- blacklist.conf: kABI can be changed in SP7
- commit 625f7f3
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: Annotate struct cfg80211_scan_request with
  __counted_by (jsc#PED-10412).
- Refresh
  patches.suse/wifi-cfg80211-Extend-support-for-scanning-while-MLO-.patch.
- commit 1acc433
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: Annotate struct cfg80211_cqm_config with
  __counted_by (jsc#PED-10412).
- Refresh
  patches.suse/wifi-cfg80211-fix-CQM-for-non-range-use.patch.
- Refresh
  patches.suse/wifi-cfg80211-fix-cqm_config-access-race.patch.
- commit 8590584
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: Annotate struct cfg80211_tid_config with
  __counted_by (jsc#PED-10412).
- wifi: cfg80211: Annotate struct cfg80211_rnr_elems with
  __counted_by (jsc#PED-10412).
- wifi: cfg80211: Annotate struct cfg80211_pmsr_request with
  __counted_by (jsc#PED-10412).
- wifi: cfg80211: Annotate struct cfg80211_mbssid_elems with
  __counted_by (jsc#PED-10412).
- wifi: cfg80211: Annotate struct cfg80211_acl_data with
  __counted_by (jsc#PED-10412).
- commit 6628583
* Wed Aug 28 2024 oneukum@suse.com
- sysctl: remove struct ctl_path (git fix rejected for SP6).
- blacklist.conf: kABI can be changed in SP7
- commit 7a7014b
* Wed Aug 28 2024 iivanov@suse.de
- config/arm64: Enable Qualcomm Centriq PMU drivers (jsc#PED-10480)
- commit 8ecc2c0
* Wed Aug 28 2024 oneukum@suse.com
- sysctl: Add ctl_table_size to ctl_table_header (git-fixes).
- commit 4ff2f74
* Wed Aug 28 2024 oneukum@suse.com
- usb: new quirk to reduce the SET_ADDRESS request timeout
  (git fix rejected for SP6).
- blacklist.conf: kABI can be changed in SP7
- Refresh
  patches.suse/usb-hub-Add-quirk-to-decrease-IN-ep-poll-interval-fo.patch.
- commit ae2f991
* Wed Aug 28 2024 pjakobsson@suse.de
- drm/amd/display: Fix null pointer deref in dcn20_resource.c (CVE-2024-43899 bsc#1229754).
- commit 1811990
* Wed Aug 28 2024 oneukum@suse.com
- usb: xhci: Add timeout argument in address_device USB HCD
  callback (git fix rejected in SP6).
- blacklist.conf: kABI can be changed in SP7
- Refresh patches.suse/padding-XHCI-additional-padding.patch.
- commit 27787c3
* Wed Aug 28 2024 oneukum@suse.com
- usb: dwc3: dwc3-octeon: Verify clock divider (git fixes not
  applicable in SP6).
- blacklist.conf: reason for blacklisting applied only in SP6, removing
  for SP7
- commit ed55fa9
* Wed Aug 28 2024 oneukum@suse.com
- usb: dwc3: dwc3-octeon: Add SPDX header and copyright (git
  fix rejected for SP6).
- usb: dwc3: dwc3-octeon: Dump control register on clock init
  failure (git fix rejected for SP6).
- usb: dwc3: dwc3-octeon: Move node parsing into driver probe
  (git fix rejected for SP6).
- usb: dwc3: dwc3-octeon: Avoid half-initialized controller state
  (git fix rejected for SP6).
- commit e3ee233
* Wed Aug 28 2024 oneukum@suse.com
- usb: dwc3: dwc3-octeon: Pass dwc3_octeon to setup functions
  (git fix rejected for SP6).
- commit 036ff34
* Wed Aug 28 2024 oneukum@suse.com
- usb: dwc3: dwc3-octeon: Use _ULL bitfields defines (git fix
  rejected for SP6).
- commit 45a1718
* Wed Aug 28 2024 oneukum@suse.com
- usb: dwc3: dwc3-octeon: Convert to glue driver (git fix rejected
  for SP6).
- commit e8830f6
* Wed Aug 28 2024 oneukum@suse.com
- MIPS: OCTEON: octeon-usb: cleanup divider calculation (git
  fix rejected for SP6).
- MIPS: OCTEON: octeon-usb: introduce dwc3_octeon_{read,write}q
  (git fix rejected for SP6).
- MIPS: OCTEON: octeon-usb: move gpio config to separate function
  (git fix rejected for SP6).
- commit 6b04497
* Wed Aug 28 2024 oneukum@suse.com
- MIPS: OCTEON: octeon-usb: use bitfields for shim register
  (git fix rejected for SP6).
- MIPS: OCTEON: octeon-usb: use bitfields for host config register
  (git fix rejected in SP6).
- MIPS: OCTEON: octeon-usb: use bitfields for control register
  (git fix rejected for SP6).
- MIPS: OCTEON: octeon-usb: add all register offsets (git fix
  rejected for SP6).
- commit f7e9da5
* Wed Aug 28 2024 tiwai@suse.de
- Bluetooth: fix connection setup in l2cap_connect (git-fixes).
- commit 04dfce2
* Wed Aug 28 2024 tiwai@suse.de
- Bluetooth: HCI: Remove HCI_AMP support (git-fixes).
- Refresh
  patches.suse/Bluetooth-L2CAP-Fix-slab-use-after-free-in-l2cap_con.patch.
- commit 8b94a6b
* Wed Aug 28 2024 tiwai@suse.de
- Bluetooth: Remove BT_HS (git-fixes).
- blacklist.conf: drop the backported entry
- Refresh
  patches.suse/Bluetooth-L2CAP-Fix-not-validating-setsockopt-user-i.patch.
- commit 34ffe69
* Wed Aug 28 2024 andrea.porta@suse.com
- blacklist.conf: add 56769ba4b297a629148eb24d554aef72d1ddfd9e
- commit e1cb2aa
* Wed Aug 28 2024 iivanov@suse.de
- config/arm64: Disable drivers used by Spreadtrum platform (jsc#PED-10480)
- commit ceb08e9
* Wed Aug 28 2024 iivanov@suse.de
- config/arm64: Disable drivers used by Amlogic Meson platform (jsc#PED-10480)
- commit c463397
* Wed Aug 28 2024 iivanov@suse.de
- config/arm64: Disable drivers used by Samsung Exynos platform (jsc#PED-10480)
- commit 917f646
* Wed Aug 28 2024 mhocko@suse.com
- exec: Fix ToCToU between perm check and set-uid/gid usage
  (CVE-2024-43882 bsc#1229503).
- commit 7a21b9d
* Wed Aug 28 2024 iivanov@suse.de
- config/arm64: Disable drivers used by MediaTek embedded platforms (jsc#PED-10480)
- commit 63132c8
* Wed Aug 28 2024 iivanov@suse.de
- config/arm64: Disable drivers used by Qualcomm embedded platforms (jsc#PED-10480)
- commit 363a810
* Wed Aug 28 2024 tiwai@suse.de
- ALSA: hda/realtek: support HP Pavilion Aero 13-bg0xxx Mute LED
  (stable-fixes).
- ALSA: hda/realtek: Fix the speaker output on Samsung Galaxy
  Book3 Ultra (stable-fixes).
- ASoC: allow module autoloading for table board_ids
  (stable-fixes).
- ASoC: allow module autoloading for table db1200_pids
  (stable-fixes).
- ASoC: mediatek: mt8188: Mark AFE_DAC_CON0 register as volatile
  (stable-fixes).
- ASoC: SOF: mediatek: Add missing board compatible
  (stable-fixes).
- ALSA: hda/realtek - FIxed ALC285 headphone no sound
  (stable-fixes).
- ALSA: hda/realtek - Fixed ALC256 headphone no sound
  (stable-fixes).
- ALSA: hda/realtek: Enable mute/micmute LEDs on HP Laptop
  14-ey0xxx (stable-fixes).
- ALSA: hda/realtek: Implement sound init sequence for Samsung
  Galaxy Book3 Pro 360 (stable-fixes).
- commit 97adcb2
* Wed Aug 28 2024 tbogendoerfer@suse.de
- ip6_tunnel: Fix broken GRO (bsc#1229444).
- net/mlx5: Always drain health in shutdown callback
  (CVE-2024-43866 bsc#1229495).
- mlxsw: spectrum_acl_erp: Fix object nesting warning
  (CVE-2024-43880 bsc#1229481).
- commit d9a404d
* Wed Aug 28 2024 tiwai@suse.de
- pinctrl: rockchip: correct RK3328 iomux width flag for GPIO2-B
  pins (git-fixes).
- pinctrl: starfive: jh7110: Correct the level trigger
  configuration of iev register (git-fixes).
- pinctrl: mediatek: common-v2: Fix broken bias-disable for
  PULL_PU_PD_RSEL_TYPE (git-fixes).
- pinctrl: single: fix potential NULL dereference in
  pcs_get_function() (git-fixes).
- ASoC: SOF: amd: Fix for acp init sequence (git-fixes).
- ASoC: amd: acp: fix module autoloading (git-fixes).
- ALSA: seq: Skip event type filtering for UMP events (git-fixes).
- commit 3fa4a0b
* Tue Aug 27 2024 tbogendoerfer@suse.de
- ice: Fix NULL pointer access, if PF doesn't support SRIOV_LAG
  (bsc#1228737).
- commit f1a9730
* Tue Aug 27 2024 vkarasulli@suse.de
- kABI: vfio: struct virqfd kABI workaround (CVE-2024-26812
  bsc#1222808).
- commit ae735c0
* Tue Aug 27 2024 denis.kirjanov@suse.com
- net/sched: Fix mirred deadlock on device recursion
  (CVE-2024-27010 bsc#1223720).
- commit 8c34ee8
* Tue Aug 27 2024 dsterba@suse.com
- Fix reference in patches.suse/netfilter-tproxy-bail-out-if-IP-has-been-disabled-on.patch (CVE-2024-36270 bsc#1226798)
- commit 052d917
* Tue Aug 27 2024 denis.kirjanov@suse.com
- net: qdisc: preserve kabi for struct QDisc (CVE-2024-27010 bsc#1223720).
- commit e31d466
* Tue Aug 27 2024 vbabka@suse.cz
- mm/userfaultfd: reset ptes when close() for wr-protected ones
  (CVE-2024-36881 bsc#1225718).
- commit 2267d46
* Tue Aug 27 2024 vbabka@suse.cz
- mm/mglru: fix div-by-zero in vmpressure_calc_level()
  (CVE-2024-42316 bsc#1229353).
- commit ba00671
* Tue Aug 27 2024 colyli@suse.de
- md/raid1: set max_sectors during early return from
  choose_slow_rdev() (git-fixes).
- md/raid5: recheck if reshape has finished with device_lock held
  (git-fixes).
- md: Don't wait for MD_RECOVERY_NEEDED for HOT_REMOVE_DISK ioctl
  (git-fixes).
- md/raid5: fix spares errors about rcu usage (git-fixes).
- md/md-bitmap: fix writing non bitmap pages (git-fixes).
- md: fix deadlock between mddev_suspend and flush bio
  (bsc#1229342, CVE-2024-43855).
- md: change the return value type of md_write_start to void
  (git-fixes).
- md: do not delete safemode_timer in mddev_suspend (git-fixes).
- md: don't account sync_io if iostats of the disk is disabled
  (git-fixes).
- md: add check for sleepers in md_wakeup_thread() (git-fixes).
- md/raid5: fix deadlock that raid5d() wait for itself to clear
  MD_SB_CHANGE_PENDING (git-fixes).
- md: add a mddev_add_trace_msg helper (git-fixes).
- Revert "Revert "md/raid5: Wait for MD_SB_CHANGE_PENDING in
  raid5d"" (git-fixes).
- md: fix a suspicious RCU usage warning (git-fixes).
- md/raid1: support read error check (git-fixes).
- commit f1ec0d4
* Tue Aug 27 2024 colyli@suse.de
- md: factor out a helper exceed_read_errors() to check
  read_errors (git-fixes).
- Refresh for the above change,
  patches.suse/md-display-timeout-error.patch.
  patches.suse/md-raid1-10-add-a-helper-raid1_check_read_range-f298.patch.
- commit 035e3f0
* Tue Aug 27 2024 colyli@suse.de
- Revert "md/raid5: Wait for MD_SB_CHANGE_PENDING in raid5d"
  (git-fixes).
- commit 5cc0fdd
* Mon Aug 26 2024 dsterba@suse.com
- net/mlx5e: Fix CT entry update leaks of modify header context (CVE-2024-43864 bsc#1229496)
- commit 316a4fe
* Mon Aug 26 2024 msuchanek@suse.de
- rpm/check-for-config-changes: Exclude ARCH_USING_PATCHABLE_FUNCTION_ENTRY
  gcc version dependent, at least on ppc
- commit 16da158
* Mon Aug 26 2024 mkoutny@suse.com
- af_unix: Fix data races in unix_release_sock/unix_stream_sendmsg
  (bsc#1226846 CVE-2024-38596).
- Update
  patches.suse/af_unix-Fix-data-races-around-sk-sk_shutdown.patch
  (git-fixes bsc#1226846).
- commit 7ceb0cd
* Mon Aug 26 2024 tiwai@suse.de
- platform/x86/intel/pmc: Improve PKGC residency counters debug
  (jsc#PED-10411).
- platform/x86/intel/pmc/arl: Put GNA device in D3
  (jsc#PED-10411).
- platform/x86/intel/pmc/lnl: Remove SSRAM support
  (jsc#PED-10411).
- platform/x86/intel/pmc: Add missing extern (jsc#PED-10411).
- platform/x86/intel/pmc/lnl: Add GBE LTR ignore during suspend
  (jsc#PED-10411).
- platform/x86/intel/pmc/arl: Add GBE LTR ignore during suspend
  (jsc#PED-10411).
- platform/x86/intel/pmc: Add Lunar Lake M support to
  intel_pmc_core driver (jsc#PED-10411).
- platform/x86/intel/pmc: Add Arrow Lake S support to
  intel_pmc_core driver (jsc#PED-10411).
- commit 70a33f0
* Mon Aug 26 2024 tiwai@suse.de
- platform/x86/intel/pmc: Add ssram_init flag in PMC discovery
  in Meteor Lake (jsc#PED-10411).
- platform/x86/intel/pmc: Move common code to core.c
  (jsc#PED-10411).
- platform/x86/intel/pmc: Add PSON residency counter for Alder
  Lake (jsc#PED-10411).
- platform/x86/intel/pmc: Add regmap for Tiger Lake H PCH
  (jsc#PED-10411).
- platform/x86/intel/pmc: Add PSON residency counter
  (jsc#PED-10411).
- platform/x86/intel/pmc: Fix in mtl_punit_pmt_init()
  (jsc#PED-10411).
- platform/x86/intel/pmc: Fix in pmc_core_ssram_get_pmc()
  (jsc#PED-10411).
- platform/x86/intel/pmc: Show Die C6 counter on Meteor Lake
  (jsc#PED-10411).
- platform/x86/intel/pmc: Add debug attribute for Die C6 counter
  (jsc#PED-10411).
- platform/x86/intel/pmc: Read low power mode requirements for
  MTL-M and MTL-P (jsc#PED-10411).
- commit 0f7c762
* Mon Aug 26 2024 tiwai@suse.de
- platform/x86/intel/pmc: Retrieve LPM information using Intel
  PMT (jsc#PED-10411).
- platform/x86/intel/pmc: Display LPM requirements for multiple
  PMCs (jsc#PED-10411).
- platform/x86/intel/pmc: Find and register PMC telemetry entries
  (jsc#PED-10411).
- platform/x86/intel/pmc/mtl: Use return value from
  pmc_core_ssram_init() (jsc#PED-10411).
- platform/x86/intel/pmc: Cleanup SSRAM discovery (jsc#PED-10411).
- platform/x86/intel/pmc: Allow pmc_core_ssram_init to fail
  (jsc#PED-10411).
- platform/x86/intel/pmt: telemetry: Export API to read telemetry
  (jsc#PED-10411).
- platform/x86/intel/pmt: Add header to struct intel_pmt_entry
  (jsc#PED-10411).
- commit ed73596
* Mon Aug 26 2024 tiwai@suse.de
- platform/x86:intel/pmc: Call pmc_get_low_power_modes from
  platform init (jsc#PED-10411).
- commit 777c985
* Mon Aug 26 2024 ptesarik@suse.com
- string: Allow 2-argument strscpy() (bsc#1229741).
- commit d3b7527
* Mon Aug 26 2024 tiwai@suse.de
- Enable pinctrl-intel-platform driver (jsc#PED-10210)
- Update config files: CONFIG_PINCTRL_INTEL_PLATFORM=m
- supported.conf: add pinctrl-intel-platform
- commit 7cad154
* Mon Aug 26 2024 tiwai@suse.de
- pinctrl: intel: Add a generic Intel pin control platform driver
  (jsc#PED-10210).
- devres: Provide krealloc_array (jsc#PED-10210).
- commit d328690
* Mon Aug 26 2024 sjaeckel@suse.de
- ipv6: mcast: fix data-race in ipv6_mc_down / mld_ifc_work
  (CVE-2024-26631 bsc#1221630).
- commit 317a097
* Mon Aug 26 2024 tiwai@suse.de
- tools/arch/x86/intel_sdsi: Add current meter support
  (jsc#PED-10384).
- tools/arch/x86/intel_sdsi: Simplify ascii printing
  (jsc#PED-10384).
- commit 3f1383e
* Mon Aug 26 2024 tiwai@suse.de
- platform/x86/intel/sdsi: Add attribute to read the current
  meter state (jsc#PED-10384).
- platform/x86/intel/sdsi: Add in-band BIOS lock support
  (jsc#PED-10384).
- platform/x86/intel/sdsi: Combine read and write mailbox flows
  (jsc#PED-10384).
- platform/x86/intel/sdsi: Set message size during writes
  (jsc#PED-10384).
- commit e23f4a7
* Mon Aug 26 2024 dsterba@suse.com
- netfilter: nf_tables: unconditionally flush pending work before notifier (CVE-2024-42109 bsc#1228505)
- commit 7a6a06c
* Mon Aug 26 2024 dsterba@suse.com
- cxl/region: Avoid null pointer dereference in region lookup (CVE-2024-41084 bsc#1228472)
- commit fc1408b
* Mon Aug 26 2024 dsterba@suse.com
- cxl/region: Move cxl_dpa_to_region() work to the region driver (bsc#1228472)
- commit ac0e984
* Mon Aug 26 2024 dsterba@suse.com
- ipv6: fix possible race in __fib6_drop_pcpu_from() (CVE-2024-40905 bsc#1227761)
- commit 6fcd399
* Mon Aug 26 2024 dsterba@suse.com
- ipv6: sr: fix memleak in seg6_hmac_init_algo (CVE-2024-39489 bsc#1227623)
- commit c55beb2
* Mon Aug 26 2024 ptesarik@suse.com
- swiotlb: do not set total_used to 0 in
  swiotlb_create_debugfs_files() (git-fixes).
- swiotlb: fix swiotlb_bounce() to do partial sync's correctly
  (git-fixes).
- commit 99fe6bb
* Mon Aug 26 2024 ptesarik@suse.com
- blacklist.conf: add console_replay_all() rename
- commit afd359c
* Mon Aug 26 2024 ptesarik@suse.com
- Documentation: kernel-parameters: Add DEVNAME:0.0 format for
  serial ports (bsc#1229741).
- serial: core: Add
  serial_base_match_and_update_preferred_console() (bsc#1229741).
- printk: Add match_devname_and_update_preferred_console()
  (bsc#1229741).
- commit 9c7a804
* Mon Aug 26 2024 ptesarik@suse.com
- printk: cleanup deprecated uses of strncpy/strcpy (bsc#1229741).
- Revert "printk: Save console options for
  add_preferred_console_match()" (git-fixes).
- Revert "printk: Don't try to parse DEVNAME:0.0 console options"
  (git-fixes).
- Revert "printk: Flag register_console() if console is set on
  command line" (git-fixes).
- commit 46921ce
* Mon Aug 26 2024 ptesarik@suse.com
- serial: core: Fix serial core port id, including multiport
  devices (git-fixes).
- serial: port: Don't block system suspend even if bytes are
  left to xmit (git-fixes).
- serial: core: Clearing the circular buffer before NULLifying it
  (git-fixes).
- serial: core: Fix regression when runtime PM is not enabled
  (git-fixes).
- serial: core: Fix serial_base_match() after fixing controller
  port name (git-fixes).
- serial: core: Fix missing shutdown and startup for serial base
  port (git-fixes).
- commit e8f48ae
* Mon Aug 26 2024 ptesarik@suse.com
- serial: port: Don't suspend if the port is still busy
  (git-fixes).
- serial: core: Revert checks for tx runtime PM state (git-fixes).
- serial: 8250: drop lockdep annotation from
  serial8250_clear_IER() (git-fixes).
- serial: core: Revert port_id use (git-fixes).
- serial: 8250: Reinit port_id when adding back
  serial8250_isa_devs (git-fixes).
- commit 1776421
* Mon Aug 26 2024 ptesarik@suse.com
- serial: core: Fix kmemleak issue for serial core device remove
  (git-fixes).
- serial: core: Fix serial core controller port name to show
  controller id (git-fixes).
- 8250_men_mcb: remove unnecessary cast when reading register
  (git-fixes).
- 8250_men_mcb: Fix unsigned expression compared with zero
  (git-fixes).
- ARM: 9352/1: iwmmxt: Remove support for PJ4/PJ4B cores
  (git-fixes).
- commit 424f391
* Mon Aug 26 2024 ptesarik@suse.com
- arm64/arch_timer: Fix MMIO byteswap (git-fixes).
- tty/sysrq: Replay kernel log messages on consoles via sysrq
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: Add function to replay kernel log on consoles
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: Flag register_console() if console is set on command
  line (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: Don't try to parse DEVNAME:0.0 console options
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit a8a4b7e
* Mon Aug 26 2024 ptesarik@suse.com
- printk: Save console options for add_preferred_console_match()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- net: Remove conditional threaded-NAPI wakeup based on task state
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- cxgb4: Properly lock TX queue for the selftest (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- btrfs: qgroup: fix qgroup prealloc rsv leak in subvolume
  operations (CVE-2024-35956 bsc#1224674).
- blacklist.conf: Remove the above commit.
- serial: port: Introduce a common helper to read properties
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 8dcc4c4
* Mon Aug 26 2024 ptesarik@suse.com
- serial: core: Add UPIO_UNKNOWN constant for unknown port type
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Move struct uart_port::quirks closer to possible
  values (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: pch: Don't initialize uart_port's spin_lock (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: pch: Don't disable interrupts while acquiring lock in
  ISR (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: pch: Make push_rx() return void (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- commit 3993c78
* Mon Aug 26 2024 ptesarik@suse.com
- serial: pch: Invoke handle_rx_to() directly (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- panic: add option to dump blocked tasks in panic_print
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- panic: suppress gnu_printf warning (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- panic: Flush kernel log buffer at the end (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- blacklist.conf: Remove the above commit.
- serial: stm32: do not always set SER_RS485_RX_DURING_TX if RS485
  is enabled (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- xsk: Add truesize to skb_add_rx_frag() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- commit add956c
* Mon Aug 26 2024 ptesarik@suse.com
- usb: cdc-acm: return correct error code on unsupported break
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: Do not hold the port lock when setting rx-during-tx GPIO
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Update uart_poll_timeout() function to return
  unsigned long (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- device property: Add fwnode_property_match_property_string()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- ARM: 9327/1: vfp: Add missing VFP instructions to
  neon_support_hook (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- commit cf7a873
* Mon Aug 26 2024 ptesarik@suse.com
- device property: Add fwnode_name_eq() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- device property: Implement device_is_big_endian() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- device property: Add SOFTWARE_NODE() macro for defining software
  nodes (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Fix runtime PM handling for pending tx
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 064ade2
* Mon Aug 26 2024 ptesarik@suse.com
- printk: Constify name for add_preferred_console() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- printk: Check valid console index for preferred console
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: exar: Add RS-485 support for Sealevel XR17V35X based
  cards (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: use 'if' in send_break() instead of 'goto' (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty: don't check for signal_pending() in send_break()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 7496c73
* Mon Aug 26 2024 ptesarik@suse.com
- tty: early return from send_break() on TTY_DRIVER_HARDWARE_BREAK
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Use port lock wrappers (git-fixes).
- Refresh
  patches.suse/serial-core-Fix-atomicity-violation-in-uart_tiocmget.patch.
- serial: core: Use lock wrappers (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- printk: fix illegal pbufs access for !CONFIG_PRINTK (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/printk-Avoid-non-panic-CPUs-writing-to-ringbuffer.patch.
- printk: nbcon: Allow drivers to mark unsafe regions and check
  state (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: nbcon: Add emit function and callback function
  for atomic printing (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- Refresh
  patches.suse/dump_stack-Do-not-get-cpu_sync-for-panic-CPU.patch.
- Refresh patches.suse/printk-Add-this_cpu_in_panic.patch.
- Refresh
  patches.suse/printk-Avoid-non-panic-CPUs-writing-to-ringbuffer.patch.
- commit 66aa9f0
* Mon Aug 26 2024 ptesarik@suse.com
- printk: nbcon: Add sequence handling (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- printk: nbcon: Add ownership state functions (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- printk: nbcon: Add buffer management (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- printk: Make static printk buffers available to nbcon
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: nbcon: Add acquire/release logic (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit d4c512c
* Mon Aug 26 2024 ptesarik@suse.com
- printk: Add non-BKL (nbcon) console basic infrastructure
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: Reduce pr_flush() pooling time (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- =?UTF-8?q?printk:=20printk:=20Remove=20unnecessary=20stat?=
  =?UTF-8?q?ements=EF=BC=87len=20=3D=200;=EF=BC=87?= (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- bpf: Remove xdp_do_flush_map() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- signal: Don't disable preemption in ptrace_stop() on PREEMPT_RT
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 4bad803
* Mon Aug 26 2024 ptesarik@suse.com
- signal: Add a proper comment about preempt_disable() in
  ptrace_stop() (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- sched/debug: Update stale reference to sched_debug.c
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Fix checks for tx runtime PM state (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- printk: flush consoles before checking progress (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/printk-Wait-for-all-reserved-records-with-pr_flush.patch.
- selftests: hsr: Extend the testsuite to also cover HSRv1
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 272e73e
* Mon Aug 26 2024 ptesarik@suse.com
- selftests: hsr: Reorder the testsuite (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- selftests: hsr: Use `let' properly (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- printk: Add per-console suspended state (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- kdb: Do not assume write() callback available (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- Revert "tty: serial: meson: Add a earlycon for the T7 SoC"
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 62a3bb8
* Mon Aug 26 2024 ptesarik@suse.com
- serial: 8250_bcm7271: improve bcm7271 8250 port (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: sifive: Add suspend and resume operations (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty: serial: meson: Add a earlycon for the T7 SoC (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: stm32: synchronize RX DMA channel in shutdown
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: stm32: replace access to DMAR bit by
  dmaengine_pause/resume (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- commit 5173642
* Mon Aug 26 2024 ptesarik@suse.com
- serial: stm32: group dma pause/resume error handling into single
  function (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: stm32: modify parameter and rename
  stm32_usart_rx_dma_enabled (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- serial: stm32: use DMAT as a configuration bit (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: stm32: avoid clearing DMAT bit during transfer
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: use min() for size computation in iterate_tty_read()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit bc6a9a2
* Mon Aug 26 2024 ptesarik@suse.com
- tty: switch size and count types in iterate_tty_read() to size_t
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: use ssize_t for iterate_tty_read() returned type
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: use min() in iterate_tty_write() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- tty: rename and de-inline do_tty_write() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty: don't pass write() to do_tty_write() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit 7377b6a
* Mon Aug 26 2024 ptesarik@suse.com
- tty: change tty_write_lock()'s ndelay parameter to bool
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: sifive: Remove redundant of_match_ptr() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty: serial: samsung: Set missing PM ops for hibernation support
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: serial: xilinx_uartps: Do not check for 0 return after
  calling platform_get_irq() (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- tty: serial: meson: refactor objects definition for different
  devnames (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit e959e86
* Mon Aug 26 2024 ptesarik@suse.com
- 8250_men_mcb: fix error handling in
  read_uarts_available_from_reg() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- serial: st-asc: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: imx: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: sifive: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit d103400
* Mon Aug 26 2024 ptesarik@suse.com
- serial: mvebu-uart: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: sccnxp: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: sprd: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: mps2-uart: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: vt8500: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: fsl_lpuart: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit fe3c157
* Mon Aug 26 2024 ptesarik@suse.com
- serial: omap: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: tegra: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: linflexuart: Use
  devm_platform_get_and_ioremap_resource() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: clps711x: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: bcm63xx-uart: Use
  devm_platform_get_and_ioremap_resource() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit 442a43a
* Mon Aug 26 2024 ptesarik@suse.com
- serial: ar933x: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: qcom-geni: clean up clock-rate debug printk (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty: serial: fsl_lpuart: add IDLE interrupt support for
  rx_dma on imx7ulp/imx8ulp/imx8qxp (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- tty: serial: fsl_lpuart: move the lpuart32_int() below
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: serial: 8250: Define earlycon for mrvl,mmp-uart
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 048ed41
* Mon Aug 26 2024 ptesarik@suse.com
- tty: serial: meson: add independent uart_data for A1 SoC family
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: serial: meson: introduce separate uart_data for S4 SoC
  family (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: serial: meson: apply ttyS devname instead of ttyAML for
  new SoCs (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: serial: meson: redesign the module to platform_driver
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: serial: meson: use dev_err_probe (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- Refresh
  patches.suse/tty-serial-meson-fix-hard-LOCKUP-on-crtscts-mode.patch.
- commit 81dc1c3
* Mon Aug 26 2024 ptesarik@suse.com
- 8250_men_mcb: Make UART config auto configurable (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- 8250_men_mcb: Read num ports from register data (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- 8250_men_mcb: Add clockrate speed for G215/F215 boards
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: tegra: Don't print error on probe deferral (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty: Explicitly include correct DT includes (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/serial-imx-Introduce-timeout-when-waiting-on-transmi.patch.
- commit 3f8d73f
* Mon Aug 26 2024 ptesarik@suse.com
- serial: qcom-geni: use icc tag defines (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- serial: drivers: switch ch and flag to u8 (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/serial-max3100-Lock-port-lock-when-calling-uart_hand.patch.
- serial: omap-serial: remove flag from serial_omap_rdi()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: arc_uart: simplify flags handling in
  arc_serial_rx_chars() (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- serial: make uart_insert_char() accept u8s (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit bfcf125
* Mon Aug 26 2024 ptesarik@suse.com
- serial: convert uart sysrq handling to u8 (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty: make check_tty_count() void (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- ARM: entry: Make asm coproc dispatch code NWFPE only
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- ARM: iwmmxt: Use undef hook to enable coprocessor for task
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- ARM: entry: Disregard Thumb undef exception in coproc dispatch
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit b8595f0
* Mon Aug 26 2024 ptesarik@suse.com
- ARM: vfp: Use undef hook for handling VFP exceptions
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- ARM: kernel: Get rid of thread_info::used_cp[] array
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- ARM: vfp: Reimplement VFP exception entry in C code (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- ARM: vfp: Remove workaround for Feroceon CPUs (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- ARM: vfp: Record VFP bounces as perf emulation faults
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 8dc51a0
* Mon Aug 26 2024 ptesarik@suse.com
- kill do_each_thread() (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- sched: avoid false lockdep splat in put_task_struct()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Fix serial core port id to not use port->line
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Controller id cannot be negative (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- ARM: mm: Make virt_to_pfn() a static inline (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit 898f0c4
* Mon Aug 26 2024 ptesarik@suse.com
- tty_audit: make data of tty_audit_log() const (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty_audit: make icanon a bool (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- tty_audit: invert the condition in tty_audit_log() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty_audit: use kzalloc() in tty_audit_buf_alloc() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty_audit: use TASK_COMM_LEN for task comm (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit 497271a
* Mon Aug 26 2024 ptesarik@suse.com
- tty: tty_io: update timestamps on all device nodes (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: core: fix -EPROBE_DEFER handling in init (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty: serial: samsung_tty: Use abs() to simplify some code
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: Apply FSL workarounds also without
  SERIAL_8250_CONSOLE (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- commit ad55bc8
* Mon Aug 26 2024 ptesarik@suse.com
- serial: core: don't kfree device managed data (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: 8250_mtk: Simplify clock sequencing and runtime PM
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Fix error handling for
  serial_core_ctrl_device_add() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- serial: core: Fix probing serial_base_bus devices (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: core: Don't drop port_mutex in
  serial_core_remove_one_port (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- commit 54dc43c
* Mon Aug 26 2024 ptesarik@suse.com
- serial: core: Start managing serial controllers to enable
  runtime PM (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/serial-8250-Fix-oops-for-port-pm-on-uart_chang.patch.
- serial: 8250: omap: convert to modern PM ops (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/serial-8250_omap-Use-force_suspend-and-resume-f.patch.
- serial: 8250: omap: Move uart_write() inside PM section
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250-fsl: Expand description of the MPC83xx UART's
  misbehaviour (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: Indicate fintek option may also be required for RS232
  support (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 4b15607
* Mon Aug 26 2024 ptesarik@suse.com
- tty: serial: fsl_lpuart: Check the return value of
  dmaengine_tx_status (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- serial: Switch i2c drivers back to use .probe() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: 8250: synchronize and annotate UART_IER access
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: lock port for omap8250_restore_regs() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: 8250: lock port for rx_dma() callback (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit e0ca1a8
* Mon Aug 26 2024 ptesarik@suse.com
- serial: 8250: lock port in startup() callbacks (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: Make uart_remove_one_port() return void (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: 8250_rt288x: Remove unnecessary UART_REG_UNMAPPED
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250_rt288x: Name non-standard divisor latch reg
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: RT288x/Au1xxx code away from core (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/serial-8250_omap-Add-earlycon-support-for-the-AM654-.patch.
- commit a2895ad
* Mon Aug 26 2024 ptesarik@suse.com
- serial: 8250: Add dl_read/write, bugs and mapsize into
  plat_serial8250_port (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- Refresh
  patches.suse/Revert-8250-add-support-for-ASIX-devices-with-a.patch.
- serial: 8250: Document uart_8250_port's ->dl_read/write()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: Change dl_read/write to handle value as u32
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: Allow using ports higher than
  SERIAL_8250_RUNTIME_UARTS (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- serial: 8250: omap: Shut down on remove for console uart
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/serial-8250-omap-Don-t-skip-resource-freeing-if-pm_r.patch.
- commit d44d1c4
* Mon Aug 26 2024 ptesarik@suse.com
- serial: 8250: omap: Fix life cycle issues for interrupt handlers
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: omap: Fix imprecise external abort for
  omap_8250_pm() (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- Refresh
  patches.suse/serial-8250-omap-Don-t-skip-resource-freeing-if-pm_r.patch.
- Refresh
  patches.suse/serial-8250_omap-Fix-errors-with-no_console_suspend.patch.
- Refresh
  patches.suse/serial-8250_omap-Implementation-of-Errata-i2310.patch.
- serial: pl011: set UART011_CR_RXE in pl011_set_termios after
  port shutdown (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: serial: fsl_lpuart: optimize the timer based EOP logic
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- device property: Implement device_is_compatible() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit f402fd9
* Mon Aug 26 2024 ptesarik@suse.com
- serial: qcom_geni: Comment use of devm_krealloc rather than
  devm_krealloc_array (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- panic: hide unused global functions (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- lockdep: Add lock_set_cmp_fn() annotation (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- cpuidle: Use local_clock_noinstr() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- sched/clock: Provide local_clock_noinstr() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- x86/tsc: Provide sched_clock_noinstr() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- commit d6687b5
* Mon Aug 26 2024 ptesarik@suse.com
- math64: Always inline u128 version of mul_u64_u64_shr()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- s390/time: Provide sched_clock_noinstr() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- arm64/arch_timer: Provide noinstr sched_clock_read() functions
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- arm64/io: Always inline all of __raw_{read,write}[bwlq]()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- time/sched_clock: Provide sched_clock_noinstr() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit b0e396c
* Mon Aug 26 2024 ptesarik@suse.com
- seqlock/latch: Provide raw_read_seqcount_latch_retry()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- arm: update in-source documentation references (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- ARM: 9312/1: vfp: include asm/neon.h in vfpmodule.c (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit 5988720
* Mon Aug 26 2024 bdas@suse.de
- x86/kaslr: Expose and use the end of the physical memory
  address space (bsc#1229443).
- commit 5b98c4e
* Mon Aug 26 2024 dsterba@suse.com
- tls: fix missing memory barrier in tls_init (CVE-2024-36489 bsc#1226874)
- commit 67db543
* Mon Aug 26 2024 tiwai@suse.de
- thermal: intel: int340x: Free MSI IRQ vectors on module exit
  (jsc#PED-10407).
- thermal: intel: int340x: Allow limited thermal MSI support
  (jsc#PED-10407).
- thermal: intel: int340x: Fix kernel warning during MSI cleanup
  (jsc#PED-10407).
- thermal: intel: int340x: Enable WLT and power floor support
  for Lunar Lake (jsc#PED-10407).
- thermal: intel: int340x: Support MSI interrupt for Lunar Lake
  (jsc#PED-10407).
- thermal: intel: int340x: Remove unnecessary calls to free irq
  (jsc#PED-10407).
- thermal: intel: intel_pch: Improve cooling log (jsc#PED-10407).
- thermal: int3403: remove unused struct
  'int3403_performance_state' (jsc#PED-10407).
- thermal: int3400: Use sizeof(*pointer) instead of sizeof(type)
  (jsc#PED-10407).
- ACPI: DPTF: Add Lunar Lake support (jsc#PED-10407).
- thermal: intel: hfi: Increase the number of CPU capabilities
  per netlink event (jsc#PED-10407).
- thermal: intel: hfi: Rename HFI_MAX_THERM_NOTIFY_COUNT
  (jsc#PED-10407).
- thermal: intel: hfi: Shorten the thermal netlink event delay
  to 100ms (jsc#PED-10407).
- thermal: intel: hfi: Rename HFI_UPDATE_INTERVAL (jsc#PED-10407).
- thermal: intel: Add missing module description (jsc#PED-10407).
- thermal: intel: int340x_thermal: replace deprecated strncpy()
  with strscpy() (jsc#PED-10407).
- commit c4c5001
* Mon Aug 26 2024 tiwai@suse.de
- thermal: intel: int340x: Add DLVR support for Lunar Lake
  (jsc#PED-10407).
- thermal: intel: int340x: Capability to map user space to
  firmware values (jsc#PED-10407).
- thermal: intel: int340x: Cleanup of DLVR sysfs on driver remove
  (jsc#PED-10407).
- commit 40be547
* Mon Aug 26 2024 tiwai@suse.de
- Update patch reference for intel thermal driver (jsc#PED-10201)
- commit 586e143
* Mon Aug 26 2024 vkarasulli@suse.de
- iommu: Add kABI workaround patch (bsc#1223742
  CVE-2024-27079).
- commit c4ebc76
* Mon Aug 26 2024 wqu@suse.com
- btrfs: copy dir permission and time when creating a stub
  subvolume (bsc#1228321).
- commit 46e95d1
* Sun Aug 25 2024 tiwai@suse.de
- Refresh patches.suse/0006-KVM-guest_memfd-extract-__kvm_gmem_get_pfn.patch
  Fix a wrong return for the merge-conflict fix.
  The current SLE15-SP7 code is slightly different from the latest upstream.
- commit 8c9c102
* Sat Aug 24 2024 tiwai@suse.de
- nouveau/firmware: use dma non-coherent allocator (git-fixes).
- drm/amdgpu/sdma5.2: limit wptr workaround to sdma 5.2.1
  (git-fixes).
- drm/msm/dpu: cleanup FB if dpu_format_populate_layout fails
  (git-fixes).
- drm/msm/dp: reset the link phy params before link training
  (git-fixes).
- drm/msm/dp: fix the max supported bpp logic (git-fixes).
- drm/msm/dpu: don't play tricks with debug macros (git-fixes).
- mmc: mmc_test: Fix NULL dereference on allocation failure
  (git-fixes).
- mmc: dw_mmc: allow biu and ciu clocks to defer (git-fixes).
- mmc: mtk-sd: receive cmd8 data when hs400 tuning fail
  (git-fixes).
- commit ec72baf
* Fri Aug 23 2024 krisman@suse.de
- filelock: Fix fcntl/close race recovery compat path (bsc#1228427
  CVE-2024-41020).
- commit 2c615e8
* Fri Aug 23 2024 vkarasulli@suse.de
- vfio/pci: fix potential memory leak in vfio_intx_enable()
  (git-fixes).
- commit 45c2786
* Fri Aug 23 2024 vkarasulli@suse.de
- vfio: Introduce interface to flush virqfd inject workqueue
  (CVE-2024-26812 bsc#1222808).
- commit 0704da7
* Fri Aug 23 2024 jgross@suse.com
- KVM: x86: Disallow read-only memslots for SEV-ES and SEV-SNP
  (and TDX) (git-fixes).
- commit a269b15
* Fri Aug 23 2024 jgross@suse.com
- KVM: SEV: Implement gmem hook for invalidating private pages
  (jsc#PED-5122).
- Update config files.
- commit 48cc52c
* Fri Aug 23 2024 jgross@suse.com
- KVM: SEV: Implement gmem hook for initializing private pages
  (jsc#PED-5122).
- Update config files.
- commit 2610bc7
* Fri Aug 23 2024 vkarasulli@suse.de
- vfio/pci: Create persistent INTx handler (CVE-2024-26812
  bsc#1222808).
- commit c0eeff7
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Fix incorrect error code printout in fred_bad_type() (git-fixes).
- commit 6f369a8
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Fix typo in Kconfig description (git-fixes).
- commit a3839d4
* Fri Aug 23 2024 mkubecek@suse.cz
- netfilter: nf_tables: discard table flag update with pending
  basechain deletion (CVE-2024-35897 bsc#1224510).
- netfilter: nf_tables: reject table flag and netdev basechain
  updates (CVE-2024-35897 bsc#1224510).
- commit bc3bca5
* Fri Aug 23 2024 nik.borisov@suse.com
- MAINTAINERS: Add a maintainer entry for FRED (jsc#PED-10236).
- commit 1d1fb28
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Fix init_task thread stack pointer initialization (jsc#PED-10236).
- commit dac8439
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Fix a build warning with allmodconfig due to 'inline' failing to inline properly (jsc#PED-10236).
- commit 5323d23
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Invoke FRED initialization code to enable FRED (jsc#PED-10236).
- commit 1cea8b4
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Add FRED initialization functions (jsc#PED-10236).
- commit 9bacc0b
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/syscall: Split IDT syscall setup code into idt_syscall_init() (jsc#PED-10236).
- commit 78d6cf9
* Fri Aug 23 2024 nik.borisov@suse.com
- KVM: VMX: Call fred_entry_from_kvm() for IRQ/NMI handling (jsc#PED-10236).
- commit 286c6b4
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/entry: Add fred_entry_from_kvm() for VMX to handle IRQ/NMI (jsc#PED-10236).
- commit e91f47f
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/entry/calling: Allow PUSH_AND_CLEAR_REGS being used beyond actual  entry code (jsc#PED-10236).
- commit fa70b45
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Fixup fault on ERETU by jumping to fred_entrypoint_user (jsc#PED-10236).
- commit b838b91
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Let ret_from_fork_asm() jmp to asm_fred_exit_user when FRED is enabled (jsc#PED-10236).
- commit d6f6547
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/traps: Add sysvec_install() to install a system interrupt handler (jsc#PED-10236).
- commit 24f4cd0
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: FRED entry/exit and dispatch code (jsc#PED-10236).
- Refresh
  patches.suse/x86-bugs-Fix-the-SRSO-mitigation-on-Zen3-4.patch.
- commit 09e49bb
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Add a machine check entry stub for FRED (jsc#PED-10236).
- commit 1c5b1a1
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Add a NMI entry stub for FRED (jsc#PED-10236).
- commit 7b999cb
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Add a debug fault entry stub for FRED (jsc#PED-10236).
- commit 706f1aa
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/idtentry: Incorporate definitions/declarations of the FRED entries (jsc#PED-10236).
- commit e0c3e0b
* Fri Aug 23 2024 mkubecek@suse.cz
- kabi: restore const specifier in flow_offload_route_init()
  (CVE-2024-27403 bsc#1224415).
- netfilter: nft_flow_offload: reset dst in route object after
  setting up flow (CVE-2024-27403 bsc#1224415).
- commit f1d28bc
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Make exc_page_fault() work for FRED (jsc#PED-10236).
- Refresh patches.suse/x86-fault-Dump-RMP-table-information-when-RMP-page-faults-occur.
- commit 1e78b66
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Allow single-step trap and NMI when starting a new task (jsc#PED-10236).
- commit e51fa23
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: No ESPFIX needed when FRED is enabled (jsc#PED-10236).
- commit 3a2e473
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Disallow the swapgs instruction when FRED is enabled (jsc#PED-10236).
- commit 86c14bd
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Update MSR_IA32_FRED_RSP0 during task switch (jsc#PED-10236).
- commit 98b02ab
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Reserve space for the FRED stack frame (jsc#PED-10236).
- commit 20c25f5
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Add a new header file for FRED definitions (jsc#PED-10236).
- commit d7b2831
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/ptrace: Add FRED additional information to the pt_regs structure (jsc#PED-10236).
- commit 9e63d83
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/ptrace: Cleanup the definition of the pt_regs structure (jsc#PED-10236).
- commit 5ec5fb8
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/cpu: Add MSR numbers for FRED configuration (jsc#PED-10236).
- commit 04bffbb
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/cpu: Add X86_CR4_FRED macro (jsc#PED-10236).
- commit 69782a8
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/objtool: Teach objtool about ERET (jsc#PED-10236).
- commit 8992f34
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/opcode: Add ERET instructions to the x86 opcode map (jsc#PED-10236).
- commit 1fcadbc
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Add a fred= cmdline param (jsc#PED-10236).
- commit b3f1806
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Disable FRED support if CONFIG_X86_FRED is disabled  (jsc#PED-10236).
- Refresh patches.suse/x86-cpufeatures-Add-SEV-SNP-CPU-feature.
- Refresh patches.suse/x86-cpufeatures-Enable-unmask-SEV-SNP-CPU-feature.
- commit 1f8603b
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/cpufeatures: Add the CPU feature bit for FRED (jsc#PED-10236).
- commit 3c372ca
* Fri Aug 23 2024 tiwai@suse.de
- Bluetooth: MGMT: Add error handling to pair_device()
  (git-fixes).
- Bluetooth: SMP: Fix assumption of Central always being Initiator
  (git-fixes).
- Bluetooth: hci_core: Fix LE quote calculation (git-fixes).
- commit 82ede4a
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Add Kconfig option for FRED (CONFIG_X86_FRED) (jsc#PED-10236).
- commit 798e495
* Fri Aug 23 2024 nik.borisov@suse.com
- Documentation/x86/64: Add documentation for FRED (jsc#PED-10236).
- commit 6e88ec9
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/trapnr: Add event type macros to <asm/trapnr.h> (jsc#PED-10236).
- commit fecd499
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/entry: Remove idtentry_sysvec from entry_{32,64}.S (jsc#PED-10236).
- commit 01e57c3
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/cpufeatures,opcode,msr: Add the WRMSRNS instruction support (jsc#PED-10236).
- commit 87094b3
* Fri Aug 23 2024 sjaeckel@suse.de
- netfilter: nf_tables: fix memleak in map from abort path
  (CVE-2024-27011 bsc#1223803).
- commit df3e052
* Fri Aug 23 2024 tiwai@suse.de
- README.BRANCH: update maintainers
- commit 167e5e2
* Fri Aug 23 2024 tiwai@suse.de
- Update intel thermal patch reference (jsc#PED-10222)
- commit dfc5e63
* Fri Aug 23 2024 jgross@suse.com
- KVM: Reject overly excessive IDs in KVM_CREATE_VCPU (git-fixes).
- commit acfc6dd
* Fri Aug 23 2024 jgross@suse.com
- KVM: arm64: Fix __pkvm_init_switch_pgd call ABI (git-fixes).
- commit ca5dde8
* Fri Aug 23 2024 jgross@suse.com
- KVM: Stop processing *all* memslots when "null" mmu_notifier
  handler is found (git-fixes).
- commit edcaf30
* Fri Aug 23 2024 jgross@suse.com
- virt: guest_memfd: fix reference leak on hwpoisoned page
  (git-fixes).
- commit 7ac89c3
* Fri Aug 23 2024 jgross@suse.com
- KVM: arm64: AArch32: Fix spurious trapping of conditional
  instructions (git-fixes).
- commit 6b4a32b
* Fri Aug 23 2024 jgross@suse.com
- KVM: arm64: Allow AArch32 PSTATE.M to be restored as System mode
  (git-fixes).
- commit d2c979d
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: Fix AArch32 register narrowing on userspace write
  (git-fixes).
- commit c002253
* Thu Aug 22 2024 jgross@suse.com
- KVM: fix kvm_mmu_memory_cache allocation warning (git-fixes).
- commit 9570c83
* Thu Aug 22 2024 jgross@suse.com
- KVM: Always flush async #PF workqueue when vCPU is being
  destroyed (git-fixes).
- commit bbeeae4
* Thu Aug 22 2024 vkarasulli@suse.de
- iommu: Add static iommu_ops->release_domain (bsc#1223742
  CVE-2024-27079).
- iommu/vt-d: Fix NULL domain on device release (bsc#1223742
  CVE-2024-27079).
- Refresh
  patches.suse/iommu-vt-d-Fix-WARN_ON-in-iommu-probe-path.patch.
- commit 5ddde3c
* Thu Aug 22 2024 jgross@suse.com
- KVM: Make KVM_MEM_GUEST_MEMFD mutually exclusive with
  KVM_MEM_READONLY (git-fixes).
- commit 7a71a2a
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic-its: Test for valid IRQ in MOVALL handler
  (git-fixes).
- commit ebc54df
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic-its: Test for valid IRQ in
  its_sync_lpi_pending_table() (git-fixes).
- commit 989930f
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: Add missing memory barriers when switching to
  pKVM's hyp pgd (git-fixes).
- commit 5599b84
* Thu Aug 22 2024 tiwai@suse.de
- supported.conf: update for intel thermal drivers (jsc#PED-10050)
- commit 6bd53ef
* Thu Aug 22 2024 tiwai@suse.de
- Update config files: delete obsoleted lines
- commit 7be65b7
* Thu Aug 22 2024 tiwai@suse.de
- Update config files: CONFIG_ACPI_THERMAL_LIB=y autoselect (jsc#PED-10050)
- commit b3c562f
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic-v4: Restore pending state on host userspace
  write (git-fixes).
- commit ba9826d
* Thu Aug 22 2024 tiwai@suse.de
- thermal: core: Add governor callback for thermal zone change
  (jsc#PED-10050).
- commit 2bdc0ae
* Thu Aug 22 2024 tiwai@suse.de
- thermal/core: Check get_temp ops is present when registering
  a tz (jsc#PED-10050).
- Refresh
  patches.suse/thermal-core-Fix-thermal-zone-suspend-resume-synchro.patch.
- commit b80bc9a
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic: Force vcpu vgic teardown on vcpu destroy
  (git-fixes).
- commit 26e04aa
* Thu Aug 22 2024 tiwai@suse.de
- thermal: int340x: processor_thermal: Support shared interrupts
  (jsc#PED-10050).
- commit 46f9c76
* Thu Aug 22 2024 tiwai@suse.de
- thermal: ACPI: Invalidate trip points with temperature of 0
  or below (jsc#PED-10050).
- commit 9575253
* Thu Aug 22 2024 tiwai@suse.de
- thermal: Drop spaces before TABs (jsc#PED-10050).
- thermal: intel: int340x_thermal: Use thermal zone accessor
  functions (jsc#PED-10050).
- thermal: int340x: processor_thermal: Add Lunar Lake-M PCI ID
  (jsc#PED-10050).
- thermal: core: remove unnecessary check in
  trip_point_hyst_store() (jsc#PED-10050).
- thermal: core: Remove excess empty line from a comment
  (jsc#PED-10050).
- thermal: sysfs: Fix up white space in trip_point_temp_store()
  (jsc#PED-10050).
- thermal: intel: powerclamp: Remove dead code for target mwait
  value (jsc#PED-10050).
- thermal: core: Use kstrdup_const() during cooling device
  registration (jsc#PED-10050).
- thermal: intel: hfi: Enable an HFI instance from its first
  online CPU (jsc#PED-10050).
- thermal: trip: Constify thermal zone argument of
  thermal_zone_trip_id() (jsc#PED-10050).
- commit dc6622c
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic: Add a non-locking primitive for
  kvm_vgic_vcpu_destroy() (git-fixes).
- commit 686bc1c
* Thu Aug 22 2024 tiwai@suse.de
- thermal: core: Initialize poll_queue in
  thermal_zone_device_init() (jsc#PED-10050).
- commit edf3158
* Thu Aug 22 2024 tiwai@suse.de
- thermal/sysfs: Update governors when the 'weight' has changed
  (jsc#PED-10050).
- thermal/sysfs: Update instance->weight under tz lock
  (jsc#PED-10050).
- thermal: netlink: Add thermal_group_has_listeners() helper
  (jsc#PED-10050).
- thermal: netlink: Add enum for mutlicast groups indexes
  (jsc#PED-10050).
- thermal: cpuidle_cooling: fix kernel-doc warning and a spello
  (jsc#PED-10050).
- commit b6af56d
* Thu Aug 22 2024 mkubecek@suse.cz
- netfilter: nft_limit: reject configurations that cause integer
  overflow (CVE-2024-26668 bsc#1222335).
- commit 8ea214b
* Thu Aug 22 2024 tiwai@suse.de
- thermal: helpers: Use for_each_trip() in
  __thermal_zone_get_temp() (jsc#PED-10050).
- thermal: trip: Drop redundant __thermal_zone_get_trip() header
  (jsc#PED-10050).
- thermal: core: Rework thermal zone availability check
  (jsc#PED-10050).
- thermal: Drop redundant and confusing device_is_registered()
  checks (jsc#PED-10050).
- thermal: core: Make thermal_zone_device_unregister() return
  after freeing the zone (jsc#PED-10050).
- thermal: sysfs: Rework the reading of trip point attributes
  (jsc#PED-10050).
- commit fb69e60
* Thu Aug 22 2024 tiwai@suse.de
- overflow: Change DEFINE_FLEX to take __counted_by member
  (jsc#PED-10288).
- commit 45b4eb7
* Thu Aug 22 2024 mkubecek@suse.cz
- netfilter: nf_tables: set dormant flag on hook register failure
  (CVE-2024-26835 bsc#1222967).
- commit 8f4d028
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic: Simplify kvm_vgic_destroy() (git-fixes).
- commit 3a96863
* Thu Aug 22 2024 jgross@suse.com
- Revert "KVM: Prevent module exit until all VMs are freed"
  (git-fixes).
- commit c075225
* Thu Aug 22 2024 tiwai@suse.de
- thermal: sysfs: Rework the handling of trip point updates
  (jsc#PED-10050).
- thermal: trip: Drop a redundant check from
  thermal_zone_set_trip() (jsc#PED-10050).
- thermal: ACPI: Move the ACPI thermal library to drivers/acpi/
  (jsc#PED-10050).
- thermal: int340x: processor_thermal: Handle power floor
  interrupts (jsc#PED-10050).
- thermal: int340x: processor_thermal: Support power floor
  notifications (jsc#PED-10050).
- thermal: int340x: processor_thermal: Set feature mask before
  proc_thermal_add (jsc#PED-10050).
- thermal: int340x: processor_thermal: Common function to clear
  SOC interrupt (jsc#PED-10050).
- thermal: int340x: processor_thermal: Move interrupt status
  MMIO offset to common header (jsc#PED-10050).
- thermal: int340x: Use thermal_zone_for_each_trip()
  (jsc#PED-10050).
- thermal: int340x: processor_thermal: Ack all PCI interrupts
  (jsc#PED-10050).
- thermal: int340x: Add ArrowLake-S PCI ID (jsc#PED-10050).
- thermal: int340x: Handle workload hint interrupts
  (jsc#PED-10050).
- thermal: int340x: processor_thermal: Add workload type hint
  interface (jsc#PED-10050).
- commit 6478189
* Thu Aug 22 2024 tiwai@suse.de
- thermal: int340x: Remove PROC_THERMAL_FEATURE_WLT_REQ for
  Meteor Lake (jsc#PED-10050).
- thermal: int340x: processor_thermal: Use non MSI interrupts
  by default (jsc#PED-10050).
- thermal: int340x: processor_thermal: Add interrupt configuration
  function (jsc#PED-10050).
- thermal: int340x: processor_thermal: Move mailbox code to
  common module (jsc#PED-10050).
- thermal: trip: Define for_each_trip() macro (jsc#PED-10050).
- thermal: trip: Simplify computing trip indices (jsc#PED-10050).
- commit 472c7a3
* Thu Aug 22 2024 tiwai@suse.de
- thermal: trip: Remove lockdep assertion from
  for_each_thermal_trip() (jsc#PED-10050).
- thermal: int3406: Convert to platform remove callback returning
  void (jsc#PED-10050).
- thermal: int3403: Convert to platform remove callback returning
  void (jsc#PED-10050).
- thermal: int3402: Convert to platform remove callback returning
  void (jsc#PED-10050).
- thermal: int3401: Convert to platform remove callback returning
  void (jsc#PED-10050).
- thermal: int3400: Convert to platform remove callback returning
  void (jsc#PED-10050).
- thermal: core: Add function to walk trips under zone lock
  (jsc#PED-10050).
- thermal: core: Allow trip pointers to be used for cooling
  device binding (jsc#PED-10050).
- thermal: core: Drop trips_disabled bitmask (jsc#PED-10050).
- thermal: core: Fix disabled trip point check in
  handle_thermal_trip() (jsc#PED-10050).
- thermal: core: Drop thermal_zone_device_register()
  (jsc#PED-10050).
- thermal: Use thermal_tripless_zone_device_register()
  (jsc#PED-10050).
- thermal: core: Add function for registering tripless thermal
  zones (jsc#PED-10050).
- thermal: core: Clean up headers of thermal zone registration
  functions (jsc#PED-10050).
- commit 9b8c3a1
* Thu Aug 22 2024 mkubecek@suse.cz
- netfilter: nft_chain_filter: handle NETDEV_UNREGISTER for
  inet/ingress basechain (CVE-2024-26808 bsc#1222634).
- commit 7f0379b
* Thu Aug 22 2024 tiwai@suse.de
- thermal: core: Drop unused .get_trip_*() callbacks
  (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Remove redundant check
  (jsc#PED-10050).
- thermal: intel: int340x: simplify the code with
  module_platform_driver() (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Use struct thermal_trip
  (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Rework critical trip setup
  (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Add helper for resetting
  trip points (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Change initialization
  ordering (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Pass sensors to
  update_trip_temp() (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Untangle update_trip_temp()
  (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Always assume notification
  support (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Drop redundant symbol
  definition (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Always use 2 trips
  (jsc#PED-10050).
- thermal/drivers/int340x: Do not check the thermal zone state
  (jsc#PED-10050).
- thermal/drivers/int3400: Use thermal zone device wrappers
  (jsc#PED-10050).
- thermal: core: Do not handle trip points with invalid
  temperature (jsc#PED-10050).
- powercap: intel_rapl: Fix a sparse warning in TPMI interface
  (jsc#PED-10050).
- thermal: intel: int340x_thermal: New IOCTLs for Passive v2 table
  (jsc#PED-10050).
- commit b0aa59d
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: GICv4: Do not perform a map to a mapped vLPI
  (git-fixes).
- commit 919175d
* Thu Aug 22 2024 tiwai@suse.de
- supported.conf: mark intel-ishtp-loader as supported (jsc#PED-10288)
- commit 4bf2362
* Thu Aug 22 2024 tiwai@suse.de
- HID: intel-ish-hid: add MODULE_DESCRIPTION() (jsc#PED-10288).
- HID: intel-ish-hid: fix ishtp_wait_resume() kernel-doc
  (jsc#PED-10288).
- HID: intel-ish-hid: fix endian-conversion (jsc#PED-10288).
- HID: intel-ish-hid: Fix build error for COMPILE_TEST
  (jsc#PED-10288).
- HID: intel-ish-hid: handler multiple MNG_RESET_NOTIFY messages
  (jsc#PED-10288).
- HID: intel-ish-hid: Implement loading firmware from host feature
  (jsc#PED-10288).
- HID: intel-ish-hid: Add driver_data for specifying the firmware
  filename (jsc#PED-10288).
- HID: intel-ish-hid: ipc: Add Lunar Lake-M PCI device ID
  (jsc#PED-10288).
- HID: intel-ish-hid: Use PCI_VDEVICE() and rename device ID
  macros (jsc#PED-10288).
- HID: intel-ish-hid: ipc: Add Arrow Lake PCI device ID
  (jsc#PED-10288).
- HID: Intel-ish-hid: Ishtp: Fix sensor reads after ACPI S3
  suspend (jsc#PED-10288 jsc#PED-10032).
- HID: intel-ish-hid: ipc: Rework EHL OOB wakeup (jsc#PED-10288).
- HID: intel-ish-hid: ishtp-fw-loader: use helper functions for
  connection (jsc#PED-10288).
- HID: intel-ish-hid: ishtp-hid-client: use helper functions
  for connection (jsc#PED-10288).
- HID: Intel-ish-hid: Ishtp: Add helper functions for client
  connection (jsc#PED-10288).
- HID: make ishtp_cl_bus_type const (jsc#PED-10288).
- commit dffbc3a
* Thu Aug 22 2024 mkubecek@suse.cz
- netfilter: nft_set_pipapo: release elements in clone only from
  destroy path (CVE-2024-26809 bsc#1222633).
- commit d3a3287
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic-v2: Use cpuid from userspace as vcpu_id
  (git-fixes).
- commit 7b3deae
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: timers: Correctly handle TGE flip with CNTPOFF_EL2
  (git-fixes).
- commit 48c0cad
* Thu Aug 22 2024 mkubecek@suse.cz
- netfilter: nf_tables: fix memleak when more than 255 elements
  expired (CVE-2023-52581 bsc#1220877).
- commit 26441fd
* Thu Aug 22 2024 jgross@suse.com
- KVM: Protect vcpu->pid dereference via debugfs with RCU
  (git-fixes).
- commit 55ae2a6
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: timers: Fix resource leaks in kvm_timer_hyp_init()
  (git-fixes).
- commit f80cefe
* Thu Aug 22 2024 tiwai@suse.de
- Update config files: enable CONFIG_PINCTRL_METEORPOINT (jsc#PED-10341)
- commit e5276ac
* Thu Aug 22 2024 tiwai@suse.de
- blacklist.conf: Add pinctrl blacklist (jsc#PED-10341)
  The commit is rather useless for SLE kernel, and the backport for the
  missing macro would need too much unnecessary changes
- commit 5b7a034
* Thu Aug 22 2024 shung-hsi.yu@suse.com
- bpf: Fix updating attached freplace prog in prog_array map
  (bsc#1229297 CVE-2024-43837).
- commit a9d7d77
* Thu Aug 22 2024 tiwai@suse.de
- supported.conf: Add pinctrl-meteorpoint (jsc#PED-10341)
- commit 0ed135b
* Thu Aug 22 2024 tiwai@suse.de
- pinctrl: intel: Add Intel Meteor Point pin controller and GPIO
  support (jsc#PED-10341).
- pinctrl: intel: Make PM ops functions static (jsc#PED-10341).
- pinctrl: tigerlake: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: sunrisepoint: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: meteorlake: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: lewisburg: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: lakefield: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: jasperlake: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: icelake: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: geminilake: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: emmitsburg: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: elkhartlake: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: denverton: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: cedarfork: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: cannonlake: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: broxton: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: alderlake: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: intel: Provide Intel pin control wide PM ops structure
  (jsc#PED-10341).
- pinctrl: lynxpoint: drop runtime PM support (jsc#PED-10341).
- pinctrl: baytrail: drop runtime PM support (jsc#PED-10341).
- pinctrl: intel: consolidate ACPI dependency (jsc#PED-10341).
- pinctrl: cherryview: Switch to use DEFINE_NOIRQ_DEV_PM_OPS()
  helper (jsc#PED-10341).
- pinctrl: lynxpoint: Make use of pm_ptr() (jsc#PED-10341).
- pinctrl: baytrail: Make use of pm_ptr() (jsc#PED-10341).
- pinctrl: intel: Switch to use exported namespace
  (jsc#PED-10341).
- pinctrl: lynxpoint: reuse common functions from pinctrl-intel
  (jsc#PED-10341).
- pinctrl: cherryview: reuse common functions from pinctrl-intel
  (jsc#PED-10341).
- pinctrl: baytrail: reuse common functions from pinctrl-intel
  (jsc#PED-10341).
- pinctrl: intel: export common pinctrl functions (jsc#PED-10341).
- commit 22148aa
* Thu Aug 22 2024 nik.borisov@suse.com
- dma-direct: Leak pages on dma_set_decrypted() failure (bsc#1224535 CVE-2024-35939).
- commit 7de8166
* Thu Aug 22 2024 tiwai@suse.de
- scsi: ufs: ufs-pci: Add support for Intel Arrow Lake
  (jsc#PED-10352).
- commit 1634314
* Thu Aug 22 2024 tbogendoerfer@suse.de
- ice: Add a per-VF limit on number of FDIR filters
  (CVE-2024-42291 bsc#1229374).
- commit ee2b93b
* Thu Aug 22 2024 tbogendoerfer@suse.de
- net/mlx5: Fix missing lock on sync reset reload (CVE-2024-42268
  bsc#1229391).
- commit 268cdf6
* Thu Aug 22 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add a test to verify previous stacksafe() fix
  (bsc#1225903).
- bpf: Fix a kernel verifier crash in stacksafe() (bsc#1225903).
- commit dab2844
* Thu Aug 22 2024 dsterba@suse.com
- xdp: fix invalid wait context of page_pool_destroy() (CVE-2024-43834 bsc#1229314)
- commit 6348ec4
* Thu Aug 22 2024 jlee@suse.com
- clk: mediatek: mt7622-apmixedsys: Fix an error handling path
  in clk_mt8135_apmixed_probe() (bsc#1224711 CVE-2024-27433).
- commit 30e1ef1
* Thu Aug 22 2024 dsterba@suse.com
- netfilter: nfnetlink_queue: acquire rcu_read_lock() in instance_destroy_rcu() (CVE-2024-36286 bsc#1226801)
- commit 3278d5d
* Thu Aug 22 2024 dsterba@suse.com
- netfilter: tproxy: bail out if IP has been disabled on the device (CVE-2024-36270 1226798)
- commit 26814d6
* Thu Aug 22 2024 dsterba@suse.com
- netfilter: nf_conntrack_h323: Add protection for bmp length out of range (CVE-2024-26851 bsc#1223074)
- commit 6ad2cbe
* Wed Aug 21 2024 sjaeckel@suse.de
- net: bridge: mst: fix suspicious rcu usage in br_mst_set_state
  (CVE-2024-40920 bsc#1227781).
- net: bridge: mst: pass vlan group directly to
  br_mst_vlan_set_state (CVE-2024-40921 bsc#1227784).
- net: bridge: mst: fix vlan use-after-free (CVE-2024-36979
  bsc#1226604).
- commit 7beae73
* Wed Aug 21 2024 andrea.porta@suse.com
- blacklist.conf: git-fixes f2eaed1565acc2bdeb5c433f5f6c7bd7a0d62db1
  blacklisted since it involves backporting many other commits not
  that are relevnat only to gdb debug scripts and whose dependent
  commits may break kABI.
- commit 323e420
* Wed Aug 21 2024 rgoldwyn@suse.com
- erofs: fix inconsistent per-file compression format (bsc#1220252, CVE-2024-26590).
- commit 4f99bd1
* Wed Aug 21 2024 jlee@suse.com
- perf: hisi: Fix use-after-free when register pmu fails
  (bsc#1225582 CVE-2023-52859).
- commit a50ce06
* Wed Aug 21 2024 pmladek@suse.com
- printk/panic: Allow cpu backtraces to be written into ringbuffer
  during panic (bsc#1225607).
- commit 1ebfff4
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: Remove nuisance message (jsc#PED-10233).
- commit f5f412a
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: Add support for Lunar Lake M (jsc#PED-10233).
- commit 55567dd
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: Add base address field (jsc#PED-10233).
- commit aed1815
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: Add intel_vsec_register (jsc#PED-10233).
- commit cb022f6
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: Assign auxdev parent by argument (jsc#PED-10233).
- commit e99c08a
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: Use cleanup.h (jsc#PED-10233).
- commit df6c0e7
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: remove platform_info from vsec device structure (jsc#PED-10233).
- commit 1d42e14
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: Move structures to header (jsc#PED-10233).
- commit b6f6174
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: Remove unnecessary return (jsc#PED-10233).
- commit de6ea1c
* Wed Aug 21 2024 jgross@suse.com
- net: drop bad gso csum_start and offset in virtio_net_hdr
  (git-fixes).
- commit 6d27b13
* Wed Aug 21 2024 shung-hsi.yu@suse.com
- selftests/bpf: Test for null-pointer-deref bugfix in
  resolve_prog_type() (bsc#1229297 CVE-2024-43837).
- bpf: Fix null pointer dereference in resolve_prog_type()
  for BPF_PROG_TYPE_EXT (bsc#1229297 CVE-2024-43837).
- commit 37e60d8
* Wed Aug 21 2024 shung-hsi.yu@suse.com
- bpf: simplify btf_get_prog_ctx_type() into
  btf_is_prog_ctx_type() (git-fixes).
- Refresh patches.suse/bpf-don-t-infer-PTR_TO_CTX-for-programs-with-unnamed.patch
- Refresh patches.suse/bpf-handle-bpf_user_pt_regs_t-typedef-explicitly-for.patch
- bpf: extract bpf_ctx_convert_map logic and make it more reusable
  (git-fixes).
- Refresh patches.suse/bpf-handle-bpf_user_pt_regs_t-typedef-explicitly-for.patch
- commit a1a0c24
* Wed Aug 21 2024 jgross@suse.com
- vhost: Release worker mutex during flushes (git-fixes).
- commit be0d4d9
* Wed Aug 21 2024 jgross@suse.com
- virtio: reenable config if freezing device failed (git-fixes).
- commit d96d64e
* Wed Aug 21 2024 neilb@suse.de
- kabi fix for SUNRPC: add a missing rpc_stat for TCP TLS
  (git-fixes).
- SUNRPC: add a missing rpc_stat for TCP TLS (git-fixes).
- commit 4fa6f6d
* Wed Aug 21 2024 dsterba@suse.com
- netfilter: iptables: Fix null-ptr-deref in iptable_nat_table_init() (CVE-2024-42270 bsc#1229404)
- commit eb407e1
* Wed Aug 21 2024 dsterba@suse.com
- netfilter: iptables: Fix potential null-ptr-deref in ip6table_nat_table_init() (CVE-2024-42269 bsc#1229402)
- commit 6f31e8c
* Wed Aug 21 2024 dsterba@suse.com
- tipc: Return non-zero value from tipc_udp_addr2str() on error (CVE-2024-42284 bsc#1229382)
- commit 003e7ab
* Wed Aug 21 2024 dsterba@suse.com
- net: nexthop: Initialize all fields in dumped nexthops (CVE-2024-42283 bsc#1229383)
- commit dd830eb
* Wed Aug 21 2024 dsterba@suse.com
- sysctl: always initialize i_uid/i_gid (CVE-2024-42312 bsc#1229357)
- commit 683a109
* Wed Aug 21 2024 dsterba@suse.com
- block: initialize integrity buffer to zero before writing it to media (CVE-2024-43854 bsc#1229345)
- commit bc065ac
* Tue Aug 20 2024 dsterba@suse.com
- ipvs: properly dereference pe in ip_vs_add_service (CVE-2024-42322 bsc#1229347)
- commit 5abcd51
* Tue Aug 20 2024 jgross@suse.com
- vhost-vdpa: switch to use vmf_insert_pfn() in the fault handler
  (git-fixes).
- commit efaee02
* Tue Aug 20 2024 jgross@suse.com
- net: missing check virtio (git-fixes).
- commit 547a4d8
* Tue Aug 20 2024 jgross@suse.com
- vhost/vsock: always initialize seqpacket_allow (git-fixes).
- commit 1501797
* Tue Aug 20 2024 jgross@suse.com
- vhost: Use virtqueue mutex for swapping worker (git-fixes).
- commit ee31e9d
* Tue Aug 20 2024 dwagner@suse.de
- nvme-sysfs: add 'tls_keyring' attribute (bsc#1221857).
- nvme-sysfs: add 'tls_configured_key' sysfs attribute
  (bsc#1221857).
- nvme: split off TLS sysfs attributes into a separate group
  (bsc#1221857).
- nvme: add a newline to the 'tls_key' sysfs attribute
  (bsc#1221857).
- nvme-tcp: check for invalidated or revoked key (bsc#1221857).
- nvme-tcp: sanitize TLS key handling (bsc#1221857).
- nvme: tcp: remove unnecessary goto statement (bsc#1221857).
- commit 95902b1
* Tue Aug 20 2024 dwagner@suse.de
- Refresh patches.suse/nvme-fabrics-typo-in-nvmf_parse_key.patch.
  Move into sorted section.
- commit 24e43c3
* Tue Aug 20 2024 jgross@suse.com
- vhost-scsi: Handle vhost_vq_work_queue failures for events
  (git-fixes).
- commit bb54ef9
* Tue Aug 20 2024 tiwai@suse.de
- Update DRM patch reference (CVE-2024-42308 bsc#1229411)
- commit ddc1933
* Tue Aug 20 2024 dwagner@suse.de
- Update
  patches.suse/nvme-tcp-fix-compile-time-checks-for-TLS-mode.patch
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535
  bsc#1221857).
  Fix backporting error.
- commit 35c7df3
* Tue Aug 20 2024 tiwai@suse.de
- Update parport patch reference (CVE-2024-42301 bsc#1229407)
- commit 6707829
* Tue Aug 20 2024 dwagner@suse.de
- Refresh
  patches.suse/nvme-tcp-strict-pdu-pacing-to-avoid-send-stalls-on-T.patch.
  Use the version which got upload upstream.
- commit 4896f98
* Tue Aug 20 2024 jgross@suse.com
- blacklist.conf: add ffe6176b7f53 ("virtio: store owner from modules
  with register_virtio_driver()")
- commit 08df841
* Tue Aug 20 2024 jgross@suse.com
- virtio_net: use u64_stats_t infra to avoid data-races
  (git-fixes).
- commit 1825530
* Tue Aug 20 2024 oneukum@suse.com
- usb: typec: fsa4480: Check if the chip is really there
  (git-fixes).
- commit 771af75
* Tue Aug 20 2024 oneukum@suse.com
- usb: typec: fsa4480: Add support to swap SBU orientation
  (git-fixes).
- commit b744e01
* Tue Aug 20 2024 oneukum@suse.com
- usb: typec: fsa4480: add support for Audio Accessory Mode
  (git-fixes).
- commit 471d14e
* Tue Aug 20 2024 oneukum@suse.com
- usb: typec: fsa4480: rework mux & switch setup to handle more
  states (git-fixes).
- commit dc03605
* Tue Aug 20 2024 tiwai@suse.de
- irqchip/imx-irqsteer: Handle runtime power management correctly
  (CVE-2024-42290 bsc#1229379).
- commit a3bbc63
* Tue Aug 20 2024 ailiop@suse.com
- landlock: Don't lose track of restrictions on cred_transfer
  (bsc#1229351 CVE-2024-42318).
- commit e161e74
* Tue Aug 20 2024 rgoldwyn@suse.com
- apparmor: Fix null pointer deref when receiving skb during sock creation (bsc#1229287, CVE-2023-52889).
- commit 7a47d08
* Tue Aug 20 2024 jgross@suse.com
- kABI fix of: virtio-crypto: handle config changed by work queue
  (git-fixes).
- commit 2e4646f
* Tue Aug 20 2024 dwagner@suse.de
- nvme-multipath: implement "queue-depth" iopolicy (bsc#1227706).
- nvme-multipath: prepare for "queue-depth" iopolicy
  (bsc#1227706).
- commit 796fd31
* Tue Aug 20 2024 ailiop@suse.com
- nilfs2: handle inconsistent state in nilfs_btnode_create_block()
  (bsc#1229370 CVE-2024-42295).
- commit 34231c4
* Tue Aug 20 2024 iivanov@suse.de
- arm64: dts: imx8mp: Fix pgc vpu locations (git-fixes)
- commit 6f29859
* Tue Aug 20 2024 iivanov@suse.de
- arm64: dts: imx8mp: Fix pgc_mlmix location (git-fixes)
- commit 6b6ab8a
* Tue Aug 20 2024 tiwai@suse.de
- soc: qcom: icc-bwmon: Fix refcount imbalance seen during
  bwmon_remove (CVE-2024-43850 bsc#1229316).
- soc: qcom: icc-bwmon: Set default thresholds dynamically
  (CVE-2024-43850 bsc#1229316).
- commit e842a77
* Tue Aug 20 2024 iivanov@suse.de
- arm64: dts: imx8mp: add HDMI power-domains (git-fixes)
- commit 88b7cca
* Tue Aug 20 2024 iivanov@suse.de
- arm64: dts: imx8mp: Add NPU Node (git-fixes)
- commit 55a2e84
* Tue Aug 20 2024 tiwai@suse.de
- media: mediatek: vcodec: Handle invalid decoder vsi
  (CVE-2024-43831 bsc#1229309).
- commit a7b1ec0
* Tue Aug 20 2024 tbogendoerfer@suse.de
- bna: adjust 'name' buf size of bna_tcb and bna_ccb structures
  (CVE-2024-43839 bsc#1229301).
- net: mana: Add support for page sizes other than 4KB on ARM64
  (jsc#PED-8491 bsc#1226530).
- commit 24750b5
* Tue Aug 20 2024 ailiop@suse.com
- Squashfs: fix variable overflow triggered by sysbot (git-fixes).
- commit 90b77e5
* Tue Aug 20 2024 ailiop@suse.com
- squashfs: squashfs_read_data need to check if the length is 0
  (git-fixes).
- commit 1ab3d64
* Tue Aug 20 2024 ailiop@suse.com
- jfs: Fix shift-out-of-bounds in dbDiscardAG (git-fixes).
- commit f862c1b
* Tue Aug 20 2024 ailiop@suse.com
- jfs: fix null ptr deref in dtInsertEntry (git-fixes).
- commit 72d65ab
* Tue Aug 20 2024 ailiop@suse.com
- reiserfs: fix uninit-value in comp_keys (git-fixes).
- commit aeea4b8
* Tue Aug 20 2024 sjaeckel@suse.de
- Update
  patches.suse/0001-netlink-add-nla-be16-32-types-to-minlen-array.patch
  (CVE-2024-26849 bsc#1223053).
  Fixes: 2747893c94d9b55340403026d9430f2f93947449
- commit 4cf09d7
* Tue Aug 20 2024 jgross@suse.com
- virtio-crypto: handle config changed by work queue (git-fixes).
- Refresh
  patches.suse/crypto-virtio-Wait-for-tasklet-to-complete-on-device.patch.
- commit 3719b45
* Tue Aug 20 2024 lhenriques@suse.de
- fuse: Initialize beyond-EOF page contents before setting
  uptodate (bsc#1229456).
- fs/netfs/fscache_cookie: add missing "n_accesses" check
  (bsc#1229455).
- commit 1ffdccd
* Tue Aug 20 2024 mfranc@suse.cz
- s390/dasd: fix error recovery leading to data corruption on
  ESE devices (git-fixes bsc#1229452).
- commit 421d882
* Tue Aug 20 2024 pjakobsson@suse.de
- blacklist.conf: Change entry to alt-commit
- Refresh patches.suse/tools-Disable-__packed-attribute-compiler-warning-due-to-Werror-attributes.patch.
- commit a7c7d40
* Tue Aug 20 2024 mfranc@suse.cz
- net/iucv: fix the allocation size of iucv_path_table array
  (git-fixes bsc#1229451).
- commit 4e0b259
* Tue Aug 20 2024 mfranc@suse.cz
- blacklist.conf: we don't enable CONFIG_CPUMASK_OFFSTACK on s390
- commit 8a36035
* Tue Aug 20 2024 pjakobsson@suse.de
- Refresh patches.suse/0001-drm-mst-Fix-NULL-pointer-dereference-at-drm_dp_add_p.patch (git-fixes)
  Alt-commit
- commit 98e41cf
* Tue Aug 20 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-i915-vma-Fix-UAF-on-destroy-against-retire-race.patch (git-fixes)
  Alt-commit
- commit 11ef901
* Tue Aug 20 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Send-DTBCLK-disable-message-on-first.patch (git-fixes)
  Alt-commit
- commit 6d9aa0a
* Tue Aug 20 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Fix-DPSTREAM-CLK-on-and-off-sequence.patch (git-fixes)
  Alt-commit
- commit 24768b9
* Tue Aug 20 2024 sjaeckel@suse.de
- tcp: use signed arithmetic in tcp_rtx_probe0_timed_out()
  (CVE-2024-41007 bsc#1227863).
- commit 35aaaf5
* Tue Aug 20 2024 tiwai@suse.de
- HID: wacom: Defer calculation of resolution until
  resolution_code is known (git-fixes).
- ALSA: usb: Fix UBSAN warning in parse_audio_unit()
  (stable-fixes).
- commit a485c9b
* Tue Aug 20 2024 tiwai@suse.de
- blacklist.conf: Add libata upstream revert entry (bsc#1229054)
- commit 5ded40a
* Tue Aug 20 2024 shung-hsi.yu@suse.com
- bpf: Fix a segment issue when downgrading gso_size (bsc#1229386
  CVE-2024-42281).
- commit f593f1f
* Mon Aug 19 2024 sjaeckel@suse.de
- kABI fix for net/sched: flower: Fix chain template offload
  (CVE-2024-26669 bsc#1222350).
- net/sched: flower: Fix chain template offload (CVE-2024-26669
  bsc#1222350).
- commit 43f1cd6
* Mon Aug 19 2024 sjaeckel@suse.de
- kABI fix for rxrpc: Fix delayed ACKs to not set the reference
  serial number (CVE-2024-26677 bsc#1222387).
- rxrpc: Fix delayed ACKs to not set the reference serial number
  (CVE-2024-26677 bsc#1222387).
- commit c3c3a27
* Mon Aug 19 2024 msuchanek@suse.de
- Update patches.suse/cpu-SMT-Enable-SMT-only-if-a-core-is-online.patch
  (bsc#1214285 bsc#1205462 ltc#200161 ltc#200588 git-fixes
  bsc#1229327 ltc#206365).
- Update patches.suse/powerpc-topology-Check-if-a-core-is-online.patch
  (bsc#1214285 bsc#1205462 ltc#200161 ltc#200588 git-fixes
  bsc#1229327 ltc#206365).
- commit fd7ec4b
* Mon Aug 19 2024 neilb@suse.de
- xprtrdma: Fix rpcrdma_reqs_reset() (git-fixes).
- gss_krb5: Fix the error handling path for
  crypto_sync_skcipher_setkey (git-fixes).
- commit c717fae
* Mon Aug 19 2024 neilb@suse.de
- SUNRPC: Fix a race to wake a sync task (git-fixes).
- nfs: pass explicit offset/count to trace events (git-fixes).
- commit 6f41a0a
* Mon Aug 19 2024 neilb@suse.de
- NFSv4.1 another fix for EXCHGID4_FLAG_USE_PNFS_DS for DS server
  (git-fixes).
- NFSD: Support write delegations in LAYOUTGET (git-fixes).
- nfs: don't invalidate dentries on transient errors (git-fixes).
- nfs: propagate readlink errors in nfs_symlink_filler
  (git-fixes).
- nfs: make the rpc_stat per net namespace (git-fixes).
- nfs: expose /proc/net/sunrpc/nfs in net namespaces (git-fixes).
- sunrpc: add a struct rpc_stats arg to rpc_create_args
  (git-fixes).
- commit 6ab4001
* Mon Aug 19 2024 jlee@suse.com
- Update
  patches.suse/ata-libata-core-Fix-double-free-on-error.patch
  (git-fixes CVE-2024-41087 bsc#1228740 bsc#1228466).
- Update
  patches.suse/cachefiles-add-missing-lock-protection-when-polling.patch
  (bsc#1229256 CVE-2024-42250 bsc#1228977).
- Update
  patches.suse/cachefiles-defer-exposing-anon_fd-until-after-copy_to.patch
  (bsc#1229251 CVE-2024-40913 bsc#1227839).
- Update
  patches.suse/cachefiles-fix-slab-use-after-free-in-cachefiles_onde.patch
  (bsc#1229247 CVE-2024-39510 bsc#1227734).
- Update
  patches.suse/cachefiles-fix-slab-use-after-free-in-cachefiles_ondemand_daemon_read.patch
  (bsc#1229246 CVE-2024-40899 bsc#1227758).
- Update
  patches.suse/drm-i915-gem-Fix-Virtual-Memory-mapping-boundaries-c.patch
  (git-fixes CVE-2024-42259 bsc#1229156).
- Update
  patches.suse/powerpc-pseries-Whitelist-dtl-slub-object-for-copyin.patch
  (bsc#1194869 CVE-2024-41065 bsc#1228636).
- commit 3fec826
* Mon Aug 19 2024 tiwai@suse.de
- char: xillybus: Check USB endpoints when probing device
  (git-fixes).
- Revert "misc: fastrpc: Restrict untrusted app to attach to
  privileged PD" (git-fixes).
- tty: atmel_serial: use the correct RTS flag (git-fixes).
- tty: serial: fsl_lpuart: mark last busy before uart_add_one_port
  (git-fixes).
- xhci: Fix Panther point NULL pointer deref at full-speed
  re-enumeration (git-fixes).
- Revert "usb: typec: tcpm: clear pd_event queue in PORT_RESET"
  (git-fixes).
- commit e3fe681
* Mon Aug 19 2024 neilb@suse.de
- blacklist.conf: add unwanted nfs/sunrpc patch
- commit 405ec89
* Mon Aug 19 2024 neilb@suse.de
- Refresh patches.suse/SUNRPC-avoid-soft-lockup-when-transmitting-UDP-to-re.patch.
  Add git-commit
- commit 7a1e763
* Sun Aug 18 2024 ailiop@suse.com
- xfs: attr forks require attr, not attr2 (git-fixes).
- commit d1644af
* Sun Aug 18 2024 tiwai@suse.de
- i2c: qcom-geni: Add missing geni_icc_disable in
  geni_i2c_runtime_resume (git-fixes).
- i2c: Use IS_REACHABLE() for substituting empty ACPI functions
  (git-fixes).
- commit 37fcb0e
* Sun Aug 18 2024 tiwai@suse.de
- Move upstreamed powerpc patches into sorted section
- commit 7bdd775
* Sun Aug 18 2024 ailiop@suse.com
- xfs: journal geometry is not properly bounds checked
  (git-fixes).
- commit 7680aeb
* Sat Aug 17 2024 svarbanov@suse.de
- arm64: Fix KASAN random tag seed initialization (git-fixes)
- commit a300263
* Sat Aug 17 2024 svarbanov@suse.de
- arm64: ACPI: NUMA: initialize all values of acpi_early_node_map to (git-fixes)
- commit a089c62
* Sat Aug 17 2024 tiwai@suse.de
- spi: Add empty versions of ACPI functions (stable-fixes).
- i2c: Fix conditional for substituting empty ACPI functions
  (stable-fixes).
- commit 3dc083c
* Sat Aug 17 2024 tiwai@suse.de
- gpio: mlxbf3: Support shutdown() function (git-fixes).
- ALSA: hda/tas2781: Use correct endian conversion (git-fixes).
- ALSA: usb-audio: Support Yamaha P-125 quirk entry
  (stable-fixes).
- ALSA: hda/tas2781: fix wrong calibrated data order (git-fixes).
- ALSA: usb-audio: Add delay quirk for VIVO USB-C-XE710 HEADSET
  (stable-fixes).
- ALSA: hda/realtek: Add support for new HP G12 laptops
  (stable-fixes).
- ALSA: hda/realtek: Fix noise from speakers on Lenovo IdeaPad
  3 15IAU7 (git-fixes).
- ALSA: timer: Relax start tick time check for slave timer
  elements (git-fixes).
- drm/amd/display: Adjust cursor position (git-fixes).
- drm/amd/display: fix cursor offset on rotation 180 (git-fixes).
- device property: Add cleanup.h based fwnode_handle_put()
  scope based cleanup (stable-fixes).
- commit 51be9a0
* Fri Aug 16 2024 ailiop@suse.com
- xfs: allow cross-linking special files without project quota
  (git-fixes).
- commit 8d26aca
* Fri Aug 16 2024 jgross@suse.com
- KVM: nVMX: Check for pending posted interrupts when looking
  for nested events (git-fixes).
- commit 0b1027c
* Fri Aug 16 2024 jgross@suse.com
- KVM: VMX: Split out the non-virtualization part of
  vmx_interrupt_blocked() (git-fixes).
- commit 47fc351
* Fri Aug 16 2024 ailiop@suse.com
- xfs: use consistent uid/gid when grabbing dquots for inodes
  (git-fixes).
- commit c1c88ce
* Fri Aug 16 2024 ailiop@suse.com
- xfs: honor init_xattrs in xfs_init_new_inode for !ATTR fs
  (git-fixes).
- commit fae2711
* Fri Aug 16 2024 ailiop@suse.com
- xfs: allow unlinked symlinks and dirs with zero size
  (git-fixes).
- commit 184b713
* Fri Aug 16 2024 jgross@suse.com
- blacklist.conf: add f99b052256f1 ("KVM: SNP: Fix LBR Virtualization for SNP guest")
- commit c9ad47e
* Fri Aug 16 2024 jgross@suse.com
- KVM: x86/mmu: Bug the VM if KVM tries to split a !hugepage SPTE
  (git-fixes).
- commit 96acab8
* Fri Aug 16 2024 ailiop@suse.com
- xfs: fix unlink vs cluster buffer instantiation race
  (git-fixes).
- commit 0ae592b
* Fri Aug 16 2024 ailiop@suse.com
- xfs: upgrade the extent counters in xfs_reflink_end_cow_extent
  later (git-fixes).
- commit 730a4f0
* Fri Aug 16 2024 ailiop@suse.com
- xfs: match lock mode in xfs_buffered_write_iomap_begin()
  (git-fixes).
- commit e70a195
* Fri Aug 16 2024 ailiop@suse.com
- xfs: require XFS_SB_FEAT_INCOMPAT_LOG_XATTRS for attr log
  intent item recovery (git-fixes).
- commit 85919a1
* Fri Aug 16 2024 ailiop@suse.com
- xfs: don't use current->journal_info (git-fixes).
- commit d96f684
* Fri Aug 16 2024 jgross@suse.com
- KVM: nVMX: Request immediate exit iff pending nested event
  needs injection (git-fixes).
- commit 9d306b8
* Fri Aug 16 2024 lhenriques@suse.de
- cachefiles: add missing lock protection when polling
  (bsc#1229256).
- cachefiles: cyclic allocation of msg_id to avoid reuse
  (bsc#1228499 CVE-2024-41050).
- cachefiles: wait for ondemand_object_worker to finish when
  dropping  object (bsc#1228468 CVE-2024-41051).
- cachefiles: cancel all requests for the object that is being
  dropped (bsc#1229255).
- cachefiles: stop sending new request when dropping object
  (bsc#1229254).
- cachefiles: propagate errors from vfs_getxattr() to avoid
  infinite  loop (bsc#1229253).
- cachefiles: make on-demand read killable (bsc#1229252).
- cachefiles: Set object to close if ondemand_id < 0 in copen
  (bsc#1228643 CVE-2024-41074).
- cachefiles: defer exposing anon_fd until after copy_to_user()
  succeeds (bsc#1229251).
- cachefiles: never get a new anonymous fd if ondemand_id is valid
  (bsc#1229250).
- cachefiles: add spin_lock for cachefiles_ondemand_info
  (bsc#1229249).
- cachefiles: add consistency check for copen/cread (bsc#1228646
  CVE-2024-41075).
- cachefiles: remove err_put_fd label in
  cachefiles_ondemand_daemon_read() (bsc#1229248).
- cachefiles: fix slab-use-after-free in
  cachefiles_ondemand_daemon_read() (bsc#1229247).
- cachefiles: fix slab-use-after-free in
  cachefiles_ondemand_get_fd() (bsc#1229246).
- cachefiles, erofs: Fix NULL deref in when cachefiles is not
  doing  ondemand-mode (bsc#1229245).
- cachefiles: add restore command to recover inflight ondemand
  read  requests (bsc#1229244).
- cachefiles: narrow the scope of triggering EPOLLIN events in
  ondemand  mode (bsc#1229243).
- cachefiles: resend an open request if the read request's object
  is  closed (bsc#1229241).
- cachefiles: extract ondemand info field from cachefiles_object
  (bsc#1229240).
- cachefiles: introduce object ondemand state (bsc#1229239).
- commit 3d893c5
* Fri Aug 16 2024 jgross@suse.com
- KVM: nVMX: Add a helper to get highest pending from Posted
  Interrupt vector (git-fixes).
- commit ebf04ff
* Fri Aug 16 2024 jgross@suse.com
- KVM: VMX: Switch __vmx_exit() and kvm_x86_vendor_exit() in
  vmx_exit() (git-fixes).
- commit 8ef91ee
* Fri Aug 16 2024 jgross@suse.com
- KVM: x86: Limit check IDs for KVM_SET_BOOT_CPU_ID (git-fixes).
- commit 395837f
* Fri Aug 16 2024 jgross@suse.com
- KVM: VMX: Move posted interrupt descriptor out of VMX code
  (git-fixes).
- commit feb966b
* Fri Aug 16 2024 ailiop@suse.com
- xfs: allow symlinks with short remote targets (bsc#1229160).
- commit e82d4ad
* Fri Aug 16 2024 jgross@suse.com
- blacklist.conf: add 1c682593096a ("xen: privcmd: Switch from mutex to spinlock for irqfds")
- commit 46d4480
* Fri Aug 16 2024 jgross@suse.com
- x86/xen: Convert comma to semicolon (git-fixes).
- commit c8d2d16
* Fri Aug 16 2024 tiwai@suse.de
- Drop armv7hl builds (bsc#1229434)
  There will be no Leap 15.7, hence no 32bit Arm port
- commit 09ee386
* Fri Aug 16 2024 lhenriques@suse.de
- supported.conf: mark ceph-related modules as unsupported
  CephFS is not supported anymore, as well as the ceph-based block device
  rbd.  Also remove the LIO rbd backend from the supported.conf file as we
  are not forward-porting this code anymore.
- commit 10c2293
* Fri Aug 16 2024 tbogendoerfer@suse.de
- net: mana: Fix doorbell out of order violation and avoid
  unnecessary doorbell rings (bsc#1229154).
- net: mana: Fix RX buf alloc_size alignment and atomic op panic
  (bsc#1229086).
- commit 59cb1c7
* Fri Aug 16 2024 jgross@suse.com
- KVM: Make KVM_MEM_GUEST_MEMFD mutually exclusive with
  KVM_MEM_READONLY (git-fixes).
- commit 4020b4e
* Fri Aug 16 2024 jgross@suse.com
- KVM: SVM: Fix uninitialized variable bug (git-fixes).
- commit 385a593
* Fri Aug 16 2024 tiwai@suse.de
- wifi: brcmfmac: cfg80211: Handle SSID based pmksa deletion
  (git-fixes).
- net: ethernet: mtk_wed: fix use-after-free panic in
  mtk_wed_setup_tc_block_cb() (git-fixes).
- media: Revert "media: dvb-usb: Fix unexpected infinite loop
  in dvb_usb_read_remote_control()" (git-fixes).
- commit daf04e2
* Fri Aug 16 2024 jgross@suse.com
- KVM: SVM: Fix an error code in sev_gmem_post_populate()
  (git-fixes).
- commit db95276
* Thu Aug 15 2024 krisman@suse.de
- filelock: Remove locks reliably when fcntl/close race is
  detected (CVE-2024-41012 bsc#1228247).
- commit a736b9b
* Thu Aug 15 2024 krisman@suse.de
- io_uring: fix possible deadlock in
  io_register_iowq_max_workers() (bsc#1228616 CVE-2024-41080).
- commit eae6448
* Thu Aug 15 2024 krisman@suse.de
- io_uring: fix io_match_task must_hold (git-fixes).
- io_uring: tighten task exit cancellations (git-fixes).
- commit f9ce2d8
* Thu Aug 15 2024 krisman@suse.de
- io_uring: Fix probe of disabled operations (git-fixes).
- io_uring/advise: support 64-bit lengths (git-fixes).
- commit 7566a8d
* Thu Aug 15 2024 krisman@suse.de
- io_uring: Drop per-ctx dummy_ubuf (git-fixes).
- commit 2717cc1
* Thu Aug 15 2024 msuchanek@suse.de
- Refresh patches.suse/powerpc-pseries-Add-failure-related-checks-for-h_get.patch.
  Changing hte return value to long breaks ABI which makes the upstream
  version unsuitable for SP6.
- commit 3034e83
* Thu Aug 15 2024 msuchanek@suse.de
- powerpc/kexec_file: fix cpus node update to FDT (bsc#1194869).
- powerpc/pseries: Whitelist dtl slub object for copying to
  userspace (bsc#1194869).
- powerpc/kexec: make the update_cpus_node() function public
  (bsc#1194869).
- powerpc/xmon: Check cpu id in commands "c#", "dp#" and "dx#"
  (bsc#1194869).
- powerpc/64: Set _IO_BASE to POISON_POINTER_DELTA not 0 for
  CONFIG_PCI=n (bsc#1194869).
- powerpc/io: Avoid clang null pointer arithmetic warnings
  (bsc#1194869).
- powerpc/pseries: Add failure related checks for h_get_mpp and
  h_get_ppp (bsc#1194869).
- powerpc/kexec: split CONFIG_KEXEC_FILE and CONFIG_CRASH_DUMP
  (bsc#1194869).
- powerpc: xor_vmx: Add '-mhard-float' to CFLAGS (bsc#1194869).
- powerpc/radix: Move some functions into #ifdef
  CONFIG_KVM_BOOK3S_HV_POSSIBLE (bsc#1194869).
- commit 4e7f0fe
* Thu Aug 15 2024 msuchanek@suse.de
- blacklist.conf: Add a bunch of superfluous ppc changes reported by
  git-fixes.
- commit 7c2a851
* Thu Aug 15 2024 msuchanek@suse.de
- blacklist.conf: Add ppc more ppc unsupported arch paths and commits.
- commit 66e06b4
* Thu Aug 15 2024 msuchanek@suse.de
- blacklist.conf: Add more ppc 32bit paths.
- commit 013a9db
* Thu Aug 15 2024 iivanov@suse.de
- arm64: errata: Expand speculative SSBS workaround (again) (git-fixes)
- commit e589bbc
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-A725 definitions (git-fixes)
- commit 0d04176
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-X1C definitions (git-fixes)
- commit 6a5ea61
* Thu Aug 15 2024 iivanov@suse.de
- arm64: errata: Expand speculative SSBS workaround (git-fixes)
- commit f75d6ba
* Thu Aug 15 2024 iivanov@suse.de
- arm64: errata: Unify speculative SSBS errata logic (git-fixes).
  Update config files.
- commit ffaab08
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-X925 definitions (git-fixes)
- commit 3c8ddb7
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-A720 definitions (git-fixes)
- commit f5fd7c6
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-X3 definitions (git-fixes)
- commit d87d988
* Thu Aug 15 2024 iivanov@suse.de
- arm64: errata: Add workaround for Arm errata 3194386 and 3312417 (git-fixes)
  Refresh patches.suse/kabi-arm64-reserve-space-in-cpu_hwcaps-and-cpu_hwcap.patch
  and enable around.
- commit b3747ef
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Neoverse-V3 definitions (git-fixes)
- commit 78aeee9
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-X4 definitions (git-fixes)
- commit 2841965
* Thu Aug 15 2024 iivanov@suse.de
- arm64: barrier: Restore spec_bar() macro (git-fixes)
- commit 5c935b6
* Thu Aug 15 2024 iivanov@suse.de
- arm64: Add Neoverse-V2 part (git-fixes)
- commit 0f9f30b
* Thu Aug 15 2024 tiwai@suse.de
- rpm/kernel-source.changes.old: Re-add the lost CVE and XSA references
  Some references have been lost at smashing since they were in lower
  letters ("cve-*").  Also one CVE entry was incorrect, but keep here
  for reference.
- commit 50b21fe
* Thu Aug 15 2024 sjaeckel@suse.de
- net/rds: fix possible cp null dereference (git-fixes).
- commit cac3126
* Thu Aug 15 2024 mfranc@suse.cz
- s390/pci: Add missing virt_to_phys() for directed DIBV
  (git-fixes bsc#1229174).
- commit ea8e3e7
* Thu Aug 15 2024 mfranc@suse.cz
- s390/dasd: fix error checks in dasd_copy_pair_store()
  (git-fixes bsc#1229173).
- commit f5c4fe8
* Thu Aug 15 2024 mfranc@suse.cz
- s390/pci: Allow allocation of more than 1 MSI interrupt
  (git-fixes bsc#1229172).
- s390/pci: Refactor arch_setup_msi_irqs() (git-fixes
  bsc#1229172).
- commit ad8c54b
* Thu Aug 15 2024 mfranc@suse.cz
- s390/cpum_cf: Fix endless loop in CF_DIAG event stop (git-fixes
  bsc#1229171).
- commit 94c7469
* Thu Aug 15 2024 mfranc@suse.cz
- s390/uv: Panic for set and remove shared access UVC errors
  (git-fixes bsc#1229170).
- commit 447c271
* Thu Aug 15 2024 mfranc@suse.cz
- s390/sclp: Prevent release of buffer in I/O (git-fixes
  bsc#1229169).
- commit 9daf007
* Thu Aug 15 2024 mfranc@suse.cz
- kvm: s390: Reject memory region operations for ucontrol VMs
  (git-fixes bsc#1229168).
- commit 14a9742
* Thu Aug 15 2024 mfranc@suse.cz
- KVM: s390: fix validity interception issue when gisa is switched
  off (git-fixes bsc#1229167).
- commit 5c4e348
* Thu Aug 15 2024 kbuild@suse.de
- Delete patches.kabi/* workarounds
- commit 72e8d5f
* Thu Aug 15 2024 tiwai@suse.de
- Update patch reference of USB patch (jsc#PED-10108)
- commit edfa08b
* Thu Aug 15 2024 tiwai@suse.de
- USB: serial: debug: do not echo input by default (stable-fixes).
- usb: vhci-hcd: Do not drop references before new references
  are gained (stable-fixes).
- serial: core: check uartclk for zero to avoid divide by zero
  (stable-fixes).
- media: xc2028: avoid use-after-free in load_firmware_cb()
  (stable-fixes).
- media: uvcvideo: Fix the bandwdith quirk on USB 3.x
  (stable-fixes).
- media: uvcvideo: Ignore empty TS packets (stable-fixes).
- media: amphion: Remove lock in s_ctrl callback (stable-fixes).
- wifi: nl80211: don't give key data to userspace (stable-fixes).
- PCI: Add Edimax Vendor ID to pci_ids.h (stable-fixes).
- wifi: ath12k: fix memory leak in ath12k_dp_rx_peer_frag_setup()
  (stable-fixes).
- wifi: nl80211: disallow setting special AP channel widths
  (stable-fixes).
- gpio: prevent potential speculation leaks in
  gpio_device_get_desc() (stable-fixes).
- commit 2335bf9
* Thu Aug 15 2024 tiwai@suse.de
- docs: KVM: Fix register ID of SPSR_FIQ (git-fixes).
- drm/i915/gem: Adjust vma offset for framebuffer mmap offset
  (stable-fixes).
- drm/amd/display: Skip Recompute DSC Params if no Stream on Link
  (stable-fixes).
- drm/amdgpu: Forward soft recovery errors to userspace
  (stable-fixes).
- drm/dp_mst: Skip CSN if topology probing is not done yet
  (stable-fixes).
- drm/mediatek/dp: Fix spurious kfree() (git-fixes).
- drm/amd/display: Add null checker before passing variables
  (stable-fixes).
- Revert "drm/amd/display: Add NULL check for 'afb' before
  dereferencing in amdgpu_dm_plane_handle_cursor_update"
  (stable-fixes).
- drm/amd/display: Add NULL check for 'afb' before dereferencing
  in amdgpu_dm_plane_handle_cursor_update (stable-fixes).
- drm/bridge: analogix_dp: properly handle zero sized AUX
  transactions (stable-fixes).
- drm/amd/pm: Fix the null pointer dereference for vega10_hwmgr
  (stable-fixes).
- drm/radeon: Remove __counted_by from StateArray.states[]
  (git-fixes).
- drm/amdgpu: Add lock around VF RLCG interface (stable-fixes).
- drm/admgpu: fix dereferencing null pointer context
  (stable-fixes).
- drm/amdgpu/pm: Fix the null pointer dereference in
  apply_state_adjust_rules (stable-fixes).
- drm/amdgpu: Fix the null pointer dereference to ras_manager
  (stable-fixes).
- drm/amdgpu/pm: Fix the null pointer dereference for smu7
  (stable-fixes).
- drm/amdgpu/pm: Fix the param type of set_power_profile_mode
  (stable-fixes).
- drm/amdgpu: fix potential resource leak warning (stable-fixes).
- drm/amd/display: Add delay to improve LTTPR UHBR interop
  (stable-fixes).
- Bluetooth: btnxpuart: Shutdown timer and prevent rearming when
  driver unloading (stable-fixes).
- can: mcp251xfd: tef: update workaround for erratum DS80000789E
  6 of mcp2518fd (stable-fixes).
- can: mcp251xfd: tef: prepare to workaround broken TEF FIFO
  tail index erratum (stable-fixes).
- ACPI: SBS: manage alarm sysfs attribute through psy core
  (stable-fixes).
- ACPI: battery: create alarm sysfs attribute atomically
  (stable-fixes).
- clocksource/drivers/sh_cmt: Address race condition for clock
  events (stable-fixes).
- commit 2a8ca72
* Wed Aug 14 2024 tiwai@suse.de
- Update patch reference for SPI patch (jsc#PED-10105)
- commit a896d55
* Wed Aug 14 2024 tiwai@suse.de
- rpm/config.sh: Update for SLE15-SP7
- commit b69d639
* Wed Aug 14 2024 mfranc@suse.cz
- kabi fix for KVM: s390: fix LPSWEY handling (bsc#1227634
  git-fixes).
- KVM: s390: fix LPSWEY handling (bsc#1227634 git-fixes).
- commit 576de67
* Wed Aug 14 2024 mkoutny@suse.com
- kernfs: Convert kernfs_path_from_node_locked() from strlcpy()
  to strscpy() (bsc#1229134).
- Refresh
  patches.suse/cgroup-cpuset-Prevent-UAF-in-proc_cpuset_show.patch.
- commit bc8376b
* Wed Aug 14 2024 tiwai@suse.de
- i2c: designware: Add ACPI ID for Granite Rapids-D I2C controller
  (jsc#PED-10047).
- i2c: smbus: Support up to 8 SPD EEPROMs (jsc#PED-10046).
- commit 938da33
* Wed Aug 14 2024 tiwai@suse.de
- Update patch reference for iwlwifi fix (jsc#PED-10055)
- commit 73fda85
* Wed Aug 14 2024 tiwai@suse.de
- Input: i8042 - add Fujitsu Lifebook E756 to i8042 quirk table
  (bsc#1229056).
- commit 0ae7f4e
* Wed Aug 14 2024 jlee@suse.com
- bpf: hardcode BPF_PROG_PACK_SIZE to 2MB * num_possible_nodes()
  (git-fixes).
- bpf: don't infer PTR_TO_CTX for programs with unnamed context
  type (git-fixes).
- bpf: handle bpf_user_pt_regs_t typedef explicitly for PTR_TO_CTX
  global arg (git-fixes).
- bpf: Mark bpf_spin_{lock,unlock}() helpers with notrace
  correctly (git-fixes).
- commit dd0591b
* Wed Aug 14 2024 neilb@suse.de
- net, sunrpc: Remap EPERM in case of connection failure in
  xs_tcp_setup_socket (CVE-2024-42246 bsc#1228989).
- commit 12865c8
* Wed Aug 14 2024 jlee@suse.com
- tools/resolve_btfids: Fix comparison of distinct pointer types
  warning in resolve_btfids (git-fixes).
- tools/resolve_btfids: fix build with musl libc (git-fixes).
- commit f42b517
* Tue Aug 13 2024 fdmanana@suse.com
- btrfs: fix leak of qgroup extent records after transaction abort
  (git-fixes).
- btrfs: fix ordered extent split error handling in
  btrfs_dio_submit_io (git-fixes).
- btrfs: use irq safe locking when running and adding delayed
  iputs (git-fixes).
- commit 59b18df
* Tue Aug 13 2024 fdmanana@suse.com
- btrfs: fix extent map use-after-free when adding pages to
  compressed bio (git-fixes).
- commit b3e7c96
* Tue Aug 13 2024 tiwai@suse.de
- Drop libata patch that caused a regression (bsc#1229054)
- commit 3d5faca
* Tue Aug 13 2024 fdmanana@suse.com
- btrfs: fix double inode unlock for direct IO sync writes
  (git-fixes).
- btrfs: fix corruption after buffer fault in during direct IO
  append write (git-fixes).
- btrfs: use a btrfs_inode local variable at btrfs_sync_file()
  (git-fixes).
- btrfs: pass a btrfs_inode to btrfs_wait_ordered_range()
  (git-fixes).
- btrfs: pass a btrfs_inode to btrfs_fdatawrite_range()
  (git-fixes).
- btrfs: use a btrfs_inode in the log context (struct
  btrfs_log_ctx) (git-fixes).
- btrfs: make btrfs_finish_ordered_extent() return void
  (git-fixes).
- btrfs: ensure fast fsync waits for ordered extents after a
  write failure (git-fixes).
- btrfs: rename err to ret in btrfs_direct_write() (git-fixes).
- btrfs: uninline some static inline helpers from tree-log.h
  (git-fixes).
- btrfs: use btrfs_finish_ordered_extent to complete buffered
  writes (git-fixes).
- btrfs: use btrfs_finish_ordered_extent to complete direct writes
  (git-fixes).
- btrfs: use btrfs_finish_ordered_extent to complete compressed
  writes (git-fixes).
- btrfs: open code end_extent_writepage in
  end_bio_extent_writepage (git-fixes).
- btrfs: add a btrfs_finish_ordered_extent helper (git-fixes).
- btrfs: factor out a btrfs_queue_ordered_fn helper (git-fixes).
- btrfs: factor out a can_finish_ordered_extent helper
  (git-fixes).
- btrfs: use bbio->ordered in btrfs_csum_one_bio (git-fixes).
- btrfs: add an ordered_extent pointer to struct btrfs_bio
  (git-fixes).
- btrfs: open code btrfs_bio_end_io in btrfs_dio_submit_io
  (git-fixes).
- btrfs: add a is_data_bbio helper (git-fixes).
- btrfs: remove btrfs_add_ordered_extent (git-fixes).
- btrfs: pass an ordered_extent to btrfs_submit_compressed_write
  (git-fixes).
- btrfs: pass an ordered_extent to btrfs_reloc_clone_csums
  (git-fixes).
- btrfs: merge the two calls to btrfs_add_ordered_extent in
  run_delalloc_nocow (git-fixes).
- btrfs: limit write bios to a single ordered extent (git-fixes).
- commit 90ea198
* Tue Aug 13 2024 msuchanek@suse.de
- powerpc/topology: Check if a core is online (bsc#1214285
  bsc#1205462 ltc#200161 ltc#200588 git-fixes).
- cpu/SMT: Enable SMT only if a core is online (bsc#1214285
  bsc#1205462 ltc#200161 ltc#200588 git-fixes).
- commit 3d340df
* Tue Aug 13 2024 tiwai@suse.de
- Update patch reference for MD patch (jsc#PED-10029 jsc#PED-10045)
- commit 1bf8fd1
* Tue Aug 13 2024 tiwai@suse.de
- Update patch refefernce for MFD patch (jsc#PED-10029)
- commit f36d989
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Check HSMP support on AMD family of processors (jsc#PED-8779).
- commit c606582
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: switch to use device_add_groups() (jsc#PED-8779).
- commit 4007799
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Change devm_kzalloc() to devm_kcalloc() (jsc#PED-8779).
- commit 9854658
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Remove extra parenthesis and add a space (jsc#PED-8779).
- commit 0a84b39
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Check num_sockets against MAX_AMD_SOCKETS (jsc#PED-8779).
- commit 85ba4b7
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Non-ACPI support for AMD F1A_M00~0Fh (jsc#PED-8779).
- commit 1b89039
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Add support for ACPI based probing (jsc#PED-8779).
- commit 73c2646
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Restructure sysfs group creation (jsc#PED-8779).
- commit 9e31807
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Move dev from platdev to hsmp_socket (jsc#PED-8779).
- commit f6baa58
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Define a struct to hold mailbox regs (jsc#PED-8779).
- commit 07f864e
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Create static func to handle platdev (jsc#PED-8779).
- commit d5ea9be
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Cache pci_dev in struct hsmp_socket (jsc#PED-8779).
- commit d314cb6
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Move hsmp_test to probe (jsc#PED-8779).
- commit b00829d
* Tue Aug 13 2024 jlee@suse.com
- tools/resolve_btfids: Fix cross-compilation to non-host
  endianness (git-fixes).
- tools/resolve_btfids: Refactor set sorting with types from
  btf_ids.h (git-fixes).
- libbpf: Use OPTS_SET() macro in bpf_xdp_query() (git-fixes).
- commit 6fc7b9e
* Tue Aug 13 2024 jlee@suse.com
- libbpf: Add missing LIBBPF_API annotation to
  libbpf_set_memlock_rlim API (git-fixes).
- selftests/bpf: Disable IPv6 for lwt_redirect test (git-fixes).
- libbpf: Fix faccessat() usage on Android (git-fixes).
- selftests/bpf: Wait for the netstamp_needed_key static key to
  be turned on (git-fixes).
- commit 89d6f3b
* Tue Aug 13 2024 jlee@suse.com
- selftests/bpf: Fix the flaky tc_redirect_dtime test (git-fixes).
- selftest/bpf: Add map_in_maps with BPF_MAP_TYPE_PERF_EVENT_ARRAY
  values (git-fixes).
- libbpf: Apply map_set_def_max_entries() for inner_maps on
  creation (git-fixes).
- selftests/bpf: Fix potential premature unload in bpf_testmod
  (git-fixes).
- bpftool: Silence build warning about calloc() (git-fixes).
- commit 7aaf2fc
* Tue Aug 13 2024 nik.borisov@suse.com
- x86/asm: Use %%c/%%n instead of %%P operand modifier in asm  templates (git-fixes).
- Refresh
  patches.suse/x86-uaccess-Fix-missed-zeroing-of-ia32-u64-get_user-range-.patch.
- commit 97ffc68
* Tue Aug 13 2024 jlee@suse.com
- selftests/bpf: Fix up xdp bonding test wrt feature flags
  (git-fixes).
- selftests/bpf: fix compiler warnings in RELEASE=1 mode
  (git-fixes).
- selftests/bpf: Relax time_tai test for equal timestamps in
  tai_forward (git-fixes).
- bpf: Set uattr->batch.count as zero before batched update or
  deletion (git-fixes).
- bpf: Remove unnecessary wait from bpf_map_copy_value()
  (git-fixes).
- commit 19ebfe6
* Tue Aug 13 2024 jlee@suse.com
- bpf: enforce precision of R0 on callback return (git-fixes).
- selftests/bpf: Fix erroneous bitmask operation (git-fixes).
- bpf/tests: Remove duplicate JSGT tests (git-fixes).
- bpftool: mark orphaned programs during prog show (git-fixes).
- commit 2b6a18e
* Tue Aug 13 2024 jlee@suse.com
- bpf: Fix a few selftest failures due to llvm18 change
  (git-fixes).
- selftests/bpf: Fix issues in setup_classid_environment()
  (git-fixes).
- selftests/bpf: Add assert for user stacks in test_task_stack
  (git-fixes).
- selftests/bpf: Fix pyperf180 compilation failure with clang18
  (git-fixes).
- bpf: Add crosstask check to __bpf_get_stack (git-fixes).
- commit fce00e9
* Tue Aug 13 2024 jlee@suse.com
- bpf, lpm: Fix check prefixlen before walking trie (git-fixes).
- selftests/bpf: satisfy compiler by having explicit return in
  btf test (git-fixes).
- selftests/bpf: fix RELEASE=1 build for tc_opts (git-fixes).
- bpf: Fix prog_array_map_poke_run map poke update (git-fixes).
- commit ca200c8
* Mon Aug 12 2024 lduncan@suse.com
- scsi: mpi3mr: Use proper format specifier in
  mpi3mr_sas_port_add() (bsc#1228754 CVE-2024-42159 git-fixes).
- scsi: mpi3mr: Sanitise num_phys (bsc#1228754 CVE-2024-42159).
- commit e024eb0
* Mon Aug 12 2024 davide.benini@suse.com
- tcp_metrics: validate source addr length
  (CVE-2024-42154 bsc#1228507).
- commit a83d949
* Mon Aug 12 2024 jlee@suse.com
- selftests/bpf: check if max number of bpf_loop iterations is
  tracked (git-fixes).
  Refresh
  patches.suse/selftests-bpf-test-case-for-callback_depth-states-pr.patch.
- selftests/bpf: fix bpf_loop_bench for new callback verification
  scheme (git-fixes).
- selftests/bpf: Add netkit to tc_redirect selftest (git-fixes).
- selftests/bpf: De-veth-ize the tc_redirect test case
  (git-fixes).
- bpf: fix control-flow graph checking in privileged mode
  (git-fixes).
- commit 27db2c6
* Mon Aug 12 2024 jlee@suse.com
- bpf: Fix check_stack_write_fixed_off() to correctly spill imm
  (git-fixes).
- bpf: Fix unnecessary -EBUSY from htab_lock_bucket (git-fixes).
- commit b5c430e
* Mon Aug 12 2024 mhocko@suse.com
- mm/shmem: disable PMD-sized page cache if needed (CVE-2024-42241
  bsc#1228986).
- commit 8ecdd91
* Mon Aug 12 2024 nik.borisov@suse.com
- x86/mm: Fix pti_clone_pgtable() alignment assumption (git-fixes).
- commit 1d041a1
* Mon Aug 12 2024 nik.borisov@suse.com
- x86/mm: Fix pti_clone_entry_text() for i386 (git-fixes).
- commit 5407674
* Mon Aug 12 2024 nik.borisov@suse.com
- x86/pci: Skip early E820 check for ECAM region (git-fixes).
- commit 7ac1bfc
* Mon Aug 12 2024 nik.borisov@suse.com
- x86/mtrr: Check if fixed MTRRs exist before saving them (git-fixes).
- commit 03de6ee
* Mon Aug 12 2024 nik.borisov@suse.com
- x86/entry/64: Remove obsolete comment on tracing vs. SYSRET (git-fixes).
- commit 41708c1
* Mon Aug 12 2024 mhocko@suse.com
- memcg: protect concurrent access to mem_cgroup_idr (git-fixes).
- commit e9979b2
* Mon Aug 12 2024 rhopkins@suse.de
- Revert "sched/fair: Make sure to try to detach at least one
  movable task" (CVE-2024-42245 bsc#1228978).
- commit bff0dc0
* Mon Aug 12 2024 jlee@suse.com
- selftests/bpf: Make linked_list failure test more robust
  (git-fixes).
- bpf: Ensure proper register state printing for cond jumps
  (git-fixes).
- commit 2ec4f49
* Mon Aug 12 2024 denis.kirjanov@suse.com
- ipv6: sr: fix incorrect unregister order (git-fixes).
- commit f975fdd
* Mon Aug 12 2024 denis.kirjanov@suse.com
- ipv6: sr: fix possible use-after-free and null-ptr-deref
  (CVE-2024-26735 bsc#1222372).
- commit 75aaed9
* Mon Aug 12 2024 jlee@suse.com
- bpftool: Align output skeleton ELF code (git-fixes).
- samples/bpf: syscall_tp_user: Fix array out-of-bound access
  (git-fixes).
- samples/bpf: syscall_tp_user: Rename num_progs into nr_tests
  (git-fixes).
- bpf: Fix kfunc callback register type handling (git-fixes).
- commit ee3cca0
* Mon Aug 12 2024 jlee@suse.com
- bpf: Detect IP == ksym.end as part of BPF program (git-fixes).
- commit b5b57d0
* Mon Aug 12 2024 jlee@suse.com
- selftests/bpf: Skip module_fentry_shadow test when bpf_testmod
  is not available (git-fixes).
- commit 85b5d5e
* Mon Aug 12 2024 jlee@suse.com
- bpftool: Fix -Wcast-qual warning (git-fixes).
- commit 0417873
* Mon Aug 12 2024 sjaeckel@suse.de
- net: bridge: switchdev: Skip MDB replays of deferred events
  on offload (CVE-2024-26837 bsc#1222973).
- commit 2f55c98
* Mon Aug 12 2024 mfranc@suse.cz
- s390/pkey: Wipe copies of protected- and secure-keys
  (CVE-2024-42155 bsc#1228733).
- s390/pkey: Wipe copies of clear-key structures on failure
  (CVE-2024-42156 bsc#1228722).
- s390/pkey: Wipe sensitive data on failure (CVE-2024-42157
  bsc#1228727).
- s390/pkey: Use kfree_sensitive() to fix Coccinelle warnings
  (CVE-2024-42158 bsc#1228720).
- s390/pkey: introduce dynamic debugging for pkey (bsc#1228720).
- s390/pkey: harmonize pkey s390 debug feature calls
  (bsc#1228720).
- commit 72f0617
* Mon Aug 12 2024 tiwai@suse.de
- usb: gadget: u_serial: Set start_delayed during suspend
  (git-fixes).
- usb: gadget: core: Check for unset descriptor (git-fixes).
- usb: gadget: u_audio: Check return codes from usb_ep_enable
  and config_ep_by_speed (git-fixes).
- driver core: Fix uevent_show() vs driver detach race
  (git-fixes).
- thermal/drivers/broadcom: Fix race between removal and clock
  disable (git-fixes).
- thermal: bcm2835: Convert to platform remove callback returning
  void (stable-fixes).
- commit 9bfd8af
* Mon Aug 12 2024 shung-hsi.yu@suse.com
- selftests/bpf: Cover verifier checks for mutating
  sockmap/sockhash (bsc#1226885 CVE-2024-38662).
- Revert "bpf, sockmap: Prevent lock inversion deadlock in map
  delete elem" (bsc#1226885 CVE-2024-38662).
- bpf: Allow delete from sockmap/sockhash only if update is
  allowed (bsc#1226885 CVE-2024-38662).
- commit 7f528cf
* Mon Aug 12 2024 jslaby@suse.cz
- rpm/kernel-binary.spec.in: fix klp_symbols macro
  The commit below removed openSUSE filter from %%ifs of the klp_symbols
  definition. But it removed -c of grep too and that causes:
  error: syntax error in expression:  01 && (  || 1 )
  error:                                        ^
  error: unmatched (:  01 && (  || 1 )
  error:                     ^
  error: kernel-default.spec:137: bad %%if condition:  01 && (  || 1 )
  So reintroduce -c to the PTF's grep.
  Fixes: fd0b293bebaf (kernel-binary.spec.in: Enable klp_symbols on openSUSE Tumbleweed (boo#1229042).)
- commit 4a36fe3
* Sun Aug 11 2024 tiwai@suse.de
- i2c: qcom-geni: Add missing geni_icc_disable in
  geni_i2c_runtime_resume (git-fixes).
- i2c: qcom-geni: Add missing clk_disable_unprepare in
  geni_i2c_runtime_resume (git-fixes).
- i2c: smbus: Send alert notifications to all devices if source
  not found (git-fixes).
- i2c: smbus: Improve handling of stuck alerts (git-fixes).
- spi: spi-fsl-lpspi: Fix scldiv calculation (git-fixes).
- spi: spidev: Add missing spi_device_id for bh2228fv (git-fixes).
- drm/i915/gem: Fix Virtual Memory mapping boundaries calculation
  (git-fixes).
- drm/client: fix null pointer dereference in
  drm_client_modeset_probe (git-fixes).
- commit e093c66
* Sat Aug 10 2024 tiwai@suse.de
- Update patch references for ASoC regression fixes (bsc#1229045 bsc#1229046)
- commit 4e3f007
* Sat Aug 10 2024 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix build regression
  The previous fix forgot to take over grep -c option that broke the
  conditional expression
- commit d29edf2
* Sat Aug 10 2024 tiwai@suse.de
- Moved upstreamed ASoC patch into sorted section
- commit 3058bc3
* Sat Aug 10 2024 tiwai@suse.de
- ASoC: cs35l56: Patch CS35L56_IRQ1_MASK_18 to the default value
  (stable-fixes).
- ASoC: amd: yc: Support mic on Lenovo Thinkpad E14 Gen 6
  (stable-fixes).
- ASoC: cs35l56: Handle OTP read latency over SoundWire
  (stable-fixes).
- ASoC: nau8822: Lower debug print priority (stable-fixes).
- ASoC: fsl_micfil: Expand the range of FIFO watermark mask
  (stable-fixes).
- ASoC: amd: yc: Support mic on HP 14-em0002la (stable-fixes).
- ALSA: hda/realtek: Add Framework Laptop 13 (Intel Core Ultra)
  to quirks (stable-fixes).
- ALSA: hda/hdmi: Yet more pin fix for HP EliteDesk 800 G4
  (stable-fixes).
- ALSA: hda: Add HP MP9 G4 Retail System AMS to force connect list
  (stable-fixes).
- ALSA: line6: Fix racy access to midibuf (stable-fixes).
- ASoC: cs35l56: Patch CS35L56_IRQ1_MASK_18 to the default value
  (stable-fixes).
- ASoC: amd: yc: Support mic on Lenovo Thinkpad E14 Gen 6
  (stable-fixes).
- ASoC: cs35l56: Handle OTP read latency over SoundWire
  (stable-fixes).
- ASoC: nau8822: Lower debug print priority (stable-fixes).
- ASoC: fsl_micfil: Expand the range of FIFO watermark mask
  (stable-fixes).
- ASoC: amd: yc: Support mic on HP 14-em0002la (stable-fixes).
- ALSA: hda/realtek: Add Framework Laptop 13 (Intel Core Ultra)
  to quirks (stable-fixes).
- ALSA: hda/hdmi: Yet more pin fix for HP EliteDesk 800 G4
  (stable-fixes).
- ALSA: hda: Add HP MP9 G4 Retail System AMS to force connect list
  (stable-fixes).
- ALSA: line6: Fix racy access to midibuf (stable-fixes).
- commit a8c8868
* Sat Aug 10 2024 tiwai@suse.de
- ASoC: meson: axg-fifo: fix irq scheduling issue with PREEMPT_RT
  (git-fixes).
- ASoC: SOF: Remove libraries from topology lookups (git-fixes).
- ASoC: codecs: wsa884x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wsa883x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wsa881x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wcd938x-sdw: Correct Soundwire ports mask
  (git-fixes).
- ALSA: usb-audio: Re-add ScratchAmp quirk entries (git-fixes).
- ASoC: meson: axg-fifo: fix irq scheduling issue with PREEMPT_RT
  (git-fixes).
- ASoC: SOF: Remove libraries from topology lookups (git-fixes).
- ASoC: codecs: wsa884x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wsa883x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wsa881x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wcd938x-sdw: Correct Soundwire ports mask
  (git-fixes).
- ALSA: usb-audio: Re-add ScratchAmp quirk entries (git-fixes).
- commit cdc2939
* Fri Aug  9 2024 mpdesouza@suse.com
- kernel-binary.spec.in: Enable klp_symbols on openSUSE Tumbleweed (boo#1229042).
  After the Jump project the kernel used by SLE and openSUSE Leap are the
  same. As consequence the klp_symbols variable is set, enabling
  kernel-default-livepatch-devel on both SLE and openSUSE.
  The current rules to avoid enabling the package exclude openSUSE
  Tumbleweed alone, which doesn't makes sense for now. Enabling
  kernel-default-livepatch-devel on TW makes it easier to test the
  creation of kernel livepatches of the next SLE versions.
- commit fd0b293
* Fri Aug  9 2024 tiwai@suse.de
- Split kABI workaround of recent hyperv fixes (bsc#1229040, bsc#1225745, CVE-2024-36911, bsc#1225717, CVE-2024-36910, bsc#1225744, CVE-2024-36909)
- commit 3639306
* Fri Aug  9 2024 tiwai@suse.de
- Yet more build fix without patches.kabi (bsc#1226502)
- commit 6bc3429
* Fri Aug  9 2024 tiwai@suse.de
- Fix build errors without patches.kabi (bsc#1226502)
  Now patches.suse/x86-Stop-using-weak-symbols-for-__iowrite32_copy.patch
  has a full backport and later partially reverted via
  patches.kabi/kabi-partial-revert-commit-20516d6e51dd.patch
- commit 44c5e90
* Fri Aug  9 2024 mfranc@suse.cz
- landlock: Fix d_parent walk (CVE-2024-40938 bsc#1227840).
- commit 36de641
* Fri Aug  9 2024 tiwai@suse.de
- Drop kABI symbols and patches.kabi/* for SLE15-SP7
- commit 4244494
* Fri Aug  9 2024 tiwai@suse.de
- Fork SLE15-SP7: reduce the old changelog
  Only the old references are kept, the old entries are saved in
  old_changelog.txt
- commit 2db23fb
* Fri Aug  9 2024 mfranc@suse.cz
- net: fix sk_memory_allocated_{add|sub} vs softirqs
  (bsc#1228757).
- commit a963c0f
* Fri Aug  9 2024 msuchanek@suse.de
- minmax: fix up min3() and max3() too (bsc#1229024).
- minmax: improve macro expansion and type checking (bsc#1229024).
- minmax: simplify min()/max()/clamp() implementation
  (bsc#1229024).
- minmax: don't use max() in situations that want a C constant
  expression (bsc#1229024).
- minmax: make generic MIN() and MAX() macros available everywhere
  (bsc#1229024).
- minmax: simplify and clarify min_t()/max_t() implementation
  (bsc#1229024).
- minmax: add a few more MIN_T/MAX_T users (bsc#1229024).
- minmax: avoid overly complicated constant expressions in VM code
  (bsc#1229024).
- drm/radeon/evergreen_cs: Clean up errors in evergreen_cs.c
  (bsc#1229024).
- commit c64c296
* Fri Aug  9 2024 jslaby@suse.cz
- Update
  patches.suse/ALSA-emux-improve-patch-ioctl-data-validation.patch
  (stable-fixes CVE-2024-42097 bsc#1228766).
- Update
  patches.suse/ASoC-SOF-Intel-hda-fix-null-deref-on-system-suspend-.patch
  (git-fixes CVE-2024-41037 bsc#1228508).
- Update
  patches.suse/ASoC-amd-acp-add-a-null-check-for-chip_pdev-structur.patch
  (git-fixes CVE-2024-42074 bsc#1228481).
- Update
  patches.suse/ASoC-fsl-asoc-card-set-priv-pdev-before-using-it.patch
  (git-fixes CVE-2024-42089 bsc#1228450).
- Update
  patches.suse/Bluetooth-ISO-Check-socket-flag-instead-of-hcon.patch
  (git-fixes CVE-2024-42141 bsc#1228502).
- Update
  patches.suse/Bluetooth-Ignore-too-large-handle-values-in-BIG.patch
  (git-fixes CVE-2024-42133 bsc#1228511).
- Update
  patches.suse/Bluetooth-hci_core-cancel-all-works-upon-hci_unregis.patch
  (stable-fixes CVE-2024-41063 bsc#1228580).
- Update
  patches.suse/Bluetooth-qca-Fix-BT-enable-failure-again-for-QCA639.patch
  (git-fixes CVE-2024-42137 bsc#1228563).
- Update patches.suse/PCI-MSI-Fix-UAF-in-msi_capability_init.patch
  (git-fixes CVE-2024-41096 bsc#1228479).
- Update
  patches.suse/RDMA-restrack-Fix-potential-invalid-address-access.patch
  (git-fixes CVE-2024-42080 bsc#1228673).
- Update
  patches.suse/USB-core-Fix-duplicate-endpoint-bug-by-clearing-rese.patch
  (git-fixes CVE-2024-41035 bsc#1228485).
- Update patches.suse/USB-serial-mos7840-fix-crash-on-resume.patch
  (git-fixes CVE-2024-42244 bsc#1228967).
- Update
  patches.suse/ata-libata-core-Fix-null-pointer-dereference-on-erro.patch
  (git-fixes CVE-2024-41098 bsc#1228467).
- Update
  patches.suse/bluetooth-hci-disallow-setting-handle-bigger-than-HC.patch
  (git-fixes CVE-2024-42132 bsc#1228492).
- Update
  patches.suse/bpf-Fail-bpf_timer_cancel-when-callback-is-being-can.patch
  (bsc#1228531 CVE-2024-41045 CVE-2024-42239 bsc#1228979).
- Update
  patches.suse/can-mcp251xfd-fix-infinite-loop-when-xmit-fails.patch
  (git-fixes CVE-2024-41088 bsc#1228469).
- Update
  patches.suse/cdrom-rearrange-last_media_change-check-to-avoid-uni.patch
  (stable-fixes CVE-2024-42136 bsc#1228758).
- Update
  patches.suse/crypto-aead-cipher-zeroize-key-buffer-after-use.patch
  (stable-fixes CVE-2024-42229 bsc#1228708).
- Update
  patches.suse/crypto-ecdh-explicitly-zeroize-private_key.patch
  (stable-fixes CVE-2024-42098 bsc#1228779).
- Update
  patches.suse/drm-amd-display-ASSERT-when-failing-to-find-index-by.patch
  (stable-fixes CVE-2024-42117 bsc#1228582).
- Update
  patches.suse/drm-amd-display-Check-index-msg_id-before-read-or-wr.patch
  (stable-fixes CVE-2024-42121 bsc#1228590).
- Update
  patches.suse/drm-amd-display-Check-pipe-offset-before-setting-vbl.patch
  (stable-fixes CVE-2024-42120 bsc#1228588).
- Update
  patches.suse/drm-amd-display-Fix-array-index-out-of-bounds-in-dml.patch
  (stable-fixes CVE-2024-41061 bsc#1228572).
- Update
  patches.suse/drm-amd-display-Fix-overlapping-copy-within-dml_core.patch
  (stable-fixes CVE-2024-42227 bsc#1228707).
- Update
  patches.suse/drm-amd-display-Skip-finding-free-audio-for-unknown-.patch
  (stable-fixes CVE-2024-42119 bsc#1228584).
- Update
  patches.suse/drm-amd-display-Skip-pipe-if-the-pipe-idx-not-set-pr.patch
  (stable-fixes CVE-2024-42064 bsc#1228586).
- Update
  patches.suse/drm-amdgpu-Fix-signedness-bug-in-sdma_v4_0_process_t.patch
  (git-fixes CVE-2024-41022 bsc#1228429).
- Update
  patches.suse/drm-amdgpu-Using-uninitialized-value-size-when-calli.patch
  (stable-fixes CVE-2024-42228 bsc#1228667).
- Update
  patches.suse/drm-amdgpu-avoid-using-null-object-of-framebuffer.patch
  (stable-fixes CVE-2024-41093 bsc#1228660).
- Update
  patches.suse/drm-fbdev-dma-Only-set-smem_start-is-enable-per-modu.patch
  (git-fixes CVE-2024-41094 bsc#1228458).
- Update
  patches.suse/drm-i915-gt-Fix-potential-UAF-by-revoke-of-fence-reg.patch
  (git-fixes CVE-2024-41092 bsc#1228483).
- Update
  patches.suse/drm-lima-fix-shared-irq-handling-on-driver-remove.patch
  (stable-fixes CVE-2024-42127 bsc#1228721).
- Update
  patches.suse/drm-nouveau-dispnv04-fix-null-pointer-dereference-in-66edf3f.patch
  (stable-fixes CVE-2024-41095 bsc#1228662).
- Update
  patches.suse/drm-nouveau-dispnv04-fix-null-pointer-dereference-in.patch
  (stable-fixes CVE-2024-41089 bsc#1228658).
- Update
  patches.suse/drm-nouveau-fix-null-pointer-dereference-in-nouveau_.patch
  (git-fixes CVE-2024-42101 bsc#1228495).
- Update
  patches.suse/drm-panel-ilitek-ili9881c-Fix-warning-with-GPIO-cont.patch
  (stable-fixes CVE-2024-42087 bsc#1228677).
- Update
  patches.suse/drm-radeon-check-bo_va-bo-is-non-NULL-before-using-i.patch
  (stable-fixes CVE-2024-41060 bsc#1228567).
- Update
  patches.suse/filelock-fix-potential-use-after-free-in-posix_lock_inode.patch
  (git-fixes CVE-2024-41049 bsc#1228486).
- Update
  patches.suse/firmware-cs_dsp-Fix-overflow-checking-of-wmfw-header.patch
  (git-fixes CVE-2024-41039 bsc#1228515).
- Update
  patches.suse/firmware-cs_dsp-Prevent-buffer-overrun-when-processi.patch
  (git-fixes CVE-2024-41038 bsc#1228509).
- Update
  patches.suse/firmware-cs_dsp-Return-error-if-block-header-overflo.patch
  (git-fixes CVE-2024-42238 bsc#1228991).
- Update
  patches.suse/firmware-cs_dsp-Use-strnlen-on-name-fields-in-V1-wmf.patch
  (git-fixes CVE-2024-41056 bsc#1228480).
- Update
  patches.suse/firmware-cs_dsp-Validate-payload-length-before-proce.patch
  (git-fixes CVE-2024-42237 bsc#1228992).
- Update
  patches.suse/genirq-cpuhotplug-x86-vector-Prevent-vector-leak-dur.patch
  (git-fixes CVE-2024-31076 bsc#1226765).
- Update
  patches.suse/gpio-davinci-Validate-the-obtained-number-of-IRQs.patch
  (git-fixes CVE-2024-42092 bsc#1228447).
- Update
  patches.suse/gpio-pca953x-fix-pca953x_irq_bus_sync_unlock-race.patch
  (stable-fixes CVE-2024-42253 bsc#1229005).
- Update
  patches.suse/i2c-pnx-Fix-potential-deadlock-warning-from-del_time.patch
  (git-fixes CVE-2024-42153 bsc#1228510).
- Update
  patches.suse/iio-chemical-bme680-Fix-overflows-in-compensate-func.patch
  (git-fixes CVE-2024-42086 bsc#1228452).
- Update
  patches.suse/jffs2-Fix-potential-illegal-address-access-in-jffs2_free_inode.patch
  (git-fixes CVE-2024-42115 bsc#1228656).
- Update
  patches.suse/libceph-fix-race-between-delayed_work-and-ceph_monc_s.patch
  (bsc#1228192 CVE-2024-42232 bsc#1228959).
- Update
  patches.suse/media-dvb-frontends-tda10048-Fix-integer-overflow.patch
  (stable-fixes CVE-2024-42223 bsc#1228726).
- Update
  patches.suse/misc-fastrpc-Fix-memory-leak-in-audio-daemon-attach-.patch
  (git-fixes CVE-2024-41025 bsc#1228527).
- Update
  patches.suse/misc-fastrpc-Restrict-untrusted-app-to-attach-to-pri.patch
  (git-fixes CVE-2024-41024 bsc#1228525).
- Update
  patches.suse/mm-Avoid-overflows-in-dirty-throttling-logic.patch
  (bsc#1222364 CVE-2024-26720 CVE-2024-42131 bsc#1228650).
- Update
  patches.suse/msft-hv-3022-net-mana-Fix-possible-double-free-in-error-handling-.patch
  (git-fixes CVE-2024-42069 bsc#1228463).
- Update
  patches.suse/net-can-j1939-Initialize-unused-data-in-j1939_send_o.patch
  (git-fixes CVE-2024-42076 bsc#1228484).
- Update
  patches.suse/net-can-j1939-enhanced-error-handling-for-tightly-re.patch
  (git-fixes CVE-2023-52887 bsc#1228426).
- Update
  patches.suse/nfc-nci-Add-the-inconsistency-check-between-the-inpu.patch
  (stable-fixes CVE-2024-42130 bsc#1228687).
- Update
  patches.suse/nilfs2-add-missing-check-for-inode-numbers-on-direct.patch
  (stable-fixes CVE-2024-42104 bsc#1228654).
- Update patches.suse/nvme-avoid-double-free-special-payload.patch
  (git-fixes CVE-2024-41073 bsc#1228635).
- Update patches.suse/nvmet-always-initialize-cqe.result.patch
  (git-fixes CVE-2024-41079 bsc#1228615).
- Update
  patches.suse/nvmet-fix-a-possible-leak-when-destroy-a-ctrl-during.patch
  (git-fixes CVE-2024-42152 bsc#1228724).
- Update
  patches.suse/ocfs2-fix-DIO-failure-due-to-insufficient-transaction-credits.patch
  (git-fixes CVE-2024-42077 bsc#1228516).
- Update
  patches.suse/ocfs2-strict-bound-check-before-memcmp-in-ocfs2_xatt.patch
  (bsc#1228410 CVE-2024-41016).
- Update patches.suse/orangefs-fix-out-of-bounds-fsid-access.patch
  (git-fixes CVE-2024-42143 bsc#1228748).
- Update
  patches.suse/pinctrl-fix-deadlock-in-create_pinctrl-when-handling.patch
  (git-fixes CVE-2024-42090 bsc#1228449).
- Update
  patches.suse/platform-x86-toshiba_acpi-Fix-array-out-of-bounds-ac.patch
  (git-fixes CVE-2024-41028 bsc#1228539).
- Update
  patches.suse/powerpc-Avoid-nmi_enter-nmi_exit-in-real-mode-interr.patch
  (bsc#1221645 ltc#205739 bsc#1223191 CVE-2024-42126 bsc#1228718).
- Update
  patches.suse/powerpc-pseries-Fix-scv-instruction-crash-with-kexec.patch
  (bsc#1194869 CVE-2024-42230 bsc#1228489).
- Update
  patches.suse/thermal-drivers-mediatek-lvts_thermal-Check-NULL-ptr.patch
  (stable-fixes CVE-2024-42144 bsc#1228666).
- Update
  patches.suse/usb-atm-cxacru-fix-endpoint-checking-in-cxacru_bind.patch
  (git-fixes CVE-2024-41097 bsc#1228513).
- Update
  patches.suse/usb-dwc3-core-remove-lock-of-otg-mode-during-gadget-.patch
  (git-fixes CVE-2024-42085 bsc#1228456).
- Update
  patches.suse/usb-gadget-configfs-Prevent-OOB-read-write-in-usb_st.patch
  (stable-fixes CVE-2024-42236 bsc#1228964).
- Update
  patches.suse/usb-xhci-prevent-potential-failure-in-handle_tx_even.patch
  (stable-fixes CVE-2024-42226 bsc#1228709).
- Update
  patches.suse/wifi-cfg80211-restrict-NL80211_ATTR_TXQ_QUANTUM-valu.patch
  (git-fixes CVE-2024-42114 bsc#1228564).
- Update
  patches.suse/wifi-cfg80211-wext-add-extra-SIOCSIWSCAN-data-check.patch
  (stable-fixes CVE-2024-41072 bsc#1228626).
- Update
  patches.suse/wifi-mac80211-Avoid-address-calculations-via-out-of-.patch
  (stable-fixes CVE-2024-41071 bsc#1228625).
- Update
  patches.suse/wifi-mt76-replace-skb_put-with-skb_put_zero.patch
  (stable-fixes CVE-2024-42225 bsc#1228710).
- Update
  patches.suse/wifi-rtw89-fw-scan-offload-prohibit-all-6-GHz-channe.patch
  (bsc#1227149 CVE-2024-42125 bsc#1228674).
- Update
  patches.suse/x86-bhi-Avoid-warning-in-DB-handler-due-to-BHI-mitigation
  (git-fixes CVE-2024-42240 bsc#1228966).
  Add CVE references.
- commit dfa8582
* Fri Aug  9 2024 tbogendoerfer@suse.de
- wireguard: allowedips: avoid unaligned 64-bit memory accesses
  (CVE-2024-42247 bsc#1228988).
- commit 12abe6d
* Fri Aug  9 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add netlink helper library (bsc#1228021
  CVE-2024-41010).
- Fix BPF selftest build failure
- commit c3e9de4
* Fri Aug  9 2024 jlee@suse.com
- x86/numa: Fix the sort compare func used in numa_fill_memblks()
  (git-fixes).
- x86/numa: Fix the address overlap check in numa_fill_memblks()
  (git-fixes).
- commit b42baa2
* Thu Aug  8 2024 davide.benini@suse.com
- inet_diag: Initialize pad field in struct inet_diag_req_v2
  (CVE-2024-42106 bsc#1228493).
- commit 87d015b
* Thu Aug  8 2024 jlee@suse.com
- x86/numa: Fix SRAT lookup of CFMWS ranges with
  numa_fill_memblks() (git-fixes).
- ACPI/NUMA: Apply SRAT proximity domain to entire CFMWS window
  (git-fixes).
- x86/numa: Introduce numa_fill_memblks() (git-fixes).
- commit 7f40727
* Thu Aug  8 2024 jlee@suse.com
- ACPI: processor_idle: use raw_safe_halt() in
  acpi_idle_play_dead() (git-fixes).
- perf/smmuv3: Enable HiSilicon Erratum 162001900 quirk for
  HIP08/09 (git-fixes).
- commit 23f94eb
* Thu Aug  8 2024 tiwai@suse.de
- Fork SLE15-SP7 branch, the changelog entries until the commit
  104de54ef80a are truncated in order to save space.
  Bugzilla/CVE/Jira references from the deleted changelog entries are
  included below. The full text for these removed entries can be found in
    /usr/share/doc/packages/kernel-docs/old_changelog.txt
  from the kernel-docs package:
  bac#1214529 bnc#804482 boo#1193472 boo#1211226 boo#1221077 bsc#1012628
  bsc#1023051 bsc#1065729 bsc#1108281 bsc#1120059 bsc#1141539 bsc#1148712
  bsc#1177090 bsc#1177719 bsc#1180336 bsc#1181674 bsc#1183045 bsc#1184587
  bsc#1186716 bsc#1187236 bsc#1187716 bsc#1187829 bsc#1189965 bsc#1191396
  bsc#1192327 bsc#1193201 bsc#1193203 bsc#1193454 bsc#1193599 bsc#1193629
  bsc#1194869 bsc#1195774 bsc#1195775 bsc#1198276 bsc#1201284 bsc#1204315
  bsc#1204562 bsc#1205316 bsc#1205462 bsc#1206453 bsc#1206578 bsc#1207948
  bsc#1208410 bsc#1208593 bsc#1208724 bsc#1208783 bsc#1208788 bsc#1208995
  bsc#1209006 bsc#1209284 bsc#1209657 bsc#1209834 bsc#1210335 bsc#1210421
  bsc#1210658 bsc#1210690 bsc#1210778 bsc#1211307 bsc#1211346 bsc#1211732
  bsc#1211847 bsc#1211852 bsc#1211960 bsc#1212091 bsc#1212301 bsc#1212395
  bsc#1212405 bsc#1212445 bsc#1212471 bsc#1212505 bsc#1212514 bsc#1212533
  bsc#1212639 bsc#1212649 bsc#1212703 bsc#1212741 bsc#1212773 bsc#1212775
  bsc#1212808 bsc#1212835 bsc#1212857 bsc#1212873 bsc#1212874 bsc#1212886
  bsc#1212887 bsc#1213026 bsc#1213059 bsc#1213061 bsc#1213123 bsc#1213179
  bsc#1213270 bsc#1213287 bsc#1213456 bsc#1213491 bsc#1213534 bsc#1213545
  bsc#1213546 bsc#1213573 bsc#1213583 bsc#1213585 bsc#1213588 bsc#1213592
  bsc#1213645 bsc#1213666 bsc#1213667 bsc#1213693 bsc#1213705 bsc#1213745
  bsc#1213747 bsc#1213756 bsc#1213779 bsc#1213787 bsc#1213812 bsc#1213916
  bsc#1213968 bsc#1213971 bsc#1213972 bsc#1213978 bsc#1214022 bsc#1214073
  bsc#1214120 bsc#1214133 bsc#1214149 bsc#1214193 bsc#1214212 bsc#1214233
  bsc#1214285 bsc#1214297 bsc#1214304 bsc#1214371 bsc#1214377 bsc#1214380
  bsc#1214385 bsc#1214386 bsc#1214397 bsc#1214428 bsc#1214479 bsc#1214635
  bsc#1214683 bsc#1214700 bsc#1214727 bsc#1214746 bsc#1214747 bsc#1214754
  bsc#1214772 bsc#1214773 bsc#1214842 bsc#1214847 bsc#1214852 bsc#1214883
  bsc#1214891 bsc#1214928 bsc#1214931 bsc#1214934 bsc#1214939 bsc#1214951
  bsc#1214952 bsc#1214953 bsc#1214955 bsc#1214963 bsc#1214993 bsc#1214995
  bsc#1214997 bsc#1214998 bsc#1215115 bsc#1215117 bsc#1215124 bsc#1215143
  bsc#1215146 bsc#1215150 bsc#1215155 bsc#1215199 bsc#1215211 bsc#1215221
  bsc#1215234 bsc#1215237 bsc#1215252 bsc#1215253 bsc#1215275 bsc#1215284
  bsc#1215291 bsc#1215322 bsc#1215344 bsc#1215345 bsc#1215420 bsc#1215467
  bsc#1215528 bsc#1215529 bsc#1215530 bsc#1215541 bsc#1215587 bsc#1215612
  bsc#1215613 bsc#1215696 bsc#1215710 bsc#1215745 bsc#1215767 bsc#1215768
  bsc#1215858 bsc#1215860 bsc#1215875 bsc#1215880 bsc#1215885 bsc#1215899
  bsc#1215921 bsc#1215931 bsc#1215938 bsc#1216004 bsc#1216015 bsc#1216033
  bsc#1216046 bsc#1216062 bsc#1216196 bsc#1216213 bsc#1216214 bsc#1216215
  bsc#1216259 bsc#1216325 bsc#1216326 bsc#1216327 bsc#1216331 bsc#1216358
  bsc#1216396 bsc#1216435 bsc#1216436 bsc#1216505 bsc#1216507 bsc#1216523
  bsc#1216527 bsc#1216584 bsc#1216611 bsc#1216621 bsc#1216687 bsc#1216693
  bsc#1216702 bsc#1216759 bsc#1216760 bsc#1216761 bsc#1216776 bsc#1216837
  bsc#1216838 bsc#1216861 bsc#1216864 bsc#1216929 bsc#1216954 bsc#1216965
  bsc#1216976 bsc#1217030 bsc#1217036 bsc#1217068 bsc#1217090 bsc#1217124
  bsc#1217132 bsc#1217140 bsc#1217169 bsc#1217250 bsc#1217282 bsc#1217313
  bsc#1217344 bsc#1217362 bsc#1217382 bsc#1217384 bsc#1217408 bsc#1217410
  bsc#1217412 bsc#1217417 bsc#1217473 bsc#1217481 bsc#1217489 bsc#1217510
  bsc#1217591 bsc#1217602 bsc#1217686 bsc#1217698 bsc#1217731 bsc#1217750
  bsc#1217756 bsc#1217780 bsc#1217801 bsc#1217818 bsc#1217908 bsc#1217912
  bsc#1217927 bsc#1217930 bsc#1217931 bsc#1217938 bsc#1217944 bsc#1217946
  bsc#1217947 bsc#1217958 bsc#1217959 bsc#1217987 bsc#1217988 bsc#1217989
  bsc#1218003 bsc#1218054 bsc#1218085 bsc#1218139 bsc#1218177 bsc#1218180
  bsc#1218184 bsc#1218195 bsc#1218205 bsc#1218216 bsc#1218245 bsc#1218253
  bsc#1218258 bsc#1218272 bsc#1218286 bsc#1218335 bsc#1218336 bsc#1218359
  bsc#1218397 bsc#1218442 bsc#1218447 bsc#1218495 bsc#1218515 bsc#1218554
  bsc#1218555 bsc#1218556 bsc#1218559 bsc#1218562 bsc#1218624 bsc#1218634
  bsc#1218636 bsc#1218644 bsc#1218709 bsc#1218713 bsc#1218720 bsc#1218721
  bsc#1218726 bsc#1218727 bsc#1218730 bsc#1218753 bsc#1218757 bsc#1218768
  bsc#1218777 bsc#1218779 bsc#1218785 bsc#1218804 bsc#1218820 bsc#1218829
  bsc#1218830 bsc#1218832 bsc#1218836 bsc#1218855 bsc#1218869 bsc#1218870
  bsc#1218893 bsc#1218915 bsc#1218916 bsc#1218917 bsc#1218934 bsc#1218941
  bsc#1218948 bsc#1218958 bsc#1218960 bsc#1218968 bsc#1218986 bsc#1218987
  bsc#1218988 bsc#1218989 bsc#1218991 bsc#1218992 bsc#1218993 bsc#1218996
  bsc#1219077 bsc#1219104 bsc#1219120 bsc#1219126 bsc#1219127 bsc#1219128
  bsc#1219141 bsc#1219146 bsc#1219163 bsc#1219165 bsc#1219169 bsc#1219170
  bsc#1219216 bsc#1219222 bsc#1219224 bsc#1219246 bsc#1219247 bsc#1219254
  bsc#1219261 bsc#1219264 bsc#1219285 bsc#1219286 bsc#1219315 bsc#1219338
  bsc#1219404 bsc#1219429 bsc#1219434 bsc#1219440 bsc#1219443 bsc#1219451
  bsc#1219470 bsc#1219473 bsc#1219475 bsc#1219478 bsc#1219485 bsc#1219496
  bsc#1219497 bsc#1219509 bsc#1219510 bsc#1219551 bsc#1219558 bsc#1219566
  bsc#1219567 bsc#1219582 bsc#1219596 bsc#1219608 bsc#1219617 bsc#1219623
  bsc#1219631 bsc#1219633 bsc#1219653 bsc#1219670 bsc#1219692 bsc#1219731
  bsc#1219732 bsc#1219789 bsc#1219808 bsc#1219809 bsc#1219810 bsc#1219811
  bsc#1219812 bsc#1219814 bsc#1219815 bsc#1219816 bsc#1219825 bsc#1219827
  bsc#1219832 bsc#1219834 bsc#1219835 bsc#1219847 bsc#1219889 bsc#1219953
  bsc#1219987 bsc#1220009 bsc#1220021 bsc#1220030 bsc#1220045 bsc#1220066
  bsc#1220089 bsc#1220106 bsc#1220120 bsc#1220129 bsc#1220137 bsc#1220138
  bsc#1220140 bsc#1220144 bsc#1220148 bsc#1220154 bsc#1220174 bsc#1220182
  bsc#1220185 bsc#1220186 bsc#1220187 bsc#1220214 bsc#1220218 bsc#1220237
  bsc#1220238 bsc#1220240 bsc#1220241 bsc#1220243 bsc#1220247 bsc#1220250
  bsc#1220251 bsc#1220253 bsc#1220254 bsc#1220255 bsc#1220257 bsc#1220265
  bsc#1220277 bsc#1220287 bsc#1220319 bsc#1220320 bsc#1220322 bsc#1220325
  bsc#1220326 bsc#1220328 bsc#1220330 bsc#1220331 bsc#1220332 bsc#1220335
  bsc#1220336 bsc#1220337 bsc#1220340 bsc#1220342 bsc#1220344 bsc#1220348
  bsc#1220350 bsc#1220359 bsc#1220360 bsc#1220363 bsc#1220364 bsc#1220365
  bsc#1220369 bsc#1220398 bsc#1220411 bsc#1220413 bsc#1220419 bsc#1220424
  bsc#1220427 bsc#1220428 bsc#1220430 bsc#1220431 bsc#1220433 bsc#1220451
  bsc#1220452 bsc#1220453 bsc#1220454 bsc#1220492 bsc#1220502 bsc#1220507
  bsc#1220569 bsc#1220587 bsc#1220649 bsc#1220682 bsc#1220684 bsc#1220703
  bsc#1220709 bsc#1220735 bsc#1220736 bsc#1220738 bsc#1220783 bsc#1220790
  bsc#1220796 bsc#1220797 bsc#1220825 bsc#1220827 bsc#1220830 bsc#1220831
  bsc#1220833 bsc#1220835 bsc#1220836 bsc#1220839 bsc#1220840 bsc#1220843
  bsc#1220848 bsc#1220869 bsc#1220870 bsc#1220871 bsc#1220872 bsc#1220873
  bsc#1220874 bsc#1220876 bsc#1220878 bsc#1220879 bsc#1220883 bsc#1220885
  bsc#1220887 bsc#1220897 bsc#1220898 bsc#1220901 bsc#1220914 bsc#1220915
  bsc#1220918 bsc#1220920 bsc#1220921 bsc#1220924 bsc#1220925 bsc#1220926
  bsc#1220927 bsc#1220928 bsc#1220929 bsc#1220930 bsc#1220931 bsc#1220932
  bsc#1220933 bsc#1220935 bsc#1220936 bsc#1220937 bsc#1220938 bsc#1220939
  bsc#1220940 bsc#1220941 bsc#1220942 bsc#1220943 bsc#1220945 bsc#1220946
  bsc#1221012 bsc#1221015 bsc#1221021 bsc#1221022 bsc#1221032 bsc#1221040
  bsc#1221042 bsc#1221044 bsc#1221045 bsc#1221046 bsc#1221048 bsc#1221055
  bsc#1221056 bsc#1221057 bsc#1221058 bsc#1221060 bsc#1221061 bsc#1221062
  bsc#1221066 bsc#1221067 bsc#1221068 bsc#1221069 bsc#1221070 bsc#1221071
  bsc#1221079 bsc#1221080 bsc#1221081 bsc#1221082 bsc#1221084 bsc#1221086
  bsc#1221088 bsc#1221090 bsc#1221097 bsc#1221114 bsc#1221156 bsc#1221157
  bsc#1221161 bsc#1221162 bsc#1221261 bsc#1221269 bsc#1221271 bsc#1221273
  bsc#1221274 bsc#1221276 bsc#1221277 bsc#1221281 bsc#1221282 bsc#1221291
  bsc#1221293 bsc#1221295 bsc#1221298 bsc#1221299 bsc#1221303 bsc#1221305
  bsc#1221325 bsc#1221330 bsc#1221337 bsc#1221339 bsc#1221341 bsc#1221375
  bsc#1221379 bsc#1221388 bsc#1221389 bsc#1221390 bsc#1221391 bsc#1221392
  bsc#1221393 bsc#1221428 bsc#1221491 bsc#1221504 bsc#1221553 bsc#1221611
  bsc#1221612 bsc#1221613 bsc#1221614 bsc#1221615 bsc#1221616 bsc#1221617
  bsc#1221618 bsc#1221620 bsc#1221623 bsc#1221625 bsc#1221626 bsc#1221635
  bsc#1221645 bsc#1221647 bsc#1221649 bsc#1221652 bsc#1221654 bsc#1221656
  bsc#1221659 bsc#1221765 bsc#1221777 bsc#1221783 bsc#1221814 bsc#1221816
  bsc#1221829 bsc#1221830 bsc#1221858 bsc#1221958 bsc#1222011 bsc#1222015
  bsc#1222048 bsc#1222051 bsc#1222054 bsc#1222055 bsc#1222056 bsc#1222060
  bsc#1222066 bsc#1222067 bsc#1222070 bsc#1222072 bsc#1222073 bsc#1222080
  bsc#1222083 bsc#1222085 bsc#1222115 bsc#1222117 bsc#1222173 bsc#1222230
  bsc#1222241 bsc#1222247 bsc#1222254 bsc#1222264 bsc#1222266 bsc#1222273
  bsc#1222274 bsc#1222278 bsc#1222291 bsc#1222293 bsc#1222294 bsc#1222299
  bsc#1222300 bsc#1222301 bsc#1222303 bsc#1222304 bsc#1222307 bsc#1222317
  bsc#1222323 bsc#1222324 bsc#1222326 bsc#1222328 bsc#1222331 bsc#1222355
  bsc#1222356 bsc#1222357 bsc#1222358 bsc#1222359 bsc#1222360 bsc#1222364
  bsc#1222365 bsc#1222366 bsc#1222367 bsc#1222368 bsc#1222369 bsc#1222370
  bsc#1222371 bsc#1222373 bsc#1222374 bsc#1222378 bsc#1222379 bsc#1222380
  bsc#1222385 bsc#1222413 bsc#1222415 bsc#1222416 bsc#1222418 bsc#1222419
  bsc#1222420 bsc#1222422 bsc#1222424 bsc#1222425 bsc#1222426 bsc#1222427
  bsc#1222428 bsc#1222430 bsc#1222431 bsc#1222433 bsc#1222434 bsc#1222435
  bsc#1222437 bsc#1222438 bsc#1222444 bsc#1222445 bsc#1222449 bsc#1222451
  bsc#1222459 bsc#1222463 bsc#1222464 bsc#1222466 bsc#1222482 bsc#1222489
  bsc#1222503 bsc#1222513 bsc#1222520 bsc#1222522 bsc#1222523 bsc#1222525
  bsc#1222527 bsc#1222529 bsc#1222531 bsc#1222532 bsc#1222536 bsc#1222549
  bsc#1222550 bsc#1222552 bsc#1222557 bsc#1222559 bsc#1222561 bsc#1222563
  bsc#1222585 bsc#1222586 bsc#1222588 bsc#1222596 bsc#1222601 bsc#1222602
  bsc#1222606 bsc#1222607 bsc#1222608 bsc#1222609 bsc#1222610 bsc#1222613
  bsc#1222615 bsc#1222617 bsc#1222618 bsc#1222619 bsc#1222622 bsc#1222624
  bsc#1222625 bsc#1222626 bsc#1222627 bsc#1222630 bsc#1222632 bsc#1222635
  bsc#1222654 bsc#1222656 bsc#1222667 bsc#1222677 bsc#1222678 bsc#1222680
  bsc#1222720 bsc#1222721 bsc#1222724 bsc#1222726 bsc#1222727 bsc#1222728
  bsc#1222742 bsc#1222764 bsc#1222765 bsc#1222768 bsc#1222769 bsc#1222770
  bsc#1222771 bsc#1222772 bsc#1222775 bsc#1222777 bsc#1222779 bsc#1222780
  bsc#1222781 bsc#1222782 bsc#1222783 bsc#1222784 bsc#1222788 bsc#1222793
  bsc#1222798 bsc#1222799 bsc#1222801 bsc#1222809 bsc#1222810 bsc#1222823
  bsc#1222870 bsc#1222893 bsc#1222960 bsc#1222961 bsc#1222968 bsc#1222974
  bsc#1222975 bsc#1222976 bsc#1223007 bsc#1223010 bsc#1223011 bsc#1223012
  bsc#1223013 bsc#1223014 bsc#1223015 bsc#1223016 bsc#1223018 bsc#1223020
  bsc#1223021 bsc#1223023 bsc#1223024 bsc#1223026 bsc#1223027 bsc#1223030
  bsc#1223031 bsc#1223033 bsc#1223034 bsc#1223035 bsc#1223036 bsc#1223037
  bsc#1223038 bsc#1223039 bsc#1223041 bsc#1223042 bsc#1223043 bsc#1223044
  bsc#1223045 bsc#1223046 bsc#1223048 bsc#1223049 bsc#1223051 bsc#1223052
  bsc#1223055 bsc#1223056 bsc#1223057 bsc#1223058 bsc#1223060 bsc#1223061
  bsc#1223062 bsc#1223064 bsc#1223065 bsc#1223066 bsc#1223076 bsc#1223077
  bsc#1223078 bsc#1223081 bsc#1223084 bsc#1223111 bsc#1223113 bsc#1223115
  bsc#1223118 bsc#1223119 bsc#1223137 bsc#1223138 bsc#1223140 bsc#1223143
  bsc#1223187 bsc#1223188 bsc#1223189 bsc#1223190 bsc#1223191 bsc#1223192
  bsc#1223195 bsc#1223196 bsc#1223197 bsc#1223198 bsc#1223202 bsc#1223203
  bsc#1223204 bsc#1223205 bsc#1223207 bsc#1223265 bsc#1223285 bsc#1223315
  bsc#1223323 bsc#1223338 bsc#1223369 bsc#1223380 bsc#1223384 bsc#1223390
  bsc#1223395 bsc#1223415 bsc#1223439 bsc#1223462 bsc#1223525 bsc#1223532
  bsc#1223539 bsc#1223570 bsc#1223575 bsc#1223590 bsc#1223591 bsc#1223592
  bsc#1223593 bsc#1223625 bsc#1223626 bsc#1223627 bsc#1223628 bsc#1223629
  bsc#1223631 bsc#1223632 bsc#1223633 bsc#1223634 bsc#1223637 bsc#1223638
  bsc#1223641 bsc#1223642 bsc#1223643 bsc#1223644 bsc#1223645 bsc#1223646
  bsc#1223648 bsc#1223649 bsc#1223650 bsc#1223651 bsc#1223652 bsc#1223653
  bsc#1223654 bsc#1223655 bsc#1223657 bsc#1223660 bsc#1223661 bsc#1223663
  bsc#1223664 bsc#1223665 bsc#1223666 bsc#1223667 bsc#1223668 bsc#1223669
  bsc#1223670 bsc#1223671 bsc#1223675 bsc#1223677 bsc#1223678 bsc#1223679
  bsc#1223686 bsc#1223692 bsc#1223693 bsc#1223695 bsc#1223696 bsc#1223698
  bsc#1223699 bsc#1223705 bsc#1223709 bsc#1223711 bsc#1223712 bsc#1223714
  bsc#1223715 bsc#1223717 bsc#1223718 bsc#1223723 bsc#1223725 bsc#1223728
  bsc#1223731 bsc#1223732 bsc#1223734 bsc#1223735 bsc#1223737 bsc#1223738
  bsc#1223739 bsc#1223740 bsc#1223741 bsc#1223744 bsc#1223745 bsc#1223747
  bsc#1223748 bsc#1223749 bsc#1223750 bsc#1223752 bsc#1223754 bsc#1223756
  bsc#1223757 bsc#1223759 bsc#1223760 bsc#1223761 bsc#1223762 bsc#1223763
  bsc#1223764 bsc#1223765 bsc#1223768 bsc#1223769 bsc#1223770 bsc#1223774
  bsc#1223776 bsc#1223778 bsc#1223779 bsc#1223780 bsc#1223781 bsc#1223782
  bsc#1223787 bsc#1223788 bsc#1223789 bsc#1223790 bsc#1223802 bsc#1223804
  bsc#1223805 bsc#1223806 bsc#1223807 bsc#1223808 bsc#1223810 bsc#1223813
  bsc#1223815 bsc#1223816 bsc#1223819 bsc#1223821 bsc#1223822 bsc#1223823
  bsc#1223824 bsc#1223826 bsc#1223827 bsc#1223828 bsc#1223829 bsc#1223831
  bsc#1223834 bsc#1223836 bsc#1223837 bsc#1223838 bsc#1223842 bsc#1223843
  bsc#1223844 bsc#1223847 bsc#1223863 bsc#1223869 bsc#1223870 bsc#1223871
  bsc#1223872 bsc#1223874 bsc#1223944 bsc#1223945 bsc#1223946 bsc#1223991
  bsc#1224049 bsc#1224076 bsc#1224096 bsc#1224098 bsc#1224099 bsc#1224137
  bsc#1224166 bsc#1224174 bsc#1224177 bsc#1224180 bsc#1224181 bsc#1224187
  bsc#1224331 bsc#1224348 bsc#1224414 bsc#1224422 bsc#1224423 bsc#1224429
  bsc#1224430 bsc#1224432 bsc#1224433 bsc#1224437 bsc#1224438 bsc#1224439
  bsc#1224442 bsc#1224443 bsc#1224445 bsc#1224449 bsc#1224477 bsc#1224479
  bsc#1224480 bsc#1224481 bsc#1224482 bsc#1224485 bsc#1224486 bsc#1224487
  bsc#1224488 bsc#1224490 bsc#1224491 bsc#1224492 bsc#1224493 bsc#1224494
  bsc#1224495 bsc#1224497 bsc#1224498 bsc#1224499 bsc#1224500 bsc#1224501
  bsc#1224502 bsc#1224504 bsc#1224505 bsc#1224506 bsc#1224507 bsc#1224508
  bsc#1224509 bsc#1224511 bsc#1224512 bsc#1224513 bsc#1224515 bsc#1224516
  bsc#1224517 bsc#1224519 bsc#1224520 bsc#1224521 bsc#1224523 bsc#1224524
  bsc#1224525 bsc#1224526 bsc#1224530 bsc#1224531 bsc#1224534 bsc#1224537
  bsc#1224539 bsc#1224540 bsc#1224541 bsc#1224542 bsc#1224543 bsc#1224544
  bsc#1224545 bsc#1224546 bsc#1224549 bsc#1224550 bsc#1224552 bsc#1224553
  bsc#1224555 bsc#1224557 bsc#1224558 bsc#1224559 bsc#1224562 bsc#1224565
  bsc#1224566 bsc#1224567 bsc#1224568 bsc#1224569 bsc#1224571 bsc#1224572
  bsc#1224573 bsc#1224575 bsc#1224576 bsc#1224577 bsc#1224578 bsc#1224579
  bsc#1224580 bsc#1224581 bsc#1224582 bsc#1224583 bsc#1224584 bsc#1224585
  bsc#1224586 bsc#1224587 bsc#1224588 bsc#1224589 bsc#1224592 bsc#1224596
  bsc#1224598 bsc#1224600 bsc#1224601 bsc#1224602 bsc#1224603 bsc#1224604
  bsc#1224605 bsc#1224606 bsc#1224607 bsc#1224608 bsc#1224609 bsc#1224611
  bsc#1224612 bsc#1224613 bsc#1224614 bsc#1224615 bsc#1224617 bsc#1224618
  bsc#1224619 bsc#1224620 bsc#1224621 bsc#1224622 bsc#1224623 bsc#1224624
  bsc#1224626 bsc#1224627 bsc#1224628 bsc#1224629 bsc#1224630 bsc#1224631
  bsc#1224632 bsc#1224633 bsc#1224634 bsc#1224636 bsc#1224637 bsc#1224638
  bsc#1224639 bsc#1224640 bsc#1224641 bsc#1224643 bsc#1224644 bsc#1224645
  bsc#1224646 bsc#1224647 bsc#1224648 bsc#1224649 bsc#1224650 bsc#1224651
  bsc#1224652 bsc#1224653 bsc#1224654 bsc#1224655 bsc#1224657 bsc#1224659
  bsc#1224660 bsc#1224661 bsc#1224662 bsc#1224663 bsc#1224664 bsc#1224665
  bsc#1224666 bsc#1224667 bsc#1224668 bsc#1224670 bsc#1224671 bsc#1224672
  bsc#1224673 bsc#1224674 bsc#1224675 bsc#1224676 bsc#1224677 bsc#1224678
  bsc#1224679 bsc#1224680 bsc#1224681 bsc#1224682 bsc#1224683 bsc#1224685
  bsc#1224686 bsc#1224687 bsc#1224688 bsc#1224690 bsc#1224692 bsc#1224694
  bsc#1224696 bsc#1224697 bsc#1224698 bsc#1224699 bsc#1224700 bsc#1224701
  bsc#1224703 bsc#1224704 bsc#1224705 bsc#1224706 bsc#1224707 bsc#1224709
  bsc#1224710 bsc#1224712 bsc#1224714 bsc#1224716 bsc#1224717 bsc#1224718
  bsc#1224719 bsc#1224720 bsc#1224721 bsc#1224722 bsc#1224723 bsc#1224725
  bsc#1224727 bsc#1224728 bsc#1224729 bsc#1224730 bsc#1224731 bsc#1224732
  bsc#1224733 bsc#1224735 bsc#1224736 bsc#1224738 bsc#1224739 bsc#1224740
  bsc#1224741 bsc#1224742 bsc#1224743 bsc#1224747 bsc#1224749 bsc#1224751
  bsc#1224759 bsc#1224763 bsc#1224764 bsc#1224765 bsc#1224766 bsc#1224767
  bsc#1224790 bsc#1224792 bsc#1224793 bsc#1224803 bsc#1224804 bsc#1224866
  bsc#1224928 bsc#1224930 bsc#1224932 bsc#1224933 bsc#1224935 bsc#1224936
  bsc#1224937 bsc#1224939 bsc#1224941 bsc#1224944 bsc#1224946 bsc#1224947
  bsc#1224949 bsc#1224951 bsc#1224988 bsc#1224989 bsc#1224992 bsc#1224998
  bsc#1225000 bsc#1225001 bsc#1225004 bsc#1225006 bsc#1225007 bsc#1225008
  bsc#1225009 bsc#1225014 bsc#1225015 bsc#1225022 bsc#1225025 bsc#1225028
  bsc#1225029 bsc#1225031 bsc#1225036 bsc#1225041 bsc#1225044 bsc#1225049
  bsc#1225050 bsc#1225053 bsc#1225076 bsc#1225077 bsc#1225078 bsc#1225081
  bsc#1225085 bsc#1225086 bsc#1225088 bsc#1225090 bsc#1225092 bsc#1225096
  bsc#1225097 bsc#1225098 bsc#1225101 bsc#1225103 bsc#1225104 bsc#1225105
  bsc#1225106 bsc#1225108 bsc#1225120 bsc#1225132 bsc#1225133 bsc#1225134
  bsc#1225136 bsc#1225172 bsc#1225180 bsc#1225272 bsc#1225300 bsc#1225391
  bsc#1225472 bsc#1225475 bsc#1225476 bsc#1225477 bsc#1225478 bsc#1225485
  bsc#1225489 bsc#1225490 bsc#1225502 bsc#1225527 bsc#1225529 bsc#1225530
  bsc#1225532 bsc#1225534 bsc#1225548 bsc#1225550 bsc#1225553 bsc#1225554
  bsc#1225555 bsc#1225556 bsc#1225557 bsc#1225559 bsc#1225560 bsc#1225564
  bsc#1225565 bsc#1225566 bsc#1225568 bsc#1225569 bsc#1225570 bsc#1225571
  bsc#1225572 bsc#1225573 bsc#1225577 bsc#1225578 bsc#1225579 bsc#1225580
  bsc#1225581 bsc#1225583 bsc#1225584 bsc#1225585 bsc#1225586 bsc#1225587
  bsc#1225588 bsc#1225589 bsc#1225590 bsc#1225591 bsc#1225592 bsc#1225593
  bsc#1225594 bsc#1225595 bsc#1225599 bsc#1225600 bsc#1225601 bsc#1225602
  bsc#1225605 bsc#1225607 bsc#1225609 bsc#1225610 bsc#1225611 bsc#1225616
  bsc#1225618 bsc#1225640 bsc#1225642 bsc#1225681 bsc#1225692 bsc#1225694
  bsc#1225695 bsc#1225696 bsc#1225698 bsc#1225699 bsc#1225702 bsc#1225704
  bsc#1225705 bsc#1225708 bsc#1225710 bsc#1225711 bsc#1225712 bsc#1225714
  bsc#1225715 bsc#1225717 bsc#1225719 bsc#1225720 bsc#1225722 bsc#1225723
  bsc#1225726 bsc#1225728 bsc#1225731 bsc#1225732 bsc#1225734 bsc#1225735
  bsc#1225736 bsc#1225737 bsc#1225741 bsc#1225744 bsc#1225745 bsc#1225746
  bsc#1225747 bsc#1225748 bsc#1225749 bsc#1225750 bsc#1225752 bsc#1225753
  bsc#1225756 bsc#1225757 bsc#1225758 bsc#1225759 bsc#1225760 bsc#1225761
  bsc#1225762 bsc#1225763 bsc#1225765 bsc#1225766 bsc#1225767 bsc#1225769
  bsc#1225770 bsc#1225773 bsc#1225775 bsc#1225805 bsc#1225810 bsc#1225815
  bsc#1225820 bsc#1225823 bsc#1225827 bsc#1225829 bsc#1225830 bsc#1225834
  bsc#1225835 bsc#1225838 bsc#1225839 bsc#1225840 bsc#1225842 bsc#1225843
  bsc#1225847 bsc#1225851 bsc#1225856 bsc#1225866 bsc#1225872 bsc#1225894
  bsc#1225895 bsc#1225896 bsc#1225898 bsc#1225903 bsc#1225945 bsc#1226022
  bsc#1226031 bsc#1226127 bsc#1226131 bsc#1226145 bsc#1226149 bsc#1226155
  bsc#1226158 bsc#1226163 bsc#1226202 bsc#1226211 bsc#1226212 bsc#1226213
  bsc#1226226 bsc#1226457 bsc#1226502 bsc#1226503 bsc#1226513 bsc#1226514
  bsc#1226519 bsc#1226520 bsc#1226547 bsc#1226582 bsc#1226587 bsc#1226588
  bsc#1226592 bsc#1226593 bsc#1226594 bsc#1226595 bsc#1226597 bsc#1226607
  bsc#1226608 bsc#1226610 bsc#1226612 bsc#1226613 bsc#1226630 bsc#1226632
  bsc#1226633 bsc#1226634 bsc#1226637 bsc#1226657 bsc#1226658 bsc#1226734
  bsc#1226735 bsc#1226737 bsc#1226738 bsc#1226739 bsc#1226740 bsc#1226741
  bsc#1226742 bsc#1226743 bsc#1226744 bsc#1226746 bsc#1226747 bsc#1226749
  bsc#1226750 bsc#1226751 bsc#1226754 bsc#1226757 bsc#1226758 bsc#1226760
  bsc#1226761 bsc#1226764 bsc#1226767 bsc#1226768 bsc#1226769 bsc#1226771
  bsc#1226772 bsc#1226774 bsc#1226775 bsc#1226776 bsc#1226777 bsc#1226780
  bsc#1226781 bsc#1226783 bsc#1226785 bsc#1226786 bsc#1226788 bsc#1226789
  bsc#1226790 bsc#1226791 bsc#1226796 bsc#1226799 bsc#1226834 bsc#1226837
  bsc#1226839 bsc#1226840 bsc#1226841 bsc#1226842 bsc#1226844 bsc#1226848
  bsc#1226852 bsc#1226856 bsc#1226857 bsc#1226859 bsc#1226861 bsc#1226863
  bsc#1226864 bsc#1226866 bsc#1226867 bsc#1226868 bsc#1226875 bsc#1226876
  bsc#1226878 bsc#1226879 bsc#1226883 bsc#1226886 bsc#1226890 bsc#1226891
  bsc#1226894 bsc#1226895 bsc#1226905 bsc#1226908 bsc#1226909 bsc#1226911
  bsc#1226915 bsc#1226920 bsc#1226928 bsc#1226934 bsc#1226938 bsc#1226939
  bsc#1226941 bsc#1226948 bsc#1226949 bsc#1226950 bsc#1226962 bsc#1226976
  bsc#1226989 bsc#1226990 bsc#1226992 bsc#1226993 bsc#1226994 bsc#1226995
  bsc#1226996 bsc#1227066 bsc#1227072 bsc#1227085 bsc#1227089 bsc#1227090
  bsc#1227096 bsc#1227101 bsc#1227103 bsc#1227149 bsc#1227149# bsc#1227182
  bsc#1227190 bsc#1227282 bsc#1227362 bsc#1227363 bsc#1227383 bsc#1227432
  bsc#1227433 bsc#1227434 bsc#1227435 bsc#1227443 bsc#1227446 bsc#1227447
  bsc#1227487 bsc#1227492 bsc#1227493 bsc#1227494 bsc#1227573 bsc#1227618
  bsc#1227620 bsc#1227626 bsc#1227627 bsc#1227716 bsc#1227719 bsc#1227722
  bsc#1227723 bsc#1227724 bsc#1227725 bsc#1227728 bsc#1227729 bsc#1227730
  bsc#1227732 bsc#1227733 bsc#1227736 bsc#1227747 bsc#1227750 bsc#1227754
  bsc#1227755 bsc#1227757 bsc#1227760 bsc#1227762 bsc#1227763 bsc#1227764
  bsc#1227766 bsc#1227770 bsc#1227771 bsc#1227772 bsc#1227774 bsc#1227779
  bsc#1227780 bsc#1227783 bsc#1227785 bsc#1227786 bsc#1227787 bsc#1227788
  bsc#1227789 bsc#1227790 bsc#1227791 bsc#1227792 bsc#1227796 bsc#1227797
  bsc#1227798 bsc#1227800 bsc#1227801 bsc#1227802 bsc#1227803 bsc#1227806
  bsc#1227808 bsc#1227810 bsc#1227811 bsc#1227812 bsc#1227813 bsc#1227814
  bsc#1227815 bsc#1227816 bsc#1227818 bsc#1227820 bsc#1227823 bsc#1227824
  bsc#1227826 bsc#1227828 bsc#1227829 bsc#1227830 bsc#1227832 bsc#1227833
  bsc#1227834 bsc#1227836 bsc#1227846 bsc#1227849 bsc#1227851 bsc#1227853
  bsc#1227855 bsc#1227862 bsc#1227864 bsc#1227865 bsc#1227866 bsc#1227867
  bsc#1227869 bsc#1227870 bsc#1227883 bsc#1227884 bsc#1227886 bsc#1227891
  bsc#1227893 bsc#1227899 bsc#1227910 bsc#1227913 bsc#1227926 bsc#1227929
  bsc#1227950 bsc#1227957 bsc#1227981 bsc#1228020 bsc#1228021 bsc#1228090
  bsc#1228114 bsc#1228115 bsc#1228192 bsc#1228193 bsc#1228195 bsc#1228202
  bsc#1228211 bsc#1228235 bsc#1228236 bsc#1228237 bsc#1228269 bsc#1228289
  bsc#1228327 bsc#1228328 bsc#1228403 bsc#1228405 bsc#1228408 bsc#1228409
  bsc#1228410 bsc#1228417 bsc#1228446 bsc#1228457 bsc#1228459 bsc#1228460
  bsc#1228462 bsc#1228470 bsc#1228482 bsc#1228487 bsc#1228491 bsc#1228494
  bsc#1228496 bsc#1228500 bsc#1228501 bsc#1228503 bsc#1228518 bsc#1228520
  bsc#1228530 bsc#1228531 bsc#1228561 bsc#1228565 bsc#1228568 bsc#1228579
  bsc#1228581 bsc#1228591 bsc#1228599 bsc#1228617 bsc#1228633 bsc#1228640
  bsc#1228644 bsc#1228649 bsc#1228655 bsc#1228665 bsc#1228672 bsc#1228680
  bsc#1228705 bsc#1228706 bsc#1228723 bsc#1228740 bsc#1228743 bsc#1228756
  bsc#1228764 bsc#1228801 bsc#1228849 bsc#1228850 bsc#1228857 bsc#1228973
  CVE-2016-3695 CVE-2020-26555 CVE-2021-47432 CVE-2022-48628 CVE-2022-48669
  CVE-2022-48772 CVE-2023-0160 CVE-2023-1192 CVE-2023-1206 CVE-2023-20569
  CVE-2023-25775 CVE-2023-28746 CVE-2023-31085 CVE-2023-31248 CVE-2023-3269
  CVE-2023-34319 CVE-2023-35001 CVE-2023-35826 CVE-2023-35827 CVE-2023-3611
  CVE-2023-37453 CVE-2023-3772 CVE-2023-3773 CVE-2023-3776 CVE-2023-38417
  CVE-2023-39189 CVE-2023-39192 CVE-2023-39193 CVE-2023-39197 CVE-2023-39198
  CVE-2023-4004 CVE-2023-40283 CVE-2023-4128 CVE-2023-4134 CVE-2023-4147
  CVE-2023-4155 CVE-2023-4244 CVE-2023-4273 CVE-2023-42752 CVE-2023-42753
  CVE-2023-42754 CVE-2023-42756 CVE-2023-4563 CVE-2023-45871 CVE-2023-4611
  CVE-2023-4622 CVE-2023-4623 CVE-2023-46813 CVE-2023-46838 CVE-2023-46862
  CVE-2023-47210 CVE-2023-47233 CVE-2023-4881 CVE-2023-4921 CVE-2023-50431
  CVE-2023-51042 CVE-2023-51043 CVE-2023-5158 CVE-2023-51779 CVE-2023-5178
  CVE-2023-51780 CVE-2023-51782 CVE-2023-5197 CVE-2023-52429 CVE-2023-52433
  CVE-2023-52434 CVE-2023-52435 CVE-2023-52437 CVE-2023-52439 CVE-2023-52440
  CVE-2023-52443 CVE-2023-52445 CVE-2023-52446 CVE-2023-52447 CVE-2023-52448
  CVE-2023-52449 CVE-2023-52450 CVE-2023-52451 CVE-2023-52452 CVE-2023-52453
  CVE-2023-52454 CVE-2023-52455 CVE-2023-52456 CVE-2023-52457 CVE-2023-52458
  CVE-2023-52460 CVE-2023-52461 CVE-2023-52462 CVE-2023-52463 CVE-2023-52464
  CVE-2023-52467 CVE-2023-52468 CVE-2023-52469 CVE-2023-52470 CVE-2023-52471
  CVE-2023-52472 CVE-2023-52473 CVE-2023-52475 CVE-2023-52476 CVE-2023-52477
  CVE-2023-52478 CVE-2023-52481 CVE-2023-52482 CVE-2023-52483 CVE-2023-52484
  CVE-2023-52485 CVE-2023-52486 CVE-2023-52487 CVE-2023-52488 CVE-2023-52490
  CVE-2023-52491 CVE-2023-52492 CVE-2023-52493 CVE-2023-52494 CVE-2023-52495
  CVE-2023-52497 CVE-2023-52498 CVE-2023-52500 CVE-2023-52501 CVE-2023-52502
  CVE-2023-52503 CVE-2023-52504 CVE-2023-52505 CVE-2023-52507 CVE-2023-52508
  CVE-2023-52509 CVE-2023-52510 CVE-2023-52511 CVE-2023-52512 CVE-2023-52513
  CVE-2023-52515 CVE-2023-52517 CVE-2023-52518 CVE-2023-52519 CVE-2023-52520
  CVE-2023-52522 CVE-2023-52523 CVE-2023-52524 CVE-2023-52525 CVE-2023-52526
  CVE-2023-52527 CVE-2023-52528 CVE-2023-52529 CVE-2023-52530 CVE-2023-52531
  CVE-2023-52532 CVE-2023-52559 CVE-2023-52561 CVE-2023-52562 CVE-2023-52563
  CVE-2023-52564 CVE-2023-52565 CVE-2023-52566 CVE-2023-52567 CVE-2023-52568
  CVE-2023-52569 CVE-2023-52570 CVE-2023-52571 CVE-2023-52572 CVE-2023-52573
  CVE-2023-52574 CVE-2023-52575 CVE-2023-52576 CVE-2023-52577 CVE-2023-52578
  CVE-2023-52580 CVE-2023-52582 CVE-2023-52583 CVE-2023-52584 CVE-2023-52585
  CVE-2023-52586 CVE-2023-52587 CVE-2023-52589 CVE-2023-52590 CVE-2023-52591
  CVE-2023-52593 CVE-2023-52594 CVE-2023-52595 CVE-2023-52597 CVE-2023-52598
  CVE-2023-52599 CVE-2023-52600 CVE-2023-52601 CVE-2023-52602 CVE-2023-52603
  CVE-2023-52604 CVE-2023-52606 CVE-2023-52607 CVE-2023-52608 CVE-2023-52611
  CVE-2023-52612 CVE-2023-52614 CVE-2023-52615 CVE-2023-52616 CVE-2023-52617
  CVE-2023-52618 CVE-2023-52619 CVE-2023-52621 CVE-2023-52622 CVE-2023-52623
  CVE-2023-52624 CVE-2023-52625 CVE-2023-52626 CVE-2023-52627 CVE-2023-52628
  CVE-2023-52631 CVE-2023-52632 CVE-2023-52634 CVE-2023-52635 CVE-2023-52636
  CVE-2023-52637 CVE-2023-52638 CVE-2023-52639 CVE-2023-52640 CVE-2023-52641
  CVE-2023-52642 CVE-2023-52643 CVE-2023-52644 CVE-2023-52645 CVE-2023-52647
  CVE-2023-52648 CVE-2023-52649 CVE-2023-52650 CVE-2023-52652 CVE-2023-52653
  CVE-2023-52654 CVE-2023-52655 CVE-2023-52656 CVE-2023-52657 CVE-2023-52658
  CVE-2023-52659 CVE-2023-52660 CVE-2023-52661 CVE-2023-52662 CVE-2023-52663
  CVE-2023-52664 CVE-2023-52667 CVE-2023-52668 CVE-2023-52669 CVE-2023-52670
  CVE-2023-52671 CVE-2023-52672 CVE-2023-52673 CVE-2023-52674 CVE-2023-52675
  CVE-2023-52676 CVE-2023-52678 CVE-2023-52679 CVE-2023-52680 CVE-2023-52681
  CVE-2023-52683 CVE-2023-52685 CVE-2023-52686 CVE-2023-52687 CVE-2023-52688
  CVE-2023-52690 CVE-2023-52691 CVE-2023-52692 CVE-2023-52693 CVE-2023-52694
  CVE-2023-52695 CVE-2023-52696 CVE-2023-52697 CVE-2023-52698 CVE-2023-52699
  CVE-2023-52735 CVE-2023-52749 CVE-2023-52750 CVE-2023-52751 CVE-2023-52753
  CVE-2023-52754 CVE-2023-52757 CVE-2023-52759 CVE-2023-52762 CVE-2023-52763
  CVE-2023-52764 CVE-2023-52765 CVE-2023-52766 CVE-2023-52767 CVE-2023-52768
  CVE-2023-52769 CVE-2023-52771 CVE-2023-52772 CVE-2023-52773 CVE-2023-52774
  CVE-2023-52775 CVE-2023-52776 CVE-2023-52777 CVE-2023-52780 CVE-2023-52781
  CVE-2023-52782 CVE-2023-52783 CVE-2023-52784 CVE-2023-52786 CVE-2023-52787
  CVE-2023-52788 CVE-2023-52789 CVE-2023-52791 CVE-2023-52792 CVE-2023-52794
  CVE-2023-52795 CVE-2023-52796 CVE-2023-52798 CVE-2023-52799 CVE-2023-52800
  CVE-2023-52801 CVE-2023-52803 CVE-2023-52804 CVE-2023-52805 CVE-2023-52806
  CVE-2023-52807 CVE-2023-52808 CVE-2023-52809 CVE-2023-52810 CVE-2023-52811
  CVE-2023-52812 CVE-2023-52813 CVE-2023-52814 CVE-2023-52815 CVE-2023-52816
  CVE-2023-52817 CVE-2023-52818 CVE-2023-52819 CVE-2023-52821 CVE-2023-52825
  CVE-2023-52826 CVE-2023-52827 CVE-2023-52829 CVE-2023-52832 CVE-2023-52833
  CVE-2023-52834 CVE-2023-52835 CVE-2023-52836 CVE-2023-52837 CVE-2023-52838
  CVE-2023-52840 CVE-2023-52841 CVE-2023-52842 CVE-2023-52843 CVE-2023-52844
  CVE-2023-52845 CVE-2023-52846 CVE-2023-52847 CVE-2023-52849 CVE-2023-52850
  CVE-2023-52851 CVE-2023-52853 CVE-2023-52854 CVE-2023-52855 CVE-2023-52856
  CVE-2023-52857 CVE-2023-52858 CVE-2023-52860 CVE-2023-52861 CVE-2023-52862
  CVE-2023-52863 CVE-2023-52864 CVE-2023-52865 CVE-2023-52866 CVE-2023-52867
  CVE-2023-52868 CVE-2023-52869 CVE-2023-52870 CVE-2023-52871 CVE-2023-52872
  CVE-2023-52873 CVE-2023-52874 CVE-2023-52875 CVE-2023-52876 CVE-2023-52877
  CVE-2023-52878 CVE-2023-52879 CVE-2023-52880 CVE-2023-52881 CVE-2023-52882
  CVE-2023-52883 CVE-2023-52884 CVE-2023-52885 CVE-2023-52886 CVE-2023-5345
  CVE-2023-5633 CVE-2023-5717 CVE-2023-5972 CVE-2023-6039 CVE-2023-6121
  CVE-2023-6238 CVE-2023-6270 CVE-2023-6356 CVE-2023-6531 CVE-2023-6535
  CVE-2023-6536 CVE-2023-6546 CVE-2023-6606 CVE-2023-6610 CVE-2023-6622
  CVE-2023-6679 CVE-2023-6817 CVE-2023-6915 CVE-2023-6931 CVE-2023-6932
  CVE-2023-7042 CVE-2024-0193 CVE-2024-0565 CVE-2024-0607 CVE-2024-0639
  CVE-2024-0641 CVE-2024-0646 CVE-2024-0841 CVE-2024-1085 CVE-2024-1086
  CVE-2024-1151 CVE-2024-1312 CVE-2024-21823 CVE-2024-22099 CVE-2024-23307
  CVE-2024-23848 CVE-2024-23849 CVE-2024-23850 CVE-2024-23851 CVE-2024-24860
  CVE-2024-24861 CVE-2024-25739 CVE-2024-25741 CVE-2024-25744 CVE-2024-26482
  CVE-2024-26581 CVE-2024-26582 CVE-2024-26583 CVE-2024-26584 CVE-2024-26585
  CVE-2024-26586 CVE-2024-26589 CVE-2024-26591 CVE-2024-26593 CVE-2024-26595
  CVE-2024-26597 CVE-2024-26598 CVE-2024-26599 CVE-2024-26600 CVE-2024-26601
  CVE-2024-26602 CVE-2024-26603 CVE-2024-26605 CVE-2024-26607 CVE-2024-26610
  CVE-2024-26611 CVE-2024-26612 CVE-2024-26614 CVE-2024-26615 CVE-2024-26616
  CVE-2024-26618 CVE-2024-26620 CVE-2024-26622 CVE-2024-26623 CVE-2024-26625
  CVE-2024-26627 CVE-2024-26629 CVE-2024-26632 CVE-2024-26633 CVE-2024-26635
  CVE-2024-26636 CVE-2024-26637 CVE-2024-26638 CVE-2024-26641 CVE-2024-26642
  CVE-2024-26643 CVE-2024-26644 CVE-2024-26645 CVE-2024-26646 CVE-2024-26647
  CVE-2024-26648 CVE-2024-26649 CVE-2024-26650 CVE-2024-26651 CVE-2024-26652
  CVE-2024-26654 CVE-2024-26656 CVE-2024-26657 CVE-2024-26659 CVE-2024-26660
  CVE-2024-26661 CVE-2024-26662 CVE-2024-26663 CVE-2024-26664 CVE-2024-26665
  CVE-2024-26666 CVE-2024-26667 CVE-2024-26670 CVE-2024-26671 CVE-2024-26672
  CVE-2024-26673 CVE-2024-26674 CVE-2024-26675 CVE-2024-26676 CVE-2024-26679
  CVE-2024-26680 CVE-2024-26681 CVE-2024-26682 CVE-2024-26683 CVE-2024-26684
  CVE-2024-26685 CVE-2024-26687 CVE-2024-26688 CVE-2024-26689 CVE-2024-26691
  CVE-2024-26692 CVE-2024-26693 CVE-2024-26694 CVE-2024-26695 CVE-2024-26696
  CVE-2024-26697 CVE-2024-26698 CVE-2024-26699 CVE-2024-26700 CVE-2024-26702
  CVE-2024-26704 CVE-2024-26709 CVE-2024-26710 CVE-2024-26711 CVE-2024-26714
  CVE-2024-26715 CVE-2024-26716 CVE-2024-26717 CVE-2024-26718 CVE-2024-26720
  CVE-2024-26721 CVE-2024-26722 CVE-2024-26723 CVE-2024-26724 CVE-2024-26725
  CVE-2024-26726 CVE-2024-26727 CVE-2024-26728 CVE-2024-26729 CVE-2024-26731
  CVE-2024-26733 CVE-2024-26734 CVE-2024-26736 CVE-2024-26737 CVE-2024-26738
  CVE-2024-26739 CVE-2024-26740 CVE-2024-26742 CVE-2024-26743 CVE-2024-26744
  CVE-2024-26745 CVE-2024-26746 CVE-2024-26747 CVE-2024-26748 CVE-2024-26749
  CVE-2024-26750 CVE-2024-26751 CVE-2024-26752 CVE-2024-26753 CVE-2024-26754
  CVE-2024-26755 CVE-2024-26756 CVE-2024-26757 CVE-2024-26758 CVE-2024-26761
  CVE-2024-26763 CVE-2024-26764 CVE-2024-26766 CVE-2024-26767 CVE-2024-26769
  CVE-2024-26771 CVE-2024-26772 CVE-2024-26773 CVE-2024-26774 CVE-2024-26775
  CVE-2024-26776 CVE-2024-26777 CVE-2024-26778 CVE-2024-26779 CVE-2024-26780
  CVE-2024-26783 CVE-2024-26785 CVE-2024-26786 CVE-2024-26787 CVE-2024-26788
  CVE-2024-26789 CVE-2024-26790 CVE-2024-26791 CVE-2024-26792 CVE-2024-26793
  CVE-2024-26794 CVE-2024-26797 CVE-2024-26798 CVE-2024-26799 CVE-2024-26800
  CVE-2024-26801 CVE-2024-26802 CVE-2024-26803 CVE-2024-26805 CVE-2024-26807
  CVE-2024-26813 CVE-2024-26814 CVE-2024-26815 CVE-2024-26816 CVE-2024-26820
  CVE-2024-26822 CVE-2024-26824 CVE-2024-26825 CVE-2024-26826 CVE-2024-26828
  CVE-2024-26829 CVE-2024-26830 CVE-2024-26832 CVE-2024-26833 CVE-2024-26836
  CVE-2024-26838 CVE-2024-26839 CVE-2024-26840 CVE-2024-26843 CVE-2024-26844
  CVE-2024-26845 CVE-2024-26846 CVE-2024-26847 CVE-2024-26848 CVE-2024-26852
  CVE-2024-26853 CVE-2024-26854 CVE-2024-26855 CVE-2024-26856 CVE-2024-26857
  CVE-2024-26858 CVE-2024-26859 CVE-2024-26860 CVE-2024-26861 CVE-2024-26862
  CVE-2024-26863 CVE-2024-26865 CVE-2024-26866 CVE-2024-26868 CVE-2024-26870
  CVE-2024-26872 CVE-2024-26874 CVE-2024-26875 CVE-2024-26876 CVE-2024-26877
  CVE-2024-26878 CVE-2024-26879 CVE-2024-26880 CVE-2024-26881 CVE-2024-26882
  CVE-2024-26883 CVE-2024-26884 CVE-2024-26885 CVE-2024-26886 CVE-2024-26889
  CVE-2024-26890 CVE-2024-26891 CVE-2024-26892 CVE-2024-26893 CVE-2024-26894
  CVE-2024-26895 CVE-2024-26896 CVE-2024-26897 CVE-2024-26898 CVE-2024-26899
  CVE-2024-26900 CVE-2024-26901 CVE-2024-26903 CVE-2024-26906 CVE-2024-26907
  CVE-2024-26909 CVE-2024-26911 CVE-2024-26912 CVE-2024-26913 CVE-2024-26914
  CVE-2024-26915 CVE-2024-26916 CVE-2024-26917 CVE-2024-26919 CVE-2024-26920
  CVE-2024-26921 CVE-2024-26922 CVE-2024-26923 CVE-2024-26925 CVE-2024-26927
  CVE-2024-26928 CVE-2024-26929 CVE-2024-26930 CVE-2024-26931 CVE-2024-26932
  CVE-2024-26933 CVE-2024-26934 CVE-2024-26935 CVE-2024-26937 CVE-2024-26938
  CVE-2024-26939 CVE-2024-26940 CVE-2024-26943 CVE-2024-26944 CVE-2024-26945
  CVE-2024-26946 CVE-2024-26948 CVE-2024-26949 CVE-2024-26950 CVE-2024-26951
  CVE-2024-26955 CVE-2024-26956 CVE-2024-26957 CVE-2024-26958 CVE-2024-26959
  CVE-2024-26960 CVE-2024-26961 CVE-2024-26962 CVE-2024-26963 CVE-2024-26964
  CVE-2024-26965 CVE-2024-26966 CVE-2024-26968 CVE-2024-26969 CVE-2024-26970
  CVE-2024-26972 CVE-2024-26973 CVE-2024-26974 CVE-2024-26975 CVE-2024-26977
  CVE-2024-26978 CVE-2024-26979 CVE-2024-26981 CVE-2024-26982 CVE-2024-26983
  CVE-2024-26984 CVE-2024-26986 CVE-2024-26988 CVE-2024-26989 CVE-2024-26990
  CVE-2024-26991 CVE-2024-26992 CVE-2024-26993 CVE-2024-26994 CVE-2024-26995
  CVE-2024-26996 CVE-2024-26997 CVE-2024-26999 CVE-2024-27000 CVE-2024-27001
  CVE-2024-27002 CVE-2024-27003 CVE-2024-27004 CVE-2024-27008 CVE-2024-27009
  CVE-2024-27012 CVE-2024-27013 CVE-2024-27014 CVE-2024-27015 CVE-2024-27016
  CVE-2024-27019 CVE-2024-27020 CVE-2024-27022 CVE-2024-27023 CVE-2024-27025
  CVE-2024-27027 CVE-2024-27028 CVE-2024-27029 CVE-2024-27030 CVE-2024-27031
  CVE-2024-27036 CVE-2024-27037 CVE-2024-27038 CVE-2024-27039 CVE-2024-27040
  CVE-2024-27041 CVE-2024-27042 CVE-2024-27043 CVE-2024-27044 CVE-2024-27045
  CVE-2024-27046 CVE-2024-27047 CVE-2024-27048 CVE-2024-27049 CVE-2024-27051
  CVE-2024-27052 CVE-2024-27053 CVE-2024-27054 CVE-2024-27056 CVE-2024-27057
  CVE-2024-27059 CVE-2024-27060 CVE-2024-27062 CVE-2024-27064 CVE-2024-27065
  CVE-2024-27067 CVE-2024-27068 CVE-2024-27071 CVE-2024-27072 CVE-2024-27073
  CVE-2024-27074 CVE-2024-27075 CVE-2024-27076 CVE-2024-27077 CVE-2024-27078
  CVE-2024-27080 CVE-2024-27388 CVE-2024-27389 CVE-2024-27391 CVE-2024-27393
  CVE-2024-27395 CVE-2024-27396 CVE-2024-27398 CVE-2024-27399 CVE-2024-27400
  CVE-2024-27401 CVE-2024-27402 CVE-2024-27404 CVE-2024-27405 CVE-2024-27408
  CVE-2024-27410 CVE-2024-27411 CVE-2024-27412 CVE-2024-27413 CVE-2024-27414
  CVE-2024-27416 CVE-2024-27417 CVE-2024-27418 CVE-2024-27419 CVE-2024-27431
  CVE-2024-27432 CVE-2024-27434 CVE-2024-27435 CVE-2024-27436 CVE-2024-27437
  CVE-2024-33619 CVE-2024-34777 CVE-2024-35247 CVE-2024-35784 CVE-2024-35786
  CVE-2024-35788 CVE-2024-35789 CVE-2024-35790 CVE-2024-35791 CVE-2024-35794
  CVE-2024-35795 CVE-2024-35796 CVE-2024-35799 CVE-2024-35800 CVE-2024-35801
  CVE-2024-35803 CVE-2024-35804 CVE-2024-35805 CVE-2024-35806 CVE-2024-35807
  CVE-2024-35808 CVE-2024-35809 CVE-2024-35810 CVE-2024-35811 CVE-2024-35812
  CVE-2024-35813 CVE-2024-35814 CVE-2024-35815 CVE-2024-35817 CVE-2024-35819
  CVE-2024-35821 CVE-2024-35822 CVE-2024-35823 CVE-2024-35824 CVE-2024-35825
  CVE-2024-35827 CVE-2024-35828 CVE-2024-35829 CVE-2024-35830 CVE-2024-35831
  CVE-2024-35833 CVE-2024-35834 CVE-2024-35835 CVE-2024-35836 CVE-2024-35837
  CVE-2024-35838 CVE-2024-35841 CVE-2024-35842 CVE-2024-35843 CVE-2024-35845
  CVE-2024-35847 CVE-2024-35848 CVE-2024-35849 CVE-2024-35850 CVE-2024-35851
  CVE-2024-35852 CVE-2024-35853 CVE-2024-35854 CVE-2024-35855 CVE-2024-35857
  CVE-2024-35860 CVE-2024-35861 CVE-2024-35862 CVE-2024-35863 CVE-2024-35864
  CVE-2024-35865 CVE-2024-35866 CVE-2024-35867 CVE-2024-35868 CVE-2024-35869
  CVE-2024-35870 CVE-2024-35872 CVE-2024-35875 CVE-2024-35877 CVE-2024-35878
  CVE-2024-35879 CVE-2024-35880 CVE-2024-35883 CVE-2024-35884 CVE-2024-35885
  CVE-2024-35886 CVE-2024-35887 CVE-2024-35889 CVE-2024-35890 CVE-2024-35891
  CVE-2024-35892 CVE-2024-35893 CVE-2024-35895 CVE-2024-35896 CVE-2024-35898
  CVE-2024-35899 CVE-2024-35900 CVE-2024-35901 CVE-2024-35903 CVE-2024-35904
  CVE-2024-35905 CVE-2024-35907 CVE-2024-35908 CVE-2024-35909 CVE-2024-35911
  CVE-2024-35912 CVE-2024-35913 CVE-2024-35914 CVE-2024-35915 CVE-2024-35916
  CVE-2024-35917 CVE-2024-35921 CVE-2024-35922 CVE-2024-35924 CVE-2024-35925
  CVE-2024-35926 CVE-2024-35927 CVE-2024-35928 CVE-2024-35930 CVE-2024-35931
  CVE-2024-35932 CVE-2024-35933 CVE-2024-35934 CVE-2024-35935 CVE-2024-35936
  CVE-2024-35937 CVE-2024-35938 CVE-2024-35940 CVE-2024-35942 CVE-2024-35943
  CVE-2024-35944 CVE-2024-35945 CVE-2024-35946 CVE-2024-35947 CVE-2024-35949
  CVE-2024-35950 CVE-2024-35951 CVE-2024-35952 CVE-2024-35953 CVE-2024-35954
  CVE-2024-35955 CVE-2024-35956 CVE-2024-35957 CVE-2024-35958 CVE-2024-35959
  CVE-2024-35960 CVE-2024-35961 CVE-2024-35962 CVE-2024-35963 CVE-2024-35964
  CVE-2024-35965 CVE-2024-35966 CVE-2024-35967 CVE-2024-35969 CVE-2024-35970
  CVE-2024-35971 CVE-2024-35972 CVE-2024-35973 CVE-2024-35974 CVE-2024-35975
  CVE-2024-35976 CVE-2024-35977 CVE-2024-35978 CVE-2024-35979 CVE-2024-35981
  CVE-2024-35982 CVE-2024-35984 CVE-2024-35986 CVE-2024-35989 CVE-2024-35990
  CVE-2024-35991 CVE-2024-35992 CVE-2024-35995 CVE-2024-35997 CVE-2024-35998
  CVE-2024-35999 CVE-2024-36002 CVE-2024-36003 CVE-2024-36004 CVE-2024-36005
  CVE-2024-36006 CVE-2024-36007 CVE-2024-36008 CVE-2024-36009 CVE-2024-36010
  CVE-2024-36011 CVE-2024-36012 CVE-2024-36013 CVE-2024-36014 CVE-2024-36015
  CVE-2024-36016 CVE-2024-36017 CVE-2024-36018 CVE-2024-36019 CVE-2024-36020
  CVE-2024-36021 CVE-2024-36024 CVE-2024-36025 CVE-2024-36026 CVE-2024-36029
  CVE-2024-36030 CVE-2024-36032 CVE-2024-36281 CVE-2024-36288 CVE-2024-36477
  CVE-2024-36478 CVE-2024-36479 CVE-2024-36880 CVE-2024-36882 CVE-2024-36885
  CVE-2024-36887 CVE-2024-36889 CVE-2024-36890 CVE-2024-36891 CVE-2024-36893
  CVE-2024-36894 CVE-2024-36895 CVE-2024-36896 CVE-2024-36897 CVE-2024-36898
  CVE-2024-36899 CVE-2024-36900 CVE-2024-36901 CVE-2024-36902 CVE-2024-36903
  CVE-2024-36904 CVE-2024-36906 CVE-2024-36909 CVE-2024-36910 CVE-2024-36911
  CVE-2024-36912 CVE-2024-36913 CVE-2024-36914 CVE-2024-36915 CVE-2024-36916
  CVE-2024-36917 CVE-2024-36918 CVE-2024-36919 CVE-2024-36921 CVE-2024-36922
  CVE-2024-36923 CVE-2024-36924 CVE-2024-36926 CVE-2024-36928 CVE-2024-36930
  CVE-2024-36931 CVE-2024-36934 CVE-2024-36935 CVE-2024-36936 CVE-2024-36937
  CVE-2024-36938 CVE-2024-36939 CVE-2024-36940 CVE-2024-36941 CVE-2024-36942
  CVE-2024-36944 CVE-2024-36945 CVE-2024-36946 CVE-2024-36947 CVE-2024-36949
  CVE-2024-36950 CVE-2024-36951 CVE-2024-36952 CVE-2024-36955 CVE-2024-36957
  CVE-2024-36959 CVE-2024-36960 CVE-2024-36962 CVE-2024-36964 CVE-2024-36965
  CVE-2024-36967 CVE-2024-36969 CVE-2024-36970 CVE-2024-36971 CVE-2024-36972
  CVE-2024-36973 CVE-2024-36974 CVE-2024-36975 CVE-2024-36977 CVE-2024-36978
  CVE-2024-37021 CVE-2024-37078 CVE-2024-37353 CVE-2024-37354 CVE-2024-38381
  CVE-2024-38384 CVE-2024-38385 CVE-2024-38388 CVE-2024-38390 CVE-2024-38391
  CVE-2024-38539 CVE-2024-38540 CVE-2024-38541 CVE-2024-38543 CVE-2024-38544
  CVE-2024-38545 CVE-2024-38546 CVE-2024-38547 CVE-2024-38548 CVE-2024-38549
  CVE-2024-38550 CVE-2024-38551 CVE-2024-38552 CVE-2024-38553 CVE-2024-38554
  CVE-2024-38555 CVE-2024-38556 CVE-2024-38557 CVE-2024-38558 CVE-2024-38559
  CVE-2024-38560 CVE-2024-38562 CVE-2024-38563 CVE-2024-38564 CVE-2024-38565
  CVE-2024-38566 CVE-2024-38567 CVE-2024-38568 CVE-2024-38569 CVE-2024-38570
  CVE-2024-38571 CVE-2024-38572 CVE-2024-38573 CVE-2024-38575 CVE-2024-38578
  CVE-2024-38579 CVE-2024-38580 CVE-2024-38581 CVE-2024-38582 CVE-2024-38583
  CVE-2024-38586 CVE-2024-38587 CVE-2024-38588 CVE-2024-38590 CVE-2024-38591
  CVE-2024-38592 CVE-2024-38594 CVE-2024-38595 CVE-2024-38597 CVE-2024-38598
  CVE-2024-38599 CVE-2024-38600 CVE-2024-38601 CVE-2024-38602 CVE-2024-38603
  CVE-2024-38604 CVE-2024-38605 CVE-2024-38608 CVE-2024-38609 CVE-2024-38610
  CVE-2024-38611 CVE-2024-38615 CVE-2024-38616 CVE-2024-38617 CVE-2024-38618
  CVE-2024-38619 CVE-2024-38621 CVE-2024-38622 CVE-2024-38627 CVE-2024-38628
  CVE-2024-38629 CVE-2024-38630 CVE-2024-38633 CVE-2024-38634 CVE-2024-38635
  CVE-2024-38636 CVE-2024-38659 CVE-2024-38661 CVE-2024-38663 CVE-2024-38664
  CVE-2024-38780 CVE-2024-39276 CVE-2024-39277 CVE-2024-39291 CVE-2024-39296
  CVE-2024-39301 CVE-2024-39362 CVE-2024-39371 CVE-2024-39463 CVE-2024-39466
  CVE-2024-39468 CVE-2024-39469 CVE-2024-39471 CVE-2024-39472 CVE-2024-39473
  CVE-2024-39474 CVE-2024-39475 CVE-2024-39479 CVE-2024-39481 CVE-2024-39482
  CVE-2024-39483 CVE-2024-39484 CVE-2024-39486 CVE-2024-39487 CVE-2024-39488
  CVE-2024-39490 CVE-2024-39491 CVE-2024-39493 CVE-2024-39494 CVE-2024-39496
  CVE-2024-39497 CVE-2024-39498 CVE-2024-39499 CVE-2024-39500 CVE-2024-39501
  CVE-2024-39502 CVE-2024-39504 CVE-2024-39505 CVE-2024-39506 CVE-2024-39507
  CVE-2024-39508 CVE-2024-39509 CVE-2024-40900 CVE-2024-40901 CVE-2024-40902
  CVE-2024-40903 CVE-2024-40904 CVE-2024-40906 CVE-2024-40908 CVE-2024-40909
  CVE-2024-40910 CVE-2024-40911 CVE-2024-40912 CVE-2024-40916 CVE-2024-40919
  CVE-2024-40922 CVE-2024-40923 CVE-2024-40924 CVE-2024-40925 CVE-2024-40926
  CVE-2024-40927 CVE-2024-40928 CVE-2024-40929 CVE-2024-40930 CVE-2024-40931
  CVE-2024-40932 CVE-2024-40934 CVE-2024-40935 CVE-2024-40936 CVE-2024-40937
  CVE-2024-40940 CVE-2024-40941 CVE-2024-40942 CVE-2024-40943 CVE-2024-40944
  CVE-2024-40945 CVE-2024-40947 CVE-2024-40948 CVE-2024-40953 CVE-2024-40954
  CVE-2024-40956 CVE-2024-40957 CVE-2024-40958 CVE-2024-40959 CVE-2024-40960
  CVE-2024-40961 CVE-2024-40962 CVE-2024-40964 CVE-2024-40966 CVE-2024-40967
  CVE-2024-40970 CVE-2024-40972 CVE-2024-40975 CVE-2024-40976 CVE-2024-40977
  CVE-2024-40978 CVE-2024-40979 CVE-2024-40981 CVE-2024-40982 CVE-2024-40984
  CVE-2024-40987 CVE-2024-40988 CVE-2024-40989 CVE-2024-40990 CVE-2024-40992
  CVE-2024-40994 CVE-2024-40995 CVE-2024-40997 CVE-2024-40998 CVE-2024-40999
  CVE-2024-41000 CVE-2024-41001 CVE-2024-41002 CVE-2024-41004 CVE-2024-41006
  CVE-2024-41009 CVE-2024-41010 CVE-2024-41011 CVE-2024-41013 CVE-2024-41014
  CVE-2024-41015 CVE-2024-41016 CVE-2024-41017 CVE-2024-41032 CVE-2024-41036
  CVE-2024-41040 CVE-2024-41041 CVE-2024-41044 CVE-2024-41045 CVE-2024-41048
  CVE-2024-41057 CVE-2024-41058 CVE-2024-41059 CVE-2024-41064 CVE-2024-41066
  CVE-2024-41068 CVE-2024-41069 CVE-2024-41070 CVE-2024-41076 CVE-2024-41078
  CVE-2024-41081 CVE-2024-41087 CVE-2024-41090 CVE-2024-41091 CVE-2024-42070
  CVE-2024-42073 CVE-2024-42079 CVE-2024-42082 CVE-2024-42093 CVE-2024-42095
  CVE-2024-42096 CVE-2024-42105 CVE-2024-42107 CVE-2024-42110 CVE-2024-42113
  CVE-2024-42122 CVE-2024-42124 CVE-2024-42138 CVE-2024-42139 CVE-2024-42142
  CVE-2024-42145 CVE-2024-42147 CVE-2024-42148 CVE-2024-42161 CVE-2024-42162
  CVE-2024-42224 CVE-2023-34324 CVE-2024-26760
  jsc#PED-1117 jsc#PED-2006 jsc#PED-3039 jsc#PED-3184
  jsc#PED-3186 jsc#PED-3289 jsc#PED-3309 jsc#PED-3311 jsc#PED-3317 jsc#PED-3526
  jsc#PED-3527 jsc#PED-3535 jsc#PED-3545 jsc#PED-3594 jsc#PED-3616 jsc#PED-3637
  jsc#PED-3750 jsc#PED-4075 jsc#PED-4082 jsc#PED-4102 jsc#PED-4114 jsc#PED-4126
  jsc#PED-4296 jsc#PED-4486 jsc#PED-4593 jsc#PED-4647 jsc#PED-4696 jsc#PED-4698
  jsc#PED-4733 jsc#PED-4736 jsc#PED-4747 jsc#PED-4860 jsc#PED-4862 jsc#PED-4866
  jsc#PED-4868 jsc#PED-4872 jsc#PED-4874 jsc#PED-4876 jsc#PED-4897 jsc#PED-4901
  jsc#PED-4927 jsc#PED-4929 jsc#PED-4937 jsc#PED-4961 jsc#PED-5021 jsc#PED-5057
  jsc#PED-5059 jsc#PED-5062 jsc#PED-5063 jsc#PED-5064 jsc#PED-5065 jsc#PED-5067
  jsc#PED-5077 jsc#PED-5083 jsc#PED-5085 jsc#PED-5089 jsc#PED-5091 jsc#PED-5122
  jsc#PED-5174 jsc#PED-5417 jsc#PED-542 jsc#PED-5433 jsc#PED-5436 jsc#PED-5439
  jsc#PED-5441 jsc#PED-5452 jsc#PED-5453 jsc#PED-5458 jsc#PED-5460 jsc#PED-5475
  jsc#PED-5477 jsc#PED-5484 jsc#PED-5505 jsc#PED-5511 jsc#PED-5524 jsc#PED-5525
  jsc#PED-5555 jsc#PED-5557 jsc#PED-5728 jsc#PED5728 jsc#PED-5734 jsc#PED-5736
  jsc#PED-5742 jsc#PED-5759 jsc#PED-5816 jsc#PED-5824 jsc#PED-5853 jsc#PED-5859
  jsc#PED-5861 jsc#PED-5873 jsc#PED-6007 jsc#PED-6008 jsc#PED-6010 jsc#PED-6012
  jsc#PED-6014 jsc#PED-6016 jsc#PED-6018 jsc#PED-6023 jsc#PED-6028 jsc#PED-6036
  jsc#PED-6037 jsc#PED-6040 jsc#PED-6041 jsc#PED-6045 jsc#PED-6048 jsc#PED-6054
  jsc#PED-6055 jsc#PED-6056 jsc#PED-6057 jsc#PED-6061 jsc#PED-6065 jsc#PED-6067
  jsc#PED-6068 jsc#PED-6069 jsc#PED-6070 jsc#PED-6071 jsc#PED-6079 jsc#PED-6081
  jsc#PED-6090 jsc#PED-6091 jsc#PED-6104 jsc#PED-6105 jsc#PED-6106 jsc#PED-6107
  jsc#PED-6113 jsc#PED-6114 jsc#PED-6116 jsc#PED-6118 jsc#PED-6120 jsc#PED-6121
  jsc#PED-6123 jsc#PED-6124 jsc#PED-6127 jsc#PED-6130 jsc#PED-6143 jsc#PED-6156
  jsc#PED-6252 jsc#PED-6254 jsc#PED-6316 jsc#PED-6319 jsc#PED-6371 jsc#PED-6375
  jsc#PED-6384 jsc#PED-6469 jsc#PED-6528 jsc#PED-6716 jsc#PED-6719 jsc#PED-6721
  jsc#PED-6741 jsc#PED-6747 jsc#PED-6811 jsc#PED-6831 jsc#PED-6833 jsc#PED-6835
  jsc#PED-6864 jsc#PED-6866 jsc#PED-6874 jsc#PED-6875 jsc#PED-6876 jsc#PED-6878
  jsc#PED-6881 jsc#PED-6884 jsc#PED-6886 jsc#PED-6887 jsc#PED-6894 jsc#PED-6930
  jsc#PED-6931 jsc#PED-6936 jsc#PED-6937 jsc#PED-6951 jsc#PED-6953 jsc#PED-6954
  jsc#PED-7009 jsc#PED-7167 jsc#PED-7238 jsc#PED-7249 jsc#PED-7322 jsc#PED-7377
  jsc#PED-7382 jsc#PED-7477 jsc#PED-7513 jsc#PED-7514 jsc#PED-7520 jsc#PED-7542
  jsc#PED-7574 jsc#PED-7581 jsc#PED-7600 jsc#PED-7618 jsc#PED-7619 jsc#PED-7622
  jsc#PED-7623 jsc#PED-7689 jsc#PED-7779 jsc#PED-7780 jsc#PED-7785 jsc#PED-7786
  jsc#PED-7789 jsc#PED-7793 jsc#PED-7859 jsc#PED-7888 jsc#PED-7970 jsc#PED-8032
  jsc#PED-8065 jsc#PED-8111 jsc#PED-8240 jsc#PED-8491 jsc#PED-8570 jsc#PED-8644
  jsc#PED-8688 jsc#PED-8701 jsc#PED-8954 jsc#PED-949 jsc#PED-962 jsc#SES-1880
  jsc#SLE-12908 ltc#189159 ltc#193451 ltc#197503 ltc#199106 ltc#200161
  ltc#200588 ltc#202097 ltc#202582 ltc#202733 ltc#203238 LTC#203629 ltc#203927
  LTC#203998 ltc#204476 ltc#204477 ltc#204519 ltc#204523 ltc#204570 ltc#205270
  ltc#205305 ltc#205683 ltc#205739 ltc#205740 ltc#205770 ltc#205888 ltc#205900
  XSA-432 XSA-441, XSA-448
  The old log contained also an incorrect reference, CVE-2024-267600
* Thu Aug  8 2024 mvetter@suse.com
- config.sh: generate and install compile_commands.json (bsc#1228971)
  This file contains the command line options used to compile every C file.
  It's useful for the livepatching team.
- kernel-binary: generate and install compile_commands.json (bsc#1228971)
  This file contains the command line options used to compile every C file.
  It's useful for the livepatching team.
- commit 15eff3e
* Wed Aug  7 2024 sjaeckel@suse.de
- tcp: avoid too many retransmit packets (CVE-2024-41007
  bsc#1227863).
- commit 8f47fe6
* Tue Aug  6 2024 davide.benini@suse.com
- tipc: force a dst refcount before doing decryption (CVE-2024-40983 bsc#1227819).
- commit cee1bad
* Tue Aug  6 2024 jgross@suse.com
- KVM: x86/mmu: fix determination of max NPT mapping level for
  private pages (git-fixes).
- commit cc71c2c
* Mon Aug  5 2024 dwagner@suse.de
- kabi/severity: add nvme common code
  The nvme common code is also allowed to change the data structures, there
  are only internal users.
- commit 3abdbd5
* Fri Aug  2 2024 dbond@suse.com
- nvme_core: scan namespaces asynchronously (bsc#1224105).
- commit e6f41be
* Fri Aug  2 2024 sjaeckel@suse.de
- net: wwan: iosm: Fix tainted pointer delete is case of region
  creation fail (CVE-2024-40939 bsc#1227799).
- commit 0b93a9f
* Fri Aug  2 2024 sjaeckel@suse.de
- nsh: Restore skb->{protocol,data,mac_header} for outer header
  in nsh_gso_segment() (CVE-2024-36933 bsc#1225832).
- commit 6740d82
* Fri Aug  2 2024 sjaeckel@suse.de
- net: core: reject skb_copy(_expand) for fraglist GSO skbs
  (CVE-2024-36929 bsc#1225814).
- commit e49ed10
* Mon Jul 29 2024 sjaeckel@suse.de
- netlink: add nla be16/32 types to minlen array (CVE-2024-26849
  bsc#1223053).
- commit 2747893
* Fri Jul 26 2024 jroedel@suse.de
- blacklist.conf: Add "mm, virt: merge AS_UNMOVABLE and AS_INACCESSIBLE"
- commit 9155db2
* Fri Jul 26 2024 jroedel@suse.de
- KVM: interrupt kvm_gmem_populate() on signals (jsc#PED-5122).
- KVM: SEV: Don't WARN() if RMP lookup fails when invalidating
  gmem pages (jsc#PED-5122).
- commit 83c7177
* Fri Jul 26 2024 jroedel@suse.de
- KVM: x86/mmu: check for invalid async page faults involving
  private memory (jsc#PED-5122).
- Refresh
  patches.suse/kabi-placeholders-for-coco-host-support.patch.
- commit 8ffcad3
* Fri Jul 26 2024 jroedel@suse.de
- KVM: x86: Fully re-initialize supported_vm_types on vendor
  module load (jsc#PED-5122).
- Refresh
  patches.suse/KVM-x86-Fully-re-initialize-supported_mce_cap-on-ven.patch.
- commit 928d5b0
* Fri Jul 26 2024 jroedel@suse.de
- KVM: SEV: sync FPU and AVX state at LAUNCH_UPDATE_VMSA time
  (jsc#PED-5122).
- Refresh
  patches.suse/KVM-SEV-ES-Delegate-LBR-virtualization-to-the-proces.patch.
- commit f5d649f
* Fri Jul 26 2024 jroedel@suse.de
- KVM: x86: Add supported_vm_types to kvm_caps (jsc#PED-5122).
- Refresh
  patches.suse/KVM-x86-Fully-re-initialize-supported_mce_cap-on-ven.patch.
- commit 8e54974
* Fri Jul 26 2024 jroedel@suse.de
- crypto: ccp: Add the SNP_VLEK_LOAD command (jsc#PED-5122).
- KVM: SEV: Provide support for SNP_EXTENDED_GUEST_REQUEST NAE
  event (jsc#PED-5122).
- KVM: SEV: Provide support for SNP_GUEST_REQUEST NAE event
  (jsc#PED-5122).
- KVM: SNP: Fix LBR Virtualization for SNP guest (jsc#PED-5122).
- KVM: SVM: Add module parameter to enable SEV-SNP (jsc#PED-5122).
- KVM: SEV: Avoid WBINVD for HVA-based MMU notifications for SNP
  (jsc#PED-5122).
- KVM: x86: Implement hook for determining max NPT mapping level
  (jsc#PED-5122).
- KVM: SEV: Support SEV-SNP AP Creation NAE event (jsc#PED-5122).
- KVM: SEV: Add support to handle RMP nested page faults
  (jsc#PED-5122).
- KVM: SEV: Add support to handle Page State Change VMGEXIT
  (jsc#PED-5122).
- KVM: SEV: Add support to handle MSR based Page State Change
  VMGEXIT (jsc#PED-5122).
- KVM: SEV: Add support to handle GHCB GPA register VMGEXIT
  (jsc#PED-5122).
- KVM: SEV: Add KVM_SEV_SNP_LAUNCH_FINISH command (jsc#PED-5122).
- KVM: SEV: Add KVM_SEV_SNP_LAUNCH_UPDATE command (jsc#PED-5122).
- KVM: SEV: Add KVM_SEV_SNP_LAUNCH_START command (jsc#PED-5122).
- KVM: SEV: Add initial SEV-SNP support (jsc#PED-5122).
- KVM: SEV: Select KVM_GENERIC_PRIVATE_MEM when
  CONFIG_KVM_AMD_SEV=y (jsc#PED-5122).
- KVM: MMU: Disable fast path if KVM_EXIT_MEMORY_FAULT is needed
  (jsc#PED-5122).
- KVM: x86: Add hook for determining max NPT mapping level
  (jsc#PED-5122).
- KVM: guest_memfd: Add hook for invalidating memory
  (jsc#PED-5122).
- KVM: guest_memfd: Add interface for populating gmem pages with
  user data (jsc#PED-5122).
- KVM: guest_memfd: extract __kvm_gmem_get_pfn() (jsc#PED-5122).
- KVM: guest_memfd: Add hook for initializing memory
  (jsc#PED-5122).
- KVM: guest_memfd: limit overzealous WARN (jsc#PED-5122).
- KVM: guest_memfd: pass error up from filemap_grab_folio
  (jsc#PED-5122).
- KVM: guest_memfd: Use AS_INACCESSIBLE when creating guest_memfd
  inode (jsc#PED-5122).
- mm: Introduce AS_INACCESSIBLE for encrypted/confidential memory
  (jsc#PED-5122).
- KVM: x86/mmu: Don't save mmu_invalidate_seq after checking
  private attr (jsc#PED-5122).
- KVM: SEV: Allow per-guest configuration of GHCB protocol version
  (jsc#PED-5122).
- KVM: SEV: Add GHCB handling for termination requests
  (jsc#PED-5122).
- KVM: SEV: Add GHCB handling for Hypervisor Feature Support
  requests (jsc#PED-5122).
- KVM: SEV: Add support to handle AP reset MSR protocol
  (jsc#PED-5122).
- KVM: x86/mmu: Sanity check that __kvm_faultin_pfn() doesn't
  create noslot pfns (jsc#PED-5122).
- KVM: x86/mmu: Initialize kvm_page_fault's pfn and hva to error
  values (jsc#PED-5122).
- KVM: x86/mmu: Set kvm_page_fault.hva to KVM_HVA_ERR_BAD for
  "no slot" faults (jsc#PED-5122).
- KVM: x86/mmu: Handle no-slot faults at the beginning of
  kvm_faultin_pfn() (jsc#PED-5122).
- KVM: x86/mmu: Move slot checks from __kvm_faultin_pfn() to
  kvm_faultin_pfn() (jsc#PED-5122).
- KVM: x86/mmu: Explicitly disallow private accesses to emulated
  MMIO (jsc#PED-5122).
- KVM: x86/mmu: WARN and skip MMIO cache on private, reserved
  page faults (jsc#PED-5122).
- KVM: x86/mmu: Use synthetic page fault error code to indicate
  private faults (jsc#PED-5122).
- KVM: x86/mmu: WARN if upper 32 bits of legacy #PF error code
  are non-zero (jsc#PED-5122).
- KVM: x86/mmu: Pass full 64-bit error code when handling page
  faults (jsc#PED-5122).
- KVM: x86: Move synthetic PFERR_* sanity checks to SVM's #NPF
  handler (jsc#PED-5122).
- KVM: x86: Define more SEV+ page fault error bits/flags for #NPF
  (jsc#PED-5122).
- KVM: x86: Remove separate "bit" defines for page fault error
  code masks (jsc#PED-5122).
- KVM: x86/mmu: Exit to userspace with -EFAULT if private fault
  hits emulation (jsc#PED-5122).
- KVM: SEV: introduce KVM_SEV_INIT2 operation (jsc#PED-5122).
- KVM: SEV: define VM types for SEV and SEV-ES (jsc#PED-5122).
- KVM: SEV: introduce to_kvm_sev_info (jsc#PED-5122).
- KVM: x86: add fields to struct kvm_arch for CoCo features
  (jsc#PED-5122).
- KVM: SEV: store VMSA features in kvm_sev_info (jsc#PED-5122).
- KVM: SEV: publish supported VMSA features (jsc#PED-5122).
- KVM: introduce new vendor op for KVM_GET_DEVICE_ATTR
  (jsc#PED-5122).
- KVM: x86: use u64_to_user_ptr() (jsc#PED-5122).
- KVM: SVM: Compile sev.c if and only if CONFIG_KVM_AMD_SEV=y
  (jsc#PED-5122).
- KVM: SVM: Invert handling of SEV and SEV_ES feature flags
  (jsc#PED-5122).
- x86/CPU/AMD: Track SNP host status with cc_platform_*()
  (jsc#PED-5122).
- x86/cc: Add cc_platform_set/_clear() helpers (jsc#PED-5122).
- commit 8b9927e
* Wed Jul 24 2024 sjaeckel@suse.de
- net/rds: fix WARNING in rds_conn_connect_if_down (CVE-2024-27024
  bsc#1223777).
- commit 466c800
* Tue Jul  2 2024 dwagner@suse.de
- blk-mq: add helper for checking if one CPU is mapped to
  specified hctx (bsc#1223600).
- blk-mq: don't schedule block kworker on isolated CPUs
  (bsc#1223600).
- commit 2b67848
* Fri Jun 14 2024 ematsumiya@suse.de
- smb: client: fix use-after-free bug in
  cifs_debug_data_proc_show() (bsc#1225487, CVE-2023-52752).
- commit c4e1b53
* Fri May 10 2024 msuchanek@suse.de
- Update ppc64le config files (bsc#1223982).
  drop support for agpgart, there is no driver enabled
  drop support for pinctrl and backlight drivers, these are not used
  drop support for auxiliary display, none is exposed
  drop support for i2c leds, timers, multiplexors, watchdogs, displays, HID - these are not used
  drop support for PC CMOS rtc, there is rtc_opal and rtc_generic
  drop support for platform-specific DMA found on other platforms
  drop support for SoC-specific PWM, USB, PCI, gpio, and clk drivers
  drop support for DSA
- commit 1f4aae4
* Fri Oct 20 2023 ohering@suse.de
- README.BRANCH: Update to SLE15 SP7 AZURE
- commit 1b464b6
* Fri Jul 14 2023 tiwai@suse.de
- Please note: To save space, changelog entries from prior to the
  SLE15-SP6 kernel rebase (to v6.4) have been removed at the commit
  b35e0a62edf4. Listed below are the Bugzilla/CVE/Jira references
  from the deleted changelog entries (typos included).
  The full text for these removed entries can be found in
    /usr/share/doc/packages/kernel-docs/old_changelog.txt
  from the kernel-docs package:
  bsc#158563 boo#173030 bsc#178378 bsc#182715 bsc#182716 bsc#182717
  bsc#185032 bnc#464461 bsc#464461 bnc#754690 bnc#814005 bnc#854875
  bsc#865869 bsc#873195 bsc#927455 bsc#951844 bsc#954532 bsc#962720
  bsc#964063 bsc#974406 bnc#981838 bsc#981838 bnc#1012628 bsc#1012628
  bnc#1018348 bsc#1020657 bsc#1023051 bsc#1024015 bsc#1024412 boo#1027378
  boo#1029158 bsc#1032323 boo#1039806 bsc#1040020 bsc#1040364 bsc#1040855
  bsc#1043990 bsc#1044120 bsc#1044767 bsc#1047233 bsc#1048129 bsc#1048585
  bsc#1048934 bnc#1048935 bsc#1050582 bsc#1051510 bsc#1053501 bsc#1053802
  bsc#1054239 bsc#1054610 bsc#1055013 bsc#1055014 bsc#1055117 bsc#1055186
  bsc#1055817 bsc#1055826 bsc#1056427 bsc#1056588 bsc#1056686 bsc#1056979
  bsc#1057199 bnc#1057389 bnc#1058115 bsc#1058115 bsc#1058410 bsc#1059807
  bsc#1060333 bsc#1061593 bsc#1061840 bsc#1061843 boo#1062303 bsc#1062597
  bsc#1063667 bnc#1064414 bsc#1064414 bnc#1064590 boo#1065536 bsc#1065600
  bsc#1065729 bnc#1066110 bsc#1066369 bsc#1066382 bsc#1066573 bsc#1066606
  bnc#1066845 bsc#1067087 bsc#1067105 bsc#1067494 bsc#1067593 bnc#1068032
  bsc#1068032 boo#1068256 bsc#1068680 bnc#1068877 bnc#1069562 bnc#1069605
  boo#1069828 boo#1069830 bsc#1071995 boo#1072032 boo#1073193 bsc#1073579
  bsc#1073836 boo#1076393 bsc#1076905 bsc#1077428 bsc#1077692 bsc#1078019
  bsc#1078248 bsc#1078720 bsc#1078788 bsc#1079747 boo#1080250 boo#1080435
  bsc#1080449 bsc#1080813 bsc#1081134 boo#1081473 bsc#1082504 bsc#1082555
  bsc#1082635 bnc#1082905 bsc#1083215 bsc#1083527 bsc#1083694 bsc#1084332
  bsc#1084610 bsc#1084620 bsc#1085030 bsc#1085174 bsc#1085224 bsc#1085308
  bsc#1085996 bsc#1087082 bsc#1088640 bsc#1089086 bsc#1089644 bsc#1089764
  bsc#1090162 bsc#1090717 bsc#1091041 bsc#1091101 bsc#1092456 bnc#1092466
  bsc#1093118 bsc#1094244 bsc#1094840 bsc#1095042 boo#1095717 bsc#1097593
  boo#1098050 bnc#1098392 bsc#1098626 bsc#1098995 bsc#1099078 bsc#1099745
  bsc#1099924 bsc#1100944 bsc#1101465 bsc#1103269 bsc#1103636 boo#1104529
  bsc#1104708 boo#1104833 bsc#1105536 bsc#1105672 bsc#1106061 bsc#1106751
  bsc#1107829 bsc#1107870 bsc#1108281 bsc#1108533 bsc#1109137 bsc#1109158
  boo#1109665 bsc#1109695 bsc#1110716 bsc#1111183 bsc#1112504 bsc#1113295
  bsc#1113399 bsc#1114523 boo#1114846 bsc#1115431 bsc#1116448 bsc#1116724
  bsc#1117016 bsc#1117665 bsc#1118212 bsc#1118338 bsc#1119838 bsc#1119846
  bsc#1119861 bsc#1120163 bsc#1120853 bsc#1121726 bsc#1123015 bsc#1123317
  bsc#1123348 bsc#1123697 bsc#1124167 bsc#1124235 bsc#1124431 bsc#1125004
  bsc#1125580 bsc#1125907 bsc#1127155 boo#1127188 bsc#1127188 bsc#1127339
  bsc#1127552 bsc#1127650 bnc#1127808 bsc#1127808 bsc#1127886 bsc#1128045
  bnc#1128245 bsc#1128910 bsc#1129551 bsc#1129923 bsc#1130365 boo#1130448
  bsc#1131107 bsc#1131437 boo#1132154 bsc#1132477 bsc#1133021 bsc#1133147
  bsc#1133401 bsc#1133945 boo#1134303 bsc#1134760 bsc#1134906 bnc#1135217
  bsc#1135333 bsc#1135481 bnc#1135646 bsc#1135854 bnc#1135868 bsc#1135966
  bsc#1135967 bsc#1136157 bsc#1136666 bsc#1136922 bsc#1137325 bsc#1137361
  bsc#1137586 bsc#1137625 bnc#1137686 bsc#1137728 bsc#1138374 boo#1138496
  bsc#1138496 boo#1139244 bsc#1139944 bsc#1140025 bsc#1140221 bsc#1140494
  bsc#1141340 bsc#1141456 bsc#1141558 bsc#1141600 bsc#1142019 bsc#1142095
  bsc#1142685 bsc#1142701 bsc#1143706 bsc#1143841 bsc#1143959 bsc#1144123
  bsc#1144168 bnc#1144446 bsc#1144653 bsc#1144700 boo#1144723 bsc#1144903
  bnc#1144943 bsc#1144943 bsc#1145929 boo#1146026 bsc#1146352 bsc#1146368
  bsc#1146378 bsc#1146512 bsc#1146514 bsc#1146516 bsc#1146539 bsc#1146540
  bsc#1146543 bnc#1147116 bsc#1148030 bsc#1148712 bsc#1148868 bsc#1149032
  bsc#1149119 bsc#1149313 bsc#1149652 bsc#1149713 bsc#1149940 bsc#1150305
  bsc#1150423 bsc#1150452 bsc#1150457 bsc#1150465 bsc#1150466 bsc#1150577
  bsc#1150727 bsc#1150846 bsc#1150850 bnc#1150875 bsc#1151192 bsc#1151225
  bsc#1151508 bsc#1151674 bsc#1151675 bsc#1151676 bsc#1151677 bsc#1151678
  bsc#1151679 bsc#1151680 bsc#1151794 bnc#1151927 bsc#1151927 bsc#1152109
  bsc#1152148 bsc#1152161 bsc#1152187 bsc#1152243 bsc#1152457 bsc#1152472
  bsc#1152489 bsc#1152525 bsc#1152624 bsc#1152631 bsc#1152879 bsc#1152885
  bsc#1152932 bsc#1152972 bsc#1152973 bsc#1152974 bsc#1152975 bsc#1153013
  bsc#1153112 bsc#1153137 bsc#1153158 bsc#1153192 bsc#1153217 bsc#1153274
  bsc#1153275 bsc#1153535 bsc#1153713 bsc#1153917 bsc#1153954 bsc#1153955
  bsc#1153956 bsc#1153957 bsc#1153962 bsc#1153963 bsc#1153964 bsc#1153965
  bnc#1153969 bsc#1154010 bsc#1154043 bsc#1154208 bsc#1154242 bsc#1154268
  bsc#1154329 bsc#1154353 bsc#1154354 bsc#1154355 bsc#1154372 bsc#1154395
  bsc#1154488 bsc#1154492 bsc#1154536 boo#1154578 bsc#1154617 bsc#1154619
  bsc#1154624 bsc#1154625 bsc#1154626 bsc#1154627 bsc#1154628 bsc#1154629
  bsc#1154630 bsc#1154631 bsc#1154632 bsc#1154633 bsc#1154634 bsc#1154635
  bsc#1154636 bsc#1154637 bsc#1154772 bsc#1154776 bsc#1154824 bnc#1154866
  bsc#1155178 bsc#1155179 bsc#1155184 bsc#1155186 bsc#1155364 bsc#1155518
  bnc#1155628 bsc#1155689 bnc#1155756 bnc#1155780 bnc#1155798 bsc#1155798
  bsc#1155836 bsc#1155897 bnc#1155921 bsc#1156043 bsc#1156055 bsc#1156256
  bsc#1156258 bsc#1156259 bsc#1156277 bsc#1156278 bsc#1156315 bsc#1156395
  bsc#1156419 bsc#1156466 bsc#1156494 bsc#1156510 bnc#1156537 bsc#1156538
  bsc#1156561 bsc#1156632 bsc#1156700 bsc#1156773 bsc#1156782 bsc#1156882
  bsc#1156898 bsc#1156919 bsc#1156954 bsc#1157032 bsc#1157038 bsc#1157042
  bsc#1157044 bsc#1157045 bsc#1157046 bsc#1157049 bsc#1157064 bsc#1157067
  bsc#1157069 bsc#1157070 bsc#1157115 bsc#1157143 bsc#1157145 bsc#1157155
  bsc#1157157 bsc#1157158 bsc#1157160 bsc#1157162 bsc#1157169 bsc#1157171
  bsc#1157173 bsc#1157177 bsc#1157178 bsc#1157180 bsc#1157191 bsc#1157192
  bsc#1157193 bsc#1157197 bsc#1157294 bsc#1157298 bsc#1157300 bsc#1157303
  bsc#1157304 bsc#1157307 bsc#1157319 bsc#1157324 bsc#1157333 bsc#1157336
  bsc#1157424 bsc#1157480 bsc#1157698 bsc#1157715 bsc#1157717 bsc#1157720
  bsc#1157774 bsc#1157778 bnc#1157813 bsc#1157923 bsc#1157966 bsc#1158013
  bsc#1158050 bsc#1158055 bsc#1158071 bsc#1158107 bsc#1158193 bsc#1158210
  bsc#1158242 bsc#1158265 bsc#1158279 bsc#1158370 bsc#1158371 bsc#1158373
  bsc#1158374 bsc#1158376 bsc#1158378 bsc#1158380 bsc#1158381 bsc#1158383
  bsc#1158389 bsc#1158398 bsc#1158407 bsc#1158413 bsc#1158417 bsc#1158451
  bsc#1158454 bsc#1158455 bsc#1158456 bsc#1158457 bsc#1158458 bsc#1158459
  bsc#1158460 bsc#1158632 bsc#1158633 bsc#1158746 bnc#1158748 bsc#1158748
  bsc#1158749 bsc#1158751 bsc#1158753 bnc#1158765 bsc#1158765 bsc#1158775
  bsc#1158776 bsc#1158811 bsc#1158819 bsc#1158824 bsc#1158827 bsc#1158834
  bsc#1158887 bsc#1158893 bsc#1158954 bsc#1158962 bsc#1158983 bsc#1159024
  bsc#1159037 bsc#1159058 bsc#1159152 bsc#1159198 bsc#1159271 bsc#1159280
  bsc#1159281 bsc#1159285 bsc#1159297 bsc#1159370 bsc#1159374 bsc#1159375
  bsc#1159441 bsc#1159455 bsc#1159484 bsc#1159519 bsc#1159522 bsc#1159523
  bsc#1159535 bsc#1159537 bsc#1159555 bsc#1159588 bsc#1159592 bsc#1159594
  bsc#1159662 bsc#1159717 bnc#1159781 bsc#1159811 bsc#1159816 bsc#1159864
  bsc#1159867 bsc#1159886 bsc#1159889 bsc#1159911 bsc#1159929 bsc#1159949
  bsc#1159955 bsc#1159986 bsc#1160010 bsc#1160018 bsc#1160067 bsc#1160102
  bsc#1160135 bsc#1160136 bsc#1160137 bsc#1160138 bsc#1160139 bsc#1160140
  bsc#1160141 bsc#1160142 bsc#1160143 bsc#1160195 bsc#1160214 bsc#1160215
  bsc#1160218 bsc#1160227 bsc#1160228 bsc#1160229 bsc#1160231 bsc#1160310
  bsc#1160311 bsc#1160320 bsc#1160366 bsc#1160388 bsc#1160435 bsc#1160442
  bsc#1160461 bsc#1160508 bsc#1160561 bsc#1160609 bsc#1160632 bsc#1160634
  bsc#1160647 bsc#1160659 bsc#1160750 bsc#1160751 bsc#1160752 bsc#1160784
  bsc#1160787 bsc#1160794 bsc#1160803 bsc#1160804 bsc#1160831 bnc#1160896
  bsc#1160947 bsc#1160977 bsc#1160979 bsc#1161073 bsc#1161099 bsc#1161154
  bsc#1161207 bsc#1161291 boo#1161305 boo#1161360 bsc#1161428 bsc#1161495
  bsc#1161518 bsc#1161520 bsc#1161549 bnc#1161692 bsc#1161692 bsc#1161695
  bsc#1161720 bsc#1161726 bsc#1161731 bsc#1161785 bsc#1161889 bsc#1161907
  bsc#1161930 bsc#1161931 bsc#1161934 bsc#1161935 bsc#1161936 bsc#1161937
  bsc#1161943 bsc#1161948 bsc#1161951 bsc#1162002 bsc#1162028 bsc#1162063
  bsc#1162067 bsc#1162109 bsc#1162209 bsc#1162393 bsc#1162400 bsc#1162414
  bnc#1162503 bsc#1162557 bnc#1162576 bsc#1162583 bsc#1162590 bsc#1162684
  bsc#1162702 bsc#1162831 bnc#1162928 bsc#1162929 bsc#1162931 bsc#1162943
  bsc#1163036 bsc#1163206 bsc#1163335 bsc#1163383 bsc#1163384 bsc#1163388
  bsc#1163403 bsc#1163419 bsc#1163458 bsc#1163459 bsc#1163463 bsc#1163493
  bsc#1163496 bsc#1163521 bsc#1163524 bsc#1163560 bsc#1163592 bsc#1163617
  bsc#1163727 bsc#1163762 bsc#1163774 bsc#1163776 bsc#1163836 bsc#1163838
  bsc#1163843 bsc#1163850 bsc#1163852 bsc#1163853 bsc#1163855 bsc#1163856
  bsc#1163867 bsc#1163869 bsc#1163880 bsc#1163891 bsc#1163892 bsc#1163893
  bsc#1163894 bsc#1163896 bsc#1163897 bsc#1163898 bsc#1163899 bsc#1163901
  bsc#1163902 bsc#1163904 bsc#1163905 bsc#1163907 bsc#1163909 bsc#1163910
  bsc#1163911 bsc#1163912 bsc#1163913 bsc#1163915 bsc#1163916 bsc#1163917
  bsc#1163918 bsc#1163919 bsc#1163920 bsc#1163921 bsc#1163930 bsc#1163971
  bsc#1163984 bsc#1163988 bsc#1164051 bsc#1164069 bsc#1164094 bsc#1164095
  bsc#1164118 bsc#1164141 bsc#1164146 bsc#1164147 bsc#1164148 bsc#1164149
  bsc#1164150 bsc#1164151 bsc#1164152 bsc#1164153 bsc#1164154 bsc#1164155
  bsc#1164156 bsc#1164157 bsc#1164158 bsc#1164159 bsc#1164160 bsc#1164161
  bsc#1164162 bsc#1164163 bsc#1164164 bsc#1164165 bsc#1164166 bsc#1164167
  bsc#1164168 bsc#1164169 bsc#1164170 bsc#1164171 bsc#1164172 bsc#1164173
  bsc#1164174 bsc#1164175 bsc#1164176 bsc#1164177 bsc#1164178 bsc#1164179
  bsc#1164180 bsc#1164181 bsc#1164182 bsc#1164183 bsc#1164184 bsc#1164185
  bsc#1164186 bsc#1164194 bsc#1164195 bsc#1164196 bsc#1164197 bsc#1164198
  bsc#1164199 bsc#1164200 bsc#1164201 bsc#1164202 bsc#1164203 bsc#1164205
  bsc#1164206 bsc#1164208 bsc#1164209 bsc#1164210 bsc#1164211 bsc#1164212
  bsc#1164214 bsc#1164215 bsc#1164216 bsc#1164217 bsc#1164218 bsc#1164219
  bsc#1164220 bsc#1164221 bsc#1164254 bsc#1164268 bsc#1164272 bsc#1164276
  bsc#1164284 bsc#1164285 bsc#1164302 bsc#1164303 bsc#1164304 bsc#1164305
  bsc#1164306 bsc#1164307 bsc#1164308 bsc#1164328 bsc#1164329 bsc#1164330
  bsc#1164331 bsc#1164332 bsc#1164333 bsc#1164334 bsc#1164335 bsc#1164336
  bsc#1164337 bsc#1164338 bsc#1164339 bsc#1164340 bsc#1164342 bsc#1164343
  bsc#1164344 bsc#1164345 bsc#1164346 bsc#1164347 bsc#1164348 bsc#1164349
  bsc#1164350 bsc#1164351 bsc#1164352 bsc#1164353 bsc#1164354 bsc#1164355
  bsc#1164356 bsc#1164357 bsc#1164359 bsc#1164360 bsc#1164361 bsc#1164362
  bsc#1164363 bsc#1164364 bsc#1164365 bsc#1164366 bsc#1164367 bsc#1164368
  bsc#1164369 bsc#1164370 bsc#1164371 bsc#1164372 bsc#1164373 bsc#1164374
  bsc#1164375 bsc#1164376 bsc#1164377 bsc#1164378 bsc#1164379 bsc#1164380
  bsc#1164381 bsc#1164382 bsc#1164383 bsc#1164388 bsc#1164436 bsc#1164445
  bsc#1164446 bsc#1164461 bsc#1164471 bsc#1164482 bsc#1164514 bsc#1164534
  bsc#1164565 boo#1164632 bsc#1164648 bsc#1164711 bsc#1164722 bsc#1164777
  bsc#1164780 bsc#1164893 bsc#1164917 bsc#1164993 bsc#1165019 bsc#1165047
  bsc#1165102 bsc#1165111 bsc#1165167 bsc#1165181 bsc#1165187 bsc#1165211
  bsc#1165245 bsc#1165404 bsc#1165455 bsc#1165527 bsc#1165545 bsc#1165581
  bsc#1165618 bsc#1165629 bsc#1165692 bsc#1165741 bsc#1165806 bsc#1165807
  bsc#1165813 bsc#1165823 bsc#1165873 bsc#1165929 bsc#1165933 bsc#1165950
  bsc#1165954 bsc#1165975 bsc#1165980 bsc#1166003 bsc#1166091 bsc#1166132
  bsc#1166133 bsc#1166136 bsc#1166140 bsc#1166143 bsc#1166144 bsc#1166145
  bsc#1166146 bsc#1166147 bsc#1166149 bsc#1166152 bsc#1166153 bsc#1166154
  bsc#1166155 bsc#1166156 bsc#1166158 bsc#1166160 bsc#1166161 bsc#1166162
  bsc#1166164 bsc#1166166 bsc#1166226 bsc#1166323 bsc#1166340 bsc#1166486
  bsc#1166535 bsc#1166547 bsc#1166632 bsc#1166658 boo#1166664 bsc#1166685
  bsc#1166686 bsc#1166687 bsc#1166722 bsc#1166723 bsc#1166724 bsc#1166725
  bsc#1166726 bsc#1166727 bsc#1166728 bsc#1166729 bsc#1166769 bsc#1166772
  bsc#1166780 bsc#1166859 bsc#1166860 bsc#1166861 bsc#1166862 bsc#1166864
  bsc#1166866 bsc#1166867 bsc#1166868 bsc#1166870 bsc#1166871 bsc#1166872
  bsc#1166874 bsc#1166875 bsc#1166876 bsc#1166878 bsc#1166940 bsc#1166965
  bsc#1166969 bsc#1166982 bsc#1166985 bsc#1167030 bsc#1167032 bsc#1167104
  bsc#1167137 bsc#1167151 bsc#1167197 bsc#1167201 bsc#1167241 bsc#1167260
  bsc#1167288 bsc#1167338 bnc#1167384 bnc#1167415 bsc#1167421 bsc#1167423
  bsc#1167517 bsc#1167527 bsc#1167574 bsc#1167594 bsc#1167629 bsc#1167649
  bsc#1167650 bsc#1167651 bsc#1167657 bsc#1167722 bsc#1167765 bsc#1167769
  bsc#1167773 bsc#1167851 bsc#1167867 bsc#1167878 bsc#1167903 bsc#1168081
  bsc#1168202 bsc#1168230 bsc#1168236 bsc#1168297 bsc#1168354 bsc#1168423
  bsc#1168424 bsc#1168461 bsc#1168468 bsc#1168476 bsc#1168486 bsc#1168553
  bsc#1168575 bsc#1168596 bsc#1168670 bsc#1168760 bsc#1168761 bsc#1168762
  bsc#1168763 bsc#1168764 bsc#1168765 bsc#1168768 bsc#1168777 bsc#1168779
  bsc#1168829 bsc#1168838 bsc#1168847 bsc#1168854 bsc#1168888 bsc#1168952
  bsc#1168959 bsc#1168999 bsc#1169003 bsc#1169005 bsc#1169013 bsc#1169021
  bsc#1169045 bsc#1169048 bsc#1169049 bsc#1169050 bsc#1169051 bsc#1169052
  bsc#1169053 bsc#1169056 bsc#1169078 bsc#1169094 bsc#1169194 bsc#1169263
  bsc#1169493 bsc#1169514 bsc#1169518 bsc#1169524 bsc#1169625 bnc#1169681
  bsc#1169681 bsc#1169709 bsc#1169763 bsc#1169771 bsc#1169790 bsc#1169795
  bsc#1170011 bsc#1170030 bsc#1170056 bsc#1170139 boo#1170232 bsc#1170269
  bsc#1170284 bsc#1170415 bsc#1170442 bsc#1170511 bsc#1170522 bsc#1170617
  bsc#1170621 bsc#1170630 bsc#1170680 bsc#1170774 bsc#1170791 bsc#1170799
  bsc#1170828 bsc#1170879 bsc#1170891 bsc#1170895 bsc#1170901 bsc#1171000
  bsc#1171068 bsc#1171073 bsc#1171075 bsc#1171076 bsc#1171078 bsc#1171079
  bsc#1171080 bsc#1171081 bsc#1171082 bsc#1171083 bsc#1171084 bsc#1171117
  bsc#1171150 bsc#1171156 bsc#1171189 bsc#1171191 bsc#1171195 bsc#1171202
  bsc#1171205 bsc#1171214 bsc#1171217 bsc#1171218 bsc#1171219 bsc#1171220
  bsc#1171236 bsc#1171242 bsc#1171246 bsc#1171279 bsc#1171285 bsc#1171293
  bsc#1171295 bsc#1171374 bsc#1171390 bsc#1171391 bsc#1171392 bsc#1171417
  bsc#1171420 bsc#1171426 bsc#1171507 bsc#1171513 bsc#1171514 bsc#1171529
  bsc#1171530 bsc#1171558 bsc#1171634 bsc#1171644 bsc#1171662 bsc#1171675
  bsc#1171688 bsc#1171699 bsc#1171709 bsc#1171730 bsc#1171732 bsc#1171736
  bsc#1171739 bsc#1171742 bsc#1171743 bsc#1171759 bsc#1171773 bsc#1171774
  bsc#1171775 bsc#1171776 bsc#1171777 bsc#1171778 bsc#1171779 bsc#1171780
  bsc#1171781 bsc#1171782 bsc#1171783 bsc#1171784 bsc#1171785 bsc#1171786
  bsc#1171787 bsc#1171788 bsc#1171789 bsc#1171790 bsc#1171791 bsc#1171792
  bsc#1171793 bsc#1171794 bsc#1171795 bsc#1171796 bsc#1171797 bsc#1171798
  bsc#1171799 bsc#1171810 bsc#1171827 bsc#1171828 bsc#1171832 bsc#1171833
  bsc#1171834 bsc#1171835 bsc#1171839 bsc#1171840 bsc#1171841 bsc#1171842
  bsc#1171843 bsc#1171844 bsc#1171849 bsc#1171857 bsc#1171868 bsc#1171904
  bsc#1171915 bsc#1171982 bsc#1171983 bsc#1171988 bsc#1172017 bsc#1172046
  bsc#1172061 bsc#1172062 bsc#1172063 bsc#1172064 bsc#1172065 bsc#1172066
  bsc#1172067 bsc#1172068 bsc#1172069 boo#1172073 bsc#1172086 bsc#1172095
  bsc#1172108 bsc#1172145 bsc#1172169 bsc#1172170 bsc#1172197 bsc#1172201
  bsc#1172208 bsc#1172223 bsc#1172247 bsc#1172266 bsc#1172317 bsc#1172342
  bsc#1172343 bsc#1172344 bsc#1172355 bsc#1172365 bsc#1172366 bsc#1172374
  bsc#1172391 bsc#1172393 bsc#1172394 bsc#1172418 bsc#1172419 bsc#1172453
  bsc#1172458 bsc#1172467 bsc#1172484 bsc#1172537 bsc#1172543 bsc#1172687
  bsc#1172719 bsc#1172733 bsc#1172739 bsc#1172751 bsc#1172757 bsc#1172759
  bsc#1172775 bsc#1172781 bsc#1172782 bsc#1172783 bsc#1172814 bsc#1172823
  bsc#1172841 bsc#1172871 bsc#1172873 bsc#1172938 bsc#1172939 bsc#1172940
  boo#1172956 bsc#1172963 bsc#1172983 bsc#1172984 bsc#1172985 bsc#1172986
  bsc#1172987 bsc#1172988 bsc#1172989 bsc#1172990 bsc#1172999 bsc#1173017
  bsc#1173068 bsc#1173074 bsc#1173085 bsc#1173115 bsc#1173139 bsc#1173206
  bsc#1173267 bnc#1173271 bsc#1173280 bsc#1173284 bsc#1173428 bsc#1173438
  bsc#1173461 bsc#1173468 bsc#1173485 bsc#1173514 bsc#1173552 bsc#1173573
  bsc#1173625 bsc#1173746 bsc#1173776 bsc#1173798 boo#1173813 bsc#1173817
  bsc#1173818 bsc#1173820 bsc#1173822 bsc#1173823 bsc#1173824 bsc#1173825
  bsc#1173826 bsc#1173827 bsc#1173828 bsc#1173830 bsc#1173831 bsc#1173832
  bsc#1173833 bsc#1173834 bsc#1173836 bsc#1173837 bsc#1173838 bsc#1173839
  bsc#1173841 bsc#1173843 bsc#1173844 bsc#1173845 bsc#1173847 bsc#1173849
  bsc#1173860 bsc#1173894 bsc#1173941 bsc#1173954 bsc#1174002 bsc#1174003
  bsc#1174018 bsc#1174019 bsc#1174026 bsc#1174029 bsc#1174072 bsc#1174098
  bsc#1174110 bsc#1174111 bsc#1174116 bsc#1174126 bsc#1174127 bsc#1174128
  bsc#1174129 bsc#1174185 bsc#1174205 bsc#1174244 bsc#1174263 bsc#1174264
  bsc#1174331 bsc#1174332 bsc#1174333 bsc#1174345 bsc#1174356 bsc#1174358
  bsc#1174362 bsc#1174387 bsc#1174396 bsc#1174398 bsc#1174407 bsc#1174409
  bsc#1174411 bsc#1174416 bsc#1174426 bsc#1174438 bsc#1174462 bsc#1174484
  bsc#1174486 bsc#1174513 bsc#1174527 bsc#1174585 bsc#1174625 bsc#1174627
  bsc#1174645 bsc#1174689 bsc#1174699 bsc#1174737 bsc#1174748 bsc#1174757
  bsc#1174762 bsc#1174764 bsc#1174770 bsc#1174771 bsc#1174777 bsc#1174805
  bsc#1174824 bsc#1174825 bsc#1174852 bsc#1174865 bsc#1174880 bsc#1174897
  bsc#1174899 bsc#1174906 bsc#1174914 bsc#1174969 bsc#1174978 bsc#1175009
  bsc#1175010 bsc#1175011 bsc#1175012 bsc#1175013 bsc#1175014 bsc#1175015
  bsc#1175016 bsc#1175017 bsc#1175018 bsc#1175019 bsc#1175020 bsc#1175021
  bsc#1175052 bsc#1175079 bsc#1175112 bsc#1175116 bsc#1175128 bsc#1175149
  bsc#1175175 bsc#1175176 bsc#1175180 bsc#1175181 bsc#1175182 bsc#1175183
  bsc#1175184 bsc#1175185 bsc#1175186 bsc#1175187 bsc#1175188 bsc#1175189
  bsc#1175190 bsc#1175191 bsc#1175192 bsc#1175195 bsc#1175199 bsc#1175213
  bsc#1175232 bsc#1175263 bsc#1175284 bsc#1175296 bsc#1175306 bsc#1175344
  bsc#1175345 bsc#1175346 bsc#1175347 bsc#1175367 bsc#1175377 bsc#1175389
  bsc#1175440 bsc#1175480 bsc#1175493 bsc#1175499 bsc#1175543 bsc#1175546
  bsc#1175550 bsc#1175599 bsc#1175621 bsc#1175654 bsc#1175667 bsc#1175691
  bsc#1175697 bsc#1175713 bsc#1175718 bsc#1175721 bsc#1175746 bsc#1175749
  bsc#1175768 bsc#1175769 bsc#1175770 bsc#1175771 bsc#1175772 bsc#1175774
  bsc#1175775 bsc#1175787 bsc#1175807 bsc#1175834 bsc#1175873 boo#1175882
  bsc#1175898 bsc#1175918 bsc#1175952 bsc#1175995 bsc#1175996 bsc#1175997
  bsc#1175998 bsc#1175999 bsc#1176000 bsc#1176001 bsc#1176019 bsc#1176022
  bsc#1176038 bsc#1176063 bsc#1176069 bsc#1176109 bsc#1176137 bsc#1176180
  bsc#1176200 bsc#1176235 bsc#1176236 bsc#1176237 bsc#1176242 bsc#1176248
  bsc#1176354 bsc#1176357 bsc#1176358 bsc#1176359 bsc#1176360 bsc#1176361
  bsc#1176362 bsc#1176363 bsc#1176364 bsc#1176365 bsc#1176366 bsc#1176367
  bsc#1176381 bsc#1176395 bsc#1176396 bsc#1176400 bsc#1176423 bsc#1176447
  bsc#1176449 bsc#1176481 bsc#1176485 bsc#1176486 bsc#1176507 bsc#1176536
  bsc#1176537 bsc#1176538 bsc#1176539 bsc#1176540 bsc#1176541 bsc#1176542
  bsc#1176543 bsc#1176544 bsc#1176545 bsc#1176546 bsc#1176548 bsc#1176558
  bsc#1176559 bnc#1176586 bsc#1176587 bnc#1176588 bsc#1176647 bsc#1176659
  bsc#1176695 bsc#1176698 bsc#1176699 bsc#1176700 bsc#1176713 bsc#1176721
  bsc#1176722 bsc#1176725 bsc#1176732 bsc#1176741 bsc#1176763 bsc#1176771
  bsc#1176774 bsc#1176775 bsc#1176788 bsc#1176789 bsc#1176792 bsc#1176831
  bsc#1176833 bsc#1176846 bsc#1176855 bsc#1176869 bsc#1176877 bsc#1176907
  bsc#1176912 bsc#1176914 bsc#1176916 bsc#1176918 bsc#1176919 bsc#1176925
  bsc#1176940 bsc#1176942 bsc#1176956 bsc#1176961 bsc#1176962 bsc#1176979
  bsc#1176980 bsc#1176983 bsc#1176990 bsc#1177002 bsc#1177020 bsc#1177021
  bsc#1177028 bsc#1177030 bsc#1177066 bsc#1177070 bsc#1177075 bsc#1177086
  bsc#1177090 bsc#1177095 bsc#1177109 bsc#1177116 bsc#1177117 bsc#1177121
  bsc#1177142 bsc#1177154 bsc#1177185 bsc#1177193 bsc#1177194 bsc#1177206
  bsc#1177240 bsc#1177258 bsc#1177271 bsc#1177277 bsc#1177278 bsc#1177279
  bsc#1177280 bsc#1177281 bsc#1177283 bsc#1177284 bsc#1177285 bsc#1177286
  bsc#1177287 bsc#1177297 bsc#1177326 bsc#1177353 bsc#1177384 bsc#1177385
  bsc#1177393 bsc#1177397 bsc#1177399 bsc#1177403 bsc#1177410 bsc#1177411
  bsc#1177434 bsc#1177437 bsc#1177440 bsc#1177470 bsc#1177471 bsc#1177476
  bsc#1177500 bsc#1177511 bsc#1177529 bsc#1177547 bsc#1177591 bsc#1177599
  bsc#1177617 bsc#1177666 bsc#1177678 bsc#1177679 bsc#1177681 bsc#1177683
  bsc#1177686 bsc#1177687 bsc#1177694 bsc#1177697 bsc#1177703 bsc#1177709
  bnc#1177710 bsc#1177710 bsc#1177719 bsc#1177724 bsc#1177725 bsc#1177726
  bsc#1177733 bsc#1177739 bsc#1177749 bsc#1177750 bsc#1177754 bsc#1177755
  bsc#1177765 bnc#1177766 bnc#1177788 bsc#1177799 bsc#1177801 bsc#1177814
  bsc#1177817 bsc#1177820 bsc#1177854 bsc#1177855 bsc#1177856 bsc#1177861
  bsc#1177889 bsc#1177971 bsc#1178002 bsc#1178049 bsc#1178079 bsc#1178089
  bsc#1178123 bsc#1178134 bsc#1178142 bsc#1178163 bsc#1178166 bsc#1178173
  bsc#1178175 bsc#1178176 bsc#1178177 bsc#1178181 bsc#1178182 bsc#1178183
  bsc#1178184 bsc#1178185 bsc#1178186 bsc#1178190 bsc#1178191 bsc#1178203
  bsc#1178226 bnc#1178227 bsc#1178246 bsc#1178255 bsc#1178270 bsc#1178286
  bsc#1178307 bsc#1178325 bsc#1178330 bsc#1178366 bsc#1178367 bsc#1178372
  bsc#1178378 bsc#1178393 bsc#1178395 bsc#1178401 bsc#1178402 bsc#1178404
  bsc#1178418 bsc#1178420 bsc#1178426 bsc#1178431 bsc#1178461 bsc#1178464
  bsc#1178579 bsc#1178581 bsc#1178584 bsc#1178585 bsc#1178589 bsc#1178590
  bsc#1178609 bsc#1178612 bsc#1178631 bsc#1178634 bsc#1178635 bsc#1178648
  bsc#1178653 bsc#1178659 bsc#1178660 bsc#1178661 bsc#1178669 bsc#1178686
  bsc#1178740 bsc#1178755 bsc#1178756 bsc#1178760 bsc#1178762 bsc#1178780
  bsc#1178838 bsc#1178852 bsc#1178853 bsc#1178886 bsc#1178901 bsc#1178908
  bsc#1178995 bsc#1179001 bsc#1179012 bsc#1179014 boo#1179015 bsc#1179045
  bsc#1179076 boo#1179082 bsc#1179082 bsc#1179090 bsc#1179107 bsc#1179137
  bsc#1179140 bsc#1179141 bsc#1179142 bsc#1179160 bsc#1179201 bsc#1179204
  bsc#1179205 bsc#1179211 bsc#1179217 bsc#1179243 bsc#1179344 bsc#1179365
  bsc#1179396 bsc#1179419 bsc#1179424 bsc#1179425 bsc#1179426 bsc#1179427
  bsc#1179429 bsc#1179432 bsc#1179434 bsc#1179435 bsc#1179439 bsc#1179442
  bsc#1179446 bsc#1179454 bsc#1179508 bsc#1179509 bsc#1179519 bsc#1179531
  bsc#1179550 bsc#1179565 bsc#1179567 bsc#1179572 bsc#1179575 bsc#1179578
  bsc#1179585 bsc#1179597 bsc#1179599 bsc#1179601 bsc#1179603 bsc#1179604
  bsc#1179611 bsc#1179639 bsc#1179652 bsc#1179656 bsc#1179660 bsc#1179670
  bsc#1179671 bsc#1179672 bsc#1179673 bsc#1179675 bsc#1179676 bsc#1179677
  bsc#1179678 bsc#1179679 bsc#1179680 bsc#1179681 bsc#1179682 bsc#1179683
  bsc#1179684 bsc#1179685 bsc#1179687 bsc#1179688 bsc#1179689 bsc#1179690
  bsc#1179703 bsc#1179704 bsc#1179707 bsc#1179709 bsc#1179710 bsc#1179711
  bsc#1179712 bsc#1179713 bsc#1179714 bsc#1179715 bsc#1179716 bsc#1179745
  bsc#1179763 bsc#1179814 bsc#1179815 bsc#1179819 bsc#1179825 bsc#1179827
  bsc#1179851 bsc#1179863 bsc#1179878 bsc#1179882 bsc#1179887 bsc#1179888
  bsc#1179892 bsc#1179896 bsc#1179929 bsc#1179950 bsc#1179960 bsc#1179963
  bsc#1180027 bsc#1180029 bsc#1180031 bsc#1180052 bsc#1180056 bsc#1180058
  bsc#1180072 bsc#1180086 bsc#1180092 bsc#1180100 bsc#1180103 bsc#1180114
  bsc#1180117 bsc#1180130 bsc#1180141 bsc#1180197 bsc#1180214 bsc#1180221
  bsc#1180258 bsc#1180261 bsc#1180264 bsc#1180334 bsc#1180336 bsc#1180347
  bsc#1180412 bsc#1180506 bsc#1180541 bsc#1180543 bsc#1180559 bsc#1180566
  bsc#1180567 bsc#1180581 bsc#1180598 bsc#1180682 bsc#1180731 bsc#1180744
  bsc#1180749 bsc#1180759 bsc#1180765 bsc#1180773 bsc#1180809 bsc#1180812
  bsc#1180814 bsc#1180846 bsc#1180848 bsc#1180870 bsc#1180889 bsc#1180891
  bsc#1180945 bsc#1180964 bsc#1180971 bsc#1180980 bsc#1180989 bsc#1181006
  bsc#1181014 boo#1181018 bsc#1181070 bsc#1181076 bsc#1181077 bsc#1181104
  bsc#1181133 bsc#1181147 bsc#1181148 bsc#1181158 bsc#1181161 bsc#1181169
  bsc#1181203 bsc#1181206 bsc#1181207 bsc#1181208 bsc#1181209 bsc#1181210
  bsc#1181211 bsc#1181212 bsc#1181213 bsc#1181214 bsc#1181215 bsc#1181217
  bsc#1181218 bsc#1181219 bsc#1181220 bsc#1181237 bsc#1181259 bsc#1181284
  bsc#1181318 bsc#1181335 bsc#1181346 bsc#1181349 bsc#1181383 bsc#1181425
  bsc#1181494 bsc#1181504 bsc#1181507 bsc#1181511 bsc#1181538 bsc#1181544
  bsc#1181572 bsc#1181574 bsc#1181584 bsc#1181637 bsc#1181655 bsc#1181671
  bsc#1181674 bsc#1181710 bsc#1181719 bsc#1181720 bsc#1181735 bsc#1181736
  bsc#1181738 bsc#1181747 bsc#1181753 bsc#1181785 bsc#1181787 bsc#1181795
  bsc#1181818 bsc#1181843 bsc#1181854 bsc#1181862 bsc#1181896 bsc#1181928
  bsc#1181958 bsc#1181960 bsc#1181972 bsc#1181985 bsc#1182011 bsc#1182035
  bsc#1182047 bsc#1182077 bsc#1182114 bsc#1182118 bsc#1182128 bsc#1182140
  bsc#1182161 bsc#1182171 bsc#1182175 bsc#1182217 bsc#1182257 bsc#1182259
  bsc#1182265 bsc#1182266 bsc#1182267 bsc#1182268 bsc#1182271 bsc#1182272
  bsc#1182273 bsc#1182275 bsc#1182276 bsc#1182278 bsc#1182283 bsc#1182374
  bsc#1182377 bsc#1182378 bsc#1182380 bsc#1182381 bsc#1182406 bsc#1182430
  bsc#1182439 bsc#1182441 bsc#1182442 bsc#1182443 bsc#1182444 bsc#1182445
  bsc#1182446 bsc#1182447 bsc#1182449 bsc#1182454 bsc#1182455 bsc#1182456
  bsc#1182457 bsc#1182458 bsc#1182459 bsc#1182460 bsc#1182461 bsc#1182462
  bsc#1182463 bsc#1182464 bsc#1182465 bsc#1182466 bsc#1182470 bsc#1182485
  bsc#1182489 bsc#1182490 bsc#1182547 bsc#1182552 bsc#1182558 bsc#1182560
  bsc#1182561 bsc#1182571 bsc#1182574 bsc#1182591 bsc#1182595 bsc#1182599
  bsc#1182602 bsc#1182613 bsc#1182616 bsc#1182626 bsc#1182632 bsc#1182650
  boo#1182672 bsc#1182676 bsc#1182683 bsc#1182684 bsc#1182686 bsc#1182697
  bsc#1182715 bsc#1182716 bsc#1182717 bsc#1182743 bsc#1182770 bsc#1182798
  bsc#1182800 bsc#1182801 bsc#1182853 bsc#1182854 bsc#1182856 bsc#1182857
  bsc#1182989 bsc#1182992 bsc#1182999 bsc#1183002 bsc#1183009 bsc#1183015
  bsc#1183018 bsc#1183022 bsc#1183023 bsc#1183030 bsc#1183033 bsc#1183048
  boo#1183063 bsc#1183077 bsc#1183203 bsc#1183225 bsc#1183249 bsc#1183252
  bsc#1183277 bsc#1183278 bsc#1183279 bsc#1183280 bsc#1183281 bsc#1183282
  bsc#1183283 bsc#1183284 bsc#1183285 bsc#1183286 bsc#1183287 bsc#1183288
  bsc#1183289 bsc#1183310 bsc#1183311 bsc#1183312 bsc#1183313 bsc#1183314
  bsc#1183315 bsc#1183316 bsc#1183317 bsc#1183318 bsc#1183319 bsc#1183320
  bsc#1183321 bsc#1183322 bsc#1183323 bsc#1183324 bsc#1183325 bsc#1183326
  bsc#1183346 bsc#1183366 bsc#1183369 bsc#1183386 bsc#1183392 bsc#1183405
  bsc#1183412 bsc#1183416 bsc#1183427 bsc#1183428 bsc#1183440 bsc#1183445
  bsc#1183447 bsc#1183501 bsc#1183509 bsc#1183530 bsc#1183534 bsc#1183540
  bsc#1183551 bsc#1183552 bsc#1183553 bsc#1183593 bsc#1183596 bsc#1183598
  bsc#1183637 bsc#1183646 bsc#1183662 bsc#1183682 bsc#1183686 bsc#1183692
  bsc#1183696 bsc#1183712 bsc#1183746 bsc#1183750 bsc#1183756 bsc#1183757
  bsc#1183773 bsc#1183775 bsc#1183815 bsc#1183843 bsc#1183850 bsc#1183859
  bsc#1183860 bsc#1183868 bsc#1183871 bsc#1183872 bsc#1183873 bsc#1183897
  bsc#1183932 bsc#1183947 bsc#1183976 bsc#1184074 bsc#1184081 bsc#1184082
  bsc#1184111 bsc#1184114 bsc#1184120 bsc#1184129 bsc#1184134 bsc#1184167
  bsc#1184168 bsc#1184170 bsc#1184176 bsc#1184180 bsc#1184192 bsc#1184193
  bsc#1184196 bsc#1184197 bsc#1184198 bsc#1184208 bsc#1184209 bsc#1184211
  bsc#1184212 bsc#1184217 bsc#1184218 bsc#1184219 bsc#1184220 bsc#1184224
  bsc#1184259 bsc#1184264 bsc#1184318 bsc#1184350 bsc#1184386 bsc#1184388
  bsc#1184391 bsc#1184393 bsc#1184436 bsc#1184485 bsc#1184509 bsc#1184511
  bsc#1184512 bsc#1184514 bsc#1184570 bsc#1184583 bsc#1184585 bsc#1184615
  bsc#1184631 bsc#1184647 bsc#1184650 bsc#1184673 bsc#1184685 bsc#1184724
  bsc#1184728 bsc#1184730 bsc#1184731 bsc#1184736 bsc#1184737 bsc#1184738
  bsc#1184740 bsc#1184741 bsc#1184742 bsc#1184760 bsc#1184769 boo#1184804
  bsc#1184811 bsc#1184855 bsc#1184893 bsc#1184924 bsc#1184934 bsc#1184942
  bsc#1184943 bsc#1184957 bsc#1184969 bsc#1184984 bsc#1185010 bsc#1185032
  bsc#1185038 bsc#1185041 bsc#1185110 bsc#1185113 bsc#1185195 bsc#1185233
  bsc#1185244 bsc#1185269 bsc#1185308 bsc#1185365 bsc#1185377 bsc#1185428
  bsc#1185454 bsc#1185472 bsc#1185486 bsc#1185491 bsc#1185495 bsc#1185497
  bsc#1185549 bsc#1185550 bsc#1185558 bsc#1185570 bsc#1185573 bsc#1185581
  bsc#1185586 bsc#1185587 bsc#1185589 bsc#1185606 bsc#1185640 bsc#1185641
  bsc#1185642 bsc#1185645 bsc#1185670 bsc#1185675 bsc#1185677 bsc#1185680
  bsc#1185701 bsc#1185703 bsc#1185725 bsc#1185726 bsc#1185758 bsc#1185762
  bsc#1185791 bsc#1185840 bsc#1185857 bsc#1185859 bsc#1185860 bsc#1185861
  bsc#1185862 bsc#1185863 bsc#1185898 bsc#1185902 bsc#1185911 bsc#1185927
  bsc#1185938 bsc#1185950 bsc#1185954 bsc#1185980 bsc#1185982 bsc#1185987
  bsc#1185988 bsc#1186009 bsc#1186060 bsc#1186062 bsc#1186071 bsc#1186111
  bsc#1186155 bsc#1186194 bsc#1186206 bsc#1186219 bnc#1186264 bsc#1186286
  bsc#1186320 bsc#1186349 bsc#1186352 bsc#1186353 bsc#1186354 bsc#1186355
  bsc#1186356 bsc#1186357 bsc#1186416 bsc#1186439 bsc#1186441 bsc#1186449
  bsc#1186451 bsc#1186460 bsc#1186463 bsc#1186467 bsc#1186472 bsc#1186479
  bsc#1186482 bsc#1186484 bsc#1186501 bsc#1186512 bsc#1186573 bsc#1186666
  bsc#1186672 bsc#1186677 bsc#1186681 bsc#1186731 bsc#1186752 bsc#1186885
  boo#1186928 bsc#1186949 bsc#1186950 bsc#1186951 bsc#1186952 bsc#1186953
  bsc#1186954 bsc#1186955 bsc#1186956 bsc#1186957 bsc#1186958 bsc#1186959
  bsc#1186960 bsc#1186961 bsc#1186962 bsc#1186963 bsc#1186964 bsc#1186965
  bsc#1186966 bsc#1186967 bsc#1186968 bsc#1186969 bsc#1186970 bsc#1186971
  bsc#1186972 bsc#1186973 bsc#1186974 bsc#1186976 bsc#1186977 bsc#1186978
  bsc#1186979 bsc#1186980 bsc#1186981 bsc#1186982 bsc#1186983 bsc#1186984
  bsc#1186985 bsc#1186986 bsc#1186987 bsc#1186988 bsc#1186989 bsc#1186990
  bsc#1186991 bsc#1186992 bsc#1186993 bsc#1186994 bsc#1186995 bsc#1186996
  bsc#1186997 bsc#1186998 bsc#1186999 bsc#1187000 bsc#1187001 bsc#1187002
  bsc#1187003 bsc#1187038 bsc#1187039 bsc#1187050 bsc#1187067 bsc#1187068
  bsc#1187069 bsc#1187072 bsc#1187143 bsc#1187144 bsc#1187167 bsc#1187171
  bsc#1187211 bsc#1187215 bsc#1187263 bsc#1187334 bsc#1187344 bsc#1187345
  bsc#1187346 bsc#1187347 bsc#1187348 bsc#1187349 bsc#1187350 bsc#1187351
  bsc#1187356 bsc#1187357 bsc#1187402 bsc#1187403 bsc#1187404 bsc#1187407
  bsc#1187408 bsc#1187409 bsc#1187410 bsc#1187411 bsc#1187412 bsc#1187413
  bsc#1187428 bsc#1187452 bsc#1187455 bsc#1187468 bsc#1187476 bsc#1187483
  bsc#1187495 bsc#1187541 bsc#1187554 bsc#1187585 bsc#1187591 bsc#1187595
  bsc#1187601 bsc#1187619 bsc#1187711 bsc#1187716 bsc#1187795 bsc#1187829
  bsc#1187867 bsc#1187883 bsc#1187886 bsc#1187927 bsc#1187959 bsc#1187972
  bsc#1187980 bsc#1188036 bsc#1188062 bsc#1188064 bsc#1188067 bsc#1188080
  bsc#1188101 bsc#1188116 bsc#1188121 bsc#1188130 bsc#1188172 bsc#1188176
  bsc#1188231 bsc#1188234 bsc#1188238 bsc#1188267 bsc#1188268 bsc#1188269
  bsc#1188270 bsc#1188303 bsc#1188366 bsc#1188404 bsc#1188405 bsc#1188412
  bsc#1188418 bsc#1188439 bsc#1188445 bsc#1188504 bsc#1188605 bsc#1188616
  bsc#1188620 bsc#1188651 bsc#1188683 bsc#1188694 bsc#1188700 bsc#1188703
  bsc#1188746 bsc#1188747 bsc#1188748 bsc#1188752 bsc#1188770 bsc#1188771
  bsc#1188772 bsc#1188773 bsc#1188774 bsc#1188777 bsc#1188780 bsc#1188781
  bsc#1188782 bsc#1188783 bsc#1188784 bsc#1188786 bsc#1188787 bsc#1188788
  bsc#1188790 bsc#1188838 bsc#1188876 bsc#1188878 bsc#1188885 bsc#1188893
  bsc#1188896 bsc#1188924 bsc#1188973 bsc#1188982 bsc#1188983 bsc#1188985
  bnc#1189021 bsc#1189057 bsc#1189074 bsc#1189076 bsc#1189077 bsc#1189111
  bsc#1189126 bsc#1189153 bsc#1189158 bsc#1189197 bsc#1189209 bsc#1189210
  bsc#1189212 bsc#1189213 bsc#1189214 bsc#1189215 bsc#1189216 bsc#1189217
  bsc#1189218 bsc#1189219 bsc#1189220 bsc#1189221 bsc#1189222 bsc#1189225
  bsc#1189229 bsc#1189233 bsc#1189262 bsc#1189291 bsc#1189292 bsc#1189296
  bsc#1189297 bsc#1189298 bsc#1189301 bsc#1189305 bsc#1189323 bsc#1189384
  bsc#1189385 bsc#1189392 bsc#1189393 bsc#1189399 bsc#1189400 bsc#1189427
  bsc#1189449 bsc#1189503 bsc#1189504 bsc#1189505 bsc#1189506 bsc#1189507
  bsc#1189562 bsc#1189563 bsc#1189564 bsc#1189565 bsc#1189566 bsc#1189567
  bsc#1189568 bsc#1189569 bsc#1189573 bsc#1189574 bsc#1189575 bsc#1189576
  bsc#1189577 bsc#1189579 bsc#1189581 bsc#1189582 bsc#1189583 bsc#1189584
  bsc#1189585 bsc#1189586 bsc#1189587 bsc#1189671 bsc#1189685 bsc#1189689
  bsc#1189690 bsc#1189693 bsc#1189694 bsc#1189695 bsc#1189696 bsc#1189706
  bsc#1189760 bsc#1189762 bsc#1189832 bsc#1189841 bsc#1189870 bsc#1189872
  bsc#1189883 bsc#1189884 bsc#1189922 bsc#1189964 bsc#1189965 bnc#1189998
  bsc#1189998 bnc#1189999 bsc#1189999 bsc#1190003 bsc#1190022 bsc#1190025
  bsc#1190050 bsc#1190067 bsc#1190068 bsc#1190093 bsc#1190111 bsc#1190115
  bsc#1190117 bsc#1190120 bsc#1190131 bsc#1190137 bsc#1190138 bsc#1190181
  bsc#1190187 bnc#1190208 bsc#1190208 bsc#1190209 bsc#1190232 bsc#1190256
  bsc#1190277 bsc#1190282 bsc#1190336 bsc#1190351 bsc#1190358 bsc#1190366
  bsc#1190378 bsc#1190406 bsc#1190412 bsc#1190413 bsc#1190418 bsc#1190424
  bsc#1190428 bsc#1190449 bsc#1190450 bsc#1190451 bsc#1190469 bsc#1190479
  bsc#1190497 bsc#1190506 bsc#1190523 bsc#1190534 bsc#1190543 bsc#1190544
  bsc#1190569 bsc#1190576 bsc#1190620 bsc#1190661 bsc#1190664 bsc#1190758
  bsc#1190759 bsc#1190768 bsc#1190786 bsc#1190801 bsc#1190812 bsc#1190923
  bsc#1190941 bsc#1190969 bsc#1191026 bsc#1191229 bsc#1191256 bsc#1191259
  bsc#1191261 bsc#1191269 bsc#1191270 bsc#1191271 bsc#1191279 bsc#1191292
  bsc#1191317 bsc#1191321 bsc#1191349 boo#1191384 bsc#1191396 boo#1191417
  bsc#1191428 bsc#1191540 bsc#1191580 bsc#1191647 bsc#1191649 bsc#1191663
  bsc#1191731 bsc#1191738 bsc#1191740 bsc#1191793 bsc#1191867 bsc#1191876
  bsc#1191949 bsc#1191958 bsc#1191980 bsc#1192069 bsc#1192107 bsc#1192120
  bsc#1192145 bsc#1192202 bsc#1192258 bsc#1192260 bsc#1192267 bsc#1192273
  bsc#1192295 bsc#1192327 bsc#1192341 bsc#1192354 bsc#1192375 bsc#1192456
  bsc#1192473 bsc#1192483 bsc#1192507 bsc#1192547 bsc#1192569 bsc#1192590
  bsc#1192611 bsc#1192644 bsc#1192700 bsc#1192718 bsc#1192720 bsc#1192724
  bsc#1192740 bsc#1192745 bsc#1192750 bsc#1192761 bsc#1192825 bsc#1192837
  bsc#1192845 bsc#1192847 bsc#1192891 bsc#1192894 bsc#1192896 bsc#1192913
  bsc#1192946 bsc#1192968 bsc#1192969 bsc#1192974 bsc#1192987 bsc#1192988
  bsc#1192990 bsc#1193000 bsc#1193039 bsc#1193064 bsc#1193088 bsc#1193124
  bsc#1193136 bnc#1193175 bnc#1193199 bsc#1193200 bnc#1193239 bsc#1193244
  bsc#1193255 bsc#1193277 bsc#1193289 bsc#1193302 bsc#1193306 bsc#1193318
  bsc#1193328 bnc#1193329 bsc#1193349 bnc#1193353 bsc#1193377 bnc#1193431
  bsc#1193440 bsc#1193442 bsc#1193470 bsc#1193482 bsc#1193490 bsc#1193506
  bsc#1193524 bsc#1193554 bsc#1193556 bsc#1193629 bsc#1193640 bsc#1193655
  bsc#1193660 bnc#1193663 bsc#1193669 bsc#1193674 bsc#1193727 bsc#1193767
  bsc#1193787 bsc#1193791 bsc#1193802 bsc#1193823 bsc#1193852 bsc#1193867
  bsc#1193883 bsc#1193901 bsc#1193924 bsc#1193925 bsc#1193927 bsc#1193976
  bsc#1193983 bsc#1194023 bsc#1194027 bsc#1194048 bsc#1194086 bsc#1194090
  bsc#1194111 bsc#1194163 bsc#1194191 bsc#1194266 bsc#1194272 bsc#1194298
  bsc#1194302 bsc#1194305 bsc#1194316 bsc#1194317 bsc#1194324 bsc#1194346
  bsc#1194396 bsc#1194409 bsc#1194501 bsc#1194516 bsc#1194517 bsc#1194523
  bsc#1194526 bsc#1194529 bsc#1194578 bsc#1194583 bsc#1194585 bsc#1194586
  bsc#1194592 bsc#1194595 bsc#1194625 bsc#1194628 bsc#1194636 bsc#1194638
  bsc#1194639 bsc#1194641 bsc#1194644 bsc#1194647 bsc#1194650 bsc#1194656
  bsc#1194659 bsc#1194667 bsc#1194765 bsc#1194773 bsc#1194774 bsc#1194777
  bsc#1194778 bnc#1194825 bsc#1194826 bsc#1194839 bsc#1194850 bsc#1194858
  bsc#1194869 bsc#1194880 bsc#1194887 bsc#1194889 bsc#1194904 bsc#1194943
  bsc#1194959 bsc#1194966 bsc#1194975 bsc#1194985 bsc#1195012 bsc#1195051
  bsc#1195056 bsc#1195065 bsc#1195073 bsc#1195082 bsc#1195099 bsc#1195142
  bsc#1195160 bsc#1195175 bsc#1195183 bsc#1195184 bsc#1195187 bsc#1195195
  bsc#1195199 bsc#1195224 bsc#1195254 bsc#1195275 bsc#1195276 bsc#1195287
  bsc#1195293 bsc#1195306 bsc#1195341 bsc#1195342 bsc#1195346 bsc#1195349
  bsc#1195352 boo#1195353 bsc#1195357 bsc#1195376 bsc#1195400 bnc#1195403
  bsc#1195464 bsc#1195478 bsc#1195480 bsc#1195482 bsc#1195501 bsc#1195504
  bsc#1195516 bsc#1195543 bsc#1195612 bsc#1195639 bsc#1195651 bsc#1195655
  bsc#1195668 bsc#1195669 bsc#1195752 bsc#1195774 bsc#1195775 bsc#1195823
  bsc#1195826 bsc#1195897 bsc#1195905 bsc#1195913 bsc#1195915 bsc#1195917
  bsc#1195921 bsc#1195926 bsc#1195927 bsc#1195944 bsc#1195953 bsc#1195957
  bsc#1195987 bsc#1195993 bsc#1195995 bsc#1196018 bsc#1196058 bsc#1196079
  bsc#1196095 bsc#1196114 bsc#1196130 bsc#1196155 bsc#1196213 bsc#1196235
  bsc#1196248 bsc#1196261 bsc#1196261 bsc#1196299 bsc#1196306 bsc#1196346
  bsc#1196367 bsc#1196400 bsc#1196403 bsc#1196426 bsc#1196444 bsc#1196478
  bsc#1196488 bsc#1196514 bsc#1196516 bsc#1196570 bsc#1196584 bsc#1196589
  bsc#1196591 bsc#1196616 bsc#1196627 bsc#1196632 bsc#1196723 bsc#1196746
  bsc#1196779 bsc#1196802 bsc#1196806 bsc#1196823 bsc#1196830 bsc#1196836
  bsc#1196848 bsc#1196849 bsc#1196866 bsc#1196868 bsc#1196869 bsc#1196894
  bsc#1196930 bsc#1196942 bsc#1196956 bsc#1196960 bsc#1196961 bsc#1197016
  bsc#1197035 bsc#1197082 bsc#1197128 bsc#1197131 bsc#1197146 bsc#1197157
  bsc#1197158 bsc#1197174 bsc#1197227 bsc#1197243 bsc#1197245 bsc#1197246
  bsc#1197247 bsc#1197287 bsc#1197291 bsc#1197292 bsc#1197302 bsc#1197303
  bsc#1197304 bsc#1197331 bsc#1197343 bsc#1197362 bsc#1197366 bsc#1197386
  bsc#1197391 bsc#1197446 bsc#1197460 bsc#1197472 bsc#1197501 bsc#1197534
  bsc#1197601 bsc#1197617 bsc#1197658 bsc#1197659 bsc#1197660 bsc#1197661
  bsc#1197675 bsc#1197685 bsc#1197702 bsc#1197755 bsc#1197756 bsc#1197757
  bsc#1197761 bsc#1197762 bsc#1197763 bsc#1197801 bsc#1197817 bsc#1197819
  bsc#1197820 bsc#1197888 bsc#1197889 bsc#1197894 bsc#1197914 bsc#1197915
  bsc#1197917 bsc#1197918 bsc#1197920 bsc#1197921 bsc#1197922 bsc#1197926
  bsc#1198009 bsc#1198010 bsc#1198012 bsc#1198013 bsc#1198014 bsc#1198015
  bsc#1198016 bsc#1198017 bsc#1198018 bsc#1198019 bsc#1198020 bsc#1198021
  bsc#1198022 bsc#1198023 bsc#1198024 bsc#1198025 bsc#1198027 bsc#1198028
  bsc#1198029 bsc#1198030 bsc#1198031 bsc#1198032 bsc#1198033 bsc#1198034
  bsc#1198058 bsc#1198101 bsc#1198110 bsc#1198189 bsc#1198217 bsc#1198228
  bsc#1198240 bsc#1198330 bsc#1198379 bsc#1198400 bsc#1198402 bsc#1198410
  bsc#1198412 bsc#1198413 bsc#1198417 bsc#1198438 bsc#1198484 bsc#1198515
  bsc#1198577 bsc#1198585 bsc#1198602 bsc#1198660 bsc#1198702 bsc#1198802
  bsc#1198803 bsc#1198806 bsc#1198811 bsc#1198826 bsc#1198829 bsc#1198835
  bsc#1198866 bsc#1198968 bsc#1198971 bsc#1199011 bsc#1199012 bsc#1199024
  bsc#1199035 bsc#1199046 bsc#1199052 bsc#1199063 bsc#1199086 bsc#1199124
  bsc#1199163 bsc#1199173 bsc#1199260 bsc#1199291 bsc#1199294 bsc#1199295
  bsc#1199304 bsc#1199314 bnc#1199356 bsc#1199364 bsc#1199390 bsc#1199405
  bsc#1199426 bsc#1199433 bsc#1199439 bsc#1199482 bsc#1199487 bsc#1199505
  bsc#1199507 bsc#1199509 bsc#1199515 bsc#1199564 bsc#1199605 bsc#1199611
  bsc#1199626 bsc#1199631 bsc#1199650 bsc#1199657 bsc#1199665 bsc#1199670
  bsc#1199674 bsc#1199701 bsc#1199736 bsc#1199793 bsc#1199839 bsc#1199875
  bsc#1199904 bsc#1199909 bsc#1200015 bsc#1200019 bsc#1200045 bsc#1200046
  bsc#1200054 bsc#1200143 bsc#1200144 bsc#1200205 bsc#1200211 bsc#1200259
  bsc#1200263 bsc#1200288 bsc#1200301 bsc#1200313 bsc#1200315 bsc#1200343
  bnc#1200420 bsc#1200431 bsc#1200442 bsc#1200465 bsc#1200475 bsc#1200502
  bsc#1200544 bsc#1200567 bsc#1200569 bsc#1200571 bsc#1200599 bsc#1200600
  bsc#1200611 bsc#1200619 bsc#1200622 bsc#1200644 bsc#1200651 bsc#1200692
  bsc#1200762 bsc#1200763 bsc#1200788 bsc#1200806 bsc#1200807 bsc#1200808
  bsc#1200809 bsc#1200810 bsc#1200812 bsc#1200813 bsc#1200815 bsc#1200816
  bsc#1200820 bsc#1200821 bsc#1200822 bsc#1200824 bsc#1200825 bsc#1200827
  bsc#1200828 bsc#1200829 bsc#1200830 bsc#1200845 bsc#1200868 bsc#1200869
  bsc#1200870 bsc#1200871 bsc#1200872 bsc#1200873 bsc#1200882 bsc#1200925
  bsc#1201019 bsc#1201050 bsc#1201068 bsc#1201160 bsc#1201171 bsc#1201193
  bsc#1201196 bsc#1201218 bsc#1201228 bsc#1201251 bsc#1201258 bsc#1201308
  bsc#1201323 bsc#1201361 bsc#1201381 bsc#1201391 bsc#1201427 bsc#1201442
  bsc#1201455 bsc#1201458 bsc#1201471 bsc#1201489 bsc#1201524 bsc#1201592
  bsc#1201593 bsc#1201595 bsc#1201596 bsc#1201610 bsc#1201635 bsc#1201651
  bsc#1201675 bsc#1201691 boo#1201705 bsc#1201725 bsc#1201726 bsc#1201768
  bsc#1201846 bsc#1201855 bsc#1201865 bsc#1201930 bsc#1201940 bsc#1201948
  bsc#1201954 bsc#1201956 bsc#1201958 bsc#1201987 bsc#1202094 bsc#1202095
  bsc#1202096 bsc#1202097 bsc#1202113 bsc#1202131 bsc#1202154 bsc#1202187
  bsc#1202262 bsc#1202265 bsc#1202341 bsc#1202346 bsc#1202347 bsc#1202353
  bsc#1202385 bsc#1202393 bsc#1202447 bsc#1202471 bnc#1202494 bsc#1202558
  bsc#1202564 bsc#1202623 bsc#1202633 bsc#1202636 bsc#1202672 bsc#1202681
  bsc#1202686 bsc#1202700 bsc#1202710 bsc#1202711 bsc#1202712 bsc#1202713
  bsc#1202715 bsc#1202716 bsc#1202757 bsc#1202758 bsc#1202759 bsc#1202761
  bsc#1202762 bsc#1202763 bsc#1202764 bsc#1202765 bsc#1202766 bsc#1202767
  bsc#1202768 bsc#1202769 bsc#1202770 bsc#1202771 bsc#1202772 bsc#1202773
  bsc#1202774 bsc#1202775 bsc#1202776 bsc#1202778 bsc#1202779 bsc#1202780
  bsc#1202781 bsc#1202782 bsc#1202783 bsc#1202822 bsc#1202823 bsc#1202824
  bsc#1202860 bsc#1202867 bsc#1202872 bsc#1202898 bsc#1202914 bsc#1202960
  bsc#1202989 bsc#1203036 bsc#1203039 bsc#1203041 bsc#1203063 bsc#1203066
  bsc#1203098 bsc#1203101 bsc#1203107 bsc#1203117 bsc#1203138 bsc#1203139
  bsc#1203159 bsc#1203183 bsc#1203197 bsc#1203200 bsc#1203219 bsc#1203229
  bsc#1203263 bsc#1203290 bsc#1203325 bsc#1203331 bsc#1203332 bsc#1203338
  bsc#1203360 bsc#1203361 bsc#1203389 bsc#1203391 bsc#1203410 bsc#1203435
  bsc#1203479 bsc#1203505 bsc#1203514 bsc#1203552 bsc#1203664 bsc#1203693
  bsc#1203699 bsc#1203739 bsc#1203740 bsc#1203767 bsc#1203769 bsc#1203770
  bsc#1203794 bsc#1203798 bsc#1203802 bnc#1203829 bsc#1203836 bsc#1203893
  bsc#1203902 bsc#1203906 bsc#1203908 bsc#1203922 bsc#1203935 bsc#1203939
  bsc#1203960 bsc#1203969 bsc#1203987 bsc#1203992 bsc#1204017 bsc#1204051
  bsc#1204059 bsc#1204060 boo#1204063 bsc#1204125 bsc#1204142 bsc#1204166
  bsc#1204168 bsc#1204171 bsc#1204228 bsc#1204241 bsc#1204353 bsc#1204354
  bsc#1204355 bsc#1204356 bsc#1204363 bsc#1204402 bsc#1204405 bsc#1204413
  bsc#1204414 bsc#1204415 bsc#1204417 bsc#1204428 bsc#1204431 bsc#1204433
  bsc#1204439 bsc#1204470 bsc#1204479 bnc#1204498 bsc#1204533 bsc#1204569
  bsc#1204570 bsc#1204574 bsc#1204575 bsc#1204614 bsc#1204619 bsc#1204631
  bsc#1204635 bsc#1204637 bsc#1204646 bsc#1204647 bsc#1204650 bsc#1204652
  bsc#1204653 bsc#1204662 bsc#1204693 bsc#1204705 bsc#1204719 bsc#1204728
  bsc#1204753 bsc#1204760 bsc#1204780 bsc#1204799 bsc#1204810 bsc#1204850
  bsc#1204868 bsc#1204877 bsc#1204911 bsc#1204926 bsc#1204933 bsc#1204934
  bsc#1204947 bsc#1204957 bsc#1204963 bsc#1204970 bsc#1204989 bsc#1204993
  bsc#1204996 bsc#1205007 bsc#1205100 bsc#1205111 bnc#1205113 bsc#1205128
  boo#1205149 bsc#1205153 bsc#1205173 bsc#1205191 bnc#1205205 bsc#1205205
  bsc#1205220 bsc#1205257 bsc#1205263 bsc#1205264 bnc#1205282 bsc#1205331
  bsc#1205332 bsc#1205381 bsc#1205427 bsc#1205428 bsc#1205473 bsc#1205485
  bsc#1205493 bsc#1205495 bsc#1205496 bsc#1205507 bsc#1205514 bsc#1205521
  bsc#1205544 bsc#1205567 bsc#1205572 bsc#1205588 bsc#1205601 bsc#1205616
  bsc#1205617 bsc#1205635 bsc#1205650 bnc#1205653 bsc#1205670 bsc#1205671
  bsc#1205679 bsc#1205683 bsc#1205695 bsc#1205700 bsc#1205701 bsc#1205705
  bsc#1205709 bsc#1205711 bsc#1205744 bsc#1205756 bsc#1205758 bsc#1205760
  bsc#1205762 bsc#1205764 bsc#1205796 bsc#1205803 bsc#1205846 bsc#1205882
  bsc#1205993 bsc#1206006 bsc#1206024 bsc#1206035 bsc#1206036 bsc#1206037
  bsc#1206045 bsc#1206046 bsc#1206047 bsc#1206048 bsc#1206049 bsc#1206050
  bsc#1206051 bsc#1206056 bsc#1206057 bsc#1206073 bsc#1206098 bsc#1206101
  bsc#1206103 bsc#1206113 bsc#1206114 bsc#1206147 bsc#1206149 bsc#1206188
  bsc#1206207 bsc#1206209 bsc#1206224 bsc#1206232 bsc#1206258 bsc#1206273
  bsc#1206340 bsc#1206344 bsc#1206376 bsc#1206389 bsc#1206390 bsc#1206391
  bsc#1206393 bsc#1206394 bsc#1206395 bsc#1206396 bsc#1206397 bsc#1206398
  bsc#1206399 bsc#1206418 bsc#1206451 bsc#1206456 bsc#1206459 bsc#1206468
  bsc#1206476 bsc#1206492 bsc#1206493 bsc#1206515 bsc#1206536 bsc#1206552
  bsc#1206554 bsc#1206578 bsc#1206602 bsc#1206616 bsc#1206619 bsc#1206640
  bsc#1206649 bsc#1206664 bsc#1206677 bsc#1206703 bsc#1206784 bsc#1206794
  bsc#1206824 bsc#1206843 bsc#1206876 bsc#1206877 bsc#1206878 bsc#1206880
  bsc#1206881 bsc#1206882 bsc#1206883 bsc#1206884 bsc#1206885 bsc#1206886
  bsc#1206887 bsc#1206888 bsc#1206889 bsc#1206890 bsc#1206891 bsc#1206893
  bsc#1206894 bsc#1206896 bsc#1206912 boo#1206935 bsc#1206992 bsc#1207010
  bsc#1207016 bsc#1207034 bsc#1207036 bsc#1207050 bsc#1207051 bsc#1207088
  bsc#1207100 bsc#1207125 bsc#1207129 bsc#1207134 bsc#1207149 bsc#1207158
  bsc#1207168 bsc#1207184 bsc#1207185 bsc#1207186 bsc#1207210 bsc#1207237
  bsc#1207263 bsc#1207269 bsc#1207270 bsc#1207284 bsc#1207301 bsc#1207315
  bsc#1207328 bsc#1207333 bsc#1207345 bsc#1207361 bsc#1207439 bsc#1207497
  bsc#1207500 bsc#1207501 bsc#1207506 bsc#1207507 bsc#1207511 bsc#1207521
  bsc#1207529 bsc#1207553 bsc#1207560 bsc#1207574 bsc#1207588 bsc#1207589
  bsc#1207590 bsc#1207591 bsc#1207592 bsc#1207593 bsc#1207594 bsc#1207602
  bsc#1207603 bsc#1207605 bsc#1207606 bsc#1207607 bsc#1207608 bsc#1207609
  bsc#1207610 bsc#1207611 bsc#1207612 bsc#1207613 bsc#1207614 bsc#1207615
  bsc#1207616 bsc#1207617 bsc#1207618 bsc#1207619 bsc#1207620 bsc#1207621
  bsc#1207622 bsc#1207623 bsc#1207624 bsc#1207625 bsc#1207626 bsc#1207627
  bsc#1207628 bsc#1207629 bsc#1207630 bsc#1207631 bsc#1207632 bsc#1207633
  bsc#1207634 bsc#1207635 bsc#1207636 bsc#1207637 bsc#1207638 bsc#1207639
  bsc#1207640 bsc#1207641 bsc#1207642 bsc#1207643 bsc#1207644 bsc#1207645
  bsc#1207646 bsc#1207647 bsc#1207648 bsc#1207649 bsc#1207650 bsc#1207651
  bsc#1207652 bsc#1207653 bsc#1207734 bsc#1207768 bsc#1207769 bsc#1207770
  bsc#1207771 bsc#1207773 bsc#1207795 bsc#1207827 bsc#1207842 bsc#1207845
  bsc#1207875 bsc#1207878 bsc#1207894 bsc#1207933 bsc#1207935 bsc#1207948
  bsc#1208050 bsc#1208076 bsc#1208081 bsc#1208105 bsc#1208107 bsc#1208128
  bsc#1208130 bsc#1208149 bsc#1208153 bsc#1208179 bsc#1208183 bsc#1208203
  bsc#1208209 bsc#1208212 bsc#1208219 bsc#1208266 bsc#1208290 bsc#1208368
  bsc#1208376 bsc#1208410 bsc#1208420 bsc#1208428 bsc#1208429 bsc#1208449
  bsc#1208534 bsc#1208541 bsc#1208542 bsc#1208565 bsc#1208570 bsc#1208588
  bsc#1208598 bsc#1208599 bsc#1208600 bsc#1208601 bsc#1208602 bsc#1208604
  bsc#1208605 bsc#1208607 bsc#1208619 bsc#1208628 bsc#1208700 bsc#1208741
  bsc#1208757 bsc#1208758 bsc#1208759 bsc#1208776 bsc#1208777 bsc#1208784
  bsc#1208787 bsc#1208788 bsc#1208815 bsc#1208816 bsc#1208829 bsc#1208837
  bsc#1208843 bsc#1208845 bsc#1208848 bsc#1208864 bsc#1208902 bsc#1208921
  bsc#1208948 bsc#1208976 bsc#1209008 bsc#1209039 bsc#1209052 bsc#1209079
  bsc#1209092 bsc#1209118 bsc#1209159 bsc#1209256 bsc#1209258 bsc#1209262
  bsc#1209287 bsc#1209288 bsc#1209290 bsc#1209291 bsc#1209292 bsc#1209366
  bsc#1209367 bsc#1209436 bsc#1209457 bsc#1209504 bsc#1209532 bsc#1209547
  bsc#1209556 bsc#1209572 bsc#1209600 bsc#1209615 bsc#1209634 bsc#1209635
  bsc#1209636 bsc#1209637 bsc#1209681 bsc#1209684 bsc#1209687 bsc#1209693
  bsc#1209739 bsc#1209779 bsc#1209780 bsc#1209788 bsc#1209798 bsc#1209799
  bsc#1209801 bsc#1209804 bsc#1209805 bsc#1209841 bsc#1209856 bsc#1209858
  bsc#1209871 bsc#1209927 bsc#1209965 bsc#1209980 bsc#1209982 bsc#1209999
  bsc#1210034 bsc#1210050 bsc#1210158 bsc#1210165 bsc#1210202 bsc#1210203
  bsc#1210206 bsc#1210216 bsc#1210230 bsc#1210294 bsc#1210301 bsc#1210329
  bsc#1210335 bsc#1210336 bsc#1210337 bsc#1210409 bsc#1210439 bsc#1210449
  bsc#1210450 bsc#1210453 bsc#1210454 bsc#1210469 bsc#1210498 bsc#1210506
  bsc#1210533 bsc#1210551 bsc#1210565 bsc#1210584 bsc#1210627 bsc#1210629
  bsc#1210644 bsc#1210647 bsc#1210725 bsc#1210741 bsc#1210762 bsc#1210763
  bsc#1210764 bsc#1210765 bsc#1210766 bsc#1210767 bsc#1210768 bsc#1210769
  bsc#1210770 bsc#1210771 bsc#1210775 bsc#1210780 bsc#1210783 boo#1210791
  bsc#1210793 bsc#1210806 bsc#1210816 bsc#1210817 bsc#1210825 bsc#1210827
  bsc#1210853 bsc#1210940 bsc#1210943 bsc#1210947 bsc#1210953 bsc#1210986
  bsc#1211014 bsc#1211025 bsc#1211037 bsc#1211043 bsc#1211044 bsc#1211089
  bsc#1211105 bsc#1211113 bsc#1211131 bsc#1211140 bsc#1211205 bsc#1211243
  bsc#1211263 bsc#1211280 bsc#1211281 bsc#1211299 bsc#1211346 bsc#1211387
  bsc#1211400 bsc#1211410 bsc#1211414 bsc#1211449 bsc#1211465 bsc#1211519
  bsc#1211564 bsc#1211590 bsc#1211592 bsc#1211593 bsc#1211595 bsc#1211654
  bsc#1211686 bsc#1211687 bsc#1211688 bsc#1211689 bsc#1211690 bsc#1211691
  bsc#1211692 bsc#1211693 bsc#1211714 bsc#1211738 bsc#1211794 boo#1211796
  bsc#1211804 bsc#1211807 bsc#1211808 bsc#1211811 bsc#1211820 bsc#1211836
  bsc#1211847 bsc#1211852 bsc#1211855 bsc#1211867 bsc#1211960 bsc#1212051
  bsc#1212129 bsc#1212142 bsc#1212154 bsc#1212155 bsc#1212158 bsc#1212256
  bsc#1212265 bsc#1212301 bsc#1212350 bsc#1212405 bsc#1212423 bsc#1212445
  bsc#1212448 bsc#1212456 bsc#1212494 bsc#1212495 bsc#1212502 bsc#1212504
  bsc#1212513 bsc#1212525 bsc#1212540 bsc#1212561 bsc#1212563 bsc#1212564
  bsc#1212584 bsc#1212592 bsc#1212603 bsc#1212604 bsc#1212605 bsc#1212606
  bsc#1212619 bsc#1212685 bsc#1212701 bsc#1212741 bsc#1212766 bsc#1212835
  bsc#1212838 bsc#1212842 bsc#1212846 bsc#1212848 bsc#1212861 bsc#1212869
  bsc#1212892 bsc#1212901 bsc#1212905 bsc#1212961 bsc#1213010 bsc#1213011
  bsc#1213012 bsc#1213013 bsc#1213014 bsc#1213015 bsc#1213016 bsc#1213017
  bsc#1213018 bsc#1213019 bsc#1213020 bsc#1213021 bsc#1213024 bsc#1213025
  bsc#1213032 bsc#1213034 bsc#1213035 bsc#1213036 bsc#1213037 bsc#1213038
  bsc#1213039 bsc#1213040 bsc#1213041 bsc#1213059 bsc#1213061 bsc#1213087
  bsc#1213088 bsc#1213089 bsc#1213090 bsc#1213092 bsc#1213093 bsc#1213094
  bsc#1213095 bsc#1213096 bsc#1213098 bsc#1213099 bsc#1213100 bsc#1213102
  bsc#1213103 bsc#1213104 bsc#1213105 bsc#1213106 bsc#1213107 bsc#1213108
  bsc#1213109 bsc#1213110 bsc#1213111 bsc#1213112 bsc#1213113 bsc#1213114
  bsc#1213116 bsc#1213134 bsc#1213167 bsc#1213205 bsc#1213206 bsc#1213226
  bsc#1213233 bsc#1213245 bsc#1213247 bsc#1213252 bsc#1213258 bsc#1213259
  bsc#1213263 bsc#1213264 bsc#1213272 bsc#1213286 bsc#1213287 bsc#1213304
  bsc#1213311 bsc#1213417 bsc#1213493 bsc#1213523 bsc#1213524 bsc#1213533
  bsc#1213543 bsc#1213546 bsc#1213578 bsc#1213580 bsc#1213585 bsc#1213586
  bsc#1213588 bsc#1213601 bsc#1213620 bsc#1213632 bsc#1213653 bsc#1213705
  bsc#1213713 bsc#1213715 bsc#1213733 bsc#1213747 bsc#1213756 bsc#1213757
  bsc#1213759 bsc#1213777 bsc#1213810 bsc#1213812 bsc#1213856 bsc#1213857
  bsc#1213863 bsc#1213867 bsc#1213870 bsc#1213871 bsc#1213872 bsc#1213968
  bsc#1213970 bsc#1214000 bsc#1214019 bsc#1214073
  CVE-2016-3695 CVE-2017-5715 CVE-2017-5753 CVE-2017-5754 CVE-2017-12153
  CVE-2017-13080 CVE-2017-14051 CVE-2017-16536 CVE-2017-16537 CVE-2017-16646
  CVE-2017-16648 CVE-2017-1000251 CVE-2018-10323 CVE-2018-12232
  CVE-2018-13053 CVE-2018-20669 CVE-2019-0154 CVE-2019-0155 CVE-2019-3016
  CVE-2019-8912 CVE-2019-10220 CVE-2019-11477 CVE-2019-11478 CVE-2019-11479
  CVE-2019-12456 CVE-2019-14615 CVE-2019-14814 CVE-2019-14815 CVE-2019-14816
  CVE-2019-14895 CVE-2019-14896 CVE-2019-14897 CVE-2019-14901 CVE-2019-15030
  CVE-2019-15031 CVE-2019-15098 CVE-2019-15099 CVE-2019-15290 CVE-2019-15291
  CVE-2019-15504 CVE-2019-16231 CVE-2019-16232 CVE-2019-16233 CVE-2019-16234
  CVE-2019-17133 CVE-2019-17666 CVE-2019-18198 CVE-2019-18660 CVE-2019-18683
  CVE-2019-18786 CVE-2019-18808 CVE-2019-18809 CVE-2019-18811 CVE-2019-18812
  CVE-2019-18813 CVE-2019-18814 CVE-2019-19037 CVE-2019-19043 CVE-2019-19044
  CVE-2019-19045 CVE-2019-19046 CVE-2019-19047 CVE-2019-19048 CVE-2019-19049
  CVE-2019-19050 CVE-2019-19051 CVE-2019-19052 CVE-2019-19053 CVE-2019-19054
  CVE-2019-19055 CVE-2019-19056 CVE-2019-19057 CVE-2019-19058 CVE-2019-19060
  CVE-2019-19061 CVE-2019-19062 CVE-2019-19063 CVE-2019-19064 CVE-2019-19065
  CVE-2019-19066 CVE-2019-19067 CVE-2019-19068 CVE-2019-19069 CVE-2019-19070
  CVE-2019-19071 CVE-2019-19072 CVE-2019-19073 CVE-2019-19074 CVE-2019-19075
  CVE-2019-19077 CVE-2019-19078 CVE-2019-19080 CVE-2019-19081 CVE-2019-19082
  CVE-2019-19083 CVE-2019-19241 CVE-2019-19252 CVE-2019-19332 CVE-2019-19338
  CVE-2019-19447 CVE-2019-19462 CVE-2019-19523 CVE-2019-19524 CVE-2019-19525
  CVE-2019-19526 CVE-2019-19528 CVE-2019-19529 CVE-2019-19532 CVE-2019-19533
  CVE-2019-19534 CVE-2019-19602 CVE-2019-19767 CVE-2019-19768 CVE-2019-19769
  CVE-2019-19770 CVE-2019-19807 CVE-2019-19922 CVE-2019-19947 CVE-2019-19965
  CVE-2019-20422 CVE-2019-20810 CVE-2019-20812 CVE-2020-0110 CVE-2020-0305
  CVE-2020-0404 CVE-2020-0427 CVE-2020-0431 CVE-2020-0432 CVE-2020-0444
  CVE-2020-0465 CVE-2020-0466 CVE-2020-0543 CVE-2020-1749 CVE-2020-2521
  CVE-2020-2732 CVE-2020-4788 CVE-2020-8428 CVE-2020-8647 CVE-2020-8648
  CVE-2020-8649 CVE-2020-8694 CVE-2020-8835 CVE-2020-8992 CVE-2020-9383
  CVE-2020-10135 CVE-2020-10690 CVE-2020-10711 CVE-2020-10732 CVE-2020-10751
  CVE-2020-10757 CVE-2020-10766 CVE-2020-10767 CVE-2020-10768 CVE-2020-10773
  CVE-2020-10781 CVE-2020-10942 CVE-2020-11494 CVE-2020-11608 CVE-2020-11668
  CVE-2020-11884 CVE-2020-12351 CVE-2020-12352 CVE-2020-12362 CVE-2020-12363
  CVE-2020-12364 CVE-2020-12373 CVE-2020-12464 CVE-2020-12465 CVE-2020-12652
  CVE-2020-12653 CVE-2020-12654 CVE-2020-12655 CVE-2020-12656 CVE-2020-12657
  CVE-2020-12659 CVE-2020-12769 CVE-2020-12770 CVE-2020-12771 CVE-2020-12888
  CVE-2020-13143 CVE-2020-13974 CVE-2020-14314 CVE-2020-14331 CVE-2020-14351
  CVE-2020-14356 CVE-2020-14385 CVE-2020-14386 CVE-2020-14390 CVE-2020-14416
  CVE-2020-15393 CVE-2020-15436 CVE-2020-15437 CVE-2020-15780 CVE-2020-16119
  CVE-2020-16120 CVE-2020-16166 CVE-2020-24490 CVE-2020-24586 CVE-2020-24587
  CVE-2020-24588 CVE-2020-25211 CVE-2020-25212 CVE-2020-25284 CVE-2020-25285
  CVE-2020-25639 CVE-2020-25641 CVE-2020-25643 CVE-2020-25645 CVE-2020-25656
  CVE-2020-25668 CVE-2020-25669 CVE-2020-25670 CVE-2020-25671 CVE-2020-25672
  CVE-2020-25673 CVE-2020-25704 CVE-2020-25705 CVE-2020-26088 CVE-2020-26139
  CVE-2020-26141 CVE-2020-26145 CVE-2020-26147 CVE-2020-26558 CVE-2020-27068
  CVE-2020-27170 CVE-2020-27171 CVE-2020-27194 CVE-2020-27673 CVE-2020-27675
  CVE-2020-27777 CVE-2020-27786 CVE-2020-27815 CVE-2020-27820 CVE-2020-27825
  CVE-2020-27830 CVE-2020-27835 CVE-2020-28374 CVE-2020-28915 CVE-2020-28941
  CVE-2020-28974 CVE-2020-29368 CVE-2020-29369 CVE-2020-29370 CVE-2020-29371
  CVE-2020-29373 CVE-2020-29568 CVE-2020-29569 CVE-2020-29660 CVE-2020-29661
  CVE-2020-35519 CVE-2020-36158 CVE-2020-36310 CVE-2020-36311 CVE-2020-36312
  CVE-2020-36322 CVE-2020-36385 CVE-2020-36386 CVE-2020-36516 CVE-2021-0129
  CVE-2021-0342 CVE-2021-0512 CVE-2021-0605 CVE-2021-3347 CVE-2021-3348
  CVE-2021-3428 CVE-2021-3444 CVE-2021-3483 CVE-2021-3489 CVE-2021-3490
  CVE-2021-3491 CVE-2021-3542 CVE-2021-3573 CVE-2021-3609 CVE-2021-3612
  CVE-2021-3640 CVE-2021-3653 CVE-2021-3656 CVE-2021-3659 CVE-2021-3679
  CVE-2021-3732 CVE-2021-3739 CVE-2021-3743 CVE-2021-3744 CVE-2021-3753
  CVE-2021-3759 CVE-2021-3760 CVE-2021-3764 CVE-2021-3772 CVE-2021-3896
  CVE-2021-4001 CVE-2021-4002 CVE-2021-4037 CVE-2021-4083 CVE-2021-4090
  CVE-2021-4135 CVE-2021-4148 CVE-2021-4155 CVE-2021-4197 CVE-2021-4202
  CVE-2021-4204 CVE-2021-20177 CVE-2021-20268 CVE-2021-20321 CVE-2021-21781
  CVE-2021-22543 CVE-2021-22555 CVE-2021-22600 CVE-2021-23134 CVE-2021-26341
  CVE-2021-26930 CVE-2021-26931 CVE-2021-26932 CVE-2021-27363 CVE-2021-27364
  CVE-2021-27365 CVE-2021-28038 CVE-2021-28375 CVE-2021-28660 CVE-2021-28688
  CVE-2021-28711 CVE-2021-28712 CVE-2021-28713 CVE-2021-28714 CVE-2021-28715
  CVE-2021-28950 CVE-2021-28952 CVE-2021-28964 CVE-2021-28971 CVE-2021-28972
  CVE-2021-29154 CVE-2021-29155 CVE-2021-29264 CVE-2021-29265 CVE-2021-29647
  CVE-2021-29650 CVE-2021-30002 CVE-2021-32399 CVE-2021-33034 CVE-2021-33061
  CVE-2021-33135 CVE-2021-33200 CVE-2021-33624 CVE-2021-33655 CVE-2021-33909
  CVE-2021-34556 CVE-2021-34693 CVE-2021-35039 CVE-2021-35477 CVE-2021-37576
  CVE-2021-38160 CVE-2021-38166 CVE-2021-38198 CVE-2021-38204 CVE-2021-38205
  CVE-2021-38206 CVE-2021-38207 CVE-2021-38209 CVE-2021-39685 CVE-2021-39698
  CVE-2021-41073 CVE-2021-41864 CVE-2021-42252 CVE-2021-42327 CVE-2021-42739
  CVE-2021-43056 CVE-2021-43057 CVE-2021-43267 CVE-2021-43389 CVE-2021-43975
  CVE-2021-43976 CVE-2021-44733 CVE-2021-44879 CVE-2021-45095 CVE-2021-45402
  CVE-2021-45480 CVE-2021-45868 CVE-2022-0001 CVE-2022-0002 CVE-2022-0168
  CVE-2022-0171 CVE-2022-0185 CVE-2022-0264 CVE-2022-0322 CVE-2022-0330
  CVE-2022-0382 CVE-2022-0435 CVE-2022-0487 CVE-2022-0492 CVE-2022-0494
  CVE-2022-0500 CVE-2022-0516 CVE-2022-0617 CVE-2022-0644 CVE-2022-0742
  CVE-2022-0847 CVE-2022-0854 CVE-2022-0886 CVE-2022-0995 CVE-2022-0998
  CVE-2022-1011 CVE-2022-1012 CVE-2022-1015 CVE-2022-1016 CVE-2022-1048
  CVE-2022-1055 CVE-2022-1158 CVE-2022-1184 CVE-2022-1195 CVE-2022-1198
  CVE-2022-1199 CVE-2022-1204 CVE-2022-1205 CVE-2022-1263 CVE-2022-1280
  CVE-2022-1462 CVE-2022-1508 CVE-2022-1516 CVE-2022-1651 CVE-2022-1652
  CVE-2022-1671 CVE-2022-1679 CVE-2022-1729 CVE-2022-1734 CVE-2022-1789
  CVE-2022-1836 CVE-2022-1852 CVE-2022-1882 CVE-2022-1966 CVE-2022-1972
  CVE-2022-1974 CVE-2022-1975 CVE-2022-1998 CVE-2022-2153 CVE-2022-2196
  CVE-2022-2318 CVE-2022-2585 CVE-2022-2586 CVE-2022-2588 CVE-2022-2602
  CVE-2022-2639 CVE-2022-2663 CVE-2022-2873 CVE-2022-2905 CVE-2022-2938
  CVE-2022-2959 CVE-2022-2964 CVE-2022-2977 CVE-2022-2978 CVE-2022-3028
  CVE-2022-3078 CVE-2022-3104 CVE-2022-3105 CVE-2022-3106 CVE-2022-3107
  CVE-2022-3108 CVE-2022-3111 CVE-2022-3112 CVE-2022-3113 CVE-2022-3114
  CVE-2022-3115 CVE-2022-3169 CVE-2022-3176 CVE-2022-3202 CVE-2022-3239
  CVE-2022-3303 CVE-2022-3344 CVE-2022-3424 CVE-2022-3435 CVE-2022-3521
  CVE-2022-3523 CVE-2022-3524 CVE-2022-3526 CVE-2022-3535 CVE-2022-3542
  CVE-2022-3545 CVE-2022-3564 CVE-2022-3565 CVE-2022-3566 CVE-2022-3567
  CVE-2022-3577 CVE-2022-3586 CVE-2022-3594 CVE-2022-3619 CVE-2022-3621
  CVE-2022-3625 CVE-2022-3628 CVE-2022-3629 CVE-2022-3633 CVE-2022-3635
  CVE-2022-3640 CVE-2022-3643 CVE-2022-3646 CVE-2022-3649 CVE-2022-3707
  CVE-2022-3903 CVE-2022-4095 CVE-2022-4129 CVE-2022-4139 CVE-2022-4269
  CVE-2022-4378 CVE-2022-4379 CVE-2022-4382 CVE-2022-4662 CVE-2022-4744
  CVE-2022-20008 CVE-2022-20132 CVE-2022-20154 CVE-2022-20368 CVE-2022-20369
  CVE-2022-21123 CVE-2022-21125 CVE-2022-21127 CVE-2022-21166 CVE-2022-21180
  CVE-2022-21499 CVE-2022-21505 CVE-2022-22942 CVE-2022-23036 CVE-2022-23037
  CVE-2022-23038 CVE-2022-23039 CVE-2022-23040 CVE-2022-23041 CVE-2022-23042
  CVE-2022-23222 CVE-2022-23960 CVE-2022-24122 CVE-2022-24448 CVE-2022-24958
  CVE-2022-24959 CVE-2022-25258 CVE-2022-25375 CVE-2022-25636 CVE-2022-26365
  CVE-2022-26373 CVE-2022-26490 CVE-2022-26878 CVE-2022-26966 CVE-2022-27223
  CVE-2022-28356 CVE-2022-28388 CVE-2022-28389 CVE-2022-28390 CVE-2022-28693
  CVE-2022-28748 CVE-2022-28893 CVE-2022-29156 CVE-2022-29581 CVE-2022-29582
  CVE-2022-29900 CVE-2022-29901 CVE-2022-30594 CVE-2022-32250 CVE-2022-32296
  CVE-2022-33740 CVE-2022-33741 CVE-2022-33742 CVE-2022-33743 CVE-2022-33981
  CVE-2022-34918 CVE-2022-36280 CVE-2022-36879 CVE-2022-36946 CVE-2022-38096
  CVE-2022-39188 CVE-2022-39189 CVE-2022-39190 CVE-2022-40476 CVE-2022-40768
  CVE-2022-40982 CVE-2022-41218 CVE-2022-41674 CVE-2022-41848 CVE-2022-41849
  CVE-2022-41850 CVE-2022-41858 CVE-2022-42328 CVE-2022-42329 CVE-2022-42703
  CVE-2022-42719 CVE-2022-42720 CVE-2022-42721 CVE-2022-42722 CVE-2022-42895
  CVE-2022-42896 CVE-2022-43750 CVE-2022-43945 CVE-2022-45869 CVE-2022-45884
  CVE-2022-45885 CVE-2022-45886 CVE-2022-45887 CVE-2022-45888 CVE-2022-45919
  CVE-2022-45934 CVE-2022-47520 CVE-2022-47929 CVE-2023-0045 CVE-2023-0122
  CVE-2023-0179 CVE-2023-0266 CVE-2023-0386 CVE-2023-0394 CVE-2023-0459
  CVE-2023-0461 CVE-2023-0468 CVE-2023-0469 CVE-2023-0590 CVE-2023-0597
  CVE-2023-1075 CVE-2023-1076 CVE-2023-1077 CVE-2023-1078 CVE-2023-1079
  CVE-2023-1095 CVE-2023-1118 CVE-2023-1249 CVE-2023-1281 CVE-2023-1380
  CVE-2023-1382 CVE-2023-1513 CVE-2023-1582 CVE-2023-1583 CVE-2023-1611
  CVE-2023-1637 CVE-2023-1652 CVE-2023-1670 CVE-2023-1829 CVE-2023-1838
  CVE-2023-1855 CVE-2023-1989 CVE-2023-1990 CVE-2023-1998 CVE-2023-2002
  CVE-2023-2008 CVE-2023-2019 CVE-2023-2124 CVE-2023-2156 CVE-2023-2162
  CVE-2023-2166 CVE-2023-2176 CVE-2023-2235 CVE-2023-2269 CVE-2023-2430
  CVE-2023-2483 CVE-2023-2513 CVE-2023-2985 CVE-2023-3006 CVE-2023-3090
  CVE-2023-3111 CVE-2023-3117 CVE-2023-3141 CVE-2023-3161 CVE-2023-3212
  CVE-2023-3220 CVE-2023-3268 CVE-2023-3357 CVE-2023-3358 CVE-2023-3389
  CVE-2023-3390 CVE-2023-3567 CVE-2023-3609 CVE-2023-3610 CVE-2023-3611
  CVE-2023-3776 CVE-2023-3812 CVE-2023-3863 CVE-2023-4004 CVE-2023-4133
  CVE-2023-4147 CVE-2023-4194 CVE-2023-20569 CVE-2023-20593 CVE-2023-21102
  CVE-2023-21106 CVE-2023-21400 CVE-2023-22995 CVE-2023-22998 CVE-2023-23000
  CVE-2023-23001 CVE-2023-23004 CVE-2023-23006 CVE-2023-23454 CVE-2023-23455
  CVE-2023-23559 CVE-2023-25012 CVE-2023-26545 CVE-2023-28327 CVE-2023-28328
  CVE-2023-28410 CVE-2023-28464 CVE-2023-28466 CVE-2023-28866 CVE-2023-30456
  CVE-2023-30772 CVE-2023-31083 CVE-2023-31084 CVE-2023-31248 CVE-2023-31436
  CVE-2023-32233 CVE-2023-33288 CVE-2023-33951 CVE-2023-33952 CVE-2023-34319
  CVE-2023-35001 CVE-2023-35788 CVE-2023-35823 CVE-2023-35828 CVE-2023-35829
  CVE-2023-38409
  JSC#PED-1711 JSC#SLE-13586 JSC#SLE-15234 JSC#SLE-9489 jsc#11529 jsc#13212
  jsc#13318 jsc#13356 jsc#13365 jsc#13475 jsc#13575 jsc#13695 jsc#13705
  jsc#13716 jsc#16232 jsc#ECO-1386 jsc#ECO-3191 jsc#ECO-3482 jsc#ECO-3666
  jsc#ECO-3691 jsc#IBM-458 jsc#IBM-463 jsc#IBM-505 jsc#INTEL-233
  jsc#INTEL-549 jsc#PED-1033 jsc#PED-1035 jsc#PED-1036 jsc#PED-1038
  jsc#PED-1040 jsc#PED-1044 jsc#PED-1046 jsc#PED-1052 jsc#PED-1054
  jsc#PED-1063 jsc#PED-1072 jsc#PED-1073 jsc#PED-1082 jsc#PED-1084
  jsc#PED-1085 jsc#PED-1096 jsc#PED-1109 jsc#PED-1111 jsc#PED-1113
  jsc#PED-1118 jsc#PED-1159 jsc#PED-1163 jsc#PED-1164 jsc#PED-1165
  jsc#PED-1166 jsc#PED-1168 jsc#PED-1170 jsc#PED-1176 jsc#PED-1183
  jsc#PED-1185 jsc#PED-1187 jsc#PED-1211 jsc#PED-1213 jsc#PED-1218
  jsc#PED-1220 jsc#PED-1222 jsc#PED-1223 jsc#PED-1225 jsc#PED-1247
  jsc#PED-1248 jsc#PED-1263 jsc#PED-1266 jsc#PED-1294 jsc#PED-1295
  jsc#PED-1302 jsc#PED-1368 jsc#PED-1377 jsc#PED-1379 jsc#PED-1407
  jsc#PED-1408 jsc#PED-1409 jsc#PED-1444 jsc#PED-1445 jsc#PED-1446
  jsc#PED-1465 jsc#PED-1490 jsc#PED-1491 jsc#PED-1492 jsc#PED-1494
  jsc#PED-1495 jsc#PED-1496 jsc#PED-1497 jsc#PED-1503 jsc#PED-1504
  jsc#PED-1506 jsc#PED-1508 jsc#PED-1509 jsc#PED-1516 jsc#PED-1517
  jsc#PED-1521 jsc#PED-1523 jsc#PED-1524 jsc#PED-1525 jsc#PED-1526
  jsc#PED-1529 jsc#PED-1530 jsc#PED-1547 jsc#PED-1548 jsc#PED-1549
  jsc#PED-1552 jsc#PED-1557 jsc#PED-1558 jsc#PED-1559 jsc#PED-1560
  jsc#PED-1561 jsc#PED-1565 jsc#PED-1573 jsc#PED-1599 jsc#PED-1649
  jsc#PED-1689 jsc#PED-1690 jsc#PED-1694 jsc#PED-1695 jsc#PED-1706
  jsc#PED-1715 jsc#PED-1752 jsc#PED-1754 jsc#PED-1755 jsc#PED-1756
  jsc#PED-1763 jsc#PED-1765 jsc#PED-1812 jsc#PED-1815 jsc#PED-1816
  jsc#PED-1817 jsc#PED-1819 jsc#PED-1820 jsc#PED-1917 jsc#PED-1925
  jsc#PED-1936 jsc#PED-1973 jsc#PED-1981 jsc#PED-2064 jsc#PED-2322
  jsc#PED-2639 jsc#PED-2681 jsc#PED-2684 jsc#PED-2765 jsc#PED-2766
  jsc#PED-2849 jsc#PED-3210 jsc#PED-3259 jsc#PED-342 jsc#PED-3692 jsc#PED-370
  jsc#PED-372 jsc#PED-373 jsc#PED-375 jsc#PED-3750 jsc#PED-3759 jsc#PED-376
  jsc#PED-377 jsc#PED-387 jsc#PED-3931 jsc#PED-4022 jsc#PED-448 jsc#PED-455
  jsc#PED-4718 jsc#PED-4758 jsc#PED-529 jsc#PED-531 jsc#PED-535 jsc#PED-542
  jsc#PED-548 jsc#PED-549 jsc#PED-551 jsc#PED-557 jsc#PED-568 jsc#PED-573
  jsc#PED-579 jsc#PED-588 jsc#PED-589 jsc#PED-592 jsc#PED-593 jsc#PED-594
  jsc#PED-596 jsc#PED-598 jsc#PED-599 jsc#PED-600 jsc#PED-603 jsc#PED-606
  jsc#PED-610 jsc#PED-611 jsc#PED-612 jsc#PED-613 jsc#PED-622 jsc#PED-623
  jsc#PED-628 jsc#PED-633 jsc#PED-634 jsc#PED-637 jsc#PED-648 jsc#PED-652
  jsc#PED-664 jsc#PED-667 jsc#PED-676 jsc#PED-678 jsc#PED-679 jsc#PED-681
  jsc#PED-682 jsc#PED-686 jsc#PED-688 jsc#PED-690 jsc#PED-692 jsc#PED-695
  jsc#PED-707 jsc#PED-716 jsc#PED-720 jsc#PED-729 jsc#PED-732 jsc#PED-740
  jsc#PED-743 jsc#PED-755 jsc#PED-763 jsc#PED-769 jsc#PED-808 jsc#PED-812
  jsc#PED-813 jsc#PED-817 jsc#PED-818 jsc#PED-820 jsc#PED-822 jsc#PED-823
  jsc#PED-824 jsc#PED-825 jsc#PED-826 jsc#PED-827 jsc#PED-828 jsc#PED-829
  jsc#PED-831 jsc#PED-832 jsc#PED-833 jsc#PED-835 jsc#PED-837 jsc#PED-840
  jsc#PED-842 jsc#PED-846 jsc#PED-849 jsc#PED-850 jsc#PED-851 jsc#PED-855
  jsc#PED-856 jsc#PED-857 jsc#PED-858 jsc#PED-859 jsc#PED-868 jsc#PED-956
  jsc#PED-972 jsc#PED-975 jsc#PED-990 jsc#PEd-1211 jsc#PEd-1817 jsc#PM-1318
  jsc#PM-1333 jsc#PM-1334 jsc#PM-1588 jsc#SES-1080 jsc#SES-1134 jsc#SES-1880
  jsc#SLE-10031 jsc#SLE-10146 jsc#SLE-10158 jsc#SLE-10207 jsc#SLE-10218
  jsc#SLE-10259 jsc#SLE-10262 jsc#SLE-10289 jsc#SLE-10327 jsc#SLE-10334
  jsc#SLE-10427 jsc#SLE-10505 jsc#SLE-10562 jsc#SLE-10565 jsc#SLE-10608
  jsc#SLE-10621 jsc#SLE-10687 jsc#SLE-10690 jsc#SLE-10700 jsc#SLE-10717
  jsc#SLE-10720 jsc#SLE-10790 jsc#SLE-10886 jsc#SLE-11050 jsc#SLE-11070
  jsc#SLE-11112 jsc#SLE-11113 jsc#SLE-11117 jsc#SLE-11309 jsc#SLE-11312
  jsc#SLE-11493 jsc#SLE-11598 jsc#SLE-11796 jsc#SLE-11831 jsc#SLE-11833
  jsc#SLE-12152 jsc#SLE-12203 jsc#SLE-12226 jsc#SLE-12250 jsc#SLE-12251
  jsc#SLE-12300 jsc#SLE-12424 jsc#SLE-12599 jsc#SLE-12602 jsc#SLE-12668
  jsc#SLE-12677 jsc#SLE-12679 jsc#SLE-12680 jsc#SLE-12681 jsc#SLE-12682
  jsc#SLE-12683 jsc#SLE-12688 jsc#SLE-12692 jsc#SLE-12699 jsc#SLE-12700
  jsc#SLE-12705 jsc#SLE-12710 jsc#SLE-12717 jsc#SLE-12718 jsc#SLE-12730
  jsc#SLE-12732 jsc#SLE-12734 jsc#SLE-12735 jsc#SLE-12737 jsc#SLE-12769
  jsc#SLE-12860 jsc#SLE-12866 jsc#SLE-12877 jsc#SLE-12878 jsc#SLE-12880
  jsc#SLE-12882 jsc#SLE-12883 jsc#SLE-12921 jsc#SLE-12936 jsc#SLE-12943
  jsc#SLE-12982 jsc#SLE-12983 jsc#SLE-12984 jsc#SLE-12985 jsc#SLE-13078
  jsc#SLE-13135 jsc#SLE-13172 jsc#SLE-13202 jsc#SLE-13205 jsc#SLE-13208
  jsc#SLE-13222 jsc#SLE-13261 jsc#SLE-13285 jsc#SLE-13294 jsc#SLE-13316
  jsc#SLE-13318 jsc#SLE-13338 jsc#SLE-13340 jsc#SLE-13343 jsc#SLE-13346
  jsc#SLE-13352 jsc#SLE-13356 jsc#SLE-13358 jsc#SLE-13360 jsc#SLE-13361
  jsc#SLE-13363 jsc#SLE-13371 jsc#SLE-13380 jsc#SLE-13387 jsc#SLE-13391
  jsc#SLE-13393 jsc#SLE-13398 jsc#SLE-13409 jsc#SLE-13411 jsc#SLE-13413
  jsc#SLE-13430 jsc#SLE-13436 jsc#SLE-13441 jsc#SLE-13445 jsc#SLE-13446
  jsc#SLE-13447 jsc#SLE-13451 jsc#SLE-13489 jsc#SLE-13496 jsc#SLE-13503
  jsc#SLE-13512 jsc#SLE-13513 jsc#SLE-13521 jsc#SLE-13522 jsc#SLE-13532
  jsc#SLE-13533 jsc#SLE-13535 jsc#SLE-13536 jsc#SLE-13537 jsc#SLE-13557
  jsc#SLE-13565 jsc#SLE-13573 jsc#SLE-13593 jsc#SLE-13596 jsc#SLE-13597
  jsc#SLE-13610 jsc#SLE-13614 jsc#SLE-13615 jsc#SLE-13616 jsc#SLE-13617
  jsc#SLE-13618 jsc#SLE-13628 jsc#SLE-13629 jsc#SLE-13630 jsc#SLE-13640
  jsc#SLE-13644 jsc#SLE-13654 jsc#SLE-13661 jsc#SLE-13665 jsc#SLE-13690
  jsc#SLE-13697 jsc#SLE-13701 jsc#SLE-13702 jsc#SLE-13706 jsc#SLE-13718
  jsc#SLE-13722 jsc#SLE-13726 jsc#SLE-13727 jsc#SLE-13731 jsc#SLE-13736
  jsc#SLE-13740 jsc#SLE-13746 jsc#SLE-13750 jsc#SLE-13761 jsc#SLE-13763
  jsc#SLE-13764 jsc#SLE-13766 jsc#SLE-13767 jsc#SLE-13778 jsc#SLE-13782
  jsc#SLE-13815 jsc#SLE-13818 jsc#SLE-13821 jsc#SLE-13823 jsc#SLE-13830
  jsc#SLE-13841 jsc#SLE-13847 jsc#SLE-13848 jsc#SLE-13898 jsc#SLE-13918
  jsc#SLE-13984 jsc#SLE-14018 jsc#SLE-14042 jsc#SLE-14130 jsc#SLE-14166
  jsc#SLE-14214 jsc#SLE-14262 jsc#SLE-14337 jsc#SLE-14344 jsc#SLE-14368
  jsc#SLE-14407 jsc#SLE-14454 jsc#SLE-14457 jsc#SLE-14458 jsc#SLE-14459
  jsc#SLE-14727 jsc#SLE-14763 jsc#SLE-14766 jsc#SLE-14771 jsc#SLE-14773
  jsc#SLE-14776 jsc#SLE-14777 jsc#SLE-14811 jsc#SLE-14845 jsc#SLE-14846
  jsc#SLE-14859 jsc#SLE-14911 jsc#SLE-15020 jsc#SLE-15070 jsc#SLE-15075
  jsc#SLE-15076 jsc#SLE-15082 jsc#SLE-15083 jsc#SLE-15111 jsc#SLE-15118
  jsc#SLE-15129 jsc#SLE-15131 jsc#SLE-15135 jsc#SLE-15139 jsc#SLE-15143
  jsc#SLE-15146 jsc#SLE-15148 jsc#SLE-15150 jsc#SLE-15151 jsc#SLE-15152
  jsc#SLE-15171 jsc#SLE-15172 jsc#SLE-15175 jsc#SLE-15176 jsc#SLE-15188
  jsc#SLE-15207 jsc#SLE-15209 jsc#SLE-15232 jsc#SLE-15271 jsc#SLE-15318
  jsc#SLE-15322 jsc#SLE-15356 jsc#SLE-15368 jsc#SLE-15373 jsc#SLE-15391
  jsc#SLE-15406 jsc#SLE-15442 jsc#SLE-15449 jsc#SLE-15608 jsc#SLE-15796
  jsc#SLE-15835 jsc#SLE-15847 jsc#SLE-15848 jsc#SLE-15857 jsc#SLE-15862
  jsc#SLE-15869 jsc#SLE-15871 jsc#SLE-15887 jsc#SLE-15898 jsc#SLE-15946
  jsc#SLE-16008 jsc#SLE-16056 jsc#SLE-16098 jsc#SLE-16106 jsc#SLE-16108
  jsc#SLE-16200 jsc#SLE-16259 jsc#SLE-16304 jsc#SLE-16321 jsc#SLE-16360
  jsc#SLE-16387 jsc#SLE-16402 jsc#SLE-16407 jsc#SLE-16497 jsc#SLE-16507
  jsc#SLE-16518 jsc#SLE-16543 jsc#SLE-16556 jsc#SLE-16574 jsc#SLE-1660
  jsc#SLE-16606 jsc#SLE-16610 jsc#SLE-16612 jsc#SLE-16614 jsc#SLE-16616
  jsc#SLE-16649 jsc#SLE-16683 jsc#SLE-16742 jsc#SLE-16756 jsc#SLE-16775
  jsc#SLE-16823 jsc#SLE-16869 jsc#SLE-16874 jsc#SLE-16914 jsc#SLE-16915
  jsc#SLE-17042 jsc#SLE-17043 jsc#SLE-17068 jsc#SLE-17122 jsc#SLE-17153
  jsc#SLE-17212 jsc#SLE-17227 jsc#SLE-17267 jsc#SLE-17268 jsc#SLE-17288
  jsc#SLE-17310 jsc#SLE-17337 jsc#SLE-17360 jsc#SLE-17612 jsc#SLE-17674
  jsc#SLE-17681 jsc#SLE-17823 jsc#SLE-17855 jsc#SLE-17882 jsc#SLE-17900
  jsc#SLE-18121 jsc#SLE-18128 jsc#SLE-18130 jsc#SLE-18138 jsc#SLE-18145
  jsc#SLE-18194 jsc#SLE-18234 jsc#SLE-18274 jsc#SLE-18329 jsc#SLE-18330
  jsc#SLE-18331 jsc#SLE-18375 jsc#SLE-18377 jsc#SLE-18378 jsc#SLE-18379
  jsc#SLE-18382 jsc#SLE-18383 jsc#SLE-18384 jsc#SLE-18385 jsc#SLE-18516
  jsc#SLE-18522 jsc#SLE-18523 jsc#SLE-18634 jsc#SLE-18701 jsc#SLE-18766
  jsc#SLE-18779 jsc#SLE-18805 jsc#SLE-18823 jsc#SLE-18857 jsc#SLE-18879
  jsc#SLE-18889 jsc#SLE-18899 jsc#SLE-18901 jsc#SLE-18931 jsc#SLE-18938
  jsc#SLE-18939 jsc#SLE-18967 jsc#SLE-18968 jsc#SLE-18970 jsc#SLE-18973
  jsc#SLE-18977 jsc#SLE-18978 jsc#SLE-18989 jsc#SLE-18992 jsc#SLE-18998
  jsc#SLE-19001 jsc#SLE-19002 jsc#SLE-19003 jsc#SLE-19010 jsc#SLE-19026
  jsc#SLE-19031 jsc#SLE-19033 jsc#SLE-19035 jsc#SLE-19041 jsc#SLE-19046
  jsc#SLE-19094 jsc#SLE-19223 jsc#SLE-19242 jsc#SLE-19248 jsc#SLE-19249
  jsc#SLE-19250 jsc#SLE-19253 jsc#SLE-19255 jsc#SLE-19256 jsc#SLE-19274
  jsc#SLE-19277 jsc#SLE-19282 jsc#SLE-19284 jsc#SLE-19299 jsc#SLE-19355
  jsc#SLE-19356 jsc#SLE-19357 jsc#SLE-19358 jsc#SLE-19359 jsc#SLE-19360
  jsc#SLE-19430 jsc#SLE-19436 jsc#SLE-19438 jsc#SLE-19556 jsc#SLE-19704
  jsc#SLE-19733 jsc#SLE-19789 jsc#SLE-19855 jsc#SLE-19875 jsc#SLE-19924
  jsc#SLE-20043 jsc#SLE-20056 jsc#SLE-20148 jsc#SLE-20163 jsc#SLE-20183
  jsc#SLE-20497 jsc#SLE-20498 jsc#SLE-20721 jsc#SLE-21132 jsc#SLE-21166
  jsc#SLE-21213 jsc#SLE-21256 jsc#SLE-21315 jsc#SLE-21844 jsc#SLE-21874
  jsc#SLE-22489 jsc#SLE-22496 jsc#SLE-22573 jsc#SLE-22575 jsc#SLE-22601
  jsc#SLE-22616 jsc#SLE-22690 jsc#SLE-22724 jsc#SLE-22725 jsc#SLE-23098
  jsc#SLE-23099 jsc#SLE-23139 jsc#SLE-23643 jsc#SLE-23766 jsc#SLE-24072
  jsc#SLE-24093 jsc#SLE-24350 jsc#SLE-24549 jsc#SLE-24569 jsc#SLE-24570
  jsc#SLE-24571 jsc#SLE-24572 jsc#SLE-24578 jsc#SLE-24635 jsc#SLE-24682
  jsc#SLE-24814 jsc#SLE-3853 jsc#SLE-4117 jsc#SLE-5640 jsc#SLE-6138
  jsc#SLE-7395 jsc#SLE-7474 jsc#SLE-7506 jsc#SLE-7512 jsc#SLE-7521
  jsc#SLE-7524 jsc#SLE-7533 jsc#SLE-7542 jsc#SLE-7545 jsc#SLE-7702
  jsc#SLE-7730 jsc#SLE-7741 jsc#SLE-7772 jsc#SLE-7795 jsc#SLE-7885
  jsc#SLE-7925 jsc#SLE-7926 jsc#SLE-7930 jsc#SLE-7935 jsc#SLE-7940
  jsc#SLE-7946 jsc#SLE-7953 jsc#SLE-7966 jsc#SLE-7967 jsc#SLE-7979
  jsc#SLE-7981 jsc#SLE-8009 jsc#SLE-8010 jsc#SLE-8014 jsc#SLE-8025
  jsc#SLE-8032 jsc#SLE-8100 jsc#SLE-8133 jsc#SLE-8176 jsc#SLE-8184
  jsc#SLE-8203 jsc#SLE-8215 jsc#SLE-8281 jsc#SLE-8284 jsc#SLE-8314
  jsc#SLE-8330 jsc#SLE-8371 jsc#SLE-8372 jsc#SLE-8375 jsc#SLE-8381
  jsc#SLE-8389 jsc#SLE-8392 jsc#SLE-8401 jsc#SLE-8446 jsc#SLE-8449
  jsc#SLE-8460 jsc#SLE-8461 jsc#SLE-8464 jsc#SLE-8633 jsc#SLE-8654
  jsc#SLE-8714 jsc#SLE-8896 jsc#SLE-8898 jsc#SLE-8923 jsc#SLE-8944
  jsc#SLE-8959 jsc#SLE-9099 jsc#SLE-9120 jsc#SLE-9176 jsc#SLE-9228
  jsc#SLE-9246 jsc#SLE-9251 jsc#SLE-9255 jsc#SLE-9263 jsc#SLE-9308
  jsc#SLE-9316 jsc#SLE-9326 jsc#SLE-9388 jsc#SLE-9391 jsc#SLE-9416
  jsc#SLE-9418 jsc#SLE-9457 jsc#SLE-9482 jsc#SLE-9527 jsc#SLE-95282
  jsc#SLE-9582 jsc#SLE-9619 jsc#SLE-9687 jsc#SLE-9696 jsc#SLE-9711
  jsc#SLE-9714 jsc#SLE-9858 jsc#SLE-9870 jsc#SLE-9943 jsc#SLE-9968
  jsc#SLE-9971 jsc#SLE10540 jsc#SLE14454 jsc#SLE19356 jsc#SLE19359
  jsc#sle-12891 jsc#sle-15113 jsc#sle-15116 jsc#sle-15119 jsc#sle-19733
  FATE#300516 FATE#314508 FATE#316531 FATE#322021 FATE#322022 FATE#322447
  FATE#323247 FATE#323286 FATE#323394 FATE#323406 FATE#323821 FATE#324143
  FATE#324503 FATE#324825 FATE#324970 FATE#325281 FATE#325281 FATE#325312
  FATE#325581 FATE#325617 FATE#326394 FATE#326579 FATE#326628 FATE#327775
  fate#315712 fate#316350 fate#316531 fate#317919 fate#318836 fate#322438
  fate#322786 fate#323189 fate#323487 fate#323682 fate#323887 fate#325592
  fate#326572 fate#326668
  ltc#153436 ltc#155067 ltc#155231 ltc#155423 ltc#155681 ltc#159753
  ltc#160943 ltc#163882 ltc#164363 ltc#164631 ltc#165122 ltc#165544
  ltC#165630 ltc#166495 ltc#167098 ltc#168122 ltc#169177 ltc#169948
  ltc#171067 ltc#171853 ltc#173734 ltc#174432 ltc#174633 ltc#175530
  ltc#176086 ltc#176097 ltc#177197 ltc#177449 LTC#178106 ltc#178199
  ltc#178840 LTC#178844 LTC#178852 LTC#178859 ltc#178925 LTC#178954
  LTC#178970 LTC#179078 LTC#179220 ltc#179509 ltc#179635 ltc#179958
  ltc#181028 ltc#181472 LTC#181532 ltc#181664 ltc#181740 ltc#181778
  ltc#181798 ltc#182047 LTC#182406 LTC#182407 ltc#182435 ltc#182459
  ltc#182520 ltc#182579 ltc#182612 LTC#182629 ltc#182902 ltc#182983
  ltc#182993 ltc#183000 ltc#183002 ltc#183046 LTC#183076 LTC#183077
  ltc#183498 ltc#183501 ltc#183538 ltc#183551 ltc#183834 ltc#183850
  ltc#183929 ltc#183935 LTC#183960 ltc#184087 ltc#184091 LTC#184104
  LTC#184105 ltc#184149 ltc#184171 ltc#184239 ltc#184375 LTC#184504
  LTC#184507 ltc#184611 ltc#184616 ltc#184617 ltc#184630 LTC#184760
  ltc#184814 ltc#185010 LTC#185029 LTC#185092 ltc#185128 LTC#185152
  LTC#185290 ltc#185369 ltc#185686 ltc#185738 LTC#185786 LTC#185911
  LTC#186069 ltc#186099 ltc#186162 ltc#186249 ltc#186322 LTC#186340
  LTC#186349 ltc#186394 ltc#186397 ltc#186474 LTC#186574 ltc#186863
  ltc#187090 ltc#187208 ltc#187293 ltc#187459 ltc#187461 ltc#187506
  ltc#187574 ltc#187588 LTC#187760 ltc#187922 LTC#187935 ltc#187962
  ltc#187964 ltc#188074 ltc#188130 ltc#188140 ltc#188226 LTC#188235
  ltc#188243 ltc#188252 ltc#188304 LTC#188341 LTC#188342 ltc#188522
  ltc#188629 LTC#188733 LTC#188735 ltc#188897 ltc#189002 ltc#189159
  ltc#189290 ltc#189313 ltc#189835 ltc#189960 LTC#189977 ltc#190030
  ltc#190038 ltc#190092 LTC#190110 LTC#190111 LTC#190112 LTC#190151
  LTC#190152 LTC#190155 ltc#190174 ltc#190253 ltc#190255 ltc#190257
  ltc#190285 ltc#190309 LTC#190383 ltc#190572 ltc#190579 ltc#190612
  ltc#190624 ltc#190702 ltc#190851 ltc#190855 LTC#190858 LTC#190860
  ltc#190900 ltc#190909 LTC#190914 ltc#190917 ltc#190924 ltc#190997
  ltc#191041 ltc#191079 ltc#191080 ltc#191222 ltc#191231 ltc#191273
  ltc#191345 LTC#191375 ltc#191460 ltc#191464 ltc#191533 ltc#191591
  ltc#191637 ltc#191791 ltc#191844 ltc#191922 ltc#191943 ltc#191963
  ltc#192043 ltc#192075 ltc#192091 ltc#192129 ltc#192139 LTC#192153
  ltc#192221 ltc#192232 ltc#192237 ltc#192244 ltc#192356 LTC#192526
  ltc#192531 ltc#192576 ltc#192610 ltc#192641 LTC#192679 LTC#193282
  ltc#193451 ltc#193509 ltc#193581 ltc#193646 ltc#193722 ltc#193771
  LTC#193817 ltc#193865 ltc#193906 ltc#193985 ltc#194498 ltc#194510
  ltc#194520 ltc#194523 ltc#194629 ltc#194757 LTC#194817 ltc#194976
  LTC#195546 ltc#195566 ltc#195568 ltc#195599 ltc#195600 ltc#195634
  ltc#195651 ltc#195662 ltc#195713 ltc#195733 ltc#195810 ltc#195811
  ltc#195815 LTC#196029 LTC#196087 ltc#196102 ltc#196198 LTC#196353
  ltc#196362 ltc#196391 ltc#196394 LTC#196420 ltc#197256 ltc#197259
  ltc#197388 ltc#197803 ltc#197920 LTC#198456 LTC#198457 LTC#198473
  ltc#198477 LTC#198619 LTC#198623 ltc#198761 ltc#199236 LTC#199322
  LTC#199895 ltc#199904 LTC#199905 ltc#200074 ltc#200103 ltc#200162
  ltc#200176 ltc#200177 ltc#200179 ltc#200180 LTC#200451 LTC#200501
  LTC#200502 ltc#200603 ltc#201076 ltc#201108 ltc#201363 ltc#201367
  ltc#201368 ltc#201370 ltc#201535 ltc#201612 ltc#201720 ltc#202140
  ltc#202189 ltc#202604 ltc#202861 ltc#1195655
  XSA-331 XSA-332 XSA-349 XSA-350 XSA-361 XSA-362 XSA-365 XSA-367 XSA-371
  XSA-391 XSA-392 XSA-396 XSA-403 XSA-405 XSA-423 XSA-424 XSA-432
